@@ -3,10 +3,15 @@ import sys
 from typing import Any, Dict, List, Tuple, Union
 from urllib.parse import unquote
 
+from moto.core.responses import TYPE_RESPONSE, BaseResponse
 from moto.core.utils import path_url
 from moto.utilities.aws_headers import amz_crc32, amzn_request_id
-from moto.core.responses import BaseResponse, TYPE_RESPONSE
-from .models import lambda_backends, LambdaBackend
+
+from .exceptions import (
+    FunctionAlreadyExists,
+    UnknownFunctionException,
+)
+from .models import LambdaBackend, lambda_backends
 
 
 class LambdaResponse(BaseResponse):
@@ -46,8 +51,13 @@ class LambdaResponse(BaseResponse):
 
     def aliases(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
+
         if request.method == "POST":
             return self._create_alias()
+        elif request.method == "GET":
+            path = request.path if hasattr(request, "path") else path_url(request.url)
+            function_name = path.split("/")[-2]
+            return self._list_aliases(function_name)
 
     def alias(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
@@ -80,10 +90,12 @@ class LambdaResponse(BaseResponse):
 
     def layers_version(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
+        layer_name = unquote(self.path.split("/")[-3])
+        layer_version = self.path.split("/")[-1]
         if request.method == "DELETE":
-            return self._delete_layer_version()
+            return self._delete_layer_version(layer_name, layer_version)
         elif request.method == "GET":
-            return self._get_layer_version()
+            return self._get_layer_version(layer_name, layer_version)
 
     def layers_versions(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
@@ -117,7 +129,9 @@ class LambdaResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def invoke(self, request: Any, full_url: str, headers: Any) -> Tuple[int, Dict[str, str], Union[str, bytes]]:  # type: ignore[misc]
+    def invoke(  # type: ignore
+        self, request=None, full_url="", headers=None
+    ) -> Tuple[int, Dict[str, str], Union[str, bytes]]:
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self._invoke(request)
@@ -126,7 +140,9 @@ class LambdaResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def invoke_async(self, request: Any, full_url: str, headers: Any) -> Tuple[int, Dict[str, str], Union[str, bytes]]:  # type: ignore[misc]
+    def invoke_async(
+        self, request: Any, full_url: str, headers: Any
+    ) -> Tuple[int, Dict[str, str], Union[str, bytes]]:
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self._invoke_async()
@@ -142,7 +158,7 @@ class LambdaResponse(BaseResponse):
         elif request.method == "DELETE":
             return self._untag_resource()
         else:
-            raise ValueError("Cannot handle {0} request".format(request.method))
+            raise ValueError(f"Cannot handle {request.method} request")
 
     def policy(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:
         self.setup_class(request, full_url, headers)
@@ -153,7 +169,7 @@ class LambdaResponse(BaseResponse):
         elif request.method == "DELETE":
             return self._del_policy(request, self.querystring)
         else:
-            raise ValueError("Cannot handle {0} request".format(request.method))
+            raise ValueError(f"Cannot handle {request.method} request")
 
     def configuration(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:
         self.setup_class(request, full_url, headers)
@@ -215,7 +231,8 @@ class LambdaResponse(BaseResponse):
     def _get_policy(self, request: Any) -> TYPE_RESPONSE:
         path = request.path if hasattr(request, "path") else path_url(request.url)
         function_name = unquote(path.split("/")[-2])
-        out = self.backend.get_policy(function_name)
+        qualifier = self.querystring.get("Qualifier", [None])[0]
+        out = self.backend.get_policy(function_name, qualifier)
         return 200, {}, out
 
     def _del_policy(self, request: Any, querystring: Dict[str, Any]) -> TYPE_RESPONSE:
@@ -256,7 +273,10 @@ class LambdaResponse(BaseResponse):
             elif request.headers.get("X-Amz-Invocation-Type") == "DryRun":
                 status_code = 204
             else:
-                if request.headers.get("X-Amz-Log-Type") != "Tail":
+                if (
+                    request.headers.get("X-Amz-Log-Type") != "Tail"
+                    and "x-amz-log-result" in response_headers
+                ):
                     del response_headers["x-amz-log-result"]
                 status_code = 200
             return status_code, response_headers, payload
@@ -294,10 +314,25 @@ class LambdaResponse(BaseResponse):
 
         return 200, {}, json.dumps(result)
 
+    def _list_aliases(self, function_name: str) -> TYPE_RESPONSE:
+        result: Dict[str, Any] = {"Aliases": []}
+
+        aliases = self.backend.list_aliases(function_name)
+        for alias in aliases:
+            json_data = alias.to_json()
+            result["Aliases"].append(json_data)
+
+        return 200, {}, json.dumps(result)
+
     def _create_function(self) -> TYPE_RESPONSE:
-        fn = self.backend.create_function(self.json_body)
-        config = fn.get_configuration(on_create=True)
-        return 201, {}, json.dumps(config)
+        function_name = self.json_body["FunctionName"].rsplit(":", 1)[-1]
+        try:
+            self.backend.get_function(function_name, None)
+        except UnknownFunctionException:
+            fn = self.backend.create_function(self.json_body)
+            config = fn.get_configuration(on_create=True)
+            return 201, {}, json.dumps(config)
+        raise FunctionAlreadyExists(function_name)
 
     def _create_function_url_config(self) -> TYPE_RESPONSE:
         function_name = unquote(self.path.split("/")[-2])
@@ -370,7 +405,17 @@ class LambdaResponse(BaseResponse):
         return 204, {}, ""
 
     @staticmethod
-    def _set_configuration_qualifier(configuration: Dict[str, Any], qualifier: str) -> Dict[str, Any]:  # type: ignore[misc]
+    def _set_configuration_qualifier(configuration: Dict[str, Any], function_name: str, qualifier: str) -> Dict[str, Any]:  # type: ignore[misc]
+        # Qualifier may be explicitly passed or part of function name or ARN, extract it here
+        if function_name.startswith("arn:aws"):
+            # Extract from ARN
+            if ":" in function_name.split(":function:")[-1]:
+                qualifier = function_name.split(":")[-1]
+        else:
+            # Extract from function name
+            if ":" in function_name:
+                qualifier = function_name.split(":")[1]
+
         if qualifier is None or qualifier == "$LATEST":
             configuration["Version"] = "$LATEST"
         if qualifier == "$LATEST":
@@ -385,7 +430,7 @@ class LambdaResponse(BaseResponse):
 
         code = fn.get_code()
         code["Configuration"] = self._set_configuration_qualifier(
-            code["Configuration"], qualifier
+            code["Configuration"], function_name, qualifier
         )
         return 200, {}, json.dumps(code)
 
@@ -396,7 +441,7 @@ class LambdaResponse(BaseResponse):
         fn = self.backend.get_function(function_name, qualifier)
 
         configuration = self._set_configuration_qualifier(
-            fn.get_configuration(), qualifier
+            fn.get_configuration(), function_name, qualifier
         )
         return 200, {}, json.dumps(configuration)
 
@@ -492,17 +537,13 @@ class LambdaResponse(BaseResponse):
         layers = self.backend.list_layers()
         return 200, {}, json.dumps({"Layers": layers})
 
-    def _delete_layer_version(self) -> TYPE_RESPONSE:
-        layer_name = self.path.split("/")[-3]
-        layer_version = self.path.split("/")[-1]
-
+    def _delete_layer_version(
+        self, layer_name: str, layer_version: str
+    ) -> TYPE_RESPONSE:
         self.backend.delete_layer_version(layer_name, layer_version)
         return 200, {}, "{}"
 
-    def _get_layer_version(self) -> TYPE_RESPONSE:
-        layer_name = self.path.split("/")[-3]
-        layer_version = self.path.split("/")[-1]
-
+    def _get_layer_version(self, layer_name: str, layer_version: str) -> TYPE_RESPONSE:
         layer = self.backend.get_layer_version(layer_name, layer_version)
         return 200, {}, json.dumps(layer.get_layer_version())
 
@@ -568,3 +609,39 @@ class LambdaResponse(BaseResponse):
             routing_config=routing_config,
         )
         return 201, {}, json.dumps(alias.to_json())
+
+    def event_invoke_config_handler(
+        self, request: Any, full_url: str, headers: Any
+    ) -> TYPE_RESPONSE:
+        self.setup_class(request, full_url, headers)
+        function_name = unquote(self.path.rsplit("/", 2)[1])
+
+        if self.method == "PUT":
+            response = self.backend.put_function_event_invoke_config(
+                function_name, self.json_body
+            )
+            return 200, {}, json.dumps(response)
+        elif self.method == "GET":
+            response = self.backend.get_function_event_invoke_config(function_name)
+            return 200, {}, json.dumps(response)
+        elif self.method == "DELETE":
+            self.backend.delete_function_event_invoke_config(function_name)
+            return 204, {}, json.dumps({})
+        elif self.method == "POST":
+            response = self.backend.update_function_event_invoke_config(
+                function_name, self.json_body
+            )
+            return 200, {}, json.dumps(response)
+        else:
+            raise NotImplementedError
+
+    def event_invoke_config_list(
+        self, request: Any, full_url: str, headers: Any
+    ) -> TYPE_RESPONSE:
+        self.setup_class(request, full_url, headers)
+        function_name = unquote(self.path.rsplit("/", 3)[1])
+        return (
+            200,
+            {},
+            json.dumps(self.backend.list_function_event_invoke_configs(function_name)),
+        )
