@@ -1,37 +1,43 @@
 import datetime
+import enum
 import json
 import os
+import re
 import time
 import typing
-import enum
-from jose import jws
 from collections import OrderedDict
-from typing import Any, Dict, List, Tuple, Optional, Set
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import BackendDict
+from typing import Any, Dict, List, Optional, Set, Tuple
+
+from jose import jws
+
+from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.utils import utcnow
 from moto.moto_api._internal import mock_random as random
-from .exceptions import (
-    GroupExistsException,
-    NotAuthorizedError,
-    ResourceNotFoundError,
-    UserNotFoundError,
-    UsernameExistsException,
-    UserNotConfirmedException,
-    InvalidParameterException,
-    ExpiredCodeException,
-)
-from .utils import (
-    create_id,
-    check_secret_hash,
-    generate_id,
-    validate_username_format,
-    flatten_attrs,
-    expand_attrs,
-    PAGINATION_MODEL,
-)
 from moto.utilities.paginator import paginate
 from moto.utilities.utils import md5_hash
+
 from ..settings import get_cognito_idp_user_pool_id_strategy
+from .exceptions import (
+    AliasExistsException,
+    ExpiredCodeException,
+    GroupExistsException,
+    InvalidParameterException,
+    InvalidPasswordException,
+    NotAuthorizedError,
+    ResourceNotFoundError,
+    UsernameExistsException,
+    UserNotConfirmedException,
+    UserNotFoundError,
+)
+from .utils import (
+    PAGINATION_MODEL,
+    check_secret_hash,
+    create_id,
+    expand_attrs,
+    flatten_attrs,
+    generate_id,
+    validate_username_format,
+)
 
 
 class UserStatus(str, enum.Enum):
@@ -368,12 +374,18 @@ DEFAULT_USER_POOL_CONFIG: Dict[str, Any] = {
         "EmailSubject": "Your verification code",
         "DefaultEmailOption": "CONFIRM_WITH_CODE",
     },
+    "AccountRecoverySetting": {
+        "RecoveryMechanisms": [
+            {"Priority": 1, "Name": "verified_email"},
+            {"Priority": 2, "Name": "verified_phone_number"},
+        ]
+    },
 }
 
 
 class CognitoIdpUserPool(BaseModel):
 
-    MAX_ID_LENGTH = 56
+    MAX_ID_LENGTH = 55
 
     def __init__(
         self, account_id: str, region: str, name: str, extended_config: Dict[str, Any]
@@ -384,31 +396,16 @@ class CognitoIdpUserPool(BaseModel):
         user_pool_id = generate_id(
             get_cognito_idp_user_pool_id_strategy(), region, name, extended_config
         )
-        self.id = "{}_{}".format(self.region, user_pool_id)[: self.MAX_ID_LENGTH]
+        self.id = f"{self.region}_{user_pool_id}"[: self.MAX_ID_LENGTH]
         self.arn = f"arn:aws:cognito-idp:{self.region}:{account_id}:userpool/{self.id}"
 
         self.name = name
         self.status = None
 
-        self.extended_config = DEFAULT_USER_POOL_CONFIG.copy()
-        self.extended_config.update(extended_config or {})
+        self.update_extended_config(extended_config)
 
-        message_template = self.extended_config.get("VerificationMessageTemplate")
-        if message_template and "SmsVerificationMessage" not in extended_config:
-            self.extended_config["SmsVerificationMessage"] = message_template.get(
-                "SmsMessage"
-            )
-        if message_template and "EmailVerificationSubject" not in extended_config:
-            self.extended_config["EmailVerificationSubject"] = message_template.get(
-                "EmailSubject"
-            )
-        if message_template and "EmailVerificationMessage" not in extended_config:
-            self.extended_config["EmailVerificationMessage"] = message_template.get(
-                "EmailMessage"
-            )
-
-        self.creation_date = datetime.datetime.utcnow()
-        self.last_modified_date = datetime.datetime.utcnow()
+        self.creation_date = utcnow()
+        self.last_modified_date = utcnow()
 
         self.mfa_config = "OFF"
         self.sms_mfa_config: Optional[Dict[str, Any]] = None
@@ -463,18 +460,23 @@ class CognitoIdpUserPool(BaseModel):
             None,
         )
 
-    def _account_recovery_setting(self) -> Any:
-        # AccountRecoverySetting is not present in DescribeUserPool response if the pool was created without
-        # specifying it, ForgotPassword works on default settings nonetheless
-        return self.extended_config.get(
-            "AccountRecoverySetting",
-            {
-                "RecoveryMechanisms": [
-                    {"Priority": 1, "Name": "verified_phone_number"},
-                    {"Priority": 2, "Name": "verified_email"},
-                ]
-            },
-        )
+    def update_extended_config(self, extended_config: Dict[str, Any]) -> None:
+        self.extended_config = DEFAULT_USER_POOL_CONFIG.copy()
+        self.extended_config.update(extended_config or {})
+
+        message_template = self.extended_config.get("VerificationMessageTemplate")
+        if message_template and "SmsVerificationMessage" not in extended_config:
+            self.extended_config["SmsVerificationMessage"] = message_template.get(
+                "SmsMessage"
+            )
+        if message_template and "EmailVerificationSubject" not in extended_config:
+            self.extended_config["EmailVerificationSubject"] = message_template.get(
+                "EmailSubject"
+            )
+        if message_template and "EmailVerificationMessage" not in extended_config:
+            self.extended_config["EmailVerificationMessage"] = message_template.get(
+                "EmailMessage"
+            )
 
     def _base_json(self) -> Dict[str, Any]:
         return {
@@ -531,15 +533,13 @@ class CognitoIdpUserPool(BaseModel):
     ) -> Tuple[str, int]:
         now = int(time.time())
         payload = {
-            "iss": "https://cognito-idp.{}.amazonaws.com/{}".format(
-                self.region, self.id
-            ),
+            "iss": f"https://cognito-idp.{self.region}.amazonaws.com/{self.id}",
             "sub": self._get_user(username).id,
-            "aud": client_id,
+            "client_id" if token_use == "access" else "aud": client_id,
             "token_use": token_use,
             "auth_time": now,
             "exp": now + expires_in,
-            "email": flatten_attrs(self._get_user(username).attributes).get("email"),
+            "username" if token_use == "access" else "cognito:username": username,
         }
         payload.update(extra_data or {})
         headers = {"kid": "dummy"}  # KID as present in jwks-public.json
@@ -567,6 +567,12 @@ class CognitoIdpUserPool(BaseModel):
 
     def create_id_token(self, client_id: str, username: str) -> Tuple[str, int]:
         extra_data = self.get_user_extra_data_by_client_id(client_id, username)
+        user = self._get_user(username)
+        for attr in user.attributes:
+            if attr["Name"].startswith("custom:"):
+                extra_data[attr["Name"]] = attr["Value"]
+        if len(user.groups) > 0:
+            extra_data["cognito:groups"] = [group.group_name for group in user.groups]
         id_token, expires_in = self.create_jwt(
             client_id, username, "id", extra_data=extra_data
         )
@@ -628,6 +634,10 @@ class CognitoIdpUserPool(BaseModel):
             _, logged_in_user = token_tuple
             if username == logged_in_user:
                 self.refresh_tokens[token] = None
+        for access_token, token_tuple in list(self.access_tokens.items()):
+            _, logged_in_user = token_tuple
+            if username == logged_in_user:
+                self.access_tokens.pop(access_token)
 
 
 class CognitoIdpUserPoolDomain(BaseModel):
@@ -677,7 +687,15 @@ class CognitoIdpUserPoolClient(BaseModel):
         self.id = create_id()
         self.secret = str(random.uuid4())
         self.generate_secret = generate_secret or False
-        self.extended_config = extended_config or {}
+        # Some default values - may be overridden by the user
+        self.extended_config: Dict[str, Any] = {
+            "AllowedOAuthFlowsUserPoolClient": False,
+            "AuthSessionValidity": 3,
+            "EnablePropagateAdditionalUserContextData": False,
+            "EnableTokenRevocation": True,
+            "RefreshTokenValidity": 30,
+        }
+        self.extended_config.update(extended_config or {})
 
     def _base_json(self) -> Dict[str, Any]:
         return {
@@ -703,8 +721,8 @@ class CognitoIdpIdentityProvider(BaseModel):
     def __init__(self, name: str, extended_config: Optional[Dict[str, Any]]):
         self.name = name
         self.extended_config = extended_config or {}
-        self.creation_date = datetime.datetime.utcnow()
-        self.last_modified_date = datetime.datetime.utcnow()
+        self.creation_date = utcnow()
+        self.last_modified_date = utcnow()
 
         if "AttributeMapping" not in self.extended_config:
             self.extended_config["AttributeMapping"] = {"username": "sub"}
@@ -791,8 +809,8 @@ class CognitoIdpUser(BaseModel):
         self.enabled = True
         self.attributes = attributes
         self.attribute_lookup = flatten_attrs(attributes)
-        self.create_date = datetime.datetime.utcnow()
-        self.last_modified_date = datetime.datetime.utcnow()
+        self.create_date = utcnow()
+        self.last_modified_date = utcnow()
         self.sms_mfa_enabled = False
         self.software_token_mfa_enabled = False
         self.token_verified = False
@@ -824,7 +842,7 @@ class CognitoIdpUser(BaseModel):
         user_mfa_setting_list = []
         if self.software_token_mfa_enabled:
             user_mfa_setting_list.append("SOFTWARE_TOKEN_MFA")
-        elif self.sms_mfa_enabled:
+        if self.sms_mfa_enabled:
             user_mfa_setting_list.append("SMS_MFA")
         user_json = self._base_json()
         if extended:
@@ -894,7 +912,7 @@ class CognitoResourceServer(BaseModel):
             "Name": self.name,
         }
 
-        if len(self.scopes) != 0:
+        if self.scopes:
             res.update({"Scopes": self.scopes})
 
         return res
@@ -902,6 +920,13 @@ class CognitoResourceServer(BaseModel):
 
 class CognitoIdpBackend(BaseBackend):
     """
+    Moto mocks the JWK uris.
+    If you're using decorators, you can retrieve this information by making a call to `https://cognito-idp.us-west-2.amazonaws.com/someuserpoolid/.well-known/jwks.json`.
+
+    Call `http://localhost:5000/userpoolid/.well-known/jwks.json` instead of you're running Moto in ServerMode or Docker.
+    Because Moto cannot determine this is a CognitoIDP-request based on the URL alone, you have to add an Authorization-header instead:
+    `Authorization: AWS4-HMAC-SHA256 Credential=mock_access_key/20220524/us-east-1/cognito-idp/aws4_request, SignedHeaders=content-length;content-type;host;x-amz-date, Signature=asdf`
+
     In some cases, you need to have reproducible IDs for the user pool.
     For example, a single initialization before the start of integration tests.
 
@@ -947,8 +972,8 @@ class CognitoIdpBackend(BaseBackend):
             "MfaConfiguration": user_pool.mfa_config,
         }
 
-    @paginate(pagination_model=PAGINATION_MODEL)
-    def list_user_pools(self) -> List[CognitoIdpUserPool]:  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    def list_user_pools(self) -> List[CognitoIdpUserPool]:
         return list(self.user_pools.values())
 
     def describe_user_pool(self, user_pool_id: str) -> CognitoIdpUserPool:
@@ -962,7 +987,7 @@ class CognitoIdpBackend(BaseBackend):
         self, user_pool_id: str, extended_config: Dict[str, Any]
     ) -> None:
         user_pool = self.describe_user_pool(user_pool_id)
-        user_pool.extended_config = extended_config
+        user_pool.update_extended_config(extended_config)
 
     def delete_user_pool(self, user_pool_id: str) -> None:
         self.describe_user_pool(user_pool_id)
@@ -1020,8 +1045,10 @@ class CognitoIdpBackend(BaseBackend):
         user_pool.clients[user_pool_client.id] = user_pool_client
         return user_pool_client
 
-    @paginate(pagination_model=PAGINATION_MODEL)
-    def list_user_pool_clients(self, user_pool_id: str) -> List[CognitoIdpUserPoolClient]:  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    def list_user_pool_clients(
+        self, user_pool_id: str
+    ) -> List[CognitoIdpUserPoolClient]:
         user_pool = self.describe_user_pool(user_pool_id)
 
         return list(user_pool.clients.values())
@@ -1067,8 +1094,10 @@ class CognitoIdpBackend(BaseBackend):
         user_pool.identity_providers[name] = identity_provider
         return identity_provider
 
-    @paginate(pagination_model=PAGINATION_MODEL)
-    def list_identity_providers(self, user_pool_id: str) -> List[CognitoIdpIdentityProvider]:  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    def list_identity_providers(
+        self, user_pool_id: str
+    ) -> List[CognitoIdpIdentityProvider]:
         user_pool = self.describe_user_pool(user_pool_id)
 
         return list(user_pool.identity_providers.values())
@@ -1133,8 +1162,8 @@ class CognitoIdpBackend(BaseBackend):
 
         return user_pool.groups[group_name]
 
-    @paginate(pagination_model=PAGINATION_MODEL)
-    def list_groups(self, user_pool_id: str) -> List[CognitoIdpGroup]:  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    def list_groups(self, user_pool_id: str) -> List[CognitoIdpGroup]:
         user_pool = self.describe_user_pool(user_pool_id)
 
         return list(user_pool.groups.values())
@@ -1174,8 +1203,10 @@ class CognitoIdpBackend(BaseBackend):
         group.users.add(user)
         user.groups.add(group)
 
-    @paginate(pagination_model=PAGINATION_MODEL)
-    def list_users_in_group(self, user_pool_id: str, group_name: str) -> List[CognitoIdpUser]:  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    def list_users_in_group(
+        self, user_pool_id: str, group_name: str
+    ) -> List[CognitoIdpUser]:
         user_pool = self.describe_user_pool(user_pool_id)
         group = self.get_group(user_pool_id, group_name)
         return list(filter(lambda user: user in group.users, user_pool.users.values()))
@@ -1310,8 +1341,8 @@ class CognitoIdpBackend(BaseBackend):
                 return user
         raise NotAuthorizedError("Invalid token")
 
-    @paginate(pagination_model=PAGINATION_MODEL)
-    def list_users(self, user_pool_id: str) -> List[CognitoIdpUser]:  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    def list_users(self, user_pool_id: str) -> List[CognitoIdpUser]:
         user_pool = self.describe_user_pool(user_pool_id)
 
         return list(user_pool.users.values())
@@ -1402,6 +1433,9 @@ class CognitoIdpBackend(BaseBackend):
             password: str = auth_parameters.get("PASSWORD")  # type: ignore[assignment]
             user = self.admin_get_user(user_pool_id, username)
 
+            if not user.enabled:
+                raise NotAuthorizedError("User is disabled.")
+
             if user.password != password:
                 raise NotAuthorizedError(username)
 
@@ -1418,8 +1452,21 @@ class CognitoIdpBackend(BaseBackend):
                     "Session": session,
                 }
 
+            if (
+                user.software_token_mfa_enabled
+                and user.preferred_mfa_setting == "SOFTWARE_TOKEN_MFA"
+            ):
+                session = str(random.uuid4())
+                self.sessions[session] = user_pool
+
+                return {
+                    "ChallengeName": "SOFTWARE_TOKEN_MFA",
+                    "ChallengeParameters": {},
+                    "Session": session,
+                }
+
             return self._log_user_in(user_pool, client, username)
-        elif auth_flow is AuthFlow.REFRESH_TOKEN:
+        elif auth_flow in (AuthFlow.REFRESH_TOKEN, AuthFlow.REFRESH_TOKEN_AUTH):
             refresh_token: str = auth_parameters.get("REFRESH_TOKEN")  # type: ignore[assignment]
             (
                 access_token,
@@ -1439,6 +1486,23 @@ class CognitoIdpBackend(BaseBackend):
             # We shouldn't get here due to enum validation of auth_flow
             return None  # type: ignore[return-value]
 
+    def admin_respond_to_auth_challenge(
+        self,
+        session: str,
+        client_id: str,
+        challenge_name: str,
+        challenge_responses: Dict[str, str],
+    ) -> Dict[str, Any]:
+        # Responds to an authentication challenge, as an administrator.
+        # The only differences between this admin endpoint and public endpoint are not relevant and so we can safely call
+        # the public endpoint to do the work:
+        #  - The admin endpoint requires a user pool id along with a session; the public endpoint searches across all pools
+        #  - ContextData is passed in; we don't use it
+
+        return self.respond_to_auth_challenge(
+            session, client_id, challenge_name, challenge_responses
+        )
+
     def respond_to_auth_challenge(
         self,
         session: str,
@@ -1460,6 +1524,9 @@ class CognitoIdpBackend(BaseBackend):
         if challenge_name == "NEW_PASSWORD_REQUIRED":
             username: str = challenge_responses.get("USERNAME")  # type: ignore[assignment]
             new_password = challenge_responses.get("NEW_PASSWORD")
+            if not new_password:
+                raise InvalidPasswordException()
+            self._validate_password(user_pool.id, new_password)
             user = self.admin_get_user(user_pool.id, username)
 
             user.password = new_password
@@ -1499,6 +1566,15 @@ class CognitoIdpBackend(BaseBackend):
                     "ChallengeParameters": {},
                 }
 
+            if user.status == UserStatus.FORCE_CHANGE_PASSWORD:
+                return {
+                    "ChallengeName": "NEW_PASSWORD_REQUIRED",
+                    "ChallengeParameters": {
+                        "USERNAME": username,
+                    },
+                    "Session": session,
+                }
+
             del self.sessions[session]
             return self._log_user_in(user_pool, client, username)
         elif challenge_name == "SOFTWARE_TOKEN_MFA":
@@ -1555,7 +1631,7 @@ class CognitoIdpBackend(BaseBackend):
         """
         for user_pool in self.user_pools.values():
             if client_id in user_pool.clients:
-                recovery_settings = user_pool._account_recovery_setting()
+                recovery_settings = user_pool.extended_config["AccountRecoverySetting"]
                 user = user_pool._get_user(username)
                 break
         else:
@@ -1600,6 +1676,10 @@ class CognitoIdpBackend(BaseBackend):
     ) -> None:
         for user_pool in self.user_pools.values():
             if access_token in user_pool.access_tokens:
+                self._validate_password(
+                    user_pool_id=user_pool.id, password=proposed_password
+                )
+
                 _, username = user_pool.access_tokens[access_token]
                 user = self.admin_get_user(user_pool.id, username)
 
@@ -1622,6 +1702,9 @@ class CognitoIdpBackend(BaseBackend):
     ) -> None:
         user = self.admin_get_user(user_pool_id, username)
 
+        email = self._find_attr("email", attributes)
+        self._verify_email_is_not_used(user_pool_id, email)
+
         user.update_attributes(attributes)
 
     def admin_delete_user_attributes(
@@ -1655,13 +1738,32 @@ class CognitoIdpBackend(BaseBackend):
 
         if identifier in user_pool.resource_servers:
             raise InvalidParameterException(
-                "%s already exists in user pool %s." % (identifier, user_pool_id)
+                f"{identifier} already exists in user pool {user_pool_id}."
             )
 
         resource_server = CognitoResourceServer(user_pool_id, identifier, name, scopes)
         user_pool.resource_servers[identifier] = resource_server
         return resource_server
 
+    def describe_resource_server(
+        self, user_pool_id: str, identifier: str
+    ) -> CognitoResourceServer:
+        user_pool = self.user_pools.get(user_pool_id)
+        if not user_pool:
+            raise ResourceNotFoundError(f"User pool {user_pool_id} does not exist.")
+
+        resource_server = user_pool.resource_servers.get(identifier)
+        if not resource_server:
+            raise ResourceNotFoundError(f"Resource server {identifier} does not exist.")
+
+        return resource_server
+
+    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    def list_resource_servers(self, user_pool_id: str) -> List[CognitoResourceServer]:
+        user_pool = self.user_pools[user_pool_id]
+        resource_servers = list(user_pool.resource_servers.values())
+        return resource_servers
+
     def sign_up(
         self,
         client_id: str,
@@ -1718,6 +1820,8 @@ class CognitoIdpBackend(BaseBackend):
                     "Username should be either an email or a phone number."
                 )
 
+        self._validate_password(user_pool.id, password)
+
         user = CognitoIdpUser(
             user_pool_id=user_pool.id,
             # set username to None so that it will be default to the internal GUID
@@ -1775,11 +1879,14 @@ class CognitoIdpBackend(BaseBackend):
             if client.generate_secret:
                 secret_hash: str = auth_parameters.get("SECRET_HASH")  # type: ignore[assignment]
                 if not check_secret_hash(
-                    client.secret, client.id, username, secret_hash  # type: ignore[arg-type]
+                    client.secret, client.id, username, secret_hash
                 ):
-                    raise NotAuthorizedError(secret_hash)  # type: ignore[arg-type]
+                    raise NotAuthorizedError(secret_hash)
 
-            user = self.admin_get_user(user_pool.id, username)  # type: ignore[arg-type]
+            user = self.admin_get_user(user_pool.id, username)
+
+            if not user.enabled:
+                raise NotAuthorizedError("User is disabled.")
 
             if user.status is UserStatus.UNCONFIRMED:
                 raise UserNotConfirmedException("User is not confirmed.")
@@ -1807,6 +1914,9 @@ class CognitoIdpBackend(BaseBackend):
             if not user:
                 raise UserNotFoundError(username)
 
+            if not user.enabled:
+                raise NotAuthorizedError("User is disabled.")
+
             if user.password != password:
                 raise NotAuthorizedError("Incorrect username or password.")
 
@@ -1910,26 +2020,13 @@ class CognitoIdpBackend(BaseBackend):
         for user_pool in self.user_pools.values():
             if access_token in user_pool.access_tokens:
                 _, username = user_pool.access_tokens[access_token]
-                user = self.admin_get_user(user_pool.id, username)
 
-                if software_token_mfa_settings and software_token_mfa_settings.get(
-                    "Enabled"
-                ):
-                    if user.token_verified:
-                        user.software_token_mfa_enabled = True
-                    else:
-                        raise InvalidParameterException(
-                            "User has not verified software token mfa"
-                        )
-
-                    if software_token_mfa_settings.get("PreferredMfa"):
-                        user.preferred_mfa_setting = "SOFTWARE_TOKEN_MFA"
-                elif sms_mfa_settings and sms_mfa_settings["Enabled"]:
-                    user.sms_mfa_enabled = True
-
-                    if sms_mfa_settings.get("PreferredMfa"):
-                        user.preferred_mfa_setting = "SMS_MFA"
-                return None
+                return self.admin_set_user_mfa_preference(
+                    user_pool.id,
+                    username,
+                    software_token_mfa_settings,
+                    sms_mfa_settings,
+                )
 
         raise NotAuthorizedError(access_token)
 
@@ -1942,27 +2039,68 @@ class CognitoIdpBackend(BaseBackend):
     ) -> None:
         user = self.admin_get_user(user_pool_id, username)
 
-        if software_token_mfa_settings and software_token_mfa_settings.get("Enabled"):
-            if user.token_verified:
-                user.software_token_mfa_enabled = True
+        if software_token_mfa_settings:
+            if software_token_mfa_settings.get("Enabled"):
+                if user.token_verified:
+                    user.software_token_mfa_enabled = True
+                else:
+                    raise InvalidParameterException(
+                        "User has not verified software token mfa"
+                    )
             else:
-                raise InvalidParameterException(
-                    "User has not verified software token mfa"
-                )
+                user.software_token_mfa_enabled = False
 
             if software_token_mfa_settings.get("PreferredMfa"):
                 user.preferred_mfa_setting = "SOFTWARE_TOKEN_MFA"
-        elif sms_mfa_settings and sms_mfa_settings.get("Enabled"):
-            user.sms_mfa_enabled = True
+            elif user.preferred_mfa_setting != "SMS_MFA":
+                user.preferred_mfa_setting = ""
+
+        if sms_mfa_settings:
+            if sms_mfa_settings.get("Enabled"):
+                user.sms_mfa_enabled = True
+            else:
+                user.sms_mfa_enabled = False
 
             if sms_mfa_settings.get("PreferredMfa"):
                 user.preferred_mfa_setting = "SMS_MFA"
+            elif user.preferred_mfa_setting != "SOFTWARE_TOKEN_MFA":
+                user.preferred_mfa_setting = ""
+
         return None
 
+    def _validate_password(self, user_pool_id: str, password: str) -> None:
+        user_pool = self.describe_user_pool(user_pool_id)
+        password_policy = user_pool.extended_config.get("Policies", {}).get(
+            "PasswordPolicy", {}
+        )
+        minimum = password_policy.get("MinimumLength", 5)
+        maximum = password_policy.get("MaximumLength", 99)
+        require_uppercase = password_policy.get("RequireUppercase", True)
+        require_lowercase = password_policy.get("RequireLowercase", True)
+        require_numbers = password_policy.get("RequireNumbers", True)
+        require_symbols = password_policy.get("RequireSymbols", True)
+
+        flagl = minimum <= len(password) < maximum
+        flagn = not require_numbers or bool(re.search(r"\d", password))
+        # If we require symbols, we assume False - and check a symbol is present
+        # If we don't require symbols, we assume True - and we could technically skip the for-loop
+        flag_sc = not require_symbols
+        sc = "^ $ * . [ ] { } ( ) ? \" ! @ # % & / \\ , > < ' : ; | _ ~ ` = + -"
+        for i in password:
+            if i in sc:
+                flag_sc = True
+
+        flag_u = not require_uppercase or bool(re.search(r"[A-Z]+", password))
+        flag_lo = not require_lowercase or bool(re.search(r"[a-z]+", password))
+        if not (flagl and flagn and flag_sc and flag_u and flag_lo):
+            raise InvalidPasswordException()
+
     def admin_set_user_password(
         self, user_pool_id: str, username: str, password: str, permanent: bool
     ) -> None:
         user = self.admin_get_user(user_pool_id, username)
+        # user.password = password
+        self._validate_password(user_pool_id, password)
         user.password = password
         if permanent:
             user.status = UserStatus.CONFIRMED
@@ -1986,17 +2124,42 @@ class CognitoIdpBackend(BaseBackend):
                 _, username = user_pool.access_tokens[access_token]
                 user = self.admin_get_user(user_pool.id, username)
 
+                email = self._find_attr("email", attributes)
+                self._verify_email_is_not_used(user_pool.id, email)
+
                 user.update_attributes(attributes)
                 return
 
         raise NotAuthorizedError(access_token)
 
+    def _find_attr(self, name: str, attrs: List[Dict[str, str]]) -> Optional[str]:
+        return next((a["Value"] for a in attrs if a["Name"] == name), None)
+
+    def _verify_email_is_not_used(
+        self, user_pool_id: str, email: Optional[str]
+    ) -> None:
+        if not email:
+            # We're not updating emails
+            return
+        user_pool = self.describe_user_pool(user_pool_id)
+        if "email" not in user_pool.extended_config.get("UsernameAttributes", []):
+            # email is not used as a username - duplicate emails are allowed
+            return
+
+        for user in user_pool.users.values():
+            if user.attribute_lookup.get("email", "") == email:
+                raise AliasExistsException
+
 
 class RegionAgnosticBackend:
     # Some operations are unauthenticated
     # Without authentication-header, we lose the context of which region the request was send to
     # This backend will cycle through all backends as a workaround
 
+    def __init__(self, account_id: str, region_name: str):
+        self.account_id = account_id
+        self.region_name = region_name
+
     def _find_backend_by_access_token(self, access_token: str) -> CognitoIdpBackend:
         for account_specific_backends in cognitoidp_backends.values():
             for region, backend in account_specific_backends.items():
@@ -2005,7 +2168,7 @@ class RegionAgnosticBackend:
                 for p in backend.user_pools.values():
                     if access_token in p.access_tokens:
                         return backend
-        return backend
+        return cognitoidp_backends[self.account_id][self.region_name]
 
     def _find_backend_for_clientid(self, client_id: str) -> CognitoIdpBackend:
         for account_specific_backends in cognitoidp_backends.values():
@@ -2015,7 +2178,7 @@ class RegionAgnosticBackend:
                 for p in backend.user_pools.values():
                     if client_id in p.clients:
                         return backend
-        return backend
+        return cognitoidp_backends[self.account_id][self.region_name]
 
     def sign_up(
         self,
@@ -2041,6 +2204,18 @@ class RegionAgnosticBackend:
         backend = self._find_backend_by_access_token(access_token)
         return backend.get_user(access_token)
 
+    def admin_respond_to_auth_challenge(
+        self,
+        session: str,
+        client_id: str,
+        challenge_name: str,
+        challenge_responses: Dict[str, str],
+    ) -> Dict[str, Any]:
+        backend = self._find_backend_for_clientid(client_id)
+        return backend.admin_respond_to_auth_challenge(
+            session, client_id, challenge_name, challenge_responses
+        )
+
     def respond_to_auth_challenge(
         self,
         session: str,
@@ -2060,7 +2235,9 @@ cognitoidp_backends = BackendDict(CognitoIdpBackend, "cognito-idp")
 # Hack to help moto-server process requests on localhost, where the region isn't
 # specified in the host header. Some endpoints (change password, confirm forgot
 # password) have no authorization header from which to extract the region.
-def find_account_region_by_value(key: str, value: str) -> Tuple[str, str]:
+def find_account_region_by_value(
+    key: str, value: str, fallback: Tuple[str, str]
+) -> Tuple[str, str]:
     for account_id, account_specific_backend in cognitoidp_backends.items():
         for region, backend in account_specific_backend.items():
             for user_pool in backend.user_pools.values():
@@ -2072,4 +2249,4 @@ def find_account_region_by_value(key: str, value: str) -> Tuple[str, str]:
     # If we can't find the `client_id` or `access_token`, we just pass
     # back a default backend region, which will raise the appropriate
     # error message (e.g. NotAuthorized or NotFound).
-    return account_id, region
+    return fallback
