@@ -1,18 +1,17 @@
-from functools import lru_cache
-
 import datetime
 import inspect
 import re
-from botocore.exceptions import ClientError
-from boto3 import Session
-from moto.settings import allow_unknown_region
-from threading import RLock
-from typing import Any, Optional, List
+from gzip import decompress
+from typing import Any, Callable, Dict, List, Optional, Tuple
 from urllib.parse import urlparse
-from uuid import uuid4
+
+from botocore.exceptions import ClientError
+
+from .common_types import TYPE_RESPONSE
+from .versions import PYTHON_311
 
 
-def camelcase_to_underscores(argument: Optional[str]) -> str:
+def camelcase_to_underscores(argument: str) -> str:
     """Converts a camelcase param like theNewAttribute to the equivalent
     python underscore variable like the_new_attribute"""
     result = ""
@@ -38,7 +37,7 @@ def camelcase_to_underscores(argument: Optional[str]) -> str:
     return result
 
 
-def underscores_to_camelcase(argument):
+def underscores_to_camelcase(argument: str) -> str:
     """Converts a camelcase param like the_new_attribute to the equivalent
     camelcase version like theNewAttribute. Note that the first letter is
     NOT capitalized by this function"""
@@ -54,31 +53,31 @@ def underscores_to_camelcase(argument):
     return result
 
 
-def pascal_to_camelcase(argument):
+def pascal_to_camelcase(argument: str) -> str:
     """Converts a PascalCase param to the camelCase equivalent"""
     return argument[0].lower() + argument[1:]
 
 
-def camelcase_to_pascal(argument):
+def camelcase_to_pascal(argument: str) -> str:
     """Converts a camelCase param to the PascalCase equivalent"""
     return argument[0].upper() + argument[1:]
 
 
-def method_names_from_class(clazz):
+def method_names_from_class(clazz: object) -> List[str]:
     predicate = inspect.isfunction
     return [x[0] for x in inspect.getmembers(clazz, predicate=predicate)]
 
 
-def convert_regex_to_flask_path(url_path):
+def convert_regex_to_flask_path(url_path: str) -> str:
     """
     Converts a regex matching url to one that can be used with flask
     """
     for token in ["$"]:
         url_path = url_path.replace(token, "")
 
-    def caller(reg):
+    def caller(reg: Any) -> str:
         match_name, match_pattern = reg.groups()
-        return '<regex("{0}"):{1}>'.format(match_pattern, match_name)
+        return f'<regex("{match_pattern}"):{match_name}>'
 
     url_path = re.sub(r"\(\?P<(.*?)>(.*?)\)", caller, url_path)
 
@@ -89,21 +88,22 @@ def convert_regex_to_flask_path(url_path):
 
 
 class convert_to_flask_response(object):
-    def __init__(self, callback):
+    def __init__(self, callback: Callable[..., Any]):
         self.callback = callback
 
     @property
-    def __name__(self):
+    def __name__(self) -> str:
         # For instance methods, use class and method names. Otherwise
         # use module and method name
         if inspect.ismethod(self.callback):
             outer = self.callback.__self__.__class__.__name__
         else:
             outer = self.callback.__module__
-        return "{0}.{1}".format(outer, self.callback.__name__)
+        return f"{outer}.{self.callback.__name__}"
+
+    def __call__(self, args: Any = None, **kwargs: Any) -> Any:
+        from flask import Response, request
 
-    def __call__(self, args=None, **kwargs):
-        from flask import request, Response
         from moto.moto_api import recorder
 
         try:
@@ -124,20 +124,20 @@ class convert_to_flask_response(object):
 
 
 class convert_flask_to_responses_response(object):
-    def __init__(self, callback):
+    def __init__(self, callback: Callable[..., Any]):
         self.callback = callback
 
     @property
-    def __name__(self):
+    def __name__(self) -> str:
         # For instance methods, use class and method names. Otherwise
         # use module and method name
         if inspect.ismethod(self.callback):
             outer = self.callback.__self__.__class__.__name__
         else:
             outer = self.callback.__module__
-        return "{0}.{1}".format(outer, self.callback.__name__)
+        return f"{outer}.{self.callback.__name__}"
 
-    def __call__(self, request, *args, **kwargs):
+    def __call__(self, request: Any, *args: Any, **kwargs: Any) -> TYPE_RESPONSE:
         for key, val in request.headers.items():
             if isinstance(val, bytes):
                 request.headers[key] = val.decode("utf-8")
@@ -147,17 +147,20 @@ class convert_flask_to_responses_response(object):
         return status, headers, response
 
 
-def iso_8601_datetime_with_milliseconds(value: datetime) -> str:
-    return value.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3] + "Z"
+def iso_8601_datetime_with_milliseconds(
+    value: Optional[datetime.datetime] = None,
+) -> str:
+    date_to_use = value or utcnow()
+    return date_to_use.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3] + "Z"
 
 
 # Even Python does not support nanoseconds, other languages like Go do (needed for Terraform)
-def iso_8601_datetime_with_nanoseconds(value: datetime.datetime) -> str:
-    return value.strftime("%Y-%m-%dT%H:%M:%S.%f000Z")
+def iso_8601_datetime_with_nanoseconds() -> str:
+    return utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f000Z")
 
 
-def iso_8601_datetime_without_milliseconds(value: datetime.datetime) -> Optional[str]:
-    return value.strftime("%Y-%m-%dT%H:%M:%SZ") if value else None
+def iso_8601_datetime_without_milliseconds(value: datetime.datetime) -> str:
+    return value.strftime("%Y-%m-%dT%H:%M:%SZ")
 
 
 def iso_8601_datetime_without_milliseconds_s3(
@@ -167,27 +170,86 @@ def iso_8601_datetime_without_milliseconds_s3(
 
 
 RFC1123 = "%a, %d %b %Y %H:%M:%S GMT"
+EN_WEEKDAYS = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"]
+EN_MONTHS = [
+    "Jan",
+    "Feb",
+    "Mar",
+    "Apr",
+    "May",
+    "Jun",
+    "Jul",
+    "Aug",
+    "Sep",
+    "Oct",
+    "Nov",
+    "Dec",
+]
 
 
-def rfc_1123_datetime(src):
-    return src.strftime(RFC1123)
+def rfc_1123_datetime(src: datetime.datetime) -> str:
+    """
+    Returns the datetime in the RFC-1123 format
+    Names of weekdays/months are in English
+    """
+    # strftime uses the current locale to translate values
+    # So weekday/month values may not be in English
+    # For our usecase, we need these values to always be in English, otherwise botocore is unable to parse it
+    # Having a hardcoded list ensures this always works, even if the user does not have an English locale installed
+    eng_weekday = EN_WEEKDAYS[src.isoweekday() - 1]
+    eng_month = EN_MONTHS[src.month - 1]
+    non_locallized_rfc1123 = RFC1123.replace("%a", "{}").replace("%b", "{}")
+    return src.strftime(non_locallized_rfc1123).format(eng_weekday, eng_month)
 
 
-def str_to_rfc_1123_datetime(value):
+def str_to_rfc_1123_datetime(value: str) -> datetime.datetime:
     return datetime.datetime.strptime(value, RFC1123)
 
 
-def unix_time(dt: datetime.datetime = None) -> int:
-    dt = dt or datetime.datetime.utcnow()
-    epoch = datetime.datetime.utcfromtimestamp(0)
+def unix_time(dt: Optional[datetime.datetime] = None) -> float:
+    dt = dt or utcnow()
+    epoch = utcfromtimestamp(0)
     delta = dt - epoch
     return (delta.days * 86400) + (delta.seconds + (delta.microseconds / 1e6))
 
 
-def unix_time_millis(dt: datetime = None) -> int:
+def unix_time_millis(dt: Optional[datetime.datetime] = None) -> float:
     return unix_time(dt) * 1000.0
 
 
+def utcfromtimestamp(value: int) -> datetime.datetime:
+    """
+    Return the UTC datetime corresponding to the POSIX timestamp, with tzinfo None. The resulting object is naive.
+    """
+    # Python 3.12 starts throwing deprecation warnings for utcfromtimestamp()
+    # The docs recommend to use fromtimestamp(UTC) instead
+    #
+    # fromtimestamp(UTC) creates an aware datetime - but utcfromtimestamp() creates a naive datetime
+    # That's why we have to `replace(tzinfo=None)` to make now(UTC) naive.
+    if PYTHON_311:
+        # Only available from 3.11
+        from datetime import UTC  # type: ignore
+
+        return datetime.datetime.fromtimestamp(value, tz=UTC).replace(tzinfo=None)
+    else:
+        return datetime.datetime.utcfromtimestamp(value)
+
+
+def utcnow() -> datetime.datetime:
+    # Python 3.12 starts throwing deprecation warnings for utcnow()
+    # The docs recommend to use now(UTC) instead
+    #
+    # now(UTC) creates an aware datetime - but utcnow() creates a naive datetime
+    # That's why we have to `replace(tzinfo=None)` to make now(UTC) naive.
+    if PYTHON_311:
+        # Only available from 3.11
+        from datetime import UTC  # type: ignore
+
+        return datetime.datetime.now(UTC).replace(tzinfo=None)
+    else:
+        return datetime.datetime.utcnow()
+
+
 def path_url(url: str) -> str:
     parsed_url = urlparse(url)
     path = parsed_url.path
@@ -199,28 +261,27 @@ def path_url(url: str) -> str:
 
 
 def tags_from_query_string(
-    querystring_dict, prefix="Tag", key_suffix="Key", value_suffix="Value"
-):
+    querystring_dict: Dict[str, Any],
+    prefix: str = "Tag",
+    key_suffix: str = "Key",
+    value_suffix: str = "Value",
+) -> Dict[str, str]:
     response_values = {}
     for key in querystring_dict.keys():
         if key.startswith(prefix) and key.endswith(key_suffix):
             tag_index = key.replace(prefix + ".", "").replace("." + key_suffix, "")
-            tag_key = querystring_dict.get(
-                "{prefix}.{index}.{key_suffix}".format(
-                    prefix=prefix, index=tag_index, key_suffix=key_suffix
-                )
-            )[0]
-            tag_value_key = "{prefix}.{index}.{value_suffix}".format(
-                prefix=prefix, index=tag_index, value_suffix=value_suffix
-            )
+            tag_key = querystring_dict[f"{prefix}.{tag_index}.{key_suffix}"][0]
+            tag_value_key = f"{prefix}.{tag_index}.{value_suffix}"
             if tag_value_key in querystring_dict:
-                response_values[tag_key] = querystring_dict.get(tag_value_key)[0]
+                response_values[tag_key] = querystring_dict[tag_value_key][0]
             else:
                 response_values[tag_key] = None
     return response_values
 
 
-def tags_from_cloudformation_tags_list(tags_list):
+def tags_from_cloudformation_tags_list(
+    tags_list: List[Dict[str, str]]
+) -> Dict[str, str]:
     """Return tags in dict form from cloudformation resource tags form (list of dicts)"""
     tags = {}
     for entry in tags_list:
@@ -231,7 +292,7 @@ def tags_from_cloudformation_tags_list(tags_list):
     return tags
 
 
-def remap_nested_keys(root, key_transform):
+def remap_nested_keys(root: Any, key_transform: Callable[[str], str]) -> Any:
     """This remap ("recursive map") function is used to traverse and
     transform the dictionary keys of arbitrarily nested structures.
     List comprehensions do not recurse, making it tedious to apply
@@ -258,7 +319,9 @@ def remap_nested_keys(root, key_transform):
     return root
 
 
-def merge_dicts(dict1, dict2, remove_nulls=False):
+def merge_dicts(
+    dict1: Dict[str, Any], dict2: Dict[str, Any], remove_nulls: bool = False
+) -> None:
     """Given two arbitrarily nested dictionaries, merge the second dict into the first.
 
     :param dict dict1: the dictionary to be updated.
@@ -281,7 +344,7 @@ def merge_dicts(dict1, dict2, remove_nulls=False):
                 dict1.pop(key)
 
 
-def aws_api_matches(pattern, string):
+def aws_api_matches(pattern: str, string: Any) -> bool:
     """
     AWS API can match a value based on a glob, or an exact match
     """
@@ -302,7 +365,7 @@ def aws_api_matches(pattern, string):
         return False
 
 
-def extract_region_from_aws_authorization(string):
+def extract_region_from_aws_authorization(string: str) -> Optional[str]:
     auth = string or ""
     region = re.sub(r".*Credential=[^/]+/[^/]+/([^/]+)/.*", r"\1", auth)
     if region == auth:
@@ -310,116 +373,20 @@ def extract_region_from_aws_authorization(string):
     return region
 
 
-backend_lock = RLock()
-
-
-class AccountSpecificBackend(dict):
+def params_sort_function(item: Tuple[str, Any]) -> Tuple[str, int, str]:
     """
-    Dictionary storing the data for a service in a specific account.
-    Data access pattern:
-      account_specific_backend[region: str] = backend: BaseBackend
+    sort by <string-prefix>.member.<integer>.<string-postfix>:
+    in case there are more than 10 members, the default-string sort would lead to IndexError when parsing the content.
+
+    Note: currently considers only the first occurence of `member`, but there may be cases with nested members
     """
+    key, _ = item
 
-    def __init__(
-        self, service_name, account_id, backend, use_boto3_regions, additional_regions
-    ):
-        self.service_name = service_name
-        self.account_id = account_id
-        self.backend = backend
-        self.regions = []
-        if use_boto3_regions:
-            sess = Session()
-            self.regions.extend(sess.get_available_regions(service_name))
-            self.regions.extend(
-                sess.get_available_regions(service_name, partition_name="aws-us-gov")
-            )
-            self.regions.extend(
-                sess.get_available_regions(service_name, partition_name="aws-cn")
-            )
-        self.regions.extend(additional_regions or [])
-        self._id = str(uuid4())
-
-    def __hash__(self):
-        return hash(self._id)
-
-    def __eq__(self, other):
-        return (
-            other
-            and isinstance(other, AccountSpecificBackend)
-            and other._id == self._id
-        )
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    def reset(self):
-        for region_specific_backend in self.values():
-            region_specific_backend.reset()
-
-    def __contains__(self, region):
-        return region in self.regions or region in self.keys()
-
-    @lru_cache()
-    def __getitem__(self, region_name):
-        if region_name in self.keys():
-            return super().__getitem__(region_name)
-        # Create the backend for a specific region
-        with backend_lock:
-            if region_name in self.regions and region_name not in self.keys():
-                super().__setitem__(
-                    region_name, self.backend(region_name, account_id=self.account_id)
-                )
-            if region_name not in self.regions and allow_unknown_region():
-                super().__setitem__(
-                    region_name, self.backend(region_name, account_id=self.account_id)
-                )
-        return super().__getitem__(region_name)
+    match = re.search(r"(.*?member)\.(\d+)(.*)", key)
+    if match:
+        return (match.group(1), int(match.group(2)), match.group(3))
+    return (key, 0, "")
 
 
-class BackendDict(dict):
-    """
-    Data Structure to store everything related to a specific service.
-    Format:
-      [account_id: str]: AccountSpecificBackend
-      [account_id: str][region: str] = BaseBackend
-    """
-
-    def __init__(
-        self,
-        backend: Any,
-        service_name: str,
-        use_boto3_regions: bool = True,
-        additional_regions: Optional[List[str]] = None,
-    ):
-        self.backend = backend
-        self.service_name = service_name
-        self._use_boto3_regions = use_boto3_regions
-        self._additional_regions = additional_regions
-        self._id = str(uuid4())
-
-    def __hash__(self):
-        # Required for the LRUcache to work.
-        # service_name is enough to determine uniqueness - other properties are dependent
-        return hash(self._id)
-
-    def __eq__(self, other):
-        return other and isinstance(other, BackendDict) and other._id == self._id
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    @lru_cache()
-    def __getitem__(self, account_id) -> AccountSpecificBackend:
-        self._create_account_specific_backend(account_id)
-        return super().__getitem__(account_id)
-
-    def _create_account_specific_backend(self, account_id) -> None:
-        with backend_lock:
-            if account_id not in self.keys():
-                self[account_id] = AccountSpecificBackend(
-                    service_name=self.service_name,
-                    account_id=account_id,
-                    backend=self.backend,
-                    use_boto3_regions=self._use_boto3_regions,
-                    additional_regions=self._additional_regions,
-                )
+def gzip_decompress(body: bytes) -> bytes:
+    return decompress(body)
