@@ -1,40 +1,39 @@
-import re
-import json
-import email
 import datetime
-from email.mime.base import MIMEBase
-from email.utils import parseaddr
-from email.mime.multipart import MIMEMultipart
+import email
+import json
 from email.encoders import encode_7or8bit
-from typing import Mapping
+from email.mime.base import MIMEBase
+from email.mime.multipart import MIMEMultipart
+from email.utils import formataddr, getaddresses, parseaddr
+from typing import Any, Dict, List, Optional
 
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import BackendDict
+from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.utils import utcnow
 from moto.sns.models import sns_backends
+
 from .exceptions import (
-    MessageRejectedError,
+    ConfigurationSetAlreadyExists,
     ConfigurationSetDoesNotExist,
     EventDestinationAlreadyExists,
-    TemplateNameAlreadyExists,
-    ValidationError,
     InvalidParameterValue,
     InvalidRenderingParameterException,
-    TemplateDoesNotExist,
-    RuleDoesNotExist,
-    RuleSetNameAlreadyExists,
-    RuleSetDoesNotExist,
+    MessageRejectedError,
     RuleAlreadyExists,
-    MissingRenderingAttributeException,
-    ConfigurationSetAlreadyExists,
+    RuleDoesNotExist,
+    RuleSetDoesNotExist,
+    RuleSetNameAlreadyExists,
+    TemplateDoesNotExist,
+    TemplateNameAlreadyExists,
+    ValidationError,
 )
+from .feedback import BOUNCE, COMMON_MAIL, COMPLAINT, DELIVERY
+from .template import parse_template
 from .utils import get_random_message_id, is_valid_address
-from .feedback import COMMON_MAIL, BOUNCE, COMPLAINT, DELIVERY
 
 RECIPIENT_LIMIT = 50
 
 
 class SESFeedback(BaseModel):
-
     BOUNCE = "Bounce"
     COMPLAINT = "Complaint"
     DELIVERY = "Delivery"
@@ -50,8 +49,8 @@ class SESFeedback(BaseModel):
     FORWARDING_ENABLED = "feedback_forwarding_enabled"
 
     @staticmethod
-    def generate_message(account_id, msg_type):
-        msg = dict(COMMON_MAIL)
+    def generate_message(account_id: str, msg_type: str) -> Dict[str, Any]:  # type: ignore[misc]
+        msg: Dict[str, Any] = dict(COMMON_MAIL)
         msg["mail"]["sendingAccountId"] = account_id
         if msg_type == SESFeedback.BOUNCE:
             msg["bounce"] = BOUNCE
@@ -64,7 +63,14 @@ class SESFeedback(BaseModel):
 
 
 class Message(BaseModel):
-    def __init__(self, message_id, source, subject, body, destinations):
+    def __init__(
+        self,
+        message_id: str,
+        source: str,
+        subject: str,
+        body: str,
+        destinations: Dict[str, List[str]],
+    ):
         self.id = message_id
         self.source = source
         self.subject = subject
@@ -73,7 +79,14 @@ class Message(BaseModel):
 
 
 class TemplateMessage(BaseModel):
-    def __init__(self, message_id, source, template, template_data, destinations):
+    def __init__(
+        self,
+        message_id: str,
+        source: str,
+        template: List[str],
+        template_data: List[str],
+        destinations: Any,
+    ):
         self.id = message_id
         self.source = source
         self.template = template
@@ -82,7 +95,14 @@ class TemplateMessage(BaseModel):
 
 
 class BulkTemplateMessage(BaseModel):
-    def __init__(self, message_ids, source, template, template_data, destinations):
+    def __init__(
+        self,
+        message_ids: List[str],
+        source: str,
+        template: List[str],
+        template_data: List[str],
+        destinations: Any,
+    ):
         self.ids = message_ids
         self.source = source
         self.template = template
@@ -91,7 +111,9 @@ class BulkTemplateMessage(BaseModel):
 
 
 class RawMessage(BaseModel):
-    def __init__(self, message_id, source, destinations, raw_data):
+    def __init__(
+        self, message_id: str, source: str, destinations: List[str], raw_data: str
+    ):
         self.id = message_id
         self.source = source
         self.destinations = destinations
@@ -99,25 +121,14 @@ class RawMessage(BaseModel):
 
 
 class SESQuota(BaseModel):
-    def __init__(self, sent):
+    def __init__(self, sent: int):
         self.sent = sent
 
     @property
-    def sent_past_24(self):
+    def sent_past_24(self) -> int:
         return self.sent
 
 
-def are_all_variables_present(template, template_data):
-    subject_part = template["subject_part"]
-    text_part = template["text_part"]
-    html_part = template["html_part"]
-
-    for var in re.findall("{{(.+?)}}", subject_part + text_part + html_part):
-        if not template_data.get(var):
-            return var, False
-    return None, True
-
-
 class SESBackend(BaseBackend):
     """
     Responsible for mocking calls to SES.
@@ -128,78 +139,84 @@ class SESBackend(BaseBackend):
 
         from moto.core import DEFAULT_ACCOUNT_ID
         from moto.ses import ses_backends
-        ses_backend = ses_backends[DEFAULT_ACCOUNT_ID]["global"]
+        ses_backend = ses_backends[DEFAULT_ACCOUNT_ID][region]
         messages = ses_backend.sent_messages # sent_messages is a List of Message objects
 
     Note that, as this is an internal API, the exact format may differ per versions.
     """
 
-    def __init__(self, region_name, account_id):
+    def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.addresses = []
-        self.email_addresses = []
-        self.domains = []
-        self.sent_messages = []
+        self.addresses: List[str] = []
+        self.email_addresses: List[str] = []
+        self.domains: List[str] = []
+        self.sent_messages: List[Any] = []
         self.sent_message_count = 0
         self.rejected_messages_count = 0
-        self.sns_topics = {}
-        self.config_set = {}
-        self.config_set_event_destination = {}
-        self.event_destinations = {}
-        self.identity_mail_from_domains = {}
-        self.templates = {}
-        self.receipt_rule_set = {}
+        self.sns_topics: Dict[str, Dict[str, Any]] = {}
+        self.config_set: Dict[str, int] = {}
+        self.config_set_event_destination: Dict[str, Dict[str, Any]] = {}
+        self.event_destinations: Dict[str, int] = {}
+        self.identity_mail_from_domains: Dict[str, Dict[str, Any]] = {}
+        self.templates: Dict[str, Dict[str, str]] = {}
+        self.receipt_rule_set: Dict[str, List[Dict[str, Any]]] = {}
 
-    def _is_verified_address(self, source):
+    def _is_verified_address(self, source: str) -> bool:
         _, address = parseaddr(source)
         if address in self.addresses:
             return True
         if address in self.email_addresses:
             return True
-        _, host = address.split("@", 1)
+        host = address.split("@", 1)[-1]
         return host in self.domains
 
-    def verify_email_identity(self, address):
+    def verify_email_identity(self, address: str) -> None:
         _, address = parseaddr(address)
         if address not in self.addresses:
             self.addresses.append(address)
 
-    def verify_email_address(self, address):
+    def verify_email_address(self, address: str) -> None:
         _, address = parseaddr(address)
         self.email_addresses.append(address)
 
-    def verify_domain(self, domain):
+    def verify_domain(self, domain: str) -> None:
         if domain.lower() not in self.domains:
             self.domains.append(domain.lower())
 
-    def list_identities(self):
+    def list_identities(self, identity_type: str) -> List[str]:
+        if identity_type == "Domain":
+            return self.domains
+        if identity_type == "EmailAddress":
+            return self.addresses
         return self.domains + self.addresses
 
-    def list_verified_email_addresses(self):
+    def list_verified_email_addresses(self) -> List[str]:
         return self.email_addresses
 
-    def delete_identity(self, identity):
+    def delete_identity(self, identity: str) -> None:
         if "@" in identity:
             self.addresses.remove(identity)
         else:
             self.domains.remove(identity)
 
-    def send_email(self, source, subject, body, destinations, region):
+    def send_email(
+        self, source: str, subject: str, body: str, destinations: Dict[str, List[str]]
+    ) -> Message:
         recipient_count = sum(map(len, destinations.values()))
         if recipient_count > RECIPIENT_LIMIT:
             raise MessageRejectedError("Too many recipients.")
         if not self._is_verified_address(source):
             self.rejected_messages_count += 1
-            raise MessageRejectedError("Email address not verified %s" % source)
+            raise MessageRejectedError(f"Email address not verified {source}")
         destination_addresses = [
             address for addresses in destinations.values() for address in addresses
         ]
         for address in [source, *destination_addresses]:
-            valid, msg = is_valid_address(address)
-            if not valid:
+            msg = is_valid_address(address)
+            if msg is not None:
                 raise InvalidParameterValue(msg)
 
-        self.__process_sns_feedback__(source, destinations, region)
+        self.__process_sns_feedback__(source, destinations)
 
         message_id = get_random_message_id()
         message = Message(message_id, source, subject, body, destinations)
@@ -208,8 +225,12 @@ class SESBackend(BaseBackend):
         return message
 
     def send_bulk_templated_email(
-        self, source, template, template_data, destinations, region
-    ):
+        self,
+        source: str,
+        template: List[str],
+        template_data: List[str],
+        destinations: List[Dict[str, Dict[str, List[str]]]],
+    ) -> BulkTemplateMessage:
         recipient_count = len(destinations)
         if recipient_count > RECIPIENT_LIMIT:
             raise MessageRejectedError("Too many destinations.")
@@ -222,12 +243,12 @@ class SESBackend(BaseBackend):
 
         if not self._is_verified_address(source):
             self.rejected_messages_count += 1
-            raise MessageRejectedError("Email address not verified %s" % source)
+            raise MessageRejectedError(f"Email address not verified {source}")
 
         if not self.templates.get(template[0]):
-            raise TemplateDoesNotExist("Template (%s) does not exist" % template[0])
+            raise TemplateDoesNotExist(f"Template ({template[0]}) does not exist")
 
-        self.__process_sns_feedback__(source, destinations, region)
+        self.__process_sns_feedback__(source, destinations)
 
         message_id = get_random_message_id()
         message = TemplateMessage(
@@ -240,26 +261,30 @@ class SESBackend(BaseBackend):
         return BulkTemplateMessage(ids, source, template, template_data, destinations)
 
     def send_templated_email(
-        self, source, template, template_data, destinations, region
-    ):
+        self,
+        source: str,
+        template: List[str],
+        template_data: List[str],
+        destinations: Dict[str, List[str]],
+    ) -> TemplateMessage:
         recipient_count = sum(map(len, destinations.values()))
         if recipient_count > RECIPIENT_LIMIT:
             raise MessageRejectedError("Too many recipients.")
         if not self._is_verified_address(source):
             self.rejected_messages_count += 1
-            raise MessageRejectedError("Email address not verified %s" % source)
+            raise MessageRejectedError(f"Email address not verified {source}")
         destination_addresses = [
             address for addresses in destinations.values() for address in addresses
         ]
         for address in [source, *destination_addresses]:
-            valid, msg = is_valid_address(address)
-            if not valid:
+            msg = is_valid_address(address)
+            if msg is not None:
                 raise InvalidParameterValue(msg)
 
         if not self.templates.get(template[0]):
-            raise TemplateDoesNotExist("Template (%s) does not exist" % template[0])
+            raise TemplateDoesNotExist(f"Template ({template[0]}) does not exist")
 
-        self.__process_sns_feedback__(source, destinations, region)
+        self.__process_sns_feedback__(source, destinations)
 
         message_id = get_random_message_id()
         message = TemplateMessage(
@@ -269,7 +294,7 @@ class SESBackend(BaseBackend):
         self.sent_message_count += recipient_count
         return message
 
-    def __type_of_message__(self, destinations):
+    def __type_of_message__(self, destinations: Any) -> Optional[str]:
         """Checks the destination for any special address that could indicate delivery,
         complaint or bounce like in SES simulator"""
         if isinstance(destinations, list):
@@ -291,11 +316,11 @@ class SESBackend(BaseBackend):
 
         return None
 
-    def __generate_feedback__(self, msg_type):
+    def __generate_feedback__(self, msg_type: str) -> Dict[str, Any]:
         """Generates the SNS message for the feedback"""
         return SESFeedback.generate_message(self.account_id, msg_type)
 
-    def __process_sns_feedback__(self, source, destinations, region):
+    def __process_sns_feedback__(self, source: str, destinations: Any) -> None:
         domain = str(source)
         if "@" in domain:
             domain = domain.split("@")[1]
@@ -306,66 +331,74 @@ class SESBackend(BaseBackend):
                 if sns_topic is not None:
                     message = self.__generate_feedback__(msg_type)
                     if message:
-                        sns_backends[self.account_id][region].publish(
-                            message, arn=sns_topic
+                        sns_backends[self.account_id][self.region_name].publish(
+                            message,  # type: ignore[arg-type]
+                            arn=sns_topic,
                         )
 
-    def send_raw_email(self, source, destinations, raw_data, region):
+    def send_raw_email(
+        self, source: str, destinations: List[str], raw_data: str
+    ) -> RawMessage:
         if source is not None:
             _, source_email_address = parseaddr(source)
             if not self._is_verified_address(source_email_address):
                 raise MessageRejectedError(
-                    "Did not have authority to send from email %s"
-                    % source_email_address
+                    f"Did not have authority to send from email {source_email_address}"
                 )
 
-        recipient_count = len(destinations)
         message = email.message_from_string(raw_data)
         if source is None:
             if message["from"] is None:
                 raise MessageRejectedError("Source not specified")
 
-            _, source_email_address = parseaddr(message["from"])
-            if not self._is_verified_address(source_email_address):
+            _, source = parseaddr(message["from"])
+            if not self._is_verified_address(source):
                 raise MessageRejectedError(
-                    "Did not have authority to send from email %s"
-                    % source_email_address
+                    f"Did not have authority to send from email {source}"
                 )
 
-        for header in "TO", "CC", "BCC":
-            recipient_count += sum(
-                d.strip() and 1 or 0 for d in message.get(header, "").split(",")
-            )
-        if recipient_count > RECIPIENT_LIMIT:
+        fieldvalues = [message.get(header, "") for header in ["TO", "CC", "BCC"]]
+        destinations += [
+            formataddr((realname, email_address))
+            for realname, email_address in getaddresses(fieldvalues)
+            if email_address
+        ]
+        if len(destinations) > RECIPIENT_LIMIT:
             raise MessageRejectedError("Too many recipients.")
         for address in [addr for addr in [source, *destinations] if addr is not None]:
-            valid, msg = is_valid_address(address)
-            if not valid:
+            msg = is_valid_address(address)
+            if msg is not None:
                 raise InvalidParameterValue(msg)
 
-        self.__process_sns_feedback__(source, destinations, region)
+        self.__process_sns_feedback__(source, destinations)
 
-        self.sent_message_count += recipient_count
+        self.sent_message_count += len(destinations)
         message_id = get_random_message_id()
-        message = RawMessage(message_id, source, destinations, raw_data)
-        self.sent_messages.append(message)
-        return message
+        raw_message = RawMessage(message_id, source, destinations, raw_data)
+        self.sent_messages.append(raw_message)
+        return raw_message
 
-    def get_send_quota(self):
+    def get_send_quota(self) -> SESQuota:
         return SESQuota(self.sent_message_count)
 
-    def get_identity_notification_attributes(self, identities):
-        response = {}
+    def get_identity_notification_attributes(
+        self, identities: List[str]
+    ) -> Dict[str, Dict[str, Any]]:
+        response: Dict[str, Dict[str, Any]] = {}
         for identity in identities:
             response[identity] = self.sns_topics.get(identity, {})
         return response
 
-    def set_identity_feedback_forwarding_enabled(self, identity, enabled):
+    def set_identity_feedback_forwarding_enabled(
+        self, identity: str, enabled: bool
+    ) -> None:
         identity_sns_topics = self.sns_topics.get(identity, {})
         identity_sns_topics[SESFeedback.FORWARDING_ENABLED] = enabled
         self.sns_topics[identity] = identity_sns_topics
 
-    def set_identity_notification_topic(self, identity, notification_type, sns_topic):
+    def set_identity_notification_topic(
+        self, identity: str, notification_type: str, sns_topic: Optional[str]
+    ) -> None:
         identity_sns_topics = self.sns_topics.get(identity, {})
         if sns_topic is None:
             del identity_sns_topics[notification_type]
@@ -374,27 +407,22 @@ class SESBackend(BaseBackend):
 
         self.sns_topics[identity] = identity_sns_topics
 
-        return {}
-
-    def create_configuration_set(self, configuration_set_name):
+    def create_configuration_set(self, configuration_set_name: str) -> None:
         if configuration_set_name in self.config_set:
             raise ConfigurationSetAlreadyExists(
                 f"Configuration set <{configuration_set_name}> already exists"
             )
         self.config_set[configuration_set_name] = 1
-        return {}
 
-    def describe_configuration_set(self, configuration_set_name):
+    def describe_configuration_set(self, configuration_set_name: str) -> None:
         if configuration_set_name not in self.config_set:
             raise ConfigurationSetDoesNotExist(
                 f"Configuration set <{configuration_set_name}> does not exist"
             )
-        return {}
 
     def create_configuration_set_event_destination(
-        self, configuration_set_name, event_destination
-    ):
-
+        self, configuration_set_name: str, event_destination: Dict[str, Any]
+    ) -> None:
         if self.config_set.get(configuration_set_name) is None:
             raise ConfigurationSetDoesNotExist("Invalid Configuration Set Name.")
 
@@ -404,19 +432,16 @@ class SESBackend(BaseBackend):
         self.config_set_event_destination[configuration_set_name] = event_destination
         self.event_destinations[event_destination["Name"]] = 1
 
-        return {}
+    def get_send_statistics(self) -> Dict[str, Any]:
+        return {
+            "DeliveryAttempts": self.sent_message_count,
+            "Rejects": self.rejected_messages_count,
+            "Complaints": 0,
+            "Bounces": 0,
+            "Timestamp": utcnow(),
+        }
 
-    def get_send_statistics(self):
-
-        statistics = {}
-        statistics["DeliveryAttempts"] = self.sent_message_count
-        statistics["Rejects"] = self.rejected_messages_count
-        statistics["Complaints"] = 0
-        statistics["Bounces"] = 0
-        statistics["Timestamp"] = datetime.datetime.utcnow()
-        return statistics
-
-    def add_template(self, template_info):
+    def add_template(self, template_info: Dict[str, str]) -> None:
         template_name = template_info["template_name"]
         if not template_name:
             raise ValidationError(
@@ -433,7 +458,7 @@ class SESBackend(BaseBackend):
             raise InvalidParameterValue("The subject must be specified.")
         self.templates[template_name] = template_info
 
-    def update_template(self, template_info):
+    def update_template(self, template_info: Dict[str, str]) -> None:
         template_name = template_info["template_name"]
         if not template_name:
             raise ValidationError(
@@ -450,15 +475,15 @@ class SESBackend(BaseBackend):
             raise InvalidParameterValue("The subject must be specified.")
         self.templates[template_name] = template_info
 
-    def get_template(self, template_name):
+    def get_template(self, template_name: str) -> Dict[str, str]:
         if not self.templates.get(template_name, None):
             raise TemplateDoesNotExist("Invalid Template Name.")
         return self.templates[template_name]
 
-    def list_templates(self):
+    def list_templates(self) -> List[Dict[str, str]]:
         return list(self.templates.values())
 
-    def render_template(self, render_data):
+    def render_template(self, render_data: Dict[str, Any]) -> str:
         template_name = render_data.get("name", "")
         template = self.templates.get(template_name, None)
         if not template:
@@ -466,24 +491,19 @@ class SESBackend(BaseBackend):
 
         template_data = render_data.get("data")
         try:
-            template_data = json.loads(template_data)
+            template_data = json.loads(template_data)  # type: ignore
         except ValueError:
             raise InvalidRenderingParameterException(
                 "Template rendering data is invalid"
             )
 
-        var, are_variables_present = are_all_variables_present(template, template_data)
-        if not are_variables_present:
-            raise MissingRenderingAttributeException(var)
-
         subject_part = template["subject_part"]
         text_part = template["text_part"]
         html_part = template["html_part"]
 
-        for key, value in template_data.items():
-            subject_part = str.replace(str(subject_part), "{{%s}}" % key, value)
-            text_part = str.replace(str(text_part), "{{%s}}" % key, value)
-            html_part = str.replace(str(html_part), "{{%s}}" % key, value)
+        subject_part = parse_template(str(subject_part), template_data)
+        text_part = parse_template(str(text_part), template_data)
+        html_part = parse_template(str(html_part), template_data)
 
         email_obj = MIMEMultipart("alternative")
 
@@ -499,19 +519,20 @@ class SESBackend(BaseBackend):
 
         now = datetime.datetime.now().isoformat()
 
-        rendered_template = "Date: %s\r\nSubject: %s\r\n%s" % (
-            now,
-            subject_part,
-            email_obj.as_string(),
+        rendered_template = (
+            f"Date: {now}\r\nSubject: {subject_part}\r\n{email_obj.as_string()}"
         )
         return rendered_template
 
-    def create_receipt_rule_set(self, rule_set_name):
+    def delete_template(self, name: str) -> None:
+        self.templates.pop(name)
+
+    def create_receipt_rule_set(self, rule_set_name: str) -> None:
         if self.receipt_rule_set.get(rule_set_name) is not None:
             raise RuleSetNameAlreadyExists("Duplicate Receipt Rule Set Name.")
         self.receipt_rule_set[rule_set_name] = []
 
-    def create_receipt_rule(self, rule_set_name, rule):
+    def create_receipt_rule(self, rule_set_name: str, rule: Dict[str, Any]) -> None:
         rule_set = self.receipt_rule_set.get(rule_set_name)
         if rule_set is None:
             raise RuleSetDoesNotExist("Invalid Rule Set Name.")
@@ -520,7 +541,7 @@ class SESBackend(BaseBackend):
         rule_set.append(rule)
         self.receipt_rule_set[rule_set_name] = rule_set
 
-    def describe_receipt_rule_set(self, rule_set_name):
+    def describe_receipt_rule_set(self, rule_set_name: str) -> List[Dict[str, Any]]:
         rule_set = self.receipt_rule_set.get(rule_set_name)
 
         if rule_set is None:
@@ -528,7 +549,9 @@ class SESBackend(BaseBackend):
 
         return rule_set
 
-    def describe_receipt_rule(self, rule_set_name, rule_name):
+    def describe_receipt_rule(
+        self, rule_set_name: str, rule_name: str
+    ) -> Dict[str, Any]:
         rule_set = self.receipt_rule_set.get(rule_set_name)
 
         if rule_set is None:
@@ -540,7 +563,7 @@ class SESBackend(BaseBackend):
 
         raise RuleDoesNotExist("Invalid Rule Name.")
 
-    def update_receipt_rule(self, rule_set_name, rule):
+    def update_receipt_rule(self, rule_set_name: str, rule: Dict[str, Any]) -> None:
         rule_set = self.receipt_rule_set.get(rule_set_name)
 
         if rule_set is None:
@@ -554,29 +577,30 @@ class SESBackend(BaseBackend):
             raise RuleDoesNotExist(f"Rule does not exist: {rule['name']}")
 
     def set_identity_mail_from_domain(
-        self, identity, mail_from_domain=None, behavior_on_mx_failure=None
-    ):
-        if identity not in (self.domains + self.addresses):
-            raise InvalidParameterValue(
-                "Identity '{0}' does not exist.".format(identity)
-            )
+        self,
+        identity: str,
+        mail_from_domain: Optional[str] = None,
+        behavior_on_mx_failure: Optional[str] = None,
+    ) -> None:
+        if not self._is_verified_address(identity):
+            raise InvalidParameterValue(f"Identity '{identity}' does not exist.")
 
         if mail_from_domain is None:
             self.identity_mail_from_domains.pop(identity)
             return
 
-        if not mail_from_domain.endswith(identity):
+        if not mail_from_domain.endswith(identity.split("@")[-1]):
             raise InvalidParameterValue(
-                "Provided MAIL-FROM domain '{0}' is not subdomain of "
-                "the domain of the identity '{1}'.".format(mail_from_domain, identity)
+                f"Provided MAIL-FROM domain '{mail_from_domain}' is not subdomain of "
+                f"the domain of the identity '{identity.split('@')[-1]}'."
             )
 
         if behavior_on_mx_failure not in (None, "RejectMessage", "UseDefaultValue"):
             raise ValidationError(
                 "1 validation error detected: "
-                "Value '{0}' at 'behaviorOnMXFailure'"
+                f"Value '{behavior_on_mx_failure}' at 'behaviorOnMXFailure'"
                 "failed to satisfy constraint: Member must satisfy enum value set: "
-                "[RejectMessage, UseDefaultValue]".format(behavior_on_mx_failure)
+                "[RejectMessage, UseDefaultValue]"
             )
 
         self.identity_mail_from_domains[identity] = {
@@ -584,7 +608,9 @@ class SESBackend(BaseBackend):
             "behavior_on_mx_failure": behavior_on_mx_failure,
         }
 
-    def get_identity_mail_from_domain_attributes(self, identities=None):
+    def get_identity_mail_from_domain_attributes(
+        self, identities: Optional[List[str]] = None
+    ) -> Dict[str, Dict[str, str]]:
         if identities is None:
             identities = []
 
@@ -597,11 +623,13 @@ class SESBackend(BaseBackend):
 
         return attributes_by_identity
 
-    def get_identity_verification_attributes(self, identities=None):
+    def get_identity_verification_attributes(
+        self, identities: Optional[List[str]] = None
+    ) -> Dict[str, str]:
         if identities is None:
             identities = []
 
-        attributes_by_identity = {}
+        attributes_by_identity: Dict[str, str] = {}
         for identity in identities:
             if identity in (self.domains + self.addresses):
                 attributes_by_identity[identity] = "Success"
@@ -609,6 +637,4 @@ class SESBackend(BaseBackend):
         return attributes_by_identity
 
 
-ses_backends: Mapping[str, SESBackend] = BackendDict(
-    SESBackend, "ses", use_boto3_regions=False, additional_regions=["global"]
-)
+ses_backends = BackendDict(SESBackend, "ses")
