@@ -1,16 +1,18 @@
 """Unit tests for acmpca-supported APIs."""
+import datetime
+
 import boto3
+import cryptography.hazmat.primitives.asymmetric.rsa
+import cryptography.x509
 import pytest
 from botocore.exceptions import ClientError
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import hashes, serialization
+from cryptography.x509 import NameOID
+
 from moto import mock_acmpca
 from moto.core import DEFAULT_ACCOUNT_ID
-
-import datetime
-import cryptography.x509
-from cryptography.x509 import NameOID
-import cryptography.hazmat.primitives.asymmetric.rsa
-from cryptography.hazmat.primitives import serialization, hashes
-from cryptography.hazmat.backends import default_backend
+from moto.core.utils import utcnow
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
@@ -61,6 +63,37 @@ def test_describe_certificate_authority():
         "SigningAlgorithm": "SHA512WITHRSA",
         "Subject": {"CommonName": "yscb41lw.test"},
     }
+    assert ca["KeyStorageSecurityStandard"] == "FIPS_140_2_LEVEL_3_OR_HIGHER"
+
+
+@mock_acmpca
+def test_describe_certificate_authority_with_security_standard():
+    client = boto3.client("acm-pca", region_name="ap-southeast-1")
+    ca_arn = client.create_certificate_authority(
+        CertificateAuthorityConfiguration={
+            "KeyAlgorithm": "RSA_4096",
+            "SigningAlgorithm": "SHA512WITHRSA",
+            "Subject": {"CommonName": "yscb41lw.test"},
+        },
+        CertificateAuthorityType="SUBORDINATE",
+        KeyStorageSecurityStandard="FIPS_140_2_LEVEL_2_OR_HIGHER",
+        IdempotencyToken="terraform-20221125230308947400000001",
+    )["CertificateAuthorityArn"]
+    ca = client.describe_certificate_authority(CertificateAuthorityArn=ca_arn)[
+        "CertificateAuthority"
+    ]
+
+    assert ca["Arn"] == ca_arn
+    assert ca["OwnerAccount"] == DEFAULT_ACCOUNT_ID
+    assert "CreatedAt" in ca
+    assert ca["Type"] == "SUBORDINATE"
+    assert ca["Status"] == "PENDING_CERTIFICATE"
+    assert ca["CertificateAuthorityConfiguration"] == {
+        "KeyAlgorithm": "RSA_4096",
+        "SigningAlgorithm": "SHA512WITHRSA",
+        "Subject": {"CommonName": "yscb41lw.test"},
+    }
+    assert ca["KeyStorageSecurityStandard"] == "FIPS_140_2_LEVEL_2_OR_HIGHER"
 
 
 @mock_acmpca
@@ -346,8 +379,8 @@ def create_cert():
         .issuer_name(issuer)
         .public_key(key.public_key())
         .serial_number(serial_number)
-        .not_valid_before(datetime.datetime.utcnow() - datetime.timedelta(days=10))
-        .not_valid_after(datetime.datetime.utcnow() + datetime.timedelta(days=10))
+        .not_valid_before(utcnow() - datetime.timedelta(days=10))
+        .not_valid_after(utcnow() + datetime.timedelta(days=10))
         .sign(key, hashes.SHA512(), default_backend())
     )
 
