@@ -1,8 +1,9 @@
+from uuid import uuid4
+
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_amp
 
 # See our Development Tips on writing tests for hints on how to write good tests:
@@ -14,9 +15,9 @@ def test_create_workspace():
     client = boto3.client("amp", region_name="ap-southeast-1")
     resp = client.create_workspace(alias="test", clientToken="mytoken")
 
-    resp.should.have.key("arn")
-    resp.should.have.key("status").equals({"statusCode": "ACTIVE"})
-    resp.should.have.key("workspaceId")
+    assert "arn" in resp
+    assert resp["status"] == {"statusCode": "ACTIVE"}
+    assert "workspaceId" in resp
 
 
 @mock_amp
@@ -27,31 +28,32 @@ def test_describe_workspace():
     ]
 
     resp = client.describe_workspace(workspaceId=workspace_id)
-    resp.should.have.key("workspace")
+    assert "workspace" in resp
 
     workspace = resp["workspace"]
-    workspace.should.have.key("alias")
-    workspace.should.have.key("arn")
-    workspace.should.have.key("createdAt")
-    workspace.should.have.key("prometheusEndpoint")
-    workspace.should.have.key("status").equals({"statusCode": "ACTIVE"})
-    workspace.should.have.key("workspaceId").equals(workspace_id)
+    assert "alias" in workspace
+    assert "arn" in workspace
+    assert "createdAt" in workspace
+    assert "prometheusEndpoint" in workspace
+    assert workspace["status"] == {"statusCode": "ACTIVE"}
+    assert workspace["workspaceId"] == workspace_id
 
 
 @mock_amp
 def test_list_workspaces():
+    my_alias = str(uuid4())[0:6]
     client = boto3.client("amp", region_name="ap-southeast-1")
     client.create_workspace(alias="test")
-    client.create_workspace(alias="another")
-    client.create_workspace()
+    client.create_workspace(alias=my_alias)
 
-    resp = client.list_workspaces()
-    resp.should.have.key("workspaces").length_of(3)
-    resp.shouldnt.have.key("nextToken")
+    spaces = client.list_workspaces(maxResults=1000)["workspaces"]
+    assert len(spaces) >= 2
+    assert "test" in [sp.get("alias") for sp in spaces]
+    assert my_alias in [sp.get("alias") for sp in spaces]
 
-    resp = client.list_workspaces(alias="another")
-    resp.should.have.key("workspaces").length_of(1)
-    resp["workspaces"][0].should.have.key("alias").equals("another")
+    resp = client.list_workspaces(alias=my_alias)
+    assert len(resp["workspaces"]) == 1
+    assert resp["workspaces"][0]["alias"] == my_alias
 
 
 @mock_amp
@@ -62,22 +64,19 @@ def test_list_workspaces__paginated():
 
     # default pagesize is 100
     page1 = client.list_workspaces()
-    page1.should.have.key("workspaces").length_of(100)
-    page1.should.have.key("nextToken")
+    assert len(page1["workspaces"]) == 100
+    assert "nextToken" in page1
 
     # We can ask for a smaller pagesize
     page2 = client.list_workspaces(maxResults=15, nextToken=page1["nextToken"])
-    page2.should.have.key("workspaces").length_of(15)
-    page2.should.have.key("nextToken")
-
-    page3 = client.list_workspaces(maxResults=15, nextToken=page2["nextToken"])
-    page3.should.have.key("workspaces").length_of(10)
-    page3.shouldnt.have.key("nextToken")
+    assert len(page2["workspaces"]) == 15
+    assert "nextToken" in page2
 
     # We could request all of them in one go
-    full_page = client.list_workspaces(maxResults=150)
-    full_page.should.have.key("workspaces").length_of(125)
-    full_page.shouldnt.have.key("nextToken")
+    all_workspaces = client.list_workspaces(maxResults=1000)["workspaces"]
+    length = len(all_workspaces)
+    # We don't know exactly how much workspaces there are, because we are running multiple tests at the same time
+    assert length >= 125
 
 
 @mock_amp
@@ -87,8 +86,7 @@ def test_list_tags_for_resource():
         alias="test", clientToken="mytoken", tags={"t1": "v1", "t2": "v2"}
     )["arn"]
 
-    resp = client.list_tags_for_resource(resourceArn=arn)
-    resp.should.have.key("tags").equals({"t1": "v1", "t2": "v2"})
+    assert get_tags(arn, client) == {"t1": "v1", "t2": "v2"}
 
 
 @mock_amp
@@ -98,12 +96,12 @@ def test_update_workspace_alias():
     workspace_id = client.create_workspace(alias="initial")["workspaceId"]
 
     w = client.describe_workspace(workspaceId=workspace_id)["workspace"]
-    w.should.have.key("alias").equals("initial")
+    assert w["alias"] == "initial"
 
     client.update_workspace_alias(alias="updated", workspaceId=workspace_id)
 
     w = client.describe_workspace(workspaceId=workspace_id)["workspace"]
-    w.should.have.key("alias").equals("updated")
+    assert w["alias"] == "updated"
 
 
 @mock_amp
@@ -119,8 +117,8 @@ def test_delete_workspace():
     with pytest.raises(ClientError) as exc:
         client.describe_workspace(workspaceId=workspace_id)
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal("Workspace not found")
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "Workspace not found"
 
 
 @mock_amp
@@ -133,17 +131,19 @@ def test_tag_resource():
 
     client.tag_resource(resourceArn=arn, tags={"t1": "v1", "t2": "v2"})
 
-    client.list_tags_for_resource(resourceArn=arn)["tags"].should.equal(
-        {"t": "v", "t1": "v1", "t2": "v2"}
+    expected = {"t": "v", "t1": "v1", "t2": "v2"}
+    assert get_tags(arn, client) == expected
+    assert (
+        client.describe_workspace(workspaceId=workspace_id)["workspace"]["tags"]
+        == expected
     )
-    client.describe_workspace(workspaceId=workspace_id)["workspace"][
-        "tags"
-    ].should.equal({"t": "v", "t1": "v1", "t2": "v2"})
 
     client.untag_resource(resourceArn=arn, tagKeys=["t1"])
-    client.list_tags_for_resource(resourceArn=arn)["tags"].should.equal(
-        {"t": "v", "t2": "v2"}
-    )
+    assert get_tags(arn, client) == {"t": "v", "t2": "v2"}
 
     client.untag_resource(resourceArn=arn, tagKeys=["t", "t2"])
-    client.list_tags_for_resource(resourceArn=arn)["tags"].should.equal({})
+    assert get_tags(arn, client) == {}
+
+
+def get_tags(arn, client):
+    return client.list_tags_for_resource(resourceArn=arn)["tags"]
