@@ -1,7 +1,8 @@
-import boto3
 import json
 
-from moto import mock_lambda, mock_cloudformation, mock_apigateway, mock_iam, mock_logs
+import boto3
+
+from moto import mock_apigateway, mock_cloudformation, mock_iam, mock_lambda, mock_logs
 
 template = """{
   "AWSTemplateFormatVersion": "2010-09-09",
@@ -108,7 +109,7 @@ template = """{
             "Arn"
           ]
         },
-        "Runtime": "python2.7",
+        "Runtime": "python3.11",
         "Timeout": 6
       },
       "DependsOn": [
