@@ -1,21 +1,22 @@
-import boto3
 import json
+from unittest import SkipTest
+
+import boto3
 import requests
 
-from moto import mock_apigateway, mock_dynamodb
-from moto import settings
+from moto import mock_apigateway, mock_dynamodb, settings
 from moto.core.models import responses_mock
-from unittest import SkipTest
 
 
 @mock_apigateway
 def test_http_integration():
-    if settings.TEST_SERVER_MODE:
+    if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
     responses_mock.add(
         responses_mock.GET, "http://httpbin.org/robots.txt", body="a fake response"
     )
-
+    registered = responses_mock.registered()
+    assert isinstance(registered, list) and len(registered) > 1
     region_name = "us-west-2"
     client = boto3.client("apigateway", region_name=region_name)
     response = client.create_rest_api(name="my_api", description="this is my api")
@@ -41,6 +42,7 @@ def test_http_integration():
         type="HTTP",
         uri="http://httpbin.org/robots.txt",
         integrationHttpMethod="GET",
+        requestParameters={"integration.request.header.X-Custom": "'Custom'"},
     )
 
     stage_name = "staging"
@@ -50,13 +52,13 @@ def test_http_integration():
         f"https://{api_id}.execute-api.{region_name}.amazonaws.com/{stage_name}"
     )
 
-    requests.get(deploy_url).content.should.equal(b"a fake response")
+    assert requests.get(deploy_url).content == b"a fake response"
 
 
 @mock_apigateway
 @mock_dynamodb
 def test_aws_integration_dynamodb():
-    if settings.TEST_SERVER_MODE:
+    if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
 
     client = boto3.client("apigateway", region_name="us-west-2")
@@ -74,14 +76,14 @@ def test_aws_integration_dynamodb():
         f"https://{api_id}.execute-api.us-west-2.amazonaws.com/{stage_name}",
         json={"TableName": table_name, "Item": {"name": {"S": "the-key"}}},
     )
-    res.status_code.should.equal(200)
-    res.content.should.equal(b"{}")
+    assert res.status_code == 200
+    assert res.content == b"{}"
 
 
 @mock_apigateway
 @mock_dynamodb
 def test_aws_integration_dynamodb_multiple_stages():
-    if settings.TEST_SERVER_MODE:
+    if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
 
     client = boto3.client("apigateway", region_name="us-west-2")
@@ -99,26 +101,26 @@ def test_aws_integration_dynamodb_multiple_stages():
         f"https://{api_id}.execute-api.us-west-2.amazonaws.com/dev",
         json={"TableName": table_name, "Item": {"name": {"S": "the-key"}}},
     )
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
 
     res = requests.put(
         f"https://{api_id}.execute-api.us-west-2.amazonaws.com/staging",
         json={"TableName": table_name, "Item": {"name": {"S": "the-key"}}},
     )
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
 
     # We haven't pushed to prod yet
     res = requests.put(
         f"https://{api_id}.execute-api.us-west-2.amazonaws.com/prod",
         json={"TableName": table_name, "Item": {"name": {"S": "the-key"}}},
     )
-    res.status_code.should.equal(400)
+    assert res.status_code == 400
 
 
 @mock_apigateway
 @mock_dynamodb
 def test_aws_integration_dynamodb_multiple_resources():
-    if settings.TEST_SERVER_MODE:
+    if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Cannot test mock of execute-api.apigateway in ServerMode")
 
     client = boto3.client("apigateway", region_name="us-west-2")
@@ -152,17 +154,34 @@ def test_aws_integration_dynamodb_multiple_resources():
             "Item": {"name": {"S": "the-key"}, "attr2": {"S": "sth"}},
         },
     )
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
 
     # Get item from child resource
     res = requests.get(
         f"https://{api_id}.execute-api.us-west-2.amazonaws.com/dev/item",
         json={"TableName": table_name, "Key": {"name": {"S": "the-key"}}},
     )
-    res.status_code.should.equal(200)
-    json.loads(res.content).should.equal(
-        {"Item": {"name": {"S": "the-key"}, "attr2": {"S": "sth"}}}
+    assert res.status_code == 200
+    assert json.loads(res.content) == {
+        "Item": {"name": {"S": "the-key"}, "attr2": {"S": "sth"}}
+    }
+
+
+@mock_apigateway
+def test_aws_integration_sagemaker():
+    region = "us-west-2"
+    client = boto3.client("apigateway", region_name=region)
+    sagemaker_endpoint = "non-existing"
+    integration_action = f"arn:aws:apigateway:{region}:runtime.sagemaker:path//endpoints/{sagemaker_endpoint}/invocations"
+
+    api_id, resource_id = create_integration_test_api(client, integration_action)
+
+    # We can't invoke Sagemaker
+    # Just verify that the integration action was successful
+    response = client.get_integration(
+        restApiId=api_id, resourceId=resource_id, httpMethod="PUT"
     )
+    assert response["uri"] == integration_action
 
 
 def create_table(dynamodb, table_name):
