@@ -1,8 +1,7 @@
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_appsync
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
@@ -15,19 +14,19 @@ def test_create_graphql_api():
     client = boto3.client("appsync", region_name="ap-southeast-1")
     resp = client.create_graphql_api(name="api1", authenticationType="API_KEY")
 
-    resp.should.have.key("graphqlApi")
+    assert "graphqlApi" in resp
 
     api = resp["graphqlApi"]
-    api.should.have.key("name").equals("api1")
-    api.should.have.key("apiId")
-    api.should.have.key("authenticationType").equals("API_KEY")
-    api.should.have.key("arn").equals(
-        f"arn:aws:appsync:ap-southeast-1:{ACCOUNT_ID}:apis/{api['apiId']}"
+    assert api["name"] == "api1"
+    assert "apiId" in api
+    assert api["authenticationType"] == "API_KEY"
+    assert (
+        api["arn"] == f"arn:aws:appsync:ap-southeast-1:{ACCOUNT_ID}:apis/{api['apiId']}"
     )
-    api.should.have.key("uris").equals({"GRAPHQL": "http://graphql.uri"})
-    api.should.have.key("xrayEnabled").equals(False)
-    api.shouldnt.have.key("additionalAuthenticationProviders")
-    api.shouldnt.have.key("logConfig")
+    assert api["uris"] == {"GRAPHQL": "http://graphql.uri"}
+    assert api["xrayEnabled"] is False
+    assert "additionalAuthenticationProviders" not in api
+    assert "logConfig" not in api
 
 
 @mock_appsync
@@ -44,23 +43,24 @@ def test_create_graphql_api_advanced():
         xrayEnabled=True,
     )
 
-    resp.should.have.key("graphqlApi")
+    assert "graphqlApi" in resp
 
     api = resp["graphqlApi"]
-    api.should.have.key("name").equals("api1")
-    api.should.have.key("apiId")
-    api.should.have.key("authenticationType").equals("API_KEY")
-    api.should.have.key("arn").equals(
-        f"arn:aws:appsync:ap-southeast-1:{ACCOUNT_ID}:apis/{api['apiId']}"
+    assert api["name"] == "api1"
+    assert "apiId" in api
+    assert api["authenticationType"] == "API_KEY"
+    assert (
+        api["arn"] == f"arn:aws:appsync:ap-southeast-1:{ACCOUNT_ID}:apis/{api['apiId']}"
     )
-    api.should.have.key("uris").equals({"GRAPHQL": "http://graphql.uri"})
-    api.should.have.key("additionalAuthenticationProviders").equals(
-        [{"authenticationType": "API_KEY"}]
-    )
-    api.should.have.key("logConfig").equals(
-        {"cloudWatchLogsRoleArn": "arn:aws:cloudwatch:role", "fieldLogLevel": "ERROR"}
-    )
-    api.should.have.key("xrayEnabled").equals(True)
+    assert api["uris"] == {"GRAPHQL": "http://graphql.uri"}
+    assert api["additionalAuthenticationProviders"] == [
+        {"authenticationType": "API_KEY"}
+    ]
+    assert api["logConfig"] == {
+        "cloudWatchLogsRoleArn": "arn:aws:cloudwatch:role",
+        "fieldLogLevel": "ERROR",
+    }
+    assert api["xrayEnabled"] is True
 
 
 @mock_appsync
@@ -71,12 +71,12 @@ def test_get_graphql_api():
     ]["apiId"]
 
     resp = client.get_graphql_api(apiId=api_id)
-    resp.should.have.key("graphqlApi")
+    assert "graphqlApi" in resp
 
     api = resp["graphqlApi"]
-    api.should.have.key("name").equals("api1")
-    api.should.have.key("apiId")
-    api.should.have.key("authenticationType").equals("API_KEY")
+    assert api["name"] == "api1"
+    assert "apiId" in api
+    assert api["authenticationType"] == "API_KEY"
 
 
 @mock_appsync
@@ -104,22 +104,22 @@ def test_update_graphql_api():
 
     graphql_api = client.get_graphql_api(apiId=api_id)["graphqlApi"]
 
-    graphql_api.should.have.key("name").equals("api2")
-    graphql_api.should.have.key("authenticationType").equals("AWS_IAM")
-    graphql_api.should.have.key("arn").equals(
-        f"arn:aws:appsync:ap-southeast-1:{ACCOUNT_ID}:apis/{graphql_api['apiId']}"
+    assert graphql_api["name"] == "api2"
+    assert graphql_api["authenticationType"] == "AWS_IAM"
+    assert (
+        graphql_api["arn"]
+        == f"arn:aws:appsync:ap-southeast-1:{ACCOUNT_ID}:apis/{graphql_api['apiId']}"
     )
-    graphql_api.should.have.key("logConfig").equals(
-        {"cloudWatchLogsRoleArn": "arn:aws:cloudwatch:role", "fieldLogLevel": "ERROR"}
-    )
-    graphql_api.should.have.key("userPoolConfig").equals(
-        {
-            "awsRegion": "us-east-1",
-            "defaultAction": "DENY",
-            "userPoolId": "us-east-1_391729ed4a2d430a9d2abadecfc1ab86",
-        }
-    )
-    graphql_api.should.have.key("xrayEnabled").equals(True)
+    assert graphql_api["logConfig"] == {
+        "cloudWatchLogsRoleArn": "arn:aws:cloudwatch:role",
+        "fieldLogLevel": "ERROR",
+    }
+    assert graphql_api["userPoolConfig"] == {
+        "awsRegion": "us-east-1",
+        "defaultAction": "DENY",
+        "userPoolId": "us-east-1_391729ed4a2d430a9d2abadecfc1ab86",
+    }
+    assert graphql_api["xrayEnabled"] is True
 
 
 @mock_appsync
@@ -130,8 +130,8 @@ def test_get_graphql_api_unknown():
         client.get_graphql_api(apiId="unknown")
     err = exc.value.response["Error"]
 
-    err["Code"].should.equal("NotFoundException")
-    err["Message"].should.equal("GraphQL API unknown not found.")
+    assert err["Code"] == "NotFoundException"
+    assert err["Message"] == "GraphQL API unknown not found."
 
 
 @mock_appsync
@@ -143,22 +143,22 @@ def test_delete_graphql_api():
     ]["apiId"]
 
     resp = client.list_graphql_apis()
-    resp.should.have.key("graphqlApis").length_of(1)
+    assert len(resp["graphqlApis"]) == 1
 
     client.delete_graphql_api(apiId=api_id)
 
     resp = client.list_graphql_apis()
-    resp.should.have.key("graphqlApis").length_of(0)
+    assert len(resp["graphqlApis"]) == 0
 
 
 @mock_appsync
 def test_list_graphql_apis():
     client = boto3.client("appsync", region_name="ap-southeast-1")
     resp = client.list_graphql_apis()
-    resp.should.have.key("graphqlApis").equals([])
+    assert resp["graphqlApis"] == []
 
     for _ in range(3):
         client.create_graphql_api(name="api1", authenticationType="API_KEY")
 
     resp = client.list_graphql_apis()
-    resp.should.have.key("graphqlApis").length_of(3)
+    assert len(resp["graphqlApis"]) == 3
