@@ -1,9 +1,11 @@
+from unittest import TestCase
+
 import boto3
 
 from moto import mock_autoscaling
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from tests import EXAMPLE_AMI_ID
-from unittest import TestCase
+
 from .utils import setup_networking
 
 
@@ -20,7 +22,7 @@ class TestAutoScalingGroup(TestCase):
         )
 
     def test_create_autoscaling_groups_defaults(self):
-        """Test with the minimum inputs and check that all of the proper defaults
+        """Test with the minimum inputs and check that all proper defaults
         are assigned for the other attributes"""
 
         self._create_group(name="tester_group")
