@@ -1,12 +1,13 @@
 """Unit tests for lambda-supported APIs."""
+from uuid import uuid4
+
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_lambda
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-from uuid import uuid4
+
 from .utilities import (
     get_role_name,
     get_test_zip_file1,
@@ -15,6 +16,7 @@ from .utilities import (
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
+PYTHON_VERSION = "python3.11"
 
 
 @mock_lambda
@@ -24,7 +26,7 @@ def test_create_alias():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -52,7 +54,7 @@ def test_create_alias_with_routing_config():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -78,7 +80,7 @@ def test_create_alias_using_function_arn():
 
     fn = client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -104,7 +106,7 @@ def test_delete_alias():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -129,7 +131,7 @@ def test_get_alias():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -159,14 +161,14 @@ def test_aliases_are_unique_per_function():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
     )
     client.create_function(
         FunctionName=function_name2,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -195,9 +197,9 @@ def test_aliases_are_unique_per_function():
 
     err = exc.value.response["Error"]
     assert err["Code"] == "ConflictException"
-    assert (
-        err["Message"]
-        == f"Alias already exists: arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
+    assert err["Message"] == (
+        f"Alias already exists: arn:aws:lambda:us-west-1:{ACCOUNT_ID}"
+        f":function:{function_name}:alias1"
     )
 
 
@@ -208,7 +210,7 @@ def test_get_alias_using_function_arn():
 
     fn = client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -238,7 +240,7 @@ def test_get_alias_using_alias_arn():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -268,7 +270,7 @@ def test_get_unknown_alias():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -278,9 +280,9 @@ def test_get_unknown_alias():
         client.get_alias(FunctionName=function_name, Name="unknown")
     err = exc.value.response["Error"]
     assert err["Code"] == "ResourceNotFoundException"
-    assert (
-        err["Message"]
-        == f"Cannot find alias arn: arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:unknown"
+    assert err["Message"] == (
+        f"Cannot find alias arn: arn:aws:lambda:us-west-1:{ACCOUNT_ID}"
+        f":function:{function_name}:unknown"
     )
 
 
@@ -291,7 +293,7 @@ def test_update_alias():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -331,7 +333,7 @@ def test_update_alias_errors_if_version_doesnt_exist():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -363,7 +365,7 @@ def test_update_alias_routingconfig():
 
     client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -393,13 +395,15 @@ def test_update_alias_routingconfig():
 
 
 @mock_lambda
-def test_get_function_using_alias():
+@pytest.mark.parametrize("qualifierIn", ["NAME", "SEPARATE", "BOTH"])
+def test_get_function_using_alias(qualifierIn):
     client = boto3.client("lambda", region_name="us-east-2")
     fn_name = str(uuid4())[0:6]
+    fn_qualifier = "live"
 
     client.create_function(
         FunctionName=fn_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -407,9 +411,20 @@ def test_get_function_using_alias():
     client.publish_version(FunctionName=fn_name)
     client.publish_version(FunctionName=fn_name)
 
-    client.create_alias(FunctionName=fn_name, Name="live", FunctionVersion="1")
+    client.create_alias(FunctionName=fn_name, Name=fn_qualifier, FunctionVersion="1")
 
-    fn = client.get_function(FunctionName=fn_name, Qualifier="live")["Configuration"]
+    if qualifierIn == "NAME":
+        fn = client.get_function(FunctionName=f"{fn_name}:{fn_qualifier}")[
+            "Configuration"
+        ]
+    elif qualifierIn == "SEPARATE":
+        fn = client.get_function(FunctionName=fn_name, Qualifier=fn_qualifier)[
+            "Configuration"
+        ]
+    elif qualifierIn == "BOTH":
+        fn = client.get_function(
+            FunctionName=f"{fn_name}:{fn_qualifier}", Qualifier=fn_qualifier
+        )["Configuration"]
     assert (
         fn["FunctionArn"]
         == f"arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{fn_name}:1"
