@@ -1,9 +1,14 @@
+from uuid import uuid4
+
 import boto3
 import pytest
 from botocore.exceptions import ClientError
+
 from moto import mock_lambda
-from uuid import uuid4
-from .utilities import get_test_zip_file1, get_role_name
+
+from .utilities import get_role_name, get_test_zip_file1
+
+PYTHON_VERSION = "python3.11"
 
 
 @mock_lambda
@@ -13,7 +18,7 @@ def test_create_function_url_config(key):
     function_name = str(uuid4())[0:6]
     fxn = client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -39,7 +44,7 @@ def test_create_function_url_config_with_cors():
     function_name = str(uuid4())[0:6]
     fxn = client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -74,7 +79,7 @@ def test_update_function_url_config_with_cors():
     function_name = str(uuid4())[0:6]
     fxn = client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
@@ -107,7 +112,7 @@ def test_delete_function_url_config(key):
     function_name = str(uuid4())[0:6]
     fxn = client.create_function(
         FunctionName=function_name,
-        Runtime="python3.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file1()},
