@@ -1,14 +1,18 @@
+import os
+from unittest import SkipTest, mock
+from uuid import uuid4
+
 import boto3
 import pytest
-
 from botocore.exceptions import ClientError
 from freezegun import freeze_time
-from moto import mock_lambda, mock_s3
+
+from moto import mock_lambda, mock_s3, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-from uuid import uuid4
 
 from .utilities import get_role_name, get_test_zip_file1
 
+PYTHON_VERSION = "python3.11"
 _lambda_region = "us-west-2"
 boto3.setup_default_session(region_name=_lambda_region)
 
@@ -30,6 +34,20 @@ def test_publish_lambda_layers__without_content():
     assert err["Message"] == "Missing Content"
 
 
+@mock_lambda
+@mock.patch.dict(os.environ, {"VALIDATE_LAMBDA_S3": "false"})
+def test_publish_layer_with_unknown_s3_file():
+    if not settings.TEST_DECORATOR_MODE:
+        raise SkipTest("Can only set env var in DecoratorMode")
+    conn = boto3.client("lambda", _lambda_region)
+    content = conn.publish_layer_version(
+        LayerName=str(uuid4())[0:6],
+        Content=dict(S3Bucket="my-bucket", S3Key="my-key.zip"),
+    )["Content"]
+    assert content["CodeSha256"] == ""
+    assert content["CodeSize"] == 0
+
+
 @mock_lambda
 @mock_s3
 @freeze_time("2015-01-01 00:00:00")
@@ -87,7 +105,7 @@ def test_get_lambda_layers():
     function_name = str(uuid4())[0:6]
     conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime=PYTHON_VERSION,
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"S3Bucket": bucket_name, "S3Key": "test.zip"},
@@ -115,10 +133,11 @@ def test_get_lambda_layers():
     assert result["LayerVersions"] == []
 
     # Test create function with non existant layer version
+    function_name = str(uuid4())[0:6]  # Must be different than above
     with pytest.raises(ClientError) as exc:
         conn.create_function(
             FunctionName=function_name,
-            Runtime="python2.7",
+            Runtime=PYTHON_VERSION,
             Role=get_role_name(),
             Handler="lambda_function.lambda_handler",
             Code={"S3Bucket": bucket_name, "S3Key": "test.zip"},
