@@ -1,9 +1,10 @@
-import boto3
-import sure  # noqa # pylint: disable=unused-import
-from moto import mock_batch, mock_iam, mock_ec2, mock_ecs, mock_cloudformation
 import json
 from uuid import uuid4
 
+import boto3
+
+from moto import mock_batch, mock_cloudformation, mock_ec2, mock_ecs, mock_iam
+
 DEFAULT_REGION = "eu-central-1"
 
 
@@ -86,17 +87,12 @@ def test_create_env_cf():
     ]
 
     stack_resources = cf_conn.list_stack_resources(StackName=stack_id)
+    summary = stack_resources["StackResourceSummaries"][0]
 
-    stack_resources["StackResourceSummaries"][0]["ResourceStatus"].should.equal(
-        "CREATE_COMPLETE"
-    )
+    assert summary["ResourceStatus"] == "CREATE_COMPLETE"
     # Spot checks on the ARN
-    stack_resources["StackResourceSummaries"][0]["PhysicalResourceId"].startswith(
-        "arn:aws:batch:"
-    )
-    stack_resources["StackResourceSummaries"][0]["PhysicalResourceId"].should.contain(
-        stack_name
-    )
+    assert "arn:aws:batch:" in summary["PhysicalResourceId"]
+    assert stack_name in summary["PhysicalResourceId"]
 
 
 @mock_cloudformation()
@@ -150,7 +146,7 @@ def test_create_job_queue_cf():
     ]
 
     stack_resources = cf_conn.list_stack_resources(StackName=stack_id)
-    len(stack_resources["StackResourceSummaries"]).should.equal(2)
+    assert len(stack_resources["StackResourceSummaries"]) == 2
 
     job_queue_resource = list(
         filter(
@@ -159,11 +155,11 @@ def test_create_job_queue_cf():
         )
     )[0]
 
-    job_queue_resource["ResourceStatus"].should.equal("CREATE_COMPLETE")
+    assert job_queue_resource["ResourceStatus"] == "CREATE_COMPLETE"
     # Spot checks on the ARN
     job_queue_resource["PhysicalResourceId"].startswith("arn:aws:batch:")
-    job_queue_resource["PhysicalResourceId"].should.contain(stack_name)
-    job_queue_resource["PhysicalResourceId"].should.contain("job-queue/")
+    assert stack_name in job_queue_resource["PhysicalResourceId"]
+    assert "job-queue/" in job_queue_resource["PhysicalResourceId"]
 
 
 @mock_cloudformation()
@@ -242,7 +238,7 @@ def test_create_job_def_cf():
     ]
 
     stack_resources = cf_conn.list_stack_resources(StackName=stack_id)
-    len(stack_resources["StackResourceSummaries"]).should.equal(3)
+    assert len(stack_resources["StackResourceSummaries"]) == 3
 
     job_def_resource = list(
         filter(
@@ -251,11 +247,11 @@ def test_create_job_def_cf():
         )
     )[0]
 
-    job_def_resource["ResourceStatus"].should.equal("CREATE_COMPLETE")
+    assert job_def_resource["ResourceStatus"] == "CREATE_COMPLETE"
     # Spot checks on the ARN
     job_def_resource["PhysicalResourceId"].startswith("arn:aws:batch:")
-    job_def_resource["PhysicalResourceId"].should.contain(f"{stack_name}-JobDef")
-    job_def_resource["PhysicalResourceId"].should.contain("job-definition/")
+    assert f"{stack_name}-JobDef" in job_def_resource["PhysicalResourceId"]
+    assert "job-definition/" in job_def_resource["PhysicalResourceId"]
 
     # Test the linux parameter device host path
     # This ensures that batch is parsing the parameter dictionaries
@@ -269,4 +265,4 @@ def test_create_job_def_cf():
         "containerProperties"
     ]["linuxParameters"]["devices"][0]["hostPath"]
 
-    job_def_linux_device_host_path.should.equal("test-path")
+    assert job_def_linux_device_host_path == "test-path"
