@@ -1,9 +1,12 @@
-from . import _get_clients, _setup
+from uuid import uuid4
+
 import boto3
 import pytest
 from botocore.exceptions import ClientError
-from moto import mock_batch, mock_iam, mock_ec2, mock_ecs
-from uuid import uuid4
+
+from moto import mock_batch, mock_ec2, mock_ecs, mock_iam
+
+from . import _get_clients, _setup
 
 
 @mock_ec2
