@@ -1,7 +1,8 @@
-import boto3
-from moto import mock_cloudformation, mock_ecs, mock_autoscaling, mock_s3
 import json
 
+import boto3
+
+from moto import mock_autoscaling, mock_cloudformation, mock_ecs, mock_s3
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from tests import EXAMPLE_AMI_ID
 
@@ -112,9 +113,7 @@ def test_create_stack_with_depends_on():
 
     ecs = boto3.client("ecs", region_name="us-east-1")
     cluster_arn = ecs.list_clusters()["clusterArns"][0]
-    assert cluster_arn == "arn:aws:ecs:us-east-1:{}:cluster/test-cluster".format(
-        ACCOUNT_ID
-    )
+    assert cluster_arn == f"arn:aws:ecs:us-east-1:{ACCOUNT_ID}:cluster/test-cluster"
 
 
 @mock_cloudformation
