@@ -1,9 +1,11 @@
 import boto3
+import pytest
 from botocore.exceptions import ClientError
+
 from moto import mock_cloudfront
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+
 from . import cloudfront_test_scaffolding as scaffold
-import pytest
 
 
 @mock_cloudfront
@@ -434,9 +436,10 @@ def test_create_distribution_with_invalid_s3_bucket():
 
 
 @mock_cloudfront
-def test_create_distribution_custom_config():
+@pytest.mark.parametrize("ssl_protocols", (["TLSv1"], ["TLSv1", "SSLv3"]))
+def test_create_distribution_custom_config(ssl_protocols):
     client = boto3.client("cloudfront", region_name="us-west-1")
-    config = scaffold.example_dist_custom_config("ref")
+    config = scaffold.example_dist_custom_config("ref", ssl_protocols)
 
     dist = client.create_distribution(DistributionConfig=config)["Distribution"][
         "DistributionConfig"
@@ -450,8 +453,8 @@ def test_create_distribution_custom_config():
     assert custom_config["OriginKeepaliveTimeout"] == 10
     assert custom_config["OriginProtocolPolicy"] == "http-only"
     assert custom_config["OriginSslProtocols"] == {
-        "Items": ["TLSv1", "SSLv3"],
-        "Quantity": 2,
+        "Items": ssl_protocols,
+        "Quantity": len(ssl_protocols),
     }
 
 
