@@ -1,14 +1,16 @@
-from .test_config_rules import managed_config_rule, TEST_REGION
-from botocore.exceptions import ClientError
-from moto import mock_config, mock_iam, mock_lambda
-from moto.core import ACCOUNT_ID
+import json
 from io import BytesIO
 from uuid import uuid4
-from zipfile import ZipFile, ZIP_DEFLATED
+from zipfile import ZIP_DEFLATED, ZipFile
 
 import boto3
-import json
 import pytest
+from botocore.exceptions import ClientError
+
+from moto import mock_config, mock_iam, mock_lambda
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+
+from .test_config_rules import TEST_REGION, managed_config_rule
 
 
 def custom_config_rule(func_name="test_config_rule"):
@@ -65,7 +67,7 @@ def create_lambda_for_config_rule():
     lambda_client = boto3.client("lambda", region_name=TEST_REGION)
     lambda_client.create_function(
         FunctionName="test_config_rule",
-        Runtime="python3.8",
+        Runtime="python3.11",
         Role=lambda_role,
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": zipped_lambda_function()},
