@@ -1,8 +1,10 @@
+from typing import Any
 from unittest.mock import patch
-from moto.server import main, create_backend_app, DomainDispatcherApplication
+
+from moto.server import DomainDispatcherApplication, create_backend_app, main
 
 
-def test_wrong_arguments():
+def test_wrong_arguments() -> None:
     try:
         main(["name", "test1", "test2", "test3"])
         assert False, (
@@ -14,7 +16,7 @@ def test_wrong_arguments():
 
 
 @patch("moto.server.run_simple")
-def test_right_arguments(run_simple):
+def test_right_arguments(run_simple: Any) -> None:  # type: ignore[misc]
     main(["s3"])
     func_call = run_simple.call_args[0]
     assert func_call[0] == "127.0.0.1"
@@ -22,14 +24,14 @@ def test_right_arguments(run_simple):
 
 
 @patch("moto.server.run_simple")
-def test_port_argument(run_simple):
+def test_port_argument(run_simple: Any) -> None:  # type: ignore[misc]
     main(["s3", "--port", "8080"])
     func_call = run_simple.call_args[0]
     assert func_call[0] == "127.0.0.1"
     assert func_call[1] == 8080
 
 
-def test_domain_dispatched():
+def test_domain_dispatched() -> None:
     dispatcher = DomainDispatcherApplication(create_backend_app)
     backend_app = dispatcher.get_application(
         {"HTTP_HOST": "email.us-east1.amazonaws.com"}
@@ -38,9 +40,9 @@ def test_domain_dispatched():
     assert keys[0] == "EmailResponse.dispatch"
 
 
-def test_domain_dispatched_with_service():
+def test_domain_dispatched_with_service() -> None:
     # If we pass a particular service, always return that.
     dispatcher = DomainDispatcherApplication(create_backend_app, service="s3")
     backend_app = dispatcher.get_application({"HTTP_HOST": "s3.us-east1.amazonaws.com"})
     keys = set(backend_app.view_functions.keys())
-    assert "S3Response.key_response" in keys
+    assert "moto.s3.responses.key_response" in keys
