@@ -6,14 +6,14 @@ The logic to check the details of VPCs and Subnets is shared between the
 from datetime import datetime, timezone
 
 import boto3
-from botocore.exceptions import ClientError
 import pytest
+from botocore.exceptions import ClientError
 
 from moto import mock_ds
-from moto.core.utils import get_random_hex
 from moto.ec2 import mock_ec2
+from moto.moto_api._internal import mock_random
 
-from .test_ds_simple_ad_directory import TEST_REGION, create_vpc, create_subnets
+from .test_ds_simple_ad_directory import TEST_REGION, create_subnets, create_vpc
 
 
 def create_test_ad_connector(
@@ -37,7 +37,7 @@ def create_test_ad_connector(
         tags = []
 
     result = ds_client.connect_directory(
-        Name=f"test-{get_random_hex(6)}.test",
+        Name=f"test-{mock_random.get_random_hex(6)}.test",
         Password="4ADConnectPassword",
         Size="Small",
         ConnectSettings={
@@ -59,7 +59,7 @@ def test_ds_connect_directory_validations():
     this verifies that it is invoked from connect_directory().
     """
     client = boto3.client("ds", region_name=TEST_REGION)
-    random_num = get_random_hex(6)
+    random_num = mock_random.get_random_hex(6)
 
     # Verify ValidationException error messages are accumulated properly.
     bad_name = f"bad_name_{random_num}"
