@@ -1,11 +1,15 @@
+from unittest import SkipTest
+
 import boto3
 import botocore
 import pytest
 from boto3.dynamodb.conditions import Key
 from botocore.exceptions import ClientError
-from unittest import SkipTest
+
 from moto import mock_dynamodb, settings
 
+from .. import dynamodb_aws_verified
+
 table_schema = {
     "KeySchema": [{"AttributeName": "partitionKey", "KeyType": "HASH"}],
     "GlobalSecondaryIndexes": [
@@ -144,7 +148,7 @@ def test_empty_expressionattributenames_with_empty_projection():
     table = ddb.Table("test-table")
     with pytest.raises(ClientError) as exc:
         table.get_item(
-            Key={"id": "my_id"}, ProjectionExpression="", ExpressionAttributeNames={}
+            Key={"id": "my_id"}, ProjectionExpression="a", ExpressionAttributeNames={}
         )
     err = exc.value.response["Error"]
     assert err["Code"] == "ValidationException"
@@ -493,80 +497,6 @@ def test_creating_table_with_0_global_indexes():
     )
 
 
-@mock_dynamodb
-def test_multiple_transactions_on_same_item():
-    schema = {
-        "KeySchema": [{"AttributeName": "id", "KeyType": "HASH"}],
-        "AttributeDefinitions": [{"AttributeName": "id", "AttributeType": "S"}],
-    }
-    dynamodb = boto3.client("dynamodb", region_name="us-east-1")
-    dynamodb.create_table(
-        TableName="test-table", BillingMode="PAY_PER_REQUEST", **schema
-    )
-    # Insert an item
-    dynamodb.put_item(TableName="test-table", Item={"id": {"S": "foo"}})
-
-    def update_email_transact(email):
-        return {
-            "Update": {
-                "Key": {"id": {"S": "foo"}},
-                "TableName": "test-table",
-                "UpdateExpression": "SET #e = :v",
-                "ExpressionAttributeNames": {"#e": "email_address"},
-                "ExpressionAttributeValues": {":v": {"S": email}},
-            }
-        }
-
-    with pytest.raises(ClientError) as exc:
-        dynamodb.transact_write_items(
-            TransactItems=[
-                update_email_transact("test1@moto.com"),
-                update_email_transact("test2@moto.com"),
-            ]
-        )
-    err = exc.value.response["Error"]
-    assert err["Code"] == "ValidationException"
-    assert (
-        err["Message"]
-        == "Transaction request cannot include multiple operations on one item"
-    )
-
-
-@mock_dynamodb
-def test_transact_write_items__too_many_transactions():
-    schema = {
-        "KeySchema": [{"AttributeName": "pk", "KeyType": "HASH"}],
-        "AttributeDefinitions": [{"AttributeName": "pk", "AttributeType": "S"}],
-    }
-    dynamodb = boto3.client("dynamodb", region_name="us-east-1")
-    dynamodb.create_table(
-        TableName="test-table", BillingMode="PAY_PER_REQUEST", **schema
-    )
-
-    def update_email_transact(email):
-        return {
-            "Put": {
-                "TableName": "test-table",
-                "Item": {"pk": {"S": ":v"}},
-                "ExpressionAttributeValues": {":v": {"S": email}},
-            }
-        }
-
-    update_email_transact("test1@moto.com")
-    with pytest.raises(ClientError) as exc:
-        dynamodb.transact_write_items(
-            TransactItems=[
-                update_email_transact(f"test{idx}@moto.com") for idx in range(101)
-            ]
-        )
-    err = exc.value.response["Error"]
-    assert err["Code"] == "ValidationException"
-    assert (
-        err["Message"]
-        == "1 validation error detected at 'transactItems' failed to satisfy constraint: Member must have length less than or equal to 100."
-    )
-
-
 @mock_dynamodb
 def test_update_item_non_existent_table():
     client = boto3.client("dynamodb", region_name="us-west-2")
@@ -673,6 +603,48 @@ def test_put_item_empty_set():
     )
 
 
+@mock_dynamodb
+def test_put_item_returns_old_item():
+    dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
+    table = dynamodb.create_table(
+        TableName="test-table",
+        KeySchema=[{"AttributeName": "pk", "KeyType": "HASH"}],
+        AttributeDefinitions=[{"AttributeName": "pk", "AttributeType": "S"}],
+        BillingMode="PAY_PER_REQUEST",
+    )
+
+    table.put_item(Item={"pk": "foo", "bar": "baz"})
+
+    with pytest.raises(ClientError) as exc:
+        table.put_item(
+            Item={"pk": "foo", "bar": "quuz"},
+            ConditionExpression="attribute_not_exists(pk)",
+        )
+    resp = exc.value.response
+    assert resp["Error"] == {
+        "Message": "The conditional request failed",
+        "Code": "ConditionalCheckFailedException",
+    }
+    assert resp["message"] == "The conditional request failed"
+    assert "Item" not in resp
+
+    table.put_item(Item={"pk": "foo", "bar": "baz"})
+
+    with pytest.raises(ClientError) as exc:
+        table.put_item(
+            Item={"pk": "foo", "bar": "quuz"},
+            ReturnValuesOnConditionCheckFailure="ALL_OLD",
+            ConditionExpression="attribute_not_exists(pk)",
+        )
+    resp = exc.value.response
+    assert resp["Error"] == {
+        "Message": "The conditional request failed",
+        "Code": "ConditionalCheckFailedException",
+    }
+    assert "message" not in resp
+    assert resp["Item"] == {"pk": {"S": "foo"}, "bar": {"S": "baz"}}
+
+
 @mock_dynamodb
 def test_update_expression_with_trailing_comma():
     resource = boto3.resource(service_name="dynamodb", region_name="us-east-1")
@@ -770,82 +742,6 @@ def test_query_begins_with_without_brackets():
     assert err["Code"] == "ValidationException"
 
 
-@mock_dynamodb
-def test_transact_write_items_multiple_operations_fail():
-    # Setup
-    schema = {
-        "KeySchema": [{"AttributeName": "id", "KeyType": "HASH"}],
-        "AttributeDefinitions": [{"AttributeName": "id", "AttributeType": "S"}],
-    }
-    dynamodb = boto3.client("dynamodb", region_name="us-east-1")
-    table_name = "test-table"
-    dynamodb.create_table(TableName=table_name, BillingMode="PAY_PER_REQUEST", **schema)
-
-    # Execute
-    with pytest.raises(ClientError) as exc:
-        dynamodb.transact_write_items(
-            TransactItems=[
-                {
-                    "Put": {
-                        "Item": {"id": {"S": "test"}},
-                        "TableName": table_name,
-                    },
-                    "Delete": {
-                        "Key": {"id": {"S": "test"}},
-                        "TableName": table_name,
-                    },
-                }
-            ]
-        )
-    # Verify
-    err = exc.value.response["Error"]
-    assert err["Code"] == "ValidationException"
-    assert (
-        err["Message"]
-        == "TransactItems can only contain one of Check, Put, Update or Delete"
-    )
-
-
-@mock_dynamodb
-def test_transact_write_items_with_empty_gsi_key():
-    client = boto3.client("dynamodb", "us-east-2")
-
-    client.create_table(
-        TableName="test_table",
-        KeySchema=[{"AttributeName": "unique_code", "KeyType": "HASH"}],
-        AttributeDefinitions=[
-            {"AttributeName": "unique_code", "AttributeType": "S"},
-            {"AttributeName": "unique_id", "AttributeType": "S"},
-        ],
-        GlobalSecondaryIndexes=[
-            {
-                "IndexName": "gsi_index",
-                "KeySchema": [{"AttributeName": "unique_id", "KeyType": "HASH"}],
-                "Projection": {"ProjectionType": "ALL"},
-            }
-        ],
-        ProvisionedThroughput={"ReadCapacityUnits": 5, "WriteCapacityUnits": 5},
-    )
-
-    transact_items = [
-        {
-            "Put": {
-                "Item": {"unique_code": {"S": "some code"}, "unique_id": {"S": ""}},
-                "TableName": "test_table",
-            }
-        }
-    ]
-
-    with pytest.raises(ClientError) as exc:
-        client.transact_write_items(TransactItems=transact_items)
-    err = exc.value.response["Error"]
-    assert err["Code"] == "ValidationException"
-    assert (
-        err["Message"]
-        == "One or more parameter values are not valid. A value specified for a secondary index key is not supported. The AttributeValue for a key attribute cannot contain an empty string value. IndexName: gsi_index, IndexKey: unique_id"
-    )
-
-
 @mock_dynamodb
 def test_update_primary_key_with_sortkey():
     dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
@@ -1067,3 +963,132 @@ def test_list_append_errors_for_unknown_attribute_value():
         ExpressionAttributeValues={":i": {"L": [{"S": "bar2"}]}},
         ReturnValues="UPDATED_NEW",
     )
+
+
+@mock_dynamodb
+def test_query_with_empty_filter_expression():
+    ddb = boto3.resource("dynamodb", region_name="us-east-1")
+    ddb.create_table(
+        TableName="test-table", BillingMode="PAY_PER_REQUEST", **table_schema
+    )
+    table = ddb.Table("test-table")
+    with pytest.raises(ClientError) as exc:
+        table.query(
+            KeyConditionExpression="partitionKey = sth", ProjectionExpression=""
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"]
+        == "Invalid ProjectionExpression: The expression can not be empty;"
+    )
+
+    with pytest.raises(ClientError) as exc:
+        table.query(KeyConditionExpression="partitionKey = sth", FilterExpression="")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"] == "Invalid FilterExpression: The expression can not be empty;"
+    )
+
+
+@mock_dynamodb
+def test_query_with_missing_expression_attribute():
+    ddb = boto3.resource("dynamodb", region_name="us-west-2")
+    ddb.create_table(TableName="test", BillingMode="PAY_PER_REQUEST", **table_schema)
+    client = boto3.client("dynamodb", region_name="us-west-2")
+    with pytest.raises(ClientError) as exc:
+        client.query(
+            TableName="test",
+            KeyConditionExpression="#part_key=some_value",
+            ExpressionAttributeNames={"#part_key": "partitionKey"},
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"]
+        == "Invalid condition in KeyConditionExpression: Multiple attribute names used in one condition"
+    )
+
+
+@pytest.mark.aws_verified
+@dynamodb_aws_verified()
+def test_update_item_returns_old_item(table_name=None):
+    dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
+    table = dynamodb.Table(table_name)
+    table.put_item(Item={"pk": "mark", "lock": {"acquired_at": 123}})
+
+    with pytest.raises(ClientError) as exc:
+        table.update_item(
+            Key={"pk": "mark"},
+            UpdateExpression="set #lock = :lock",
+            ExpressionAttributeNames={
+                "#lock": "lock",
+                "#acquired_at": "acquired_at",
+            },
+            ExpressionAttributeValues={":lock": {"acquired_at": 124}},
+            ConditionExpression="attribute_not_exists(#lock.#acquired_at)",
+        )
+    resp = exc.value.response
+    assert resp["Error"] == {
+        "Message": "The conditional request failed",
+        "Code": "ConditionalCheckFailedException",
+    }
+    assert resp["message"] == "The conditional request failed"
+    assert "Item" not in resp
+
+    with pytest.raises(ClientError) as exc:
+        table.update_item(
+            Key={"pk": "mark"},
+            UpdateExpression="set #lock = :lock",
+            ExpressionAttributeNames={
+                "#lock": "lock",
+                "#acquired_at": "acquired_at",
+            },
+            ExpressionAttributeValues={":lock": {"acquired_at": 123}},
+            ReturnValuesOnConditionCheckFailure="ALL_OLD",
+            ConditionExpression="attribute_not_exists(#lock.#acquired_at)",
+        )
+    resp = exc.value.response
+    assert resp["Error"] == {
+        "Message": "The conditional request failed",
+        "Code": "ConditionalCheckFailedException",
+    }
+    assert "message" not in resp
+    assert resp["Item"] == {
+        "lock": {"M": {"acquired_at": {"N": "123"}}},
+        "pk": {"S": "mark"},
+    }
+
+
+@pytest.mark.aws_verified
+@dynamodb_aws_verified()
+def test_scan_with_missing_value(table_name=None):
+    dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
+    table = dynamodb.Table(table_name)
+
+    with pytest.raises(ClientError) as exc:
+        table.scan(
+            FilterExpression="attr = loc",
+            # Missing ':'
+            ExpressionAttributeValues={"loc": "sth"},
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"]
+        == 'ExpressionAttributeValues contains invalid key: Syntax error; key: "loc"'
+    )
+
+    with pytest.raises(ClientError) as exc:
+        table.query(
+            KeyConditionExpression="attr = loc",
+            # Missing ':'
+            ExpressionAttributeValues={"loc": "sth"},
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"]
+        == 'ExpressionAttributeValues contains invalid key: Syntax error; key: "loc"'
+    )
