@@ -1,12 +1,12 @@
 from decimal import Decimal
+from uuid import uuid4
 
 import boto3
+import pytest
 from boto3.dynamodb.conditions import Key
 from botocore.exceptions import ClientError
-import pytest
 
 from moto import mock_dynamodb
-from uuid import uuid4
 
 
 @mock_dynamodb
@@ -794,6 +794,7 @@ def test_boto3_query_gsi_range_comparison():
         ScanIndexForward=True,
         IndexName="TestGSI",
     )
+    assert results["ScannedCount"] == 3
     expected = ["456", "789", "123"]
     for index, item in enumerate(results["Items"]):
         assert item["subject"] == expected[index]
@@ -1077,6 +1078,7 @@ def test_query_pagination():
 
     page1 = table.query(KeyConditionExpression=Key("forum_name").eq("the-key"), Limit=6)
     assert page1["Count"] == 6
+    assert page1["ScannedCount"] == 6
     assert len(page1["Items"]) == 6
 
     page2 = table.query(
@@ -1085,6 +1087,7 @@ def test_query_pagination():
         ExclusiveStartKey=page1["LastEvaluatedKey"],
     )
     assert page2["Count"] == 4
+    assert page2["ScannedCount"] == 4
     assert len(page2["Items"]) == 4
     assert "LastEvaluatedKey" not in page2
 
@@ -1170,24 +1173,42 @@ def test_scan_by_index():
     assert res["Count"] == 3
     assert len(res["Items"]) == 3
 
+    res = dynamodb.scan(TableName="test", Limit=1)
+    assert res["Count"] == 1
+    assert res["ScannedCount"] == 1
+
+    res = dynamodb.scan(TableName="test", ExclusiveStartKey=res["LastEvaluatedKey"])
+    assert res["Count"] == 2
+    assert res["ScannedCount"] == 2
+
     res = dynamodb.scan(TableName="test", IndexName="test_gsi")
     assert res["Count"] == 2
+    assert res["ScannedCount"] == 2
     assert len(res["Items"]) == 2
 
     res = dynamodb.scan(TableName="test", IndexName="test_gsi", Limit=1)
     assert res["Count"] == 1
+    assert res["ScannedCount"] == 1
     assert len(res["Items"]) == 1
     last_eval_key = res["LastEvaluatedKey"]
     assert last_eval_key["id"]["S"] == "1"
     assert last_eval_key["gsi_col"]["S"] == "1"
     assert last_eval_key["gsi_range_key"]["S"] == "1"
 
+    res = dynamodb.scan(
+        TableName="test", IndexName="test_gsi", ExclusiveStartKey=last_eval_key
+    )
+    assert res["Count"] == 1
+    assert res["ScannedCount"] == 1
+
     res = dynamodb.scan(TableName="test", IndexName="test_lsi")
     assert res["Count"] == 2
+    assert res["ScannedCount"] == 2
     assert len(res["Items"]) == 2
 
     res = dynamodb.scan(TableName="test", IndexName="test_lsi", Limit=1)
     assert res["Count"] == 1
+    assert res["ScannedCount"] == 1
     assert len(res["Items"]) == 1
     last_eval_key = res["LastEvaluatedKey"]
     assert last_eval_key["id"]["S"] == "1"
