@@ -1,6 +1,8 @@
 """Unit tests for ebs-supported APIs."""
-import boto3
 import hashlib
+
+import boto3
+
 from moto import mock_ebs, mock_ec2
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
@@ -51,7 +53,7 @@ def test_complete_snapshot():
 
 @mock_ebs
 def test_put_snapshot_block():
-    data = b"data for this specific block"
+    data = b"data for this specific block\xbf"
     checksum = hashlib.sha256(data).hexdigest()
     client = boto3.client("ebs", region_name="eu-west-1")
     snapshot_id = client.start_snapshot(VolumeSize=720)["SnapshotId"]
