@@ -1,5 +1,4 @@
 import boto3
-import sure  # pylint: disable=unused-import
 
 from moto import mock_ec2, mock_kms
 from tests import EXAMPLE_AMI_ID
@@ -11,8 +10,10 @@ def test_run_instance_with_encrypted_ebs():
     kms = boto3.client("kms", region_name="us-east-1")
     resp = kms.create_key(Description="my key", KeyUsage="ENCRYPT_DECRYPT")
     key_id = resp["KeyMetadata"]["Arn"]
-
     ec2 = boto3.client("ec2", region_name="us-east-1")
+    key_name = "keypair_name"
+    ec2.create_key_pair(KeyName=key_name)
+
     kwargs = {
         "MinCount": 1,
         "MaxCount": 1,
@@ -42,6 +43,6 @@ def test_run_instance_with_encrypted_ebs():
     volume = instances[0]["BlockDeviceMappings"][0]["Ebs"]
 
     volumes = ec2.describe_volumes(VolumeIds=[volume["VolumeId"]])
-    volumes["Volumes"][0]["Size"].should.equal(50)
-    volumes["Volumes"][0]["Encrypted"].should.equal(True)
-    volumes["Volumes"][0]["KmsKeyId"].should.equal(key_id)
+    assert volumes["Volumes"][0]["Size"] == 50
+    assert volumes["Volumes"][0]["Encrypted"] is True
+    assert volumes["Volumes"][0]["KmsKeyId"] == key_id
