@@ -1,15 +1,21 @@
-import pytest
-
-import sure  # noqa # pylint: disable=unused-import
-import boto3
-
-from botocore.exceptions import ClientError
-from moto import mock_ec2, settings
-from uuid import uuid4
+from datetime import datetime
 from unittest import SkipTest
+from uuid import uuid4
 
-from .helpers import rsa_check_private_key
+import boto3
+import pytest
+from botocore.exceptions import ClientError
 
+from moto import mock_ec2, settings
+
+from .helpers import check_private_key
+
+ED25519_PUBLIC_KEY_OPENSSH = b"""\
+ssh-ed25519 \
+AAAAC3NzaC1lZDI1NTE5AAAAIEwsSB9HbTeKCdkSlMZeTq9jZggaPJUwAsUi/7wakB+B \
+moto@getmoto"""
+
+ED25519_PUBLIC_KEY_FINGERPRINT = "6c:d9:cf:90:d7:f7:bc:46:83:9e:f5:56:aa:e1:13:38"
 
 RSA_PUBLIC_KEY_OPENSSH = b"""\
 ssh-rsa \
@@ -49,7 +55,7 @@ def test_key_pairs_empty_boto3():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("ServerMode is not guaranteed to be empty")
     client = boto3.client("ec2", "us-west-1")
-    client.describe_key_pairs()["KeyPairs"].should.be.empty
+    assert client.describe_key_pairs()["KeyPairs"] == []
 
 
 @mock_ec2
@@ -58,9 +64,9 @@ def test_key_pairs_invalid_id_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.describe_key_pairs(KeyNames=[str(uuid4())])
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidKeyPair.NotFound")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidKeyPair.NotFound"
 
 
 @mock_ec2
@@ -69,37 +75,41 @@ def test_key_pairs_create_dryrun_boto3():
 
     with pytest.raises(ClientError) as ex:
         ec2.create_key_pair(KeyName="foo", DryRun=True)
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the CreateKeyPair operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the CreateKeyPair operation: Request would have succeeded, but DryRun flag is set"
     )
 
 
 @mock_ec2
-def test_key_pairs_create_boto3():
+@pytest.mark.parametrize("key_type", ["rsa", "ed25519"])
+def test_key_pairs_create_boto3(key_type):
     ec2 = boto3.resource("ec2", "us-west-1")
     client = boto3.client("ec2", "us-west-1")
 
     key_name = str(uuid4())[0:6]
-    kp = ec2.create_key_pair(KeyName=key_name)
-    rsa_check_private_key(kp.key_material)
+    kp = ec2.create_key_pair(KeyName=key_name, KeyType=key_type)
+    check_private_key(kp.key_material, key_type)
     # Verify the client can create a key_pair as well - should behave the same
     key_name2 = str(uuid4())
-    kp2 = client.create_key_pair(KeyName=key_name2)
-    rsa_check_private_key(kp2["KeyMaterial"])
+    kp2 = client.create_key_pair(KeyName=key_name2, KeyType=key_type)
+    check_private_key(kp2["KeyMaterial"], key_type)
 
-    kp.key_material.shouldnt.equal(kp2["KeyMaterial"])
+    assert kp.key_material != kp2["KeyMaterial"]
 
     kps = client.describe_key_pairs()["KeyPairs"]
     all_names = set([k["KeyName"] for k in kps])
-    all_names.should.contain(key_name)
-    all_names.should.contain(key_name2)
+    assert key_name in all_names
+    assert key_name2 in all_names
 
     kps = client.describe_key_pairs(KeyNames=[key_name])["KeyPairs"]
-    kps.should.have.length_of(1)
-    kps[0].should.have.key("KeyName").equal(key_name)
-    kps[0].should.have.key("KeyFingerprint")
+    assert len(kps) == 1
+    assert "KeyPairId" in kps[0]
+    assert kps[0]["KeyName"] == key_name
+    assert "KeyFingerprint" in kps[0]
+    assert isinstance(kps[0]["CreateTime"], datetime)
 
 
 @mock_ec2
@@ -110,9 +120,9 @@ def test_key_pairs_create_exist_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.create_key_pair(KeyName=key_name)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidKeyPair.Duplicate")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidKeyPair.Duplicate"
 
 
 @mock_ec2
@@ -129,51 +139,53 @@ def test_key_pairs_delete_exist_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.delete_key_pair(KeyName=key_name, DryRun=True)
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the DeleteKeyPair operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the DeleteKeyPair operation: Request would have succeeded, but DryRun flag is set"
     )
 
     client.delete_key_pair(KeyName=key_name)
-    [kp.get("Name") for kp in client.describe_key_pairs()["KeyPairs"]].shouldnt.contain(
-        key_name
-    )
+    assert key_name not in [
+        kp.get("Name") for kp in client.describe_key_pairs()["KeyPairs"]
+    ]
 
 
 @mock_ec2
-def test_key_pairs_import_boto3():
+@pytest.mark.parametrize(
+    "public_key,fingerprint",
+    [
+        (RSA_PUBLIC_KEY_OPENSSH, RSA_PUBLIC_KEY_FINGERPRINT),
+        (RSA_PUBLIC_KEY_RFC4716, RSA_PUBLIC_KEY_FINGERPRINT),
+        (ED25519_PUBLIC_KEY_OPENSSH, ED25519_PUBLIC_KEY_FINGERPRINT),
+    ],
+    ids=["rsa-openssh", "rsa-rfc4716", "ed25519"],
+)
+def test_key_pairs_import_boto3(public_key, fingerprint):
     client = boto3.client("ec2", "us-west-1")
 
     key_name = str(uuid4())[0:6]
     with pytest.raises(ClientError) as ex:
         client.import_key_pair(
-            KeyName=key_name, PublicKeyMaterial=RSA_PUBLIC_KEY_OPENSSH, DryRun=True
+            KeyName=key_name, PublicKeyMaterial=public_key, DryRun=True
         )
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the ImportKeyPair operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the ImportKeyPair operation: Request would have succeeded, but DryRun flag is set"
     )
 
-    kp1 = client.import_key_pair(
-        KeyName=key_name, PublicKeyMaterial=RSA_PUBLIC_KEY_OPENSSH
-    )
+    kp1 = client.import_key_pair(KeyName=key_name, PublicKeyMaterial=public_key)
 
-    kp1.should.have.key("KeyName").equal(key_name)
-    kp1.should.have.key("KeyFingerprint").equal(RSA_PUBLIC_KEY_FINGERPRINT)
-
-    key_name2 = str(uuid4())
-    kp2 = client.import_key_pair(
-        KeyName=key_name2, PublicKeyMaterial=RSA_PUBLIC_KEY_RFC4716
-    )
-    kp2.should.have.key("KeyName").equal(key_name2)
-    kp2.should.have.key("KeyFingerprint").equal(RSA_PUBLIC_KEY_FINGERPRINT)
+    assert "KeyPairId" in kp1
+    assert kp1["KeyName"] == key_name
+    assert kp1["KeyFingerprint"] == fingerprint
 
     all_kps = client.describe_key_pairs()["KeyPairs"]
     all_names = [kp["KeyName"] for kp in all_kps]
-    all_names.should.contain(kp1["KeyName"])
-    all_names.should.contain(kp2["KeyName"])
+    assert kp1["KeyName"] in all_names
 
 
 @mock_ec2
@@ -184,15 +196,15 @@ def test_key_pairs_import_exist_boto3():
     kp = client.import_key_pair(
         KeyName=key_name, PublicKeyMaterial=RSA_PUBLIC_KEY_OPENSSH
     )
-    kp["KeyName"].should.equal(key_name)
+    assert kp["KeyName"] == key_name
 
-    client.describe_key_pairs(KeyNames=[key_name])["KeyPairs"].should.have.length_of(1)
+    assert len(client.describe_key_pairs(KeyNames=[key_name])["KeyPairs"]) == 1
 
     with pytest.raises(ClientError) as ex:
         client.create_key_pair(KeyName=key_name)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidKeyPair.Duplicate")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidKeyPair.Duplicate"
 
 
 @mock_ec2
@@ -201,24 +213,24 @@ def test_key_pairs_invalid_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.import_key_pair(KeyName="foo", PublicKeyMaterial=b"")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidKeyPair.Format")
-    err["Message"].should.equal("Key is not in valid OpenSSH public key format")
+    assert err["Code"] == "InvalidKeyPair.Format"
+    assert err["Message"] == "Key is not in valid OpenSSH public key format"
 
     with pytest.raises(ClientError) as ex:
         client.import_key_pair(KeyName="foo", PublicKeyMaterial=b"garbage")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidKeyPair.Format")
-    err["Message"].should.equal("Key is not in valid OpenSSH public key format")
+    assert err["Code"] == "InvalidKeyPair.Format"
+    assert err["Message"] == "Key is not in valid OpenSSH public key format"
 
     with pytest.raises(ClientError) as ex:
         client.import_key_pair(KeyName="foo", PublicKeyMaterial=DSA_PUBLIC_KEY_OPENSSH)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidKeyPair.Format")
-    err["Message"].should.equal("Key is not in valid OpenSSH public key format")
+    assert err["Code"] == "InvalidKeyPair.Format"
+    assert err["Message"] == "Key is not in valid OpenSSH public key format"
 
 
 @mock_ec2
@@ -236,9 +248,57 @@ def test_key_pair_filters_boto3():
     kp_by_name = client.describe_key_pairs(
         Filters=[{"Name": "key-name", "Values": [key_name_2]}]
     )["KeyPairs"]
-    set([kp["KeyName"] for kp in kp_by_name]).should.equal(set([kp2.name]))
+    assert set([kp["KeyName"] for kp in kp_by_name]) == set([kp2.name])
 
     kp_by_name = client.describe_key_pairs(
         Filters=[{"Name": "fingerprint", "Values": [kp3.key_fingerprint]}]
     )["KeyPairs"]
-    set([kp["KeyName"] for kp in kp_by_name]).should.equal(set([kp3.name]))
+    assert set([kp["KeyName"] for kp in kp_by_name]) == set([kp3.name])
+
+
+@mock_ec2
+def test_key_pair_with_tags():
+    client = boto3.client("ec2", "us-east-1")
+
+    key_name_1 = str(uuid4())[0:6]
+    key_name_2 = str(uuid4())[0:6]
+    key_name_3 = str(uuid4())[0:6]
+    key_name_4 = str(uuid4())[0:6]
+    resp = client.create_key_pair(
+        KeyName=key_name_1,
+        TagSpecifications=[
+            {"ResourceType": "key-pair", "Tags": [{"Key": "key", "Value": "val1"}]}
+        ],
+    )
+    assert resp["Tags"] == [{"Key": "key", "Value": "val1"}]
+    kp1 = resp["KeyPairId"]
+
+    kp2 = client.create_key_pair(
+        KeyName=key_name_2,
+        TagSpecifications=[
+            {"ResourceType": "key-pair", "Tags": [{"Key": "key", "Value": "val2"}]}
+        ],
+    )["KeyPairId"]
+
+    assert "Tags" not in client.create_key_pair(KeyName=key_name_3)
+
+    key_pairs = client.describe_key_pairs(
+        Filters=[{"Name": "tag-key", "Values": ["key"]}]
+    )["KeyPairs"]
+    assert [kp["KeyPairId"] for kp in key_pairs] == [kp1, kp2]
+
+    key_pairs = client.describe_key_pairs(
+        Filters=[{"Name": "tag:key", "Values": ["val1"]}]
+    )["KeyPairs"]
+    assert len(key_pairs) == 1
+    assert key_pairs[0]["KeyPairId"] == kp1
+    assert key_pairs[0]["Tags"] == [{"Key": "key", "Value": "val1"}]
+
+    resp = client.import_key_pair(
+        KeyName=key_name_4,
+        PublicKeyMaterial=RSA_PUBLIC_KEY_OPENSSH,
+        TagSpecifications=[
+            {"ResourceType": "key-pair", "Tags": [{"Key": "key", "Value": "val4"}]}
+        ],
+    )
+    assert resp["Tags"] == [{"Key": "key", "Value": "val4"}]
