@@ -1,11 +1,11 @@
-import boto3
-import sure  # noqa # pylint: disable=unused-import
+from uuid import uuid4
 
+import boto3
 import pytest
 from botocore.client import ClientError
 
 from moto import mock_ec2, settings
-from uuid import uuid4
+from tests import EXAMPLE_AMI_ID
 
 
 @mock_ec2
@@ -26,11 +26,11 @@ def test_launch_template_create():
         },
     )
 
-    resp.should.have.key("LaunchTemplate")
+    assert "LaunchTemplate" in resp
     lt = resp["LaunchTemplate"]
-    lt["LaunchTemplateName"].should.equal(template_name)
-    lt["DefaultVersionNumber"].should.equal(1)
-    lt["LatestVersionNumber"].should.equal(1)
+    assert lt["LaunchTemplateName"] == template_name
+    assert lt["DefaultVersionNumber"] == 1
+    assert lt["LatestVersionNumber"] == 1
 
     with pytest.raises(ClientError) as ex:
         cli.create_launch_template(
@@ -45,8 +45,32 @@ def test_launch_template_create():
             },
         )
 
-    str(ex.value).should.equal(
-        "An error occurred (InvalidLaunchTemplateName.AlreadyExistsException) when calling the CreateLaunchTemplate operation: Launch template name already in use."
+    assert (
+        str(ex.value)
+        == "An error occurred (InvalidLaunchTemplateName.AlreadyExistsException) when calling the CreateLaunchTemplate operation: Launch template name already in use."
+    )
+
+
+@mock_ec2
+def test_create_launch_template__dryrun():
+    cli = boto3.client("ec2", region_name="us-east-1")
+
+    template_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        cli.create_launch_template(
+            DryRun=True,
+            LaunchTemplateName=template_name,
+            LaunchTemplateData={"ImageId": "ami-abc123"},
+            TagSpecifications=[
+                {"ResourceType": "instance", "Tags": [{"Key": "key", "Value": "value"}]}
+            ],
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "DryRunOperation"
+    assert (
+        err["Message"]
+        == "An error occurred (DryRunOperation) when calling the CreateLaunchTemplate operation: Request would have succeeded, but DryRun flag is set"
     )
 
 
@@ -74,7 +98,7 @@ def test_describe_launch_template_versions():
     )
 
     templ = resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]
-    templ.should.equal(template_data)
+    assert templ == template_data
 
     # test using id
     resp = cli.describe_launch_template_versions(
@@ -83,7 +107,23 @@ def test_describe_launch_template_versions():
     )
 
     templ = resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]
-    templ.should.equal(template_data)
+    assert templ == template_data
+
+    # test using $Latest version
+    resp = cli.describe_launch_template_versions(
+        LaunchTemplateName=template_name, Versions=["$Latest"]
+    )
+
+    templ = resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]
+    assert templ == template_data
+
+    # test using $Default version
+    resp = cli.describe_launch_template_versions(
+        LaunchTemplateName=template_name, Versions=["$Default"]
+    )
+
+    templ = resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]
+    assert templ == template_data
 
 
 @mock_ec2
@@ -97,9 +137,16 @@ def test_describe_launch_template_versions_by_name_when_absent():
         ClientError,
         match=f"The specified launch template, with template name {template_name}, does not exist",
     ):
-
         cli.describe_launch_template_versions(LaunchTemplateName=template_name)
 
+    # test default response
+    resp = cli.describe_launch_template_versions()
+    assert resp["LaunchTemplateVersions"] == []
+
+    # test using $Latest version
+    resp = cli.describe_launch_template_versions(Versions=["$Latest"])
+    assert resp["LaunchTemplateVersions"] == []
+
 
 @mock_ec2
 def test_create_launch_template_version():
@@ -116,14 +163,38 @@ def test_create_launch_template_version():
         VersionDescription="new ami",
     )
 
-    version_resp.should.have.key("LaunchTemplateVersion")
+    assert "LaunchTemplateVersion" in version_resp
     version = version_resp["LaunchTemplateVersion"]
-    version["DefaultVersion"].should.equal(False)
-    version["LaunchTemplateId"].should.equal(
-        create_resp["LaunchTemplate"]["LaunchTemplateId"]
+    assert version["DefaultVersion"] is False
+    assert (
+        version["LaunchTemplateId"] == create_resp["LaunchTemplate"]["LaunchTemplateId"]
+    )
+    assert version["VersionDescription"] == "new ami"
+    assert version["VersionNumber"] == 2
+
+
+@mock_ec2
+def test_create_launch_template_version__dryrun():
+    cli = boto3.client("ec2", region_name="us-east-1")
+
+    template_name = str(uuid4())
+    cli.create_launch_template(
+        LaunchTemplateName=template_name, LaunchTemplateData={"ImageId": "ami-abc123"}
+    )
+
+    with pytest.raises(ClientError) as exc:
+        cli.create_launch_template_version(
+            DryRun=True,
+            LaunchTemplateName=template_name,
+            LaunchTemplateData={"ImageId": "ami-def456"},
+            VersionDescription="new ami",
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "DryRunOperation"
+    assert (
+        err["Message"]
+        == "An error occurred (DryRunOperation) when calling the CreateLaunchTemplateVersion operation: Request would have succeeded, but DryRun flag is set"
     )
-    version["VersionDescription"].should.equal("new ami")
-    version["VersionNumber"].should.equal(2)
 
 
 @mock_ec2
@@ -141,14 +212,14 @@ def test_create_launch_template_version_by_id():
         VersionDescription="new ami",
     )
 
-    version_resp.should.have.key("LaunchTemplateVersion")
+    assert "LaunchTemplateVersion" in version_resp
     version = version_resp["LaunchTemplateVersion"]
-    version["DefaultVersion"].should.equal(False)
-    version["LaunchTemplateId"].should.equal(
-        create_resp["LaunchTemplate"]["LaunchTemplateId"]
+    assert version["DefaultVersion"] is False
+    assert (
+        version["LaunchTemplateId"] == create_resp["LaunchTemplate"]["LaunchTemplateId"]
     )
-    version["VersionDescription"].should.equal("new ami")
-    version["VersionNumber"].should.equal(2)
+    assert version["VersionDescription"] == "new ami"
+    assert version["VersionNumber"] == 2
 
 
 @mock_ec2
@@ -168,12 +239,14 @@ def test_describe_launch_template_versions_with_multiple_versions():
 
     resp = cli.describe_launch_template_versions(LaunchTemplateName=template_name)
 
-    resp["LaunchTemplateVersions"].should.have.length_of(2)
-    resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-abc123"
+    assert len(resp["LaunchTemplateVersions"]) == 2
+    assert (
+        resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"]
+        == "ami-abc123"
     )
-    resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-def456"
+    assert (
+        resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"]
+        == "ami-def456"
     )
 
 
@@ -202,12 +275,14 @@ def test_describe_launch_template_versions_with_versions_option():
         LaunchTemplateName=template_name, Versions=["2", "3"]
     )
 
-    resp["LaunchTemplateVersions"].should.have.length_of(2)
-    resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-def456"
+    assert len(resp["LaunchTemplateVersions"]) == 2
+    assert (
+        resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"]
+        == "ami-def456"
     )
-    resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-hij789"
+    assert (
+        resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"]
+        == "ami-hij789"
     )
 
 
@@ -236,12 +311,14 @@ def test_describe_launch_template_versions_with_min():
         LaunchTemplateName=template_name, MinVersion="2"
     )
 
-    resp["LaunchTemplateVersions"].should.have.length_of(2)
-    resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-def456"
+    assert len(resp["LaunchTemplateVersions"]) == 2
+    assert (
+        resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"]
+        == "ami-def456"
     )
-    resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-hij789"
+    assert (
+        resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"]
+        == "ami-hij789"
     )
 
 
@@ -270,12 +347,14 @@ def test_describe_launch_template_versions_with_max():
         LaunchTemplateName=template_name, MaxVersion="2"
     )
 
-    resp["LaunchTemplateVersions"].should.have.length_of(2)
-    resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-abc123"
+    assert len(resp["LaunchTemplateVersions"]) == 2
+    assert (
+        resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"]
+        == "ami-abc123"
     )
-    resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-def456"
+    assert (
+        resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"]
+        == "ami-def456"
     )
 
 
@@ -310,12 +389,14 @@ def test_describe_launch_template_versions_with_min_and_max():
         LaunchTemplateName=template_name, MinVersion="2", MaxVersion="3"
     )
 
-    resp["LaunchTemplateVersions"].should.have.length_of(2)
-    resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-def456"
+    assert len(resp["LaunchTemplateVersions"]) == 2
+    assert (
+        resp["LaunchTemplateVersions"][0]["LaunchTemplateData"]["ImageId"]
+        == "ami-def456"
     )
-    resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"].should.equal(
-        "ami-hij789"
+    assert (
+        resp["LaunchTemplateVersions"][1]["LaunchTemplateData"]["ImageId"]
+        == "ami-hij789"
     )
 
 
@@ -328,8 +409,9 @@ def test_describe_launch_templates_with_non_existent_name():
     with pytest.raises(ClientError) as ex:
         cli.describe_launch_templates(LaunchTemplateNames=[template_name])
 
-    str(ex.value).should.equal(
-        "An error occurred (InvalidLaunchTemplateName.NotFoundException) when calling the DescribeLaunchTemplates operation: At least one of the launch templates specified in the request does not exist."
+    assert (
+        str(ex.value)
+        == "An error occurred (InvalidLaunchTemplateName.NotFoundException) when calling the DescribeLaunchTemplates operation: At least one of the launch templates specified in the request does not exist."
     )
 
 
@@ -356,24 +438,24 @@ def test_describe_launch_templates():
         # ServerMode may have many more templates, created in parallel
         all_templates = retrieve_all_templates(cli)
         my_templates = [t for t in all_templates if t["LaunchTemplateId"] in lt_ids]
-        my_templates[0]["LaunchTemplateName"].should.equal(template_name)
-        my_templates[1]["LaunchTemplateName"].should.equal(template_name2)
+        assert my_templates[0]["LaunchTemplateName"] == template_name
+        assert my_templates[1]["LaunchTemplateName"] == template_name2
 
     # filter by names
     resp = cli.describe_launch_templates(
         LaunchTemplateNames=[template_name2, template_name]
     )
-    resp.should.have.key("LaunchTemplates")
-    resp["LaunchTemplates"].should.have.length_of(2)
-    resp["LaunchTemplates"][0]["LaunchTemplateName"].should.equal(template_name2)
-    resp["LaunchTemplates"][1]["LaunchTemplateName"].should.equal(template_name)
+    assert "LaunchTemplates" in resp
+    assert len(resp["LaunchTemplates"]) == 2
+    assert resp["LaunchTemplates"][0]["LaunchTemplateName"] == template_name2
+    assert resp["LaunchTemplates"][1]["LaunchTemplateName"] == template_name
 
     # filter by ids
     resp = cli.describe_launch_templates(LaunchTemplateIds=lt_ids)
-    resp.should.have.key("LaunchTemplates")
-    resp["LaunchTemplates"].should.have.length_of(2)
-    resp["LaunchTemplates"][0]["LaunchTemplateName"].should.equal(template_name)
-    resp["LaunchTemplates"][1]["LaunchTemplateName"].should.equal(template_name2)
+    assert "LaunchTemplates" in resp
+    assert len(resp["LaunchTemplates"]) == 2
+    assert resp["LaunchTemplates"][0]["LaunchTemplateName"] == template_name
+    assert resp["LaunchTemplates"][1]["LaunchTemplateName"] == template_name2
 
 
 @mock_ec2
@@ -404,14 +486,14 @@ def test_describe_launch_templates_with_filters():
         Filters=[{"Name": "tag:tag1", "Values": [tag_value]}]
     )
 
-    resp["LaunchTemplates"].should.have.length_of(1)
-    resp["LaunchTemplates"][0]["LaunchTemplateName"].should.equal(template_name)
+    assert len(resp["LaunchTemplates"]) == 1
+    assert resp["LaunchTemplates"][0]["LaunchTemplateName"] == template_name
 
     resp = cli.describe_launch_templates(
         Filters=[{"Name": "launch-template-name", "Values": [template_name_no_tags]}]
     )
-    resp["LaunchTemplates"].should.have.length_of(1)
-    resp["LaunchTemplates"][0]["LaunchTemplateName"].should.equal(template_name_no_tags)
+    assert len(resp["LaunchTemplates"]) == 1
+    assert resp["LaunchTemplates"][0]["LaunchTemplateName"] == template_name_no_tags
 
 
 @mock_ec2
@@ -432,10 +514,33 @@ def test_create_launch_template_with_tag_spec():
     )
     version = resp["LaunchTemplateVersions"][0]
 
-    version["LaunchTemplateData"].should.have.key("TagSpecifications")
-    version["LaunchTemplateData"]["TagSpecifications"].should.have.length_of(1)
-    version["LaunchTemplateData"]["TagSpecifications"][0].should.equal(
-        {"ResourceType": "instance", "Tags": [{"Key": "key", "Value": "value"}]}
+    assert "TagSpecifications" in version["LaunchTemplateData"]
+    assert len(version["LaunchTemplateData"]["TagSpecifications"]) == 1
+    assert version["LaunchTemplateData"]["TagSpecifications"][0] == {
+        "ResourceType": "instance",
+        "Tags": [{"Key": "key", "Value": "value"}],
+    }
+
+
+@mock_ec2
+def test_get_launch_template_data():
+    client = boto3.client("ec2", region_name="us-east-1")
+
+    reservation = client.run_instances(ImageId=EXAMPLE_AMI_ID, MinCount=1, MaxCount=1)
+    instance = reservation["Instances"][0]
+
+    launch_template_data = client.get_launch_template_data(
+        InstanceId=instance["InstanceId"]
+    )["LaunchTemplateData"]
+
+    # Ensure launch template data matches instance
+    assert launch_template_data["ImageId"] == instance["ImageId"]
+    assert launch_template_data["InstanceType"] == instance["InstanceType"]
+
+    # Ensure a launch template can be created from this data
+    client.create_launch_template(
+        LaunchTemplateName=str(uuid4()),
+        LaunchTemplateData=launch_template_data,
     )
 
 
@@ -452,19 +557,33 @@ def test_delete_launch_template__dryrun():
         ],
     )
 
-    cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
-        "LaunchTemplates"
-    ].should.have.length_of(1)
+    assert (
+        len(
+            cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
+                "LaunchTemplates"
+            ]
+        )
+        == 1
+    )
 
     with pytest.raises(ClientError) as exc:
         cli.delete_launch_template(DryRun=True, LaunchTemplateName=template_name)
     err = exc.value.response["Error"]
-    err.should.have.key("Code").equals("DryRunOperation")
+    assert err["Code"] == "DryRunOperation"
+    assert (
+        err["Message"]
+        == "An error occurred (DryRunOperation) when calling the DeleteLaunchTemplate operation: Request would have succeeded, but DryRun flag is set"
+    )
 
     # Template still exists
-    cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
-        "LaunchTemplates"
-    ].should.have.length_of(1)
+    assert (
+        len(
+            cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
+                "LaunchTemplates"
+            ]
+        )
+        == 1
+    )
 
 
 @mock_ec2
@@ -476,15 +595,33 @@ def test_delete_launch_template__by_name():
         LaunchTemplateName=template_name, LaunchTemplateData={"ImageId": "ami-abc123"}
     )
 
-    cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
-        "LaunchTemplates"
-    ].should.have.length_of(1)
+    assert (
+        len(
+            cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
+                "LaunchTemplates"
+            ]
+        )
+        == 1
+    )
 
     cli.delete_launch_template(LaunchTemplateName=template_name)
 
-    cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
-        "LaunchTemplates"
-    ].should.have.length_of(0)
+    with pytest.raises(ClientError) as exc:
+        cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
+            "LaunchTemplates"
+        ]
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidLaunchTemplateName.NotFoundException"
+    assert (
+        err["Message"]
+        == "At least one of the launch templates specified in the request does not exist."
+    )
+
+    # Ensure deleted template name can be reused
+    cli.create_launch_template(
+        LaunchTemplateName=template_name,
+        LaunchTemplateData={"ImageId": "ami-abc123"},
+    )
 
 
 @mock_ec2
@@ -492,19 +629,45 @@ def test_delete_launch_template__by_id():
     cli = boto3.client("ec2", region_name="us-east-1")
 
     template_name = str(uuid4())
+
+    with pytest.raises(ClientError) as exc:
+        cli.delete_launch_template()
+    err = exc.value.response["Error"]
+    assert err["Code"] == "MissingParameter"
+    assert (
+        err["Message"]
+        == "The request must contain the parameter launch template ID or launch template name"
+    )
+
     template_id = cli.create_launch_template(
         LaunchTemplateName=template_name, LaunchTemplateData={"ImageId": "ami-abc123"}
     )["LaunchTemplate"]["LaunchTemplateId"]
 
-    cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
-        "LaunchTemplates"
-    ].should.have.length_of(1)
+    assert (
+        len(
+            cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
+                "LaunchTemplates"
+            ]
+        )
+        == 1
+    )
 
     cli.delete_launch_template(LaunchTemplateId=template_id)
 
-    cli.describe_launch_templates(LaunchTemplateNames=[template_name])[
-        "LaunchTemplates"
-    ].should.have.length_of(0)
+    with pytest.raises(ClientError) as exc:
+        cli.describe_launch_templates(LaunchTemplateNames=[template_name])
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidLaunchTemplateName.NotFoundException"
+    assert (
+        err["Message"]
+        == "At least one of the launch templates specified in the request does not exist."
+    )
+
+    # Ensure deleted template name can be reused
+    cli.create_launch_template(
+        LaunchTemplateName=template_name,
+        LaunchTemplateData={"ImageId": "ami-abc123"},
+    )
 
 
 def retrieve_all_templates(client, filters=[]):  # pylint: disable=W0102
@@ -542,13 +705,13 @@ def test_launch_template_create_with_tags():
         ],
     )
 
-    resp.should.have.key("LaunchTemplate")
+    assert "LaunchTemplate" in resp
     lt = resp["LaunchTemplate"]
-    lt["LaunchTemplateName"].should.equal(template_name)
-    lt["DefaultVersionNumber"].should.equal(1)
-    lt["LatestVersionNumber"].should.equal(1)
-    lt["Tags"].should.have.length_of(1)
-    lt["Tags"][0].should.equal({"Key": "test1", "Value": "value1"})
+    assert lt["LaunchTemplateName"] == template_name
+    assert lt["DefaultVersionNumber"] == 1
+    assert lt["LatestVersionNumber"] == 1
+    assert len(lt["Tags"]) == 1
+    assert lt["Tags"][0] == {"Key": "test1", "Value": "value1"}
 
 
 @mock_ec2
@@ -579,8 +742,8 @@ def test_launch_template_describe_with_tags():
         "LaunchTemplates"
     ][0]
 
-    lt["LaunchTemplateName"].should.equal(template_name)
-    lt["DefaultVersionNumber"].should.equal(1)
-    lt["LatestVersionNumber"].should.equal(1)
-    lt["Tags"].should.have.length_of(1)
-    lt["Tags"][0].should.equal({"Key": "test1", "Value": "value1"})
+    assert lt["LaunchTemplateName"] == template_name
+    assert lt["DefaultVersionNumber"] == 1
+    assert lt["LatestVersionNumber"] == 1
+    assert len(lt["Tags"]) == 1
+    assert lt["Tags"][0] == {"Key": "test1", "Value": "value1"}
