@@ -1,11 +1,12 @@
+from random import randint
+from unittest import SkipTest
+
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
 from moto import mock_ec2, settings
 from moto.core import DEFAULT_ACCOUNT_ID as OWNER_ID
-from random import randint
-from unittest import SkipTest
 
 
 @mock_ec2
@@ -248,7 +249,7 @@ def test_default_network_acl_default_entries():
         assert entry["Protocol"] == "-1"
         assert entry["RuleNumber"] in [100, 32767]
         assert entry["RuleAction"] in ["allow", "deny"]
-        assert type(entry["Egress"]) is bool
+        assert isinstance(entry["Egress"], bool)
         if entry["RuleAction"] == "allow":
             assert entry["RuleNumber"] == 100
         else:
