@@ -1,16 +1,14 @@
-import pytest
 import datetime
+from unittest import SkipTest
+from uuid import uuid4
 
 import boto3
+import pytest
 from botocore.exceptions import ClientError
-import pytz
-import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_ec2, settings
 from moto.core.utils import iso_8601_datetime_with_milliseconds
 from tests import EXAMPLE_AMI_ID
-from uuid import uuid4
-from unittest import SkipTest
 
 
 @mock_ec2
@@ -27,8 +25,8 @@ def test_request_spot_instances():
     conn.create_security_group(GroupName=sec_name_1, Description="description")
     conn.create_security_group(GroupName=sec_name_2, Description="description")
 
-    start_dt = datetime.datetime(2013, 1, 1).replace(tzinfo=pytz.utc)
-    end_dt = datetime.datetime(2013, 1, 2).replace(tzinfo=pytz.utc)
+    start_dt = datetime.datetime(2013, 1, 1).replace(tzinfo=datetime.timezone.utc)
+    end_dt = datetime.datetime(2013, 1, 2).replace(tzinfo=datetime.timezone.utc)
     start = iso_8601_datetime_with_milliseconds(start_dt)
     end = iso_8601_datetime_with_milliseconds(end_dt)
 
@@ -55,10 +53,11 @@ def test_request_spot_instances():
             },
             DryRun=True,
         )
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the RequestSpotInstance operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the RequestSpotInstances operation: Request would have succeeded, but DryRun flag is set"
     )
 
     request = conn.request_spot_instances(
@@ -86,29 +85,29 @@ def test_request_spot_instances():
 
     all_requests = conn.describe_spot_instance_requests()["SpotInstanceRequests"]
     requests = [r for r in all_requests if r["SpotInstanceRequestId"] == request_id]
-    requests.should.have.length_of(1)
+    assert len(requests) == 1
     request = requests[0]
 
-    request["State"].should.equal("active")
-    request["SpotPrice"].should.equal("0.500000")
-    request["Type"].should.equal("one-time")
-    request["ValidFrom"].should.equal(start_dt)
-    request["ValidUntil"].should.equal(end_dt)
-    request["LaunchGroup"].should.equal("the-group")
-    request["AvailabilityZoneGroup"].should.equal("my-group")
+    assert request["State"] == "active"
+    assert request["SpotPrice"] == "0.500000"
+    assert request["Type"] == "one-time"
+    assert request["ValidFrom"] == start_dt
+    assert request["ValidUntil"] == end_dt
+    assert request["LaunchGroup"] == "the-group"
+    assert request["AvailabilityZoneGroup"] == "my-group"
 
     launch_spec = request["LaunchSpecification"]
     security_group_names = [
         group["GroupName"] for group in launch_spec["SecurityGroups"]
     ]
-    set(security_group_names).should.equal(set([sec_name_1, sec_name_2]))
+    assert set(security_group_names) == set([sec_name_1, sec_name_2])
 
-    launch_spec["ImageId"].should.equal(EXAMPLE_AMI_ID)
-    launch_spec["KeyName"].should.equal("test")
-    launch_spec["InstanceType"].should.equal("m1.small")
-    launch_spec["KernelId"].should.equal("test-kernel")
-    launch_spec["RamdiskId"].should.equal("test-ramdisk")
-    launch_spec["SubnetId"].should.equal(subnet_id)
+    assert launch_spec["ImageId"] == EXAMPLE_AMI_ID
+    assert launch_spec["KeyName"] == "test"
+    assert launch_spec["InstanceType"] == "m1.small"
+    assert launch_spec["KernelId"] == "test-kernel"
+    assert launch_spec["RamdiskId"] == "test-ramdisk"
+    assert launch_spec["SubnetId"] == subnet_id
 
 
 @mock_ec2
@@ -125,31 +124,31 @@ def test_request_spot_instances_default_arguments():
 
     all_requests = conn.describe_spot_instance_requests()["SpotInstanceRequests"]
     requests = [r for r in all_requests if r["SpotInstanceRequestId"] == request_id]
-    requests.should.have.length_of(1)
+    assert len(requests) == 1
     request = requests[0]
 
-    request["State"].should.equal("active")
-    request["SpotPrice"].should.equal("0.500000")
-    request["Type"].should.equal("one-time")
-    request.shouldnt.contain("ValidFrom")
-    request.shouldnt.contain("ValidUntil")
-    request.shouldnt.contain("LaunchGroup")
-    request.shouldnt.contain("AvailabilityZoneGroup")
-    request.should.have.key("InstanceInterruptionBehavior").equals("terminate")
+    assert request["State"] == "active"
+    assert request["SpotPrice"] == "0.500000"
+    assert request["Type"] == "one-time"
+    assert "ValidFrom" not in request
+    assert "ValidUntil" not in request
+    assert "LaunchGroup" not in request
+    assert "AvailabilityZoneGroup" not in request
+    assert request["InstanceInterruptionBehavior"] == "terminate"
 
     launch_spec = request["LaunchSpecification"]
 
     security_group_names = [
         group["GroupName"] for group in launch_spec["SecurityGroups"]
     ]
-    security_group_names.should.equal(["default"])
+    assert security_group_names == ["default"]
 
-    launch_spec["ImageId"].should.equal(EXAMPLE_AMI_ID)
-    request.shouldnt.contain("KeyName")
-    launch_spec["InstanceType"].should.equal("m1.small")
-    request.shouldnt.contain("KernelId")
-    request.shouldnt.contain("RamdiskId")
-    request.shouldnt.contain("SubnetId")
+    assert launch_spec["ImageId"] == EXAMPLE_AMI_ID
+    assert "KeyName" not in request
+    assert launch_spec["InstanceType"] == "m1.small"
+    assert "KernelId" not in request
+    assert "RamdiskId" not in request
+    assert "SubnetId" not in request
 
 
 @mock_ec2
@@ -164,22 +163,23 @@ def test_cancel_spot_instance_request():
     requests = client.describe_spot_instance_requests(SpotInstanceRequestIds=[spot_id])[
         "SpotInstanceRequests"
     ]
-    requests.should.have.length_of(1)
+    assert len(requests) == 1
     request = requests[0]
-    request.should.have.key("CreateTime")
-    request.should.have.key("Type").equal("one-time")
-    request.should.have.key("SpotInstanceRequestId")
-    request.should.have.key("SpotPrice").equal("0.500000")
-    request["LaunchSpecification"]["ImageId"].should.equal(EXAMPLE_AMI_ID)
+    assert "CreateTime" in request
+    assert request["Type"] == "one-time"
+    assert "SpotInstanceRequestId" in request
+    assert request["SpotPrice"] == "0.500000"
+    assert request["LaunchSpecification"]["ImageId"] == EXAMPLE_AMI_ID
 
     with pytest.raises(ClientError) as ex:
         client.cancel_spot_instance_requests(
             SpotInstanceRequestIds=[request["SpotInstanceRequestId"]], DryRun=True
         )
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the CancelSpotInstance operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the CancelSpotInstanceRequests operation: Request would have succeeded, but DryRun flag is set"
     )
 
     client.cancel_spot_instance_requests(
@@ -189,7 +189,7 @@ def test_cancel_spot_instance_request():
     requests = client.describe_spot_instance_requests(SpotInstanceRequestIds=[spot_id])[
         "SpotInstanceRequests"
     ]
-    requests.should.have.length_of(0)
+    assert len(requests) == 0
 
 
 @mock_ec2
@@ -207,10 +207,10 @@ def test_request_spot_instances_fulfilled():
     requests = client.describe_spot_instance_requests(
         SpotInstanceRequestIds=[request_id]
     )["SpotInstanceRequests"]
-    requests.should.have.length_of(1)
+    assert len(requests) == 1
     request = requests[0]
 
-    request["State"].should.equal("active")
+    assert request["State"] == "active"
 
 
 @mock_ec2
@@ -232,12 +232,12 @@ def test_tag_spot_instance_request():
     requests = client.describe_spot_instance_requests(
         SpotInstanceRequestIds=[request_id]
     )["SpotInstanceRequests"]
-    requests.should.have.length_of(1)
+    assert len(requests) == 1
     request = requests[0]
 
-    request["Tags"].should.have.length_of(2)
-    request["Tags"].should.contain({"Key": "tag1", "Value": "value1"})
-    request["Tags"].should.contain({"Key": "tag2", "Value": "value2"})
+    assert len(request["Tags"]) == 2
+    assert {"Key": "tag1", "Value": "value1"} in request["Tags"]
+    assert {"Key": "tag2", "Value": "value2"} in request["Tags"]
 
 
 @mock_ec2
@@ -272,20 +272,20 @@ def test_get_all_spot_instance_requests_filtering():
         Filters=[{"Name": "state", "Values": ["failed"]}]
     )["SpotInstanceRequests"]
     r_ids = [r["SpotInstanceRequestId"] for r in requests]
-    r_ids.shouldnt.contain(request1_id)
-    r_ids.shouldnt.contain(request2_id)
+    assert request1_id not in r_ids
+    assert request2_id not in r_ids
 
     requests = client.describe_spot_instance_requests(
         Filters=[{"Name": "state", "Values": ["active"]}]
     )["SpotInstanceRequests"]
     r_ids = [r["SpotInstanceRequestId"] for r in requests]
-    r_ids.should.contain(request1_id)
-    r_ids.should.contain(request2_id)
+    assert request1_id in r_ids
+    assert request2_id in r_ids
 
     requests = client.describe_spot_instance_requests(
         Filters=[{"Name": "tag:tag1", "Values": [tag_value1]}]
     )["SpotInstanceRequests"]
-    requests.should.have.length_of(2)
+    assert len(requests) == 2
 
     requests = client.describe_spot_instance_requests(
         Filters=[
@@ -293,7 +293,7 @@ def test_get_all_spot_instance_requests_filtering():
             {"Name": "tag:tag2", "Values": ["value2"]},
         ]
     )["SpotInstanceRequests"]
-    requests.should.have.length_of(1)
+    assert len(requests) == 1
 
 
 @mock_ec2
@@ -309,7 +309,7 @@ def test_request_spot_instances_instance_lifecycle():
     response = client.describe_instances()
 
     instance = response["Reservations"][0]["Instances"][0]
-    instance["InstanceLifecycle"].should.equal("spot")
+    assert instance["InstanceLifecycle"] == "spot"
 
 
 @mock_ec2
@@ -331,7 +331,7 @@ def test_request_spot_instances_with_tags():
     request = client.describe_spot_instance_requests(
         SpotInstanceRequestIds=[request_id]
     )["SpotInstanceRequests"][0]
-    request.should.have.key("Tags").equals([{"Key": "k", "Value": "v"}])
+    assert request["Tags"] == [{"Key": "k", "Value": "v"}]
 
 
 @mock_ec2
@@ -355,7 +355,7 @@ def test_launch_spot_instance_instance_lifecycle():
 
     response = client.describe_instances(InstanceIds=[instance_id])
     instance = response["Reservations"][0]["Instances"][0]
-    instance["InstanceLifecycle"].should.equal("spot")
+    assert instance["InstanceLifecycle"] == "spot"
 
 
 @mock_ec2
@@ -378,7 +378,7 @@ def test_launch_instance_instance_lifecycle():
 
     response = client.describe_instances(InstanceIds=[instance_id])
     instance = response["Reservations"][0]["Instances"][0]
-    instance.get("InstanceLifecycle").should.equal(None)
+    assert instance.get("InstanceLifecycle") is None
 
 
 @mock_ec2
@@ -392,8 +392,8 @@ def test_spot_price_history():
         ]
     )
     price = response["SpotPriceHistory"][0]
-    price["InstanceType"].should.equal("t3a.micro")
-    price["AvailabilityZone"].should.equal("us-east-1a")
+    assert price["InstanceType"] == "t3a.micro"
+    assert price["AvailabilityZone"] == "us-east-1a"
 
     # test instance types
     i_types = ["t3a.micro", "t3.micro"]
@@ -413,10 +413,10 @@ def test_request_spot_instances__instance_should_exist():
     request = client.describe_spot_instance_requests(
         SpotInstanceRequestIds=[request_id]
     )["SpotInstanceRequests"][0]
-    request.should.have.key("InstanceId")
+    assert "InstanceId" in request
     instance_id = request["InstanceId"]
 
     response = client.describe_instances(InstanceIds=[instance_id])
     instance = response["Reservations"][0]["Instances"][0]
-    instance.should.have.key("InstanceId").equals(instance_id)
-    instance.should.have.key("ImageId").equals(EXAMPLE_AMI_ID)
+    assert instance["InstanceId"] == instance_id
+    assert instance["ImageId"] == EXAMPLE_AMI_ID
