@@ -1,14 +1,13 @@
 import random
+from unittest import SkipTest
+from uuid import uuid4
 
 import boto3
-
 import pytest
-import sure  # noqa # pylint: disable=unused-import
 from botocore.exceptions import ClientError
+
 from moto import mock_ec2, settings
 from tests import EXAMPLE_AMI_ID
-from uuid import uuid4
-from unittest import SkipTest
 
 
 @mock_ec2
@@ -19,20 +18,20 @@ def test_subnets():
     subnet = ec2.create_subnet(VpcId=vpc.id, CidrBlock="10.0.0.0/18")
 
     ours = client.describe_subnets(SubnetIds=[subnet.id])["Subnets"]
-    ours.should.have.length_of(1)
+    assert len(ours) == 1
 
     client.delete_subnet(SubnetId=subnet.id)
 
     with pytest.raises(ClientError) as ex:
         client.describe_subnets(SubnetIds=[subnet.id])
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidSubnetID.NotFound")
+    assert err["Code"] == "InvalidSubnetID.NotFound"
 
     with pytest.raises(ClientError) as ex:
         client.delete_subnet(SubnetId=subnet.id)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidSubnetID.NotFound")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidSubnetID.NotFound"
 
 
 @mock_ec2
@@ -41,9 +40,9 @@ def test_subnet_create_vpc_validation():
 
     with pytest.raises(ClientError) as ex:
         ec2.create_subnet(VpcId="vpc-abcd1234", CidrBlock="10.0.0.0/18")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidVpcID.NotFound")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidVpcID.NotFound"
 
 
 @mock_ec2
@@ -58,12 +57,12 @@ def test_subnet_tagging():
     tag = client.describe_tags(
         Filters=[{"Name": "resource-id", "Values": [subnet.id]}]
     )["Tags"][0]
-    tag["Key"].should.equal("a key")
-    tag["Value"].should.equal("some value")
+    assert tag["Key"] == "a key"
+    assert tag["Value"] == "some value"
 
     # Refresh the subnet
     subnet = client.describe_subnets(SubnetIds=[subnet.id])["Subnets"][0]
-    subnet["Tags"].should.equal([{"Key": "a key", "Value": "some value"}])
+    assert subnet["Tags"] == [{"Key": "a key", "Value": "some value"}]
 
 
 @mock_ec2
@@ -73,7 +72,7 @@ def test_subnet_should_have_proper_availability_zone_set():
     subnetA = ec2.create_subnet(
         VpcId=vpcA.id, CidrBlock="10.0.0.0/24", AvailabilityZone="us-west-1b"
     )
-    subnetA.availability_zone.should.equal("us-west-1b")
+    assert subnetA.availability_zone == "us-west-1b"
 
 
 @mock_ec2
@@ -85,7 +84,7 @@ def test_availability_zone_in_create_subnet():
     subnet = ec2.create_subnet(
         VpcId=vpc.id, CidrBlock="172.31.48.0/20", AvailabilityZoneId="use1-az6"
     )
-    subnet.availability_zone_id.should.equal("use1-az6")
+    assert subnet.availability_zone_id == "use1-az6"
 
 
 @mock_ec2
@@ -95,15 +94,15 @@ def test_default_subnet():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
     default_vpc = list(ec2.vpcs.all())[0]
-    default_vpc.cidr_block.should.equal("172.31.0.0/16")
+    assert default_vpc.cidr_block == "172.31.0.0/16"
     default_vpc.reload()
-    default_vpc.is_default.should.equal(True)
+    assert default_vpc.is_default is True
 
     subnet = ec2.create_subnet(
         VpcId=default_vpc.id, CidrBlock="172.31.48.0/20", AvailabilityZone="us-west-1a"
     )
     subnet.reload()
-    subnet.map_public_ip_on_launch.should.equal(False)
+    assert subnet.map_public_ip_on_launch is False
 
 
 @mock_ec2
@@ -113,13 +112,13 @@ def test_non_default_subnet():
     # Create the non default VPC
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     vpc.reload()
-    vpc.is_default.should.equal(False)
+    assert vpc.is_default is False
 
     subnet = ec2.create_subnet(
         VpcId=vpc.id, CidrBlock="10.0.0.0/24", AvailabilityZone="us-west-1a"
     )
     subnet.reload()
-    subnet.map_public_ip_on_launch.should.equal(False)
+    assert subnet.map_public_ip_on_launch is False
 
 
 @mock_ec2
@@ -140,19 +139,19 @@ def test_modify_subnet_attribute_public_ip_on_launch():
     subnet.reload()
 
     # For non default subnet, attribute value should be 'False'
-    subnet.map_public_ip_on_launch.should.equal(False)
+    assert subnet.map_public_ip_on_launch is False
 
     client.modify_subnet_attribute(
         SubnetId=subnet.id, MapPublicIpOnLaunch={"Value": False}
     )
     subnet.reload()
-    subnet.map_public_ip_on_launch.should.equal(False)
+    assert subnet.map_public_ip_on_launch is False
 
     client.modify_subnet_attribute(
         SubnetId=subnet.id, MapPublicIpOnLaunch={"Value": True}
     )
     subnet.reload()
-    subnet.map_public_ip_on_launch.should.equal(True)
+    assert subnet.map_public_ip_on_launch is True
 
 
 @mock_ec2
@@ -174,19 +173,19 @@ def test_modify_subnet_attribute_assign_ipv6_address_on_creation():
     client.describe_subnets()
 
     # For non default subnet, attribute value should be 'False'
-    subnet.assign_ipv6_address_on_creation.should.equal(False)
+    assert subnet.assign_ipv6_address_on_creation is False
 
     client.modify_subnet_attribute(
         SubnetId=subnet.id, AssignIpv6AddressOnCreation={"Value": False}
     )
     subnet.reload()
-    subnet.assign_ipv6_address_on_creation.should.equal(False)
+    assert subnet.assign_ipv6_address_on_creation is False
 
     client.modify_subnet_attribute(
         SubnetId=subnet.id, AssignIpv6AddressOnCreation={"Value": True}
     )
     subnet.reload()
-    subnet.assign_ipv6_address_on_creation.should.equal(True)
+    assert subnet.assign_ipv6_address_on_creation is True
 
 
 @mock_ec2
@@ -218,16 +217,16 @@ def test_subnet_get_by_id():
     subnets_by_id = client.describe_subnets(SubnetIds=[subnetA.id, subnetB1.id])[
         "Subnets"
     ]
-    subnets_by_id.should.have.length_of(2)
+    assert len(subnets_by_id) == 2
     subnets_by_id = tuple(map(lambda s: s["SubnetId"], subnets_by_id))
-    subnetA.id.should.be.within(subnets_by_id)
-    subnetB1.id.should.be.within(subnets_by_id)
+    assert subnetA.id in subnets_by_id
+    assert subnetB1.id in subnets_by_id
 
     with pytest.raises(ClientError) as ex:
         client.describe_subnets(SubnetIds=["subnet-does_not_exist"])
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidSubnetID.NotFound")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidSubnetID.NotFound"
 
 
 @mock_ec2
@@ -251,45 +250,46 @@ def test_get_subnets_filtering():
     if settings.TEST_SERVER_MODE:
         # ServerMode may have other tests running that are creating subnets
         all_subnet_ids = [s["SubnetId"] for s in all_subnets]
-        all_subnet_ids.should.contain(subnetA.id)
-        all_subnet_ids.should.contain(subnetB1.id)
-        all_subnet_ids.should.contain(subnetB2.id)
+        assert subnetA.id in all_subnet_ids
+        assert subnetB1.id in all_subnet_ids
+        assert subnetB2.id in all_subnet_ids
     else:
-        all_subnets.should.have.length_of(3 + nr_of_a_zones)
+        assert len(all_subnets) == 3 + nr_of_a_zones
 
     # Filter by VPC ID
     subnets_by_vpc = client.describe_subnets(
         Filters=[{"Name": "vpc-id", "Values": [vpcB.id]}]
     )["Subnets"]
-    subnets_by_vpc.should.have.length_of(2)
-    set([subnet["SubnetId"] for subnet in subnets_by_vpc]).should.equal(
-        set([subnetB1.id, subnetB2.id])
-    )
+    assert len(subnets_by_vpc) == 2
+    assert set([subnet["SubnetId"] for subnet in subnets_by_vpc]) == {
+        subnetB1.id,
+        subnetB2.id,
+    }
 
     # Filter by CIDR variations
     subnets_by_cidr1 = client.describe_subnets(
         Filters=[{"Name": "cidr", "Values": ["10.0.0.0/24"]}]
     )["Subnets"]
     subnets_by_cidr1 = [s["SubnetId"] for s in subnets_by_cidr1]
-    subnets_by_cidr1.should.contain(subnetA.id)
-    subnets_by_cidr1.should.contain(subnetB1.id)
-    subnets_by_cidr1.shouldnt.contain(subnetB2.id)
+    assert subnetA.id in subnets_by_cidr1
+    assert subnetB1.id in subnets_by_cidr1
+    assert subnetB2.id not in subnets_by_cidr1
 
     subnets_by_cidr2 = client.describe_subnets(
         Filters=[{"Name": "cidr-block", "Values": ["10.0.0.0/24"]}]
     )["Subnets"]
     subnets_by_cidr2 = [s["SubnetId"] for s in subnets_by_cidr2]
-    subnets_by_cidr2.should.contain(subnetA.id)
-    subnets_by_cidr2.should.contain(subnetB1.id)
-    subnets_by_cidr2.shouldnt.contain(subnetB2.id)
+    assert subnetA.id in subnets_by_cidr2
+    assert subnetB1.id in subnets_by_cidr2
+    assert subnetB2.id not in subnets_by_cidr2
 
     subnets_by_cidr3 = client.describe_subnets(
         Filters=[{"Name": "cidrBlock", "Values": ["10.0.0.0/24"]}]
     )["Subnets"]
     subnets_by_cidr3 = [s["SubnetId"] for s in subnets_by_cidr3]
-    subnets_by_cidr3.should.contain(subnetA.id)
-    subnets_by_cidr3.should.contain(subnetB1.id)
-    subnets_by_cidr3.shouldnt.contain(subnetB2.id)
+    assert subnetA.id in subnets_by_cidr3
+    assert subnetB1.id in subnets_by_cidr3
+    assert subnetB2.id not in subnets_by_cidr3
 
     # Filter by VPC ID and CIDR
     subnets_by_vpc_and_cidr = client.describe_subnets(
@@ -298,15 +298,15 @@ def test_get_subnets_filtering():
             {"Name": "cidr", "Values": ["10.0.0.0/24"]},
         ]
     )["Subnets"]
-    subnets_by_vpc_and_cidr.should.have.length_of(1)
-    subnets_by_vpc_and_cidr[0]["SubnetId"].should.equal(subnetB1.id)
+    assert len(subnets_by_vpc_and_cidr) == 1
+    assert subnets_by_vpc_and_cidr[0]["SubnetId"] == subnetB1.id
 
     # Filter by subnet ID
     subnets_by_id = client.describe_subnets(
         Filters=[{"Name": "subnet-id", "Values": [subnetA.id]}]
     )["Subnets"]
-    subnets_by_id.should.have.length_of(1)
-    subnets_by_id[0]["SubnetId"].should.equal(subnetA.id)
+    assert len(subnets_by_id) == 1
+    assert subnets_by_id[0]["SubnetId"] == subnetA.id
 
     # Filter by availabilityZone
     subnets_by_az = client.describe_subnets(
@@ -315,21 +315,20 @@ def test_get_subnets_filtering():
             {"Name": "vpc-id", "Values": [vpcB.id]},
         ]
     )["Subnets"]
-    subnets_by_az.should.have.length_of(1)
-    subnets_by_az[0]["SubnetId"].should.equal(subnetB1.id)
+    assert len(subnets_by_az) == 1
+    assert subnets_by_az[0]["SubnetId"] == subnetB1.id
 
     if not settings.TEST_SERVER_MODE:
         # Filter by defaultForAz
         subnets_by_az = client.describe_subnets(
             Filters=[{"Name": "defaultForAz", "Values": ["true"]}]
         )["Subnets"]
-        subnets_by_az.should.have.length_of(nr_of_a_zones)
+        assert len(subnets_by_az) == nr_of_a_zones
 
         # Unsupported filter
         filters = [{"Name": "not-implemented-filter", "Values": ["foobar"]}]
-        client.describe_subnets.when.called_with(Filters=filters).should.throw(
-            NotImplementedError
-        )
+        with pytest.raises(NotImplementedError):
+            client.describe_subnets(Filters=filters)
 
 
 @mock_ec2
@@ -342,27 +341,23 @@ def test_create_subnet_response_fields():
         VpcId=vpc.id, CidrBlock="10.0.0.0/24", AvailabilityZone="us-west-1a"
     )["Subnet"]
 
-    subnet.should.have.key("AvailabilityZone")
-    subnet.should.have.key("AvailabilityZoneId")
-    subnet.should.have.key("AvailableIpAddressCount")
-    subnet.should.have.key("CidrBlock")
-    subnet.should.have.key("State")
-    subnet.should.have.key("SubnetId")
-    subnet.should.have.key("VpcId")
-    subnet.should.have.key("Tags")
-    subnet.should.have.key("DefaultForAz").which.should.equal(False)
-    subnet.should.have.key("MapPublicIpOnLaunch").which.should.equal(False)
-    subnet.should.have.key("OwnerId")
-    subnet.should.have.key("AssignIpv6AddressOnCreation").which.should.equal(False)
-    subnet.should.have.key("Ipv6Native").which.should.equal(False)
+    assert "AvailabilityZone" in subnet
+    assert "AvailabilityZoneId" in subnet
+    assert "AvailableIpAddressCount" in subnet
+    assert "CidrBlock" in subnet
+    assert "State" in subnet
+    assert "SubnetId" in subnet
+    assert "VpcId" in subnet
+    assert "Tags" in subnet
+    assert subnet["DefaultForAz"] is False
+    assert subnet["MapPublicIpOnLaunch"] is False
+    assert "OwnerId" in subnet
+    assert subnet["AssignIpv6AddressOnCreation"] is False
+    assert subnet["Ipv6Native"] is False
 
-    subnet_arn = "arn:aws:ec2:{region}:{owner_id}:subnet/{subnet_id}".format(
-        region=subnet["AvailabilityZone"][0:-1],
-        owner_id=subnet["OwnerId"],
-        subnet_id=subnet["SubnetId"],
-    )
-    subnet.should.have.key("SubnetArn").which.should.equal(subnet_arn)
-    subnet.should.have.key("Ipv6CidrBlockAssociationSet").which.should.equal([])
+    subnet_arn = f"arn:aws:ec2:{subnet['AvailabilityZone'][0:-1]}:{subnet['OwnerId']}:subnet/{subnet['SubnetId']}"
+    assert subnet["SubnetArn"] == subnet_arn
+    assert subnet["Ipv6CidrBlockAssociationSet"] == []
 
 
 @mock_ec2
@@ -376,30 +371,26 @@ def test_describe_subnet_response_fields():
     )
 
     subnets = client.describe_subnets(SubnetIds=[subnet_object.id])["Subnets"]
-    subnets.should.have.length_of(1)
+    assert len(subnets) == 1
     subnet = subnets[0]
 
-    subnet.should.have.key("AvailabilityZone")
-    subnet.should.have.key("AvailabilityZoneId")
-    subnet.should.have.key("AvailableIpAddressCount")
-    subnet.should.have.key("CidrBlock")
-    subnet.should.have.key("State")
-    subnet.should.have.key("SubnetId")
-    subnet.should.have.key("VpcId")
-    subnet.shouldnt.have.key("Tags")
-    subnet.should.have.key("DefaultForAz").which.should.equal(False)
-    subnet.should.have.key("MapPublicIpOnLaunch").which.should.equal(False)
-    subnet.should.have.key("OwnerId")
-    subnet.should.have.key("AssignIpv6AddressOnCreation").which.should.equal(False)
-    subnet.should.have.key("Ipv6Native").which.should.equal(False)
+    assert "AvailabilityZone" in subnet
+    assert "AvailabilityZoneId" in subnet
+    assert "AvailableIpAddressCount" in subnet
+    assert "CidrBlock" in subnet
+    assert "State" in subnet
+    assert "SubnetId" in subnet
+    assert "VpcId" in subnet
+    assert "Tags" not in subnet
+    assert subnet["DefaultForAz"] is False
+    assert subnet["MapPublicIpOnLaunch"] is False
+    assert "OwnerId" in subnet
+    assert subnet["AssignIpv6AddressOnCreation"] is False
+    assert subnet["Ipv6Native"] is False
 
-    subnet_arn = "arn:aws:ec2:{region}:{owner_id}:subnet/{subnet_id}".format(
-        region=subnet["AvailabilityZone"][0:-1],
-        owner_id=subnet["OwnerId"],
-        subnet_id=subnet["SubnetId"],
-    )
-    subnet.should.have.key("SubnetArn").which.should.equal(subnet_arn)
-    subnet.should.have.key("Ipv6CidrBlockAssociationSet").which.should.equal([])
+    subnet_arn = f"arn:aws:ec2:{subnet['AvailabilityZone'][0:-1]}:{subnet['OwnerId']}:subnet/{subnet['SubnetId']}"
+    assert subnet["SubnetArn"] == subnet_arn
+    assert subnet["Ipv6CidrBlockAssociationSet"] == []
 
 
 @mock_ec2
@@ -418,9 +409,7 @@ def test_create_subnet_with_invalid_availability_zone():
         )
     assert str(ex.value).startswith(
         "An error occurred (InvalidParameterValue) when calling the CreateSubnet "
-        "operation: Value ({}) for parameter availabilityZone is invalid. Subnets can currently only be created in the following availability zones: ".format(
-            subnet_availability_zone
-        )
+        f"operation: Value ({subnet_availability_zone}) for parameter availabilityZone is invalid. Subnets can currently only be created in the following availability zones: "
     )
 
 
@@ -430,14 +419,14 @@ def test_create_subnet_with_invalid_cidr_range():
 
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     vpc.reload()
-    vpc.is_default.should.equal(False)
+    assert vpc.is_default is False
 
     subnet_cidr_block = "10.1.0.0/20"
     with pytest.raises(ClientError) as ex:
         ec2.create_subnet(VpcId=vpc.id, CidrBlock=subnet_cidr_block)
-    str(ex.value).should.equal(
-        "An error occurred (InvalidSubnet.Range) when calling the CreateSubnet "
-        "operation: The CIDR '{}' is invalid.".format(subnet_cidr_block)
+    assert (
+        str(ex.value)
+        == f"An error occurred (InvalidSubnet.Range) when calling the CreateSubnet operation: The CIDR '{subnet_cidr_block}' is invalid."
     )
 
 
@@ -448,14 +437,14 @@ def test_create_subnet_with_invalid_cidr_range_multiple_vpc_cidr_blocks():
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     ec2.meta.client.associate_vpc_cidr_block(CidrBlock="10.1.0.0/16", VpcId=vpc.id)
     vpc.reload()
-    vpc.is_default.should.equal(False)
+    assert vpc.is_default is False
 
     subnet_cidr_block = "10.2.0.0/20"
     with pytest.raises(ClientError) as ex:
         ec2.create_subnet(VpcId=vpc.id, CidrBlock=subnet_cidr_block)
-    str(ex.value).should.equal(
-        "An error occurred (InvalidSubnet.Range) when calling the CreateSubnet "
-        "operation: The CIDR '{}' is invalid.".format(subnet_cidr_block)
+    assert (
+        str(ex.value)
+        == f"An error occurred (InvalidSubnet.Range) when calling the CreateSubnet operation: The CIDR '{subnet_cidr_block}' is invalid."
     )
 
 
@@ -465,16 +454,14 @@ def test_create_subnet_with_invalid_cidr_block_parameter():
 
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     vpc.reload()
-    vpc.is_default.should.equal(False)
+    assert vpc.is_default is False
 
     subnet_cidr_block = "1000.1.0.0/20"
     with pytest.raises(ClientError) as ex:
         ec2.create_subnet(VpcId=vpc.id, CidrBlock=subnet_cidr_block)
-    str(ex.value).should.equal(
-        "An error occurred (InvalidParameterValue) when calling the CreateSubnet "
-        "operation: Value ({}) for parameter cidrBlock is invalid. This is not a valid CIDR block.".format(
-            subnet_cidr_block
-        )
+    assert (
+        str(ex.value)
+        == f"An error occurred (InvalidParameterValue) when calling the CreateSubnet operation: Value ({subnet_cidr_block}) for parameter cidrBlock is invalid. This is not a valid CIDR block."
     )
 
 
@@ -486,7 +473,7 @@ def test_create_subnets_with_multiple_vpc_cidr_blocks():
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     ec2.meta.client.associate_vpc_cidr_block(CidrBlock="10.1.0.0/16", VpcId=vpc.id)
     vpc.reload()
-    vpc.is_default.should.equal(False)
+    assert vpc.is_default is False
 
     subnet_cidr_block_primary = "10.0.0.0/24"
     subnet_primary = ec2.create_subnet(
@@ -501,21 +488,21 @@ def test_create_subnets_with_multiple_vpc_cidr_blocks():
     subnets = client.describe_subnets(
         SubnetIds=[subnet_primary.id, subnet_secondary.id]
     )["Subnets"]
-    subnets.should.have.length_of(2)
+    assert len(subnets) == 2
 
     for subnet in subnets:
-        subnet.should.have.key("AvailabilityZone")
-        subnet.should.have.key("AvailabilityZoneId")
-        subnet.should.have.key("AvailableIpAddressCount")
-        subnet.should.have.key("CidrBlock")
-        subnet.should.have.key("State")
-        subnet.should.have.key("SubnetId")
-        subnet.should.have.key("VpcId")
-        subnet.shouldnt.have.key("Tags")
-        subnet.should.have.key("DefaultForAz").which.should.equal(False)
-        subnet.should.have.key("MapPublicIpOnLaunch").which.should.equal(False)
-        subnet.should.have.key("OwnerId")
-        subnet.should.have.key("AssignIpv6AddressOnCreation").which.should.equal(False)
+        assert "AvailabilityZone" in subnet
+        assert "AvailabilityZoneId" in subnet
+        assert "AvailableIpAddressCount" in subnet
+        assert "CidrBlock" in subnet
+        assert "State" in subnet
+        assert "SubnetId" in subnet
+        assert "VpcId" in subnet
+        assert "Tags" not in subnet
+        assert subnet["DefaultForAz"] is False
+        assert subnet["MapPublicIpOnLaunch"] is False
+        assert "OwnerId" in subnet
+        assert subnet["AssignIpv6AddressOnCreation"] is False
 
 
 @mock_ec2
@@ -524,17 +511,15 @@ def test_create_subnets_with_overlapping_cidr_blocks():
 
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     vpc.reload()
-    vpc.is_default.should.equal(False)
+    assert vpc.is_default is False
 
     subnet_cidr_block = "10.0.0.0/24"
     with pytest.raises(ClientError) as ex:
         ec2.create_subnet(VpcId=vpc.id, CidrBlock=subnet_cidr_block)
         ec2.create_subnet(VpcId=vpc.id, CidrBlock=subnet_cidr_block)
-    str(ex.value).should.equal(
-        "An error occurred (InvalidSubnet.Conflict) when calling the CreateSubnet "
-        "operation: The CIDR '{}' conflicts with another subnet".format(
-            subnet_cidr_block
-        )
+    assert (
+        str(ex.value)
+        == f"An error occurred (InvalidSubnet.Conflict) when calling the CreateSubnet operation: The CIDR '{subnet_cidr_block}' conflicts with another subnet"
     )
 
 
@@ -585,7 +570,7 @@ def test_available_ip_addresses_in_subnet():
         ("10.0.0.0/27", 27),
         ("10.0.0.0/28", 11),
     ]
-    for (cidr, expected_count) in cidr_range_addresses:
+    for cidr, expected_count in cidr_range_addresses:
         validate_subnet_details(client, vpc, cidr, expected_count)
 
 
@@ -614,7 +599,7 @@ def test_available_ip_addresses_in_subnet_with_enis():
         ("10.0.0.0/25", 123),
         ("10.0.0.0/26", 59),
     ]
-    for (cidr, expected_count) in cidr_range_addresses:
+    for cidr, expected_count in cidr_range_addresses:
         validate_subnet_details_after_creating_eni(client, vpc, cidr, expected_count)
 
 
@@ -622,7 +607,7 @@ def validate_subnet_details(client, vpc, cidr, expected_ip_address_count):
     subnet = client.create_subnet(
         VpcId=vpc.id, CidrBlock=cidr, AvailabilityZone="us-west-1b"
     )["Subnet"]
-    subnet["AvailableIpAddressCount"].should.equal(expected_ip_address_count)
+    assert subnet["AvailableIpAddressCount"] == expected_ip_address_count
     client.delete_subnet(SubnetId=subnet["SubnetId"])
 
 
@@ -672,20 +657,11 @@ def validate_subnet_details_after_creating_eni(
         private_addresses.extend(
             [address["PrivateIpAddress"] for address in eni["PrivateIpAddresses"]]
         )
-    error_msg = (
-        "Nr of IP addresses for Subnet with CIDR {0} is incorrect. Expected: {1}, Actual: {2}. "
-        "Addresses: {3}"
-    )
-    with sure.ensure(
-        error_msg,
-        cidr,
-        str(expected_ip_address_count),
-        updated_subnet["AvailableIpAddressCount"],
-        str(private_addresses),
-    ):
-        updated_subnet["AvailableIpAddressCount"].should.equal(
-            expected_ip_address_count - ip_addresses_assigned
-        )
+    error_msg = f"Nr of IP addresses for Subnet with CIDR {cidr} is incorrect. Expected: {expected_ip_address_count}, Actual: {updated_subnet['AvailableIpAddressCount']}. Addresses: {private_addresses}"
+    assert (
+        updated_subnet["AvailableIpAddressCount"]
+        == expected_ip_address_count - ip_addresses_assigned
+    ), error_msg
     # Clean up, as we have to create a few more subnets that shouldn't interfere with each other
     for eni in enis_created:
         client.delete_network_interface(NetworkInterfaceId=eni["NetworkInterfaceId"])
@@ -694,7 +670,7 @@ def validate_subnet_details_after_creating_eni(
 
 @mock_ec2
 def test_run_instances_should_attach_to_default_subnet():
-    # https://github.com/spulec/moto/issues/2877
+    # https://github.com/getmoto/moto/issues/2877
     ec2 = boto3.resource("ec2", region_name="sa-east-1")
     client = boto3.client("ec2", region_name="sa-east-1")
     sec_group_name = str(uuid4())[0:6]
@@ -744,26 +720,26 @@ def test_describe_subnets_by_vpc_id():
     subnets = client.describe_subnets(
         Filters=[{"Name": "vpc-id", "Values": [vpc1.id]}]
     ).get("Subnets", [])
-    subnets.should.have.length_of(1)
-    subnets[0]["SubnetId"].should.equal(subnet1.id)
+    assert len(subnets) == 1
+    assert subnets[0]["SubnetId"] == subnet1.id
 
     subnets = client.describe_subnets(
         Filters=[{"Name": "vpc-id", "Values": [vpc2.id]}]
     ).get("Subnets", [])
-    subnets.should.have.length_of(1)
-    subnets[0]["SubnetId"].should.equal(subnet2.id)
+    assert len(subnets) == 1
+    assert subnets[0]["SubnetId"] == subnet2.id
 
     # Specify multiple VPCs in Filter.
     subnets = client.describe_subnets(
         Filters=[{"Name": "vpc-id", "Values": [vpc1.id, vpc2.id]}]
     ).get("Subnets", [])
-    subnets.should.have.length_of(2)
+    assert len(subnets) == 2
 
     # Specify mismatched SubnetIds/Filters.
     subnets = client.describe_subnets(
         SubnetIds=[subnet1.id], Filters=[{"Name": "vpc-id", "Values": [vpc2.id]}]
     ).get("Subnets", [])
-    subnets.should.have.length_of(0)
+    assert len(subnets) == 0
 
 
 @mock_ec2
@@ -780,7 +756,7 @@ def test_describe_subnets_by_state():
         Filters=[{"Name": "state", "Values": ["available"]}]
     ).get("Subnets", [])
     for subnet in subnets:
-        subnet["State"].should.equal("available")
+        assert subnet["State"] == "available"
 
 
 @mock_ec2
@@ -795,24 +771,22 @@ def test_associate_subnet_cidr_block():
 
     subnets = client.describe_subnets(SubnetIds=[subnet_object.id])["Subnets"]
     association_set = subnets[0]["Ipv6CidrBlockAssociationSet"]
-    association_set.should.equal([])
+    assert association_set == []
 
     res = client.associate_subnet_cidr_block(
         Ipv6CidrBlock="1080::1:200C:417A/112", SubnetId=subnet_object.id
     )
-    res.should.have.key("Ipv6CidrBlockAssociation")
+    assert "Ipv6CidrBlockAssociation" in res
     association = res["Ipv6CidrBlockAssociation"]
-    association.should.have.key("AssociationId").match("subnet-cidr-assoc-[a-z0-9]+")
-    association.should.have.key("Ipv6CidrBlock").equals("1080::1:200C:417A/112")
-    association.should.have.key("Ipv6CidrBlockState").equals({"State": "associated"})
+    assert association["AssociationId"].startswith("subnet-cidr-assoc-")
+    assert association["Ipv6CidrBlock"] == "1080::1:200C:417A/112"
+    assert association["Ipv6CidrBlockState"] == {"State": "associated"}
 
     subnets = client.describe_subnets(SubnetIds=[subnet_object.id])["Subnets"]
     association_set = subnets[0]["Ipv6CidrBlockAssociationSet"]
-    association_set.should.have.length_of(1)
-    association_set[0].should.have.key("AssociationId").equal(
-        association["AssociationId"]
-    )
-    association_set[0].should.have.key("Ipv6CidrBlock").equals("1080::1:200C:417A/112")
+    assert len(association_set) == 1
+    assert association_set[0]["AssociationId"] == association["AssociationId"]
+    assert association_set[0]["Ipv6CidrBlock"] == "1080::1:200C:417A/112"
 
 
 @mock_ec2
@@ -834,14 +808,14 @@ def test_disassociate_subnet_cidr_block():
 
     subnets = client.describe_subnets(SubnetIds=[subnet_object.id])["Subnets"]
     association_set = subnets[0]["Ipv6CidrBlockAssociationSet"]
-    association_set.should.have.length_of(2)
+    assert len(association_set) == 2
 
     client.disassociate_subnet_cidr_block(AssociationId=association_id)
 
     subnets = client.describe_subnets(SubnetIds=[subnet_object.id])["Subnets"]
     association_set = subnets[0]["Ipv6CidrBlockAssociationSet"]
-    association_set.should.have.length_of(1)
-    association_set[0]["Ipv6CidrBlock"].should.equal("1080::1:200C:417A/111")
+    assert len(association_set) == 1
+    assert association_set[0]["Ipv6CidrBlock"] == "1080::1:200C:417A/111"
 
 
 @mock_ec2
@@ -850,8 +824,9 @@ def test_describe_subnets_dryrun():
 
     with pytest.raises(ClientError) as ex:
         client.describe_subnets(DryRun=True)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the DescribeSubnets operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the DescribeSubnets operation: Request would have succeeded, but DryRun flag is set"
     )
