@@ -1,6 +1,6 @@
 import boto3
 
-from moto import mock_elb, mock_ec2
+from moto import mock_ec2, mock_elb
 
 
 @mock_elb
