@@ -1,6 +1,4 @@
-import sure  # noqa # pylint: disable=unused-import
-
-from moto import mock_elbv2, mock_ec2
+from moto import mock_ec2, mock_elbv2
 
 from .test_elbv2 import create_load_balancer
 
@@ -35,7 +33,7 @@ def test_create_listener_rule_with_tags():
     # Ensure the tags persisted
     response = elbv2.describe_tags(ResourceArns=[rule_arn])
     tags = {d["Key"]: d["Value"] for d in response["TagDescriptions"][0]["Tags"]}
-    tags.should.equal({"k1": "v1"})
+    assert tags == {"k1": "v1"}
 
 
 @mock_elbv2
@@ -62,7 +60,7 @@ def test_listener_rule_add_remove_tags():
     elbv2.add_tags(ResourceArns=[rule_arn], Tags=[{"Key": "a", "Value": "b"}])
 
     tags = elbv2.describe_tags(ResourceArns=[rule_arn])["TagDescriptions"][0]["Tags"]
-    tags.should.equal([{"Key": "a", "Value": "b"}])
+    assert tags == [{"Key": "a", "Value": "b"}]
 
     elbv2.add_tags(
         ResourceArns=[rule_arn],
@@ -74,20 +72,16 @@ def test_listener_rule_add_remove_tags():
     )
 
     tags = elbv2.describe_tags(ResourceArns=[rule_arn])["TagDescriptions"][0]["Tags"]
-    tags.should.equal(
-        [
-            {"Key": "a", "Value": "b"},
-            {"Key": "b", "Value": "b"},
-            {"Key": "c", "Value": "b"},
-        ]
-    )
+    assert tags == [
+        {"Key": "a", "Value": "b"},
+        {"Key": "b", "Value": "b"},
+        {"Key": "c", "Value": "b"},
+    ]
 
     elbv2.remove_tags(ResourceArns=[rule_arn], TagKeys=["a"])
 
     tags = elbv2.describe_tags(ResourceArns=[rule_arn])["TagDescriptions"][0]["Tags"]
-    tags.should.equal(
-        [
-            {"Key": "b", "Value": "b"},
-            {"Key": "c", "Value": "b"},
-        ]
-    )
+    assert tags == [
+        {"Key": "b", "Value": "b"},
+        {"Key": "c", "Value": "b"},
+    ]
