@@ -1,4 +1,4 @@
-from moto import mock_elbv2, mock_ec2
+from moto import mock_ec2, mock_elbv2
 
 from .test_elbv2 import create_load_balancer
 
