@@ -1,10 +1,7 @@
+"""Test the different server responses."""
 import json
-import sure  # noqa # pylint: disable=unused-import
-import moto.server as server
 
-"""
-Test the different server responses
-"""
+import moto.server as server
 
 
 def test_list_virtual_clusters():
@@ -13,4 +10,4 @@ def test_list_virtual_clusters():
 
     res = test_client.get("/virtualclusters")
 
-    json.loads(res.data).should.have.key("virtualClusters")
+    assert "virtualClusters" in json.loads(res.data)
