@@ -1,13 +1,12 @@
 """Unit tests specific to basic Firehose Delivery Stream-related APIs."""
-from unittest import SkipTest
 import warnings
+from unittest import SkipTest
 
 import boto3
-from botocore.exceptions import ClientError
 import pytest
+from botocore.exceptions import ClientError
 
-from moto import mock_firehose
-from moto import settings
+from moto import mock_firehose, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.firehose.models import DeliveryStream
 from moto.moto_api._internal import mock_random
@@ -32,18 +31,6 @@ def test_warnings():
     client = boto3.client("firehose", region_name=TEST_REGION)
     s3_dest_config = sample_s3_dest_config()
 
-    # DeliveryStreamEncryption is not supported.
-    stream_name = f"test_warning_{mock_random.get_random_hex(6)}"
-    with warnings.catch_warnings(record=True) as warn_msg:
-        client.create_delivery_stream(
-            DeliveryStreamName=stream_name,
-            ExtendedS3DestinationConfiguration=s3_dest_config,
-            DeliveryStreamEncryptionConfigurationInput={"KeyType": "AWS_OWNED_CMK"},
-        )
-    assert "server-side encryption enabled is not yet implemented" in str(
-        warn_msg[-1].message
-    )
-
     # Can't create a delivery stream for Splunk as it's unimplemented.
     stream_name = f"test_splunk_destination_{mock_random.get_random_hex(6)}"
     with warnings.catch_warnings(record=True) as warn_msg:
