@@ -1,10 +1,11 @@
+from uuid import uuid4
+
 import boto3
-import sure  # noqa # pylint: disable=unused-import
 import pytest
+from botocore.exceptions import ClientError
 
 from moto import mock_glacier
-from moto.core import ACCOUNT_ID
-from uuid import uuid4
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
 @mock_glacier
@@ -14,13 +15,13 @@ def test_describe_vault():
     client.create_vault(vaultName="myvault")
 
     describe = client.describe_vault(vaultName="myvault")
-    describe.should.have.key("NumberOfArchives").equal(0)
-    describe.should.have.key("SizeInBytes").equal(0)
-    describe.should.have.key("LastInventoryDate")
-    describe.should.have.key("CreationDate")
-    describe.should.have.key("VaultName").equal("myvault")
-    describe.should.have.key("VaultARN").equal(
-        f"arn:aws:glacier:us-west-2:{ACCOUNT_ID}:vaults/myvault"
+    assert describe["NumberOfArchives"] == 0
+    assert describe["SizeInBytes"] == 0
+    assert "LastInventoryDate" in describe
+    assert "CreationDate" in describe
+    assert describe["VaultName"] == "myvault"
+    assert (
+        describe["VaultARN"] == f"arn:aws:glacier:us-west-2:{ACCOUNT_ID}:vaults/myvault"
     )
 
 
@@ -32,8 +33,10 @@ def test_delete_vault_boto3():
 
     client.delete_vault(vaultName="myvault")
 
-    with pytest.raises(Exception):
+    with pytest.raises(ClientError) as exc:
         client.describe_vault(vaultName="myvault")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "VaultNotFound"
 
 
 @mock_glacier
@@ -46,8 +49,8 @@ def test_list_vaults():
     # Verify we cannot find these vaults yet
     vaults = client.list_vaults()["VaultList"]
     found_vaults = [v["VaultName"] for v in vaults]
-    found_vaults.shouldnt.contain(vault1_name)
-    found_vaults.shouldnt.contain(vault2_name)
+    assert vault1_name not in found_vaults
+    assert vault2_name not in found_vaults
 
     client.create_vault(vaultName=vault1_name)
     client.create_vault(vaultName=vault2_name)
@@ -55,19 +58,20 @@ def test_list_vaults():
     # Verify we can find the created vaults
     vaults = client.list_vaults()["VaultList"]
     found_vaults = [v["VaultName"] for v in vaults]
-    found_vaults.should.contain(vault1_name)
-    found_vaults.should.contain(vault2_name)
+    assert vault1_name in found_vaults
+    assert vault2_name in found_vaults
 
     # Verify all the vaults are in the correct format
     for vault in vaults:
-        vault.should.have.key("NumberOfArchives").equal(0)
-        vault.should.have.key("SizeInBytes").equal(0)
-        vault.should.have.key("LastInventoryDate")
-        vault.should.have.key("CreationDate")
-        vault.should.have.key("VaultName")
+        assert vault["NumberOfArchives"] == 0
+        assert vault["SizeInBytes"] == 0
+        assert "LastInventoryDate" in vault
+        assert "CreationDate" in vault
+        assert "VaultName" in vault
         vault_name = vault["VaultName"]
-        vault.should.have.key("VaultARN").equal(
-            f"arn:aws:glacier:us-west-2:{ACCOUNT_ID}:vaults/{vault_name}"
+        assert (
+            vault["VaultARN"]
+            == f"arn:aws:glacier:us-west-2:{ACCOUNT_ID}:vaults/{vault_name}"
         )
 
     # Verify a deleted vault is no longer returned
@@ -75,8 +79,8 @@ def test_list_vaults():
 
     vaults = client.list_vaults()["VaultList"]
     found_vaults = [v["VaultName"] for v in vaults]
-    found_vaults.shouldnt.contain(vault1_name)
-    found_vaults.should.contain(vault2_name)
+    assert vault1_name not in found_vaults
+    assert vault2_name in found_vaults
 
 
 @mock_glacier
@@ -84,4 +88,4 @@ def test_vault_name_with_special_characters():
     vault_name = "Vault.name-with_Special.characters"
     glacier = boto3.resource("glacier", region_name="us-west-2")
     vault = glacier.create_vault(accountId="-", vaultName=vault_name)
-    vault.name.should.equal(vault_name)
+    assert vault.name == vault_name
