@@ -1,14 +1,14 @@
 import copy
 
-from .fixtures.datacatalog import TABLE_INPUT, PARTITION_INPUT, DATABASE_INPUT
+from .fixtures.datacatalog import DATABASE_INPUT, PARTITION_INPUT, TABLE_INPUT
 from .fixtures.schema_registry import (
-    TEST_REGISTRY_NAME,
-    TEST_SCHEMA_NAME,
-    TEST_BACKWARD_COMPATIBILITY,
     TEST_AVRO_DATA_FORMAT,
     TEST_AVRO_SCHEMA_DEFINITION,
-    TEST_SCHEMA_ID,
+    TEST_BACKWARD_COMPATIBILITY,
     TEST_NEW_AVRO_SCHEMA_DEFINITION,
+    TEST_REGISTRY_NAME,
+    TEST_SCHEMA_ID,
+    TEST_SCHEMA_NAME,
 )
 
 
