@@ -1,7 +1,7 @@
 import boto3
-from botocore.client import ClientError
 import freezegun
 import pytest
+from botocore.client import ClientError
 
 from moto import mock_greengrass
 from moto.settings import TEST_SERVER_MODE
@@ -19,7 +19,6 @@ from moto.settings import TEST_SERVER_MODE
 @freezegun.freeze_time("2022-06-01 12:00:00")
 @mock_greengrass
 def test_create_subscription_definition(target):
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -35,21 +34,20 @@ def test_create_subscription_definition(target):
     res = client.create_subscription_definition(
         InitialVersion=init_ver, Name=subscription_name
     )
-    res.should.have.key("Arn")
-    res.should.have.key("Id")
-    res.should.have.key("LatestVersion")
-    res.should.have.key("LatestVersionArn")
-    res.should.have.key("Name").equals(subscription_name)
-    res["ResponseMetadata"]["HTTPStatusCode"].should.equal(201)
+    assert "Arn" in res
+    assert "Id" in res
+    assert "LatestVersion" in res
+    assert "LatestVersionArn" in res
+    assert res["Name"] == subscription_name
+    assert res["ResponseMetadata"]["HTTPStatusCode"] == 201
 
     if not TEST_SERVER_MODE:
-        res.should.have.key("CreationTimestamp").equals("2022-06-01T12:00:00.000Z")
-        res.should.have.key("LastUpdatedTimestamp").equals("2022-06-01T12:00:00.000Z")
+        assert res["CreationTimestamp"] == "2022-06-01T12:00:00.000Z"
+        assert res["LastUpdatedTimestamp"] == "2022-06-01T12:00:00.000Z"
 
 
 @mock_greengrass
 def test_create_subscription_definition_with_invalid_target():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -66,15 +64,16 @@ def test_create_subscription_definition_with_invalid_target():
             InitialVersion=init_ver, Name="TestSubscription"
         )
 
-    ex.value.response["Error"]["Message"].should.equal(
-        "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription target is invalid. ID is '123456' and Target is 'foo'])"
+    err = ex.value.response["Error"]
+    assert (
+        err["Message"]
+        == "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription target is invalid. ID is '123456' and Target is 'foo'])"
     )
-    ex.value.response["Error"]["Code"].should.equal("400")
+    assert err["Code"] == "400"
 
 
 @mock_greengrass
 def test_create_subscription_definition_with_invalid_source():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -91,16 +90,17 @@ def test_create_subscription_definition_with_invalid_source():
             InitialVersion=init_ver, Name="TestSubscription"
         )
 
-    ex.value.response["Error"]["Message"].should.equal(
-        "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription source is invalid. ID is '123456' and Source is 'foo'])"
+    err = ex.value.response["Error"]
+    assert (
+        err["Message"]
+        == "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription source is invalid. ID is '123456' and Source is 'foo'])"
     )
-    ex.value.response["Error"]["Code"].should.equal("400")
+    assert err["Code"] == "400"
 
 
 @freezegun.freeze_time("2022-06-01 12:00:00")
 @mock_greengrass
 def test_list_subscription_definitions():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -118,27 +118,22 @@ def test_list_subscription_definitions():
     )
 
     res = client.list_subscription_definitions()
-    res["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+    assert res["ResponseMetadata"]["HTTPStatusCode"] == 200
 
     subscription_def = res["Definitions"][0]
-    subscription_def.should.have.key("Name").equals(subscription_name)
-    subscription_def.should.have.key("Arn")
-    subscription_def.should.have.key("Id")
-    subscription_def.should.have.key("LatestVersion")
-    subscription_def.should.have.key("LatestVersionArn")
+    assert subscription_def["Name"] == subscription_name
+    assert "Arn" in subscription_def
+    assert "Id" in subscription_def
+    assert "LatestVersion" in subscription_def
+    assert "LatestVersionArn" in subscription_def
     if not TEST_SERVER_MODE:
-        subscription_def.should.have.key("CreationTimestamp").equal(
-            "2022-06-01T12:00:00.000Z"
-        )
-        subscription_def.should.have.key("LastUpdatedTimestamp").equals(
-            "2022-06-01T12:00:00.000Z"
-        )
+        assert subscription_def["CreationTimestamp"] == "2022-06-01T12:00:00.000Z"
+        assert subscription_def["LastUpdatedTimestamp"] == "2022-06-01T12:00:00.000Z"
 
 
 @freezegun.freeze_time("2022-06-01 12:00:00")
 @mock_greengrass
 def test_get_subscription_definition():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -164,38 +159,33 @@ def test_get_subscription_definition():
         SubscriptionDefinitionId=subscription_def_id
     )
 
-    get_res.should.have.key("Name").equals(subscription_name)
-    get_res.should.have.key("Arn").equals(arn)
-    get_res.should.have.key("Id").equals(subscription_def_id)
-    get_res.should.have.key("LatestVersion").equals(latest_version)
-    get_res.should.have.key("LatestVersionArn").equals(latest_version_arn)
-    get_res["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+    assert get_res["Name"] == subscription_name
+    assert get_res["Arn"] == arn
+    assert get_res["Id"] == subscription_def_id
+    assert get_res["LatestVersion"] == latest_version
+    assert get_res["LatestVersionArn"] == latest_version_arn
+    assert get_res["ResponseMetadata"]["HTTPStatusCode"] == 200
 
     if not TEST_SERVER_MODE:
-        get_res.should.have.key("CreationTimestamp").equal("2022-06-01T12:00:00.000Z")
-        get_res.should.have.key("LastUpdatedTimestamp").equals(
-            "2022-06-01T12:00:00.000Z"
-        )
+        assert get_res["CreationTimestamp"] == "2022-06-01T12:00:00.000Z"
+        assert get_res["LastUpdatedTimestamp"] == "2022-06-01T12:00:00.000Z"
 
 
 @mock_greengrass
 def test_get_subscription_definition_with_invalid_id():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     with pytest.raises(ClientError) as ex:
         client.get_subscription_definition(
             SubscriptionDefinitionId="b552443b-1888-469b-81f8-0ebc5ca92949"
         )
 
-    ex.value.response["Error"]["Message"].should.equal(
-        "That Subscription List Definition does not exist."
-    )
-    ex.value.response["Error"]["Code"].should.equal("IdNotFoundException")
+    err = ex.value.response["Error"]
+    assert err["Message"] == "That Subscription List Definition does not exist."
+    assert err["Code"] == "IdNotFoundException"
 
 
 @mock_greengrass
 def test_delete_subscription_definition():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -215,12 +205,11 @@ def test_delete_subscription_definition():
     del_res = client.delete_subscription_definition(
         SubscriptionDefinitionId=subscription_def_id
     )
-    del_res["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+    assert del_res["ResponseMetadata"]["HTTPStatusCode"] == 200
 
 
 @mock_greengrass
 def test_update_subscription_definition():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -241,17 +230,16 @@ def test_update_subscription_definition():
     update_res = client.update_subscription_definition(
         SubscriptionDefinitionId=subscription_def_id, Name=updated_subscription_name
     )
-    update_res["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+    assert update_res["ResponseMetadata"]["HTTPStatusCode"] == 200
 
     get_res = client.get_subscription_definition(
         SubscriptionDefinitionId=subscription_def_id
     )
-    get_res.should.have.key("Name").equals(updated_subscription_name)
+    assert get_res["Name"] == updated_subscription_name
 
 
 @mock_greengrass
 def test_update_subscription_definition_with_empty_name():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -272,48 +260,40 @@ def test_update_subscription_definition_with_empty_name():
         client.update_subscription_definition(
             SubscriptionDefinitionId=subscription_def_id, Name=""
         )
-    ex.value.response["Error"]["Message"].should.equal(
-        "Input does not contain any attributes to be updated"
-    )
-    ex.value.response["Error"]["Code"].should.equal(
-        "InvalidContainerDefinitionException"
-    )
+    err = ex.value.response["Error"]
+    assert err["Message"] == "Input does not contain any attributes to be updated"
+    assert err["Code"] == "InvalidContainerDefinitionException"
 
 
 @mock_greengrass
 def test_update_subscription_definition_with_invalid_id():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
 
     with pytest.raises(ClientError) as ex:
         client.update_subscription_definition(
             SubscriptionDefinitionId="6fbffc21-989e-4d29-a793-a42f450a78c6", Name="123"
         )
-    ex.value.response["Error"]["Message"].should.equal(
-        "That subscriptions definition does not exist."
-    )
-    ex.value.response["Error"]["Code"].should.equal("IdNotFoundException")
+    err = ex.value.response["Error"]
+    assert err["Message"] == "That subscriptions definition does not exist."
+    assert err["Code"] == "IdNotFoundException"
 
 
 @mock_greengrass
 def test_delete_subscription_definition_with_invalid_id():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
 
     with pytest.raises(ClientError) as ex:
         client.delete_subscription_definition(
             SubscriptionDefinitionId="6fbffc21-989e-4d29-a793-a42f450a78c6"
         )
-    ex.value.response["Error"]["Message"].should.equal(
-        "That subscriptions definition does not exist."
-    )
-    ex.value.response["Error"]["Code"].should.equal("IdNotFoundException")
+    err = ex.value.response["Error"]
+    assert err["Message"] == "That subscriptions definition does not exist."
+    assert err["Code"] == "IdNotFoundException"
 
 
 @freezegun.freeze_time("2022-06-01 12:00:00")
 @mock_greengrass
 def test_create_subscription_definition_version():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     v1_subscriptions = [
         {
@@ -342,20 +322,19 @@ def test_create_subscription_definition_version():
     subscription_def_ver_res = client.create_subscription_definition_version(
         SubscriptionDefinitionId=subscription_def_id, Subscriptions=v2_subscriptions
     )
-    subscription_def_ver_res.should.have.key("Arn")
-    subscription_def_ver_res.should.have.key("CreationTimestamp")
-    subscription_def_ver_res.should.have.key("Id").equals(subscription_def_id)
-    subscription_def_ver_res.should.have.key("Version")
+    assert "Arn" in subscription_def_ver_res
+    assert "CreationTimestamp" in subscription_def_ver_res
+    assert subscription_def_ver_res["Id"] == subscription_def_id
+    assert "Version" in subscription_def_ver_res
 
     if not TEST_SERVER_MODE:
-        subscription_def_ver_res["CreationTimestamp"].should.equal(
-            "2022-06-01T12:00:00.000Z"
+        assert (
+            subscription_def_ver_res["CreationTimestamp"] == "2022-06-01T12:00:00.000Z"
         )
 
 
 @mock_greengrass
 def test_create_subscription_definition_version_with_invalid_id():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     subscriptions = [
         {
@@ -371,15 +350,13 @@ def test_create_subscription_definition_version_with_invalid_id():
             SubscriptionDefinitionId="7b0bdeae-54c7-47cf-9f93-561e672efd9c",
             Subscriptions=subscriptions,
         )
-    ex.value.response["Error"]["Message"].should.equal(
-        "That subscriptions does not exist."
-    )
-    ex.value.response["Error"]["Code"].should.equal("IdNotFoundException")
+    err = ex.value.response["Error"]
+    assert err["Message"] == "That subscriptions does not exist."
+    assert err["Code"] == "IdNotFoundException"
 
 
 @mock_greengrass
 def test_create_subscription_definition_version_with_invalid_target():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     v1_subscriptions = [
         {
@@ -410,15 +387,16 @@ def test_create_subscription_definition_version_with_invalid_target():
             SubscriptionDefinitionId=subscription_def_id, Subscriptions=v2_subscriptions
         )
 
-    ex.value.response["Error"]["Message"].should.equal(
-        "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription target is invalid. ID is '999999' and Target is 'foo'])"
+    err = ex.value.response["Error"]
+    assert (
+        err["Message"]
+        == "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription target is invalid. ID is '999999' and Target is 'foo'])"
     )
-    ex.value.response["Error"]["Code"].should.equal("400")
+    assert err["Code"] == "400"
 
 
 @mock_greengrass
 def test_create_subscription_definition_version_with_invalid_source():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     v1_subscriptions = [
         {
@@ -449,16 +427,17 @@ def test_create_subscription_definition_version_with_invalid_source():
             SubscriptionDefinitionId=subscription_def_id, Subscriptions=v2_subscriptions
         )
 
-    ex.value.response["Error"]["Message"].should.equal(
-        "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription source is invalid. ID is '999999' and Source is 'foo'])"
+    err = ex.value.response["Error"]
+    assert (
+        err["Message"]
+        == "The subscriptions definition is invalid or corrupted. (ErrorDetails: [Subscription source is invalid. ID is '999999' and Source is 'foo'])"
     )
-    ex.value.response["Error"]["Code"].should.equal("400")
+    assert err["Code"] == "400"
 
 
 @freezegun.freeze_time("2022-06-01 12:00:00")
 @mock_greengrass
 def test_list_subscription_definition_versions():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -479,39 +458,34 @@ def test_list_subscription_definition_versions():
         SubscriptionDefinitionId=subscription_def_id
     )
 
-    subscription_def_ver_res["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
-    subscription_def_ver_res.should.have.key("Versions")
+    assert subscription_def_ver_res["ResponseMetadata"]["HTTPStatusCode"] == 200
+    assert "Versions" in subscription_def_ver_res
     subscription_def_ver = subscription_def_ver_res["Versions"][0]
-    subscription_def_ver.should.have.key("Arn")
-    subscription_def_ver.should.have.key("CreationTimestamp")
-    subscription_def_ver.should.have.key("Id").equals(subscription_def_id)
-    subscription_def_ver.should.have.key("Version")
+    assert "Arn" in subscription_def_ver
+    assert "CreationTimestamp" in subscription_def_ver
+    assert subscription_def_ver["Id"] == subscription_def_id
+    assert "Version" in subscription_def_ver
 
     if not TEST_SERVER_MODE:
-        subscription_def_ver["CreationTimestamp"].should.equal(
-            "2022-06-01T12:00:00.000Z"
-        )
+        assert subscription_def_ver["CreationTimestamp"] == "2022-06-01T12:00:00.000Z"
 
 
 @mock_greengrass
 def test_list_subscription_definition_versions_with_invalid_id():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
 
     with pytest.raises(ClientError) as ex:
         client.list_subscription_definition_versions(
             SubscriptionDefinitionId="7b0bdeae-54c7-47cf-9f93-561e672efd9c"
         )
-    ex.value.response["Error"]["Message"].should.equal(
-        "That subscriptions definition does not exist."
-    )
-    ex.value.response["Error"]["Code"].should.equal("IdNotFoundException")
+    err = ex.value.response["Error"]
+    assert err["Message"] == "That subscriptions definition does not exist."
+    assert err["Code"] == "IdNotFoundException"
 
 
 @freezegun.freeze_time("2022-06-01 12:00:00")
 @mock_greengrass
 def test_get_subscription_definition_version():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -535,19 +509,18 @@ def test_get_subscription_definition_version():
         SubscriptionDefinitionVersionId=subscription_def_ver_id,
     )
 
-    func_def_ver_res.should.have.key("Arn")
-    func_def_ver_res.should.have.key("CreationTimestamp")
-    func_def_ver_res.should.have.key("Definition").should.equal(init_ver)
-    func_def_ver_res.should.have.key("Id").equals(subscription_def_id)
-    func_def_ver_res.should.have.key("Version")
+    assert "Arn" in func_def_ver_res
+    assert "CreationTimestamp" in func_def_ver_res
+    assert func_def_ver_res["Definition"] == init_ver
+    assert func_def_ver_res["Id"] == subscription_def_id
+    assert "Version" in func_def_ver_res
 
     if not TEST_SERVER_MODE:
-        func_def_ver_res["CreationTimestamp"].should.equal("2022-06-01T12:00:00.000Z")
+        assert func_def_ver_res["CreationTimestamp"] == "2022-06-01T12:00:00.000Z"
 
 
 @mock_greengrass
 def test_get_subscription_definition_version_with_invalid_id():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
 
     with pytest.raises(ClientError) as ex:
@@ -555,15 +528,13 @@ def test_get_subscription_definition_version_with_invalid_id():
             SubscriptionDefinitionId="7b0bdeae-54c7-47cf-9f93-561e672efd9c",
             SubscriptionDefinitionVersionId="7b0bdeae-54c7-47cf-9f93-561e672efd9c",
         )
-    ex.value.response["Error"]["Message"].should.equal(
-        "That subscriptions definition does not exist."
-    )
-    ex.value.response["Error"]["Code"].should.equal("IdNotFoundException")
+    err = ex.value.response["Error"]
+    assert err["Message"] == "That subscriptions definition does not exist."
+    assert err["Code"] == "IdNotFoundException"
 
 
 @mock_greengrass
 def test_get_subscription_definition_version_with_invalid_version_id():
-
     client = boto3.client("greengrass", region_name="ap-northeast-1")
     init_ver = {
         "Subscriptions": [
@@ -587,7 +558,9 @@ def test_get_subscription_definition_version_with_invalid_version_id():
             SubscriptionDefinitionId=subscription_def_id,
             SubscriptionDefinitionVersionId=invalid_subscription_def_ver_id,
         )
-    ex.value.response["Error"]["Message"].should.equal(
-        f"Version {invalid_subscription_def_ver_id} of Subscription List Definition {subscription_def_id} does not exist."
+    err = ex.value.response["Error"]
+    assert (
+        err["Message"]
+        == f"Version {invalid_subscription_def_ver_id} of Subscription List Definition {subscription_def_id} does not exist."
     )
-    ex.value.response["Error"]["Code"].should.equal("VersionNotFoundException")
+    assert err["Code"] == "VersionNotFoundException"
