@@ -1,13 +1,16 @@
+import json
 from datetime import datetime
 
 import boto3
-import sure  # noqa  # pylint: disable=unused-import
-import json
-
 import pytest
 from botocore.exceptions import ClientError
-from moto import mock_iam
+from dateutil.tz import tzlocal
+from freezegun import freeze_time
+
+from moto import mock_iam, settings
+from moto.backends import get_backend
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from moto.core.utils import utcnow
 
 MOCK_POLICY = """
 {
@@ -23,34 +26,34 @@ MOCK_POLICY = """
 
 
 @mock_iam
-def test_create_group_boto3():
+def test_create_group():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group")
     with pytest.raises(ClientError) as ex:
         conn.create_group(GroupName="my-group")
     err = ex.value.response["Error"]
-    err["Code"].should.equal("Group my-group already exists")
-    err["Message"].should.equal(None)
+    assert err["Code"] == "Group my-group already exists"
+    assert err["Message"] is None
 
 
 @mock_iam
-def test_get_group_boto3():
+def test_get_group():
     conn = boto3.client("iam", region_name="us-east-1")
     created = conn.create_group(GroupName="my-group")["Group"]
-    created["Path"].should.equal("/")
-    created["GroupName"].should.equal("my-group")
-    created.should.have.key("GroupId")
-    created["Arn"].should.equal("arn:aws:iam::{}:group/my-group".format(ACCOUNT_ID))
-    created["CreateDate"].should.be.a(datetime)
+    assert created["Path"] == "/"
+    assert created["GroupName"] == "my-group"
+    assert "GroupId" in created
+    assert created["Arn"] == f"arn:aws:iam::{ACCOUNT_ID}:group/my-group"
+    assert isinstance(created["CreateDate"], datetime)
 
     retrieved = conn.get_group(GroupName="my-group")["Group"]
-    retrieved.should.equal(created)
+    assert retrieved == created
 
     with pytest.raises(ClientError) as ex:
         conn.get_group(GroupName="not-group")
     err = ex.value.response["Error"]
-    err["Code"].should.equal("NoSuchEntity")
-    err["Message"].should.equal("Group not-group not found")
+    assert err["Code"] == "NoSuchEntity"
+    assert err["Message"] == "Group not-group not found"
 
 
 @mock_iam()
@@ -63,24 +66,27 @@ def test_get_group_current():
     assert result["Group"]["GroupName"] == "my-group"
     assert isinstance(result["Group"]["CreateDate"], datetime)
     assert result["Group"]["GroupId"]
-    assert result["Group"]["Arn"] == "arn:aws:iam::{}:group/my-group".format(ACCOUNT_ID)
+    assert result["Group"]["Arn"] == f"arn:aws:iam::{ACCOUNT_ID}:group/my-group"
     assert not result["Users"]
 
     # Make a group with a different path:
-    other_group = conn.create_group(GroupName="my-other-group", Path="some/location")
-    assert other_group["Group"]["Path"] == "some/location"
-    assert other_group["Group"][
-        "Arn"
-    ] == "arn:aws:iam::{}:group/some/location/my-other-group".format(ACCOUNT_ID)
+    other_group = conn.create_group(GroupName="my-other-group", Path="/some/location/")
+    assert other_group["Group"]["Path"] == "/some/location/"
+    assert (
+        other_group["Group"]["Arn"]
+        == f"arn:aws:iam::{ACCOUNT_ID}:group/some/location/my-other-group"
+    )
 
 
 @mock_iam
-def test_get_all_groups_boto3():
+def test_get_all_groups():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group1")
     conn.create_group(GroupName="my-group2")
     groups = conn.list_groups()["Groups"]
-    groups.should.have.length_of(2)
+    assert len(groups) == 2
+
+    assert all([g["CreateDate"] for g in groups])
 
 
 @mock_iam
@@ -89,8 +95,8 @@ def test_add_unknown_user_to_group():
     with pytest.raises(ClientError) as ex:
         conn.add_user_to_group(GroupName="my-group", UserName="my-user")
     err = ex.value.response["Error"]
-    err["Code"].should.equal("NoSuchEntity")
-    err["Message"].should.equal("The user with name my-user cannot be found.")
+    assert err["Code"] == "NoSuchEntity"
+    assert err["Message"] == "The user with name my-user cannot be found."
 
 
 @mock_iam
@@ -100,16 +106,40 @@ def test_add_user_to_unknown_group():
     with pytest.raises(ClientError) as ex:
         conn.add_user_to_group(GroupName="my-group", UserName="my-user")
     err = ex.value.response["Error"]
-    err["Code"].should.equal("NoSuchEntity")
-    err["Message"].should.equal("Group my-group not found")
+    assert err["Code"] == "NoSuchEntity"
+    assert err["Message"] == "Group my-group not found"
 
 
 @mock_iam
-def test_add_user_to_group_boto3():
-    conn = boto3.client("iam", region_name="us-east-1")
-    conn.create_group(GroupName="my-group")
-    conn.create_user(UserName="my-user")
-    conn.add_user_to_group(GroupName="my-group", UserName="my-user")
+def test_add_user_to_group():
+    # Setup
+    frozen_time = datetime(2023, 5, 20, 10, 20, 30, tzinfo=tzlocal())
+
+    group = "my-group"
+    user = "my-user"
+    with freeze_time(frozen_time):
+        conn = boto3.client("iam", region_name="us-east-1")
+        conn.create_group(GroupName=group)
+        conn.create_user(UserName=user)
+        conn.add_user_to_group(GroupName=group, UserName=user)
+
+        # use internal api to set password, doesn't work in servermode
+        if not settings.TEST_SERVER_MODE:
+            iam_backend = get_backend("iam")[ACCOUNT_ID]["global"]
+            iam_backend.users[user].password_last_used = utcnow()
+    # Execute
+    result = conn.get_group(GroupName=group)
+
+    # Verify
+    assert len(result["Users"]) == 1
+
+    # if in servermode then we can't test for password because we can't
+    # manipulate the backend with internal an api
+    if settings.TEST_SERVER_MODE:
+        assert "CreateDate" in result["Users"][0]
+        return
+    assert result["Users"][0]["CreateDate"] == frozen_time
+    assert result["Users"][0]["PasswordLastUsed"] == frozen_time
 
 
 @mock_iam
@@ -118,8 +148,8 @@ def test_remove_user_from_unknown_group():
     with pytest.raises(ClientError) as ex:
         conn.remove_user_from_group(GroupName="my-group", UserName="my-user")
     err = ex.value.response["Error"]
-    err["Code"].should.equal("NoSuchEntity")
-    err["Message"].should.equal("Group my-group not found")
+    assert err["Code"] == "NoSuchEntity"
+    assert err["Message"] == "Group my-group not found"
 
 
 @mock_iam
@@ -130,12 +160,12 @@ def test_remove_nonattached_user_from_group():
     with pytest.raises(ClientError) as ex:
         conn.remove_user_from_group(GroupName="my-group", UserName="my-user")
     err = ex.value.response["Error"]
-    err["Code"].should.equal("NoSuchEntity")
-    err["Message"].should.equal("User my-user not in group my-group")
+    assert err["Code"] == "NoSuchEntity"
+    assert err["Message"] == "User my-user not in group my-group"
 
 
 @mock_iam
-def test_remove_user_from_group_boto3():
+def test_remove_user_from_group():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group")
     conn.create_user(UserName="my-user")
@@ -144,7 +174,24 @@ def test_remove_user_from_group_boto3():
 
 
 @mock_iam
-def test_get_groups_for_user_boto3():
+def test_add_user_should_be_idempotent():
+    conn = boto3.client("iam", region_name="us-east-1")
+    conn.create_group(GroupName="my-group")
+    conn.create_user(UserName="my-user")
+    # We'll add the same user twice, but it should only be persisted once
+    conn.add_user_to_group(GroupName="my-group", UserName="my-user")
+    conn.add_user_to_group(GroupName="my-group", UserName="my-user")
+
+    assert len(conn.list_groups_for_user(UserName="my-user")["Groups"]) == 1
+
+    # Which means that if we remove one, none should be left
+    conn.remove_user_from_group(GroupName="my-group", UserName="my-user")
+
+    assert len(conn.list_groups_for_user(UserName="my-user")["Groups"]) == 0
+
+
+@mock_iam
+def test_get_groups_for_user():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group1")
     conn.create_group(GroupName="my-group2")
@@ -154,11 +201,11 @@ def test_get_groups_for_user_boto3():
     conn.add_user_to_group(GroupName="my-group2", UserName="my-user")
 
     groups = conn.list_groups_for_user(UserName="my-user")["Groups"]
-    groups.should.have.length_of(2)
+    assert len(groups) == 2
 
 
 @mock_iam
-def test_put_group_policy_boto3():
+def test_put_group_policy():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group")
     conn.put_group_policy(
@@ -170,56 +217,57 @@ def test_put_group_policy_boto3():
 def test_attach_group_policies():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group")
-    conn.list_attached_group_policies(GroupName="my-group")[
-        "AttachedPolicies"
-    ].should.be.empty
-    policy_arn = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforEC2Role"
-    conn.list_attached_group_policies(GroupName="my-group")[
-        "AttachedPolicies"
-    ].should.be.empty
-    conn.attach_group_policy(GroupName="my-group", PolicyArn=policy_arn)
-    conn.list_attached_group_policies(GroupName="my-group")[
-        "AttachedPolicies"
-    ].should.equal(
-        [{"PolicyName": "AmazonElasticMapReduceforEC2Role", "PolicyArn": policy_arn}]
+    assert (
+        conn.list_attached_group_policies(GroupName="my-group")["AttachedPolicies"]
+        == []
     )
+    policy_arn = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforEC2Role"
+    assert (
+        conn.list_attached_group_policies(GroupName="my-group")["AttachedPolicies"]
+        == []
+    )
+    conn.attach_group_policy(GroupName="my-group", PolicyArn=policy_arn)
+    assert conn.list_attached_group_policies(GroupName="my-group")[
+        "AttachedPolicies"
+    ] == [{"PolicyName": "AmazonElasticMapReduceforEC2Role", "PolicyArn": policy_arn}]
 
     conn.detach_group_policy(GroupName="my-group", PolicyArn=policy_arn)
-    conn.list_attached_group_policies(GroupName="my-group")[
-        "AttachedPolicies"
-    ].should.be.empty
+    assert (
+        conn.list_attached_group_policies(GroupName="my-group")["AttachedPolicies"]
+        == []
+    )
 
 
 @mock_iam
-def test_get_group_policy_boto3():
+def test_get_group_policy():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group")
     with pytest.raises(ClientError) as ex:
         conn.get_group_policy(GroupName="my-group", PolicyName="my-policy")
     err = ex.value.response["Error"]
-    err["Code"].should.equal("NoSuchEntity")
-    err["Message"].should.equal("Policy my-policy not found")
+    assert err["Code"] == "NoSuchEntity"
+    assert err["Message"] == "Policy my-policy not found"
 
     conn.put_group_policy(
         GroupName="my-group", PolicyName="my-policy", PolicyDocument=MOCK_POLICY
     )
     policy = conn.get_group_policy(GroupName="my-group", PolicyName="my-policy")
-    policy["GroupName"].should.equal("my-group")
-    policy["PolicyName"].should.equal("my-policy")
-    policy["PolicyDocument"].should.equal(json.loads(MOCK_POLICY))
+    assert policy["GroupName"] == "my-group"
+    assert policy["PolicyName"] == "my-policy"
+    assert policy["PolicyDocument"] == json.loads(MOCK_POLICY)
 
 
 @mock_iam()
 def test_list_group_policies():
     conn = boto3.client("iam", region_name="us-east-1")
     conn.create_group(GroupName="my-group")
-    conn.list_group_policies(GroupName="my-group")["PolicyNames"].should.be.empty
+    assert conn.list_group_policies(GroupName="my-group")["PolicyNames"] == []
     conn.put_group_policy(
         GroupName="my-group", PolicyName="my-policy", PolicyDocument=MOCK_POLICY
     )
-    conn.list_group_policies(GroupName="my-group")["PolicyNames"].should.equal(
-        ["my-policy"]
-    )
+    assert conn.list_group_policies(GroupName="my-group")["PolicyNames"] == [
+        "my-policy"
+    ]
 
 
 @mock_iam
@@ -230,7 +278,7 @@ def test_delete_group():
     assert groups["Groups"][0]["GroupName"] == "my-group"
     assert len(groups["Groups"]) == 1
     conn.delete_group(GroupName="my-group")
-    conn.list_groups()["Groups"].should.be.empty
+    assert conn.list_groups()["Groups"] == []
 
 
 @mock_iam
@@ -238,9 +286,10 @@ def test_delete_unknown_group():
     conn = boto3.client("iam", region_name="us-east-1")
     with pytest.raises(ClientError) as err:
         conn.delete_group(GroupName="unknown-group")
-    err.value.response["Error"]["Code"].should.equal("NoSuchEntity")
-    err.value.response["Error"]["Message"].should.equal(
-        "The group with name unknown-group cannot be found."
+    assert err.value.response["Error"]["Code"] == "NoSuchEntity"
+    assert (
+        err.value.response["Error"]["Message"]
+        == "The group with name unknown-group cannot be found."
     )
 
 
@@ -255,13 +304,13 @@ def test_update_group_name():
     # The old group-name should no longer exist
     with pytest.raises(ClientError) as exc:
         conn.get_group(GroupName="my-group")
-    exc.value.response["Error"]["Code"].should.equal("NoSuchEntity")
+    assert exc.value.response["Error"]["Code"] == "NoSuchEntity"
 
     result = conn.get_group(GroupName="new-group")["Group"]
-    result["Path"].should.equal("/")
-    result["GroupName"].should.equal("new-group")
-    result["GroupId"].should.equal(initial_group["GroupId"])
-    result["Arn"].should.match(":group/new-group")
+    assert result["Path"] == "/"
+    assert result["GroupName"] == "new-group"
+    assert result["GroupId"] == initial_group["GroupId"]
+    assert ":group/new-group" in result["Arn"]
 
 
 @mock_iam
@@ -273,7 +322,7 @@ def test_update_group_name_that_has_a_path():
 
     # Verify the path hasn't changed
     new = conn.get_group(GroupName="new-group")["Group"]
-    new["Path"].should.equal("/path")
+    assert new["Path"] == "/path"
 
 
 @mock_iam
@@ -287,7 +336,7 @@ def test_update_group_path():
 
     # Verify the path has changed
     new = conn.get_group(GroupName="new-group")["Group"]
-    new["Path"].should.equal("/new-path")
+    assert new["Path"] == "/new-path"
 
 
 @mock_iam
@@ -297,8 +346,8 @@ def test_update_group_that_does_not_exist():
     with pytest.raises(ClientError) as exc:
         conn.update_group(GroupName="nonexisting", NewGroupName="..")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("NoSuchEntity")
-    err["Message"].should.equal("The group with name nonexisting cannot be found.")
+    assert err["Code"] == "NoSuchEntity"
+    assert err["Message"] == "The group with name nonexisting cannot be found."
 
 
 @mock_iam
@@ -310,5 +359,5 @@ def test_update_group_with_existing_name():
     with pytest.raises(ClientError) as exc:
         conn.update_group(GroupName="existing1", NewGroupName="existing2")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("Conflict")
-    err["Message"].should.equal("Group existing2 already exists")
+    assert err["Code"] == "Conflict"
+    assert err["Message"] == "Group existing2 already exists"
