@@ -1,8 +1,9 @@
-import boto3
 import json
-import pytest
 
+import boto3
+import pytest
 from botocore.exceptions import ClientError
+
 from moto import mock_iam
 
 invalid_policy_document_test_cases = [
@@ -1607,6 +1608,20 @@ valid_policy_documents = [
             },
         ],
     },
+    {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Sid": "",
+                "Effect": "Allow",
+                "Action": ["s3:*"],
+                "Resource": [
+                    "arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point",
+                    "arn:aws:s3:us-west-2:123456789012:accesspoint/my-access-point/object/*",
+                ],
+            },
+        ],
+    },
 ]
 
 
