@@ -10,13 +10,13 @@ from botocore.exceptions import ClientError
 from moto import mock_identitystore
 from moto.moto_api._internal import mock_random
 
-
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
 
 
 def get_identity_store_id() -> str:
-    return f"d-{random.choices(string.ascii_lowercase, k=10)}"
+    rand = "".join(random.choices(string.ascii_lowercase, k=10))
+    return f"d-{rand}"
 
 
 @mock_identitystore
@@ -90,7 +90,7 @@ def test_create_group_membership():
         Description="description",
     )["GroupId"]
 
-    user_id = __create_and_verify_sparse_user(client, identity_store_id)
+    user_id = __create_and_verify_sparse_user(client, identity_store_id)["UserId"]
 
     create_response = client.create_group_membership(
         IdentityStoreId=identity_store_id,
@@ -371,11 +371,10 @@ def test_get_group_id():
     # Create a bunch of groups
     for _ in range(1, 10):
         group = __create_test_group(client, identity_store_id)
-        groups[group[0]] = group[1]
+        groups[group[0]] = group[2]
 
     # Make sure we can get their ID
     for name, group_id in groups.items():
-
         response = client.get_group_id(
             IdentityStoreId=identity_store_id,
             AlternateIdentifier={
@@ -413,6 +412,98 @@ def test_get_group_id_does_not_exist():
     assert "RequestId" in err.response
 
 
+@mock_identitystore
+def test_list_groups():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    start = 0
+    end = 266
+    batch_size = 100
+    next_token = None
+
+    expected_groups = list()
+    for _ in range(end):
+        display_name, description, group_id = __create_test_group(
+            client=client, store_id=identity_store_id
+        )
+        expected_groups.append(
+            {
+                "GroupId": group_id,
+                "DisplayName": display_name,
+                "ExternalIds": [],
+                "Description": description,
+                "IdentityStoreId": identity_store_id,
+            }
+        )
+
+    groups = list()
+    for iteration in range(start, end, batch_size):
+        last_iteration = end - iteration <= batch_size
+        expected_size = batch_size if not last_iteration else end - iteration
+
+        if next_token is not None:
+            list_response = client.list_groups(
+                IdentityStoreId=identity_store_id,
+                MaxResults=batch_size,
+                NextToken=next_token,
+            )
+        else:
+            list_response = client.list_groups(
+                IdentityStoreId=identity_store_id,
+                MaxResults=batch_size,
+            )
+
+        assert len(list_response["Groups"]) == expected_size
+        groups.extend(list_response["Groups"])
+        if last_iteration:
+            assert "NextToken" not in list_response
+        else:
+            assert "NextToken" in list_response
+            next_token = list_response["NextToken"]
+
+    assert groups == expected_groups
+
+
+@mock_identitystore
+def test_list_groups_filter():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    display_name, description, group_id = __create_test_group(
+        client=client, store_id=identity_store_id
+    )
+    expected_group = {
+        "GroupId": group_id,
+        "DisplayName": display_name,
+        "ExternalIds": [],
+        "Description": description,
+        "IdentityStoreId": identity_store_id,
+    }
+
+    # Create a second test group to see if it is not returned
+    __create_test_group(client=client, store_id=identity_store_id)
+
+    groups = client.list_groups(
+        IdentityStoreId=identity_store_id,
+        Filters=[
+            {"AttributePath": "DisplayName", "AttributeValue": display_name},
+        ],
+    )["Groups"]
+
+    assert len(groups) == 1
+    assert groups[0] == expected_group
+
+    no_groups = client.list_groups(
+        IdentityStoreId=identity_store_id,
+        Filters=[
+            {"AttributePath": "DisplayName", "AttributeValue": "non_existant_group"},
+        ],
+    )["Groups"]
+
+    assert len(no_groups) == 0
+
+
 @mock_identitystore
 def test_list_group_memberships():
     client = boto3.client("identitystore", region_name="us-east-2")
@@ -431,7 +522,7 @@ def test_list_group_memberships():
     )["GroupId"]
 
     for _ in range(end):
-        user_id = __create_and_verify_sparse_user(client, identity_store_id)
+        user_id = __create_and_verify_sparse_user(client, identity_store_id)["UserId"]
         create_response = client.create_group_membership(
             IdentityStoreId=identity_store_id,
             GroupId=group_id,
@@ -469,6 +560,61 @@ def test_list_group_memberships():
             next_token = list_response["NextToken"]
 
 
+@mock_identitystore
+def test_list_group_memberships_for_member():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    start = 0
+    end = 50
+    batch_size = 3
+    next_token = None
+    membership_ids = []
+
+    user_id = __create_and_verify_sparse_user(client, identity_store_id)["UserId"]
+    for i in range(end):
+        group_id = client.create_group(
+            IdentityStoreId=identity_store_id,
+            DisplayName=f"test_group_{i}",
+            Description="description",
+        )["GroupId"]
+        create_response = client.create_group_membership(
+            IdentityStoreId=identity_store_id,
+            GroupId=group_id,
+            MemberId={"UserId": user_id},
+        )
+        membership_ids.append((create_response["MembershipId"], user_id))
+
+    for iteration in range(start, end, batch_size):
+        last_iteration = end - iteration <= batch_size
+        expected_size = batch_size if not last_iteration else end - iteration
+        end_index = iteration + expected_size
+
+        if next_token is not None:
+            list_response = client.list_group_memberships_for_member(
+                IdentityStoreId=identity_store_id,
+                MemberId={"UserId": user_id},
+                MaxResults=batch_size,
+                NextToken=next_token,
+            )
+        else:
+            list_response = client.list_group_memberships_for_member(
+                IdentityStoreId=identity_store_id,
+                MemberId={"UserId": user_id},
+                MaxResults=batch_size,
+            )
+
+        assert len(list_response["GroupMemberships"]) == expected_size
+        __check_membership_list_values(
+            list_response["GroupMemberships"], membership_ids[iteration:end_index]
+        )
+        if last_iteration:
+            assert "NextToken" not in list_response
+        else:
+            assert "NextToken" in list_response
+            next_token = list_response["NextToken"]
+
+
 def __check_membership_list_values(members, expected):
     assert len(members) == len(expected)
     for i in range(len(expected)):
@@ -476,6 +622,89 @@ def __check_membership_list_values(members, expected):
         assert members[i]["MemberId"]["UserId"] == expected[i][1]
 
 
+@mock_identitystore
+def test_list_users():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    start = 0
+    end = 240
+    batch_size = 100
+    next_token = None
+
+    expected_users = list()
+    for _ in range(end):
+        dummy_user = __create_and_verify_sparse_user(client, identity_store_id)
+        expected_users.append(dummy_user)
+
+    users = list()
+    for iteration in range(start, end, batch_size):
+        last_iteration = end - iteration <= batch_size
+        expected_size = batch_size if not last_iteration else end - iteration
+
+        if next_token is not None:
+            list_response = client.list_users(
+                IdentityStoreId=identity_store_id,
+                MaxResults=batch_size,
+                NextToken=next_token,
+            )
+        else:
+            list_response = client.list_users(
+                IdentityStoreId=identity_store_id,
+                MaxResults=batch_size,
+            )
+
+        assert len(list_response["Users"]) == expected_size
+        users.extend(list_response["Users"])
+        if last_iteration:
+            assert "NextToken" not in list_response
+        else:
+            assert "NextToken" in list_response
+            next_token = list_response["NextToken"]
+
+    assert users == expected_users
+
+
+@mock_identitystore
+def test_list_users_filter():
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    client.create_user(
+        IdentityStoreId=identity_store_id,
+        UserName="test_username_1",
+        DisplayName="test_display_name_1",
+        Name={"GivenName": "given_name", "FamilyName": "family_name"},
+    )
+
+    # Create a second user to see if it is not returned
+    client.create_user(
+        IdentityStoreId=identity_store_id,
+        UserName="test_username_2",
+        DisplayName="test_display_name_2",
+        Name={"GivenName": "given_name", "FamilyName": "family_name"},
+    )
+
+    users = client.list_users(
+        IdentityStoreId=identity_store_id,
+        Filters=[
+            {"AttributePath": "UserName", "AttributeValue": "test_username_1"},
+        ],
+    )["Users"]
+
+    assert len(users) == 1
+    assert users[0]["UserName"] == "test_username_1"
+
+    no_users = client.list_users(
+        IdentityStoreId=identity_store_id,
+        Filters=[
+            {"AttributePath": "UserName", "AttributeValue": "non_existant_user"},
+        ],
+    )["Users"]
+
+    assert len(no_users) == 0
+
+
 @mock_identitystore
 def test_delete_group():
     client = boto3.client("identitystore", region_name="us-east-2")
@@ -484,7 +713,7 @@ def test_delete_group():
     test_group = __create_test_group(client, identity_store_id)
     assert __group_exists(client, test_group[0], identity_store_id)
 
-    resp = client.delete_group(IdentityStoreId=identity_store_id, GroupId=test_group[1])
+    resp = client.delete_group(IdentityStoreId=identity_store_id, GroupId=test_group[2])
     assert "ResponseMetadata" in resp
     assert resp["ResponseMetadata"]["HTTPStatusCode"] == 200
 
@@ -509,8 +738,8 @@ def test_delete_group_doesnt_exist():
 def test_delete_group_membership():
     client = boto3.client("identitystore", region_name="eu-west-1")
     identity_store_id = get_identity_store_id()
-    user_id = __create_and_verify_sparse_user(client, identity_store_id)
-    _, group_id = __create_test_group(client, identity_store_id)
+    user_id = __create_and_verify_sparse_user(client, identity_store_id)["UserId"]
+    _, _, group_id = __create_test_group(client, identity_store_id)
 
     membership = client.create_group_membership(
         IdentityStoreId=identity_store_id,
@@ -539,7 +768,7 @@ def test_delete_group_membership():
 def test_delete_user():
     client = boto3.client("identitystore", region_name="us-east-2")
     identity_store_id = get_identity_store_id()
-    user_id = __create_and_verify_sparse_user(client, identity_store_id)
+    user_id = __create_and_verify_sparse_user(client, identity_store_id)["UserId"]
 
     client.delete_user(IdentityStoreId=identity_store_id, UserId=user_id)
 
@@ -560,17 +789,52 @@ def test_delete_user_doesnt_exist():
     )
 
 
+@mock_identitystore
+def test_create_describe_group() -> None:
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+    group_name, group_descriprion, group_id = __create_test_group(
+        client, identity_store_id
+    )
+
+    client_response = client.describe_group(
+        IdentityStoreId=identity_store_id, GroupId=group_id
+    )
+    assert client_response["GroupId"] == group_id
+    assert client_response["DisplayName"] == group_name
+    assert client_response["Description"] == group_descriprion
+    assert client_response["IdentityStoreId"] == identity_store_id
+
+
+@mock_identitystore
+def test_describe_group_doesnt_exist() -> None:
+    client = boto3.client("identitystore", region_name="us-east-2")
+    identity_store_id = get_identity_store_id()
+
+    with pytest.raises(ClientError) as exc:
+        client.describe_group(IdentityStoreId=identity_store_id, GroupId=str(uuid4()))
+
+    err = exc.value
+    assert err.response["Error"]["Code"] == "ResourceNotFoundException"
+    assert err.response["Error"]["Message"] == "GROUP not found."
+    assert err.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert err.response["ResourceType"] == "GROUP"
+    assert err.response["Message"] == "GROUP not found."
+    assert "RequestId" in err.response
+
+
 def __create_test_group(client, store_id: str):
     rand = "".join(random.choices(string.ascii_lowercase, k=8))
     group_name = f"test_group_{rand}"
+    description = f"random_description_{rand}"
 
     create_resp = client.create_group(
         IdentityStoreId=store_id,
         DisplayName=group_name,
-        Description="description",
+        Description=description,
     )
 
-    return group_name, create_resp["GroupId"]
+    return group_name, description, create_resp["GroupId"]
 
 
 def __group_exists(client, group_name: str, store_id: str) -> bool:
@@ -592,7 +856,8 @@ def __group_exists(client, group_name: str, store_id: str) -> bool:
 
 
 def __create_and_verify_sparse_user(client, store_id: str):
-    rand = random.choices(string.ascii_lowercase, k=8)
+    """Creates a user, verifies it is unique and returns the response of describe_user"""
+    rand = "".join(random.choices(string.ascii_lowercase, k=8))
     username = f"the_username_{rand}"
     response = client.create_user(
         IdentityStoreId=store_id,
@@ -607,4 +872,7 @@ def __create_and_verify_sparse_user(client, store_id: str):
     )
 
     assert user_resp["UserName"] == username
-    return user_resp["UserId"]
+    del user_resp[
+        "ResponseMetadata"
+    ]  # strip response metadata and just return user info
+    return user_resp
