@@ -1,11 +1,11 @@
 import json
+
 import boto3
-import sure  # noqa # pylint: disable=unused-import
 import pytest
 from botocore.exceptions import ClientError
 
 import moto.iotdata.models
-from moto import mock_iotdata, mock_iot, settings
+from moto import mock_iot, mock_iotdata, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
@@ -25,22 +25,18 @@ def test_basic():
 
     payload = json.loads(res["payload"].read())
     expected_state = '{"desired": {"led": "on"}}'
-    payload.should.have.key("state").which.should.equal(json.loads(expected_state))
-    payload.should.have.key("metadata").which.should.have.key(
-        "desired"
-    ).which.should.have.key("led")
-    payload.should.have.key("version").which.should.equal(1)
-    payload.should.have.key("timestamp")
+    assert payload["state"] == json.loads(expected_state)
+    assert "led" in payload["metadata"]["desired"]
+    assert payload["version"] == 1
+    assert "timestamp" in payload
 
     res = client.get_thing_shadow(thingName=name)
     payload = json.loads(res["payload"].read())
     expected_state = b'{"desired": {"led": "on"}, "delta": {"led": "on"}}'
-    payload.should.have.key("state").which.should.equal(json.loads(expected_state))
-    payload.should.have.key("metadata").which.should.have.key(
-        "desired"
-    ).which.should.have.key("led")
-    payload.should.have.key("version").which.should.equal(1)
-    payload.should.have.key("timestamp")
+    assert payload["state"] == json.loads(expected_state)
+    assert "led" in payload["metadata"]["desired"]
+    assert payload["version"] == 1
+    assert "timestamp" in payload
 
     client.delete_thing_shadow(thingName=name)
     with pytest.raises(ClientError):
@@ -60,50 +56,97 @@ def test_update():
     res = client.update_thing_shadow(thingName=name, payload=raw_payload)
     payload = json.loads(res["payload"].read())
     expected_state = '{"desired": {"led": "on"}}'
-    payload.should.have.key("state").which.should.equal(json.loads(expected_state))
-    payload.should.have.key("metadata").which.should.have.key(
-        "desired"
-    ).which.should.have.key("led")
-    payload.should.have.key("version").which.should.equal(1)
-    payload.should.have.key("timestamp")
+    assert payload["state"] == json.loads(expected_state)
+    assert "led" in payload["metadata"]["desired"]
+    assert payload["version"] == 1
+    assert "timestamp" in payload
 
     res = client.get_thing_shadow(thingName=name)
     payload = json.loads(res["payload"].read())
     expected_state = b'{"desired": {"led": "on"}, "delta": {"led": "on"}}'
-    payload.should.have.key("state").which.should.equal(json.loads(expected_state))
-    payload.should.have.key("metadata").which.should.have.key(
-        "desired"
-    ).which.should.have.key("led")
-    payload.should.have.key("version").which.should.equal(1)
-    payload.should.have.key("timestamp")
+    assert payload["state"] == json.loads(expected_state)
+    assert "led" in payload["metadata"]["desired"]
+    assert payload["version"] == 1
+    assert "timestamp" in payload
 
     # reporting new state
     new_payload = b'{"state": {"reported": {"led": "on"}}}'
     res = client.update_thing_shadow(thingName=name, payload=new_payload)
     payload = json.loads(res["payload"].read())
     expected_state = '{"reported": {"led": "on"}}'
-    payload.should.have.key("state").which.should.equal(json.loads(expected_state))
-    payload.should.have.key("metadata").which.should.have.key(
-        "reported"
-    ).which.should.have.key("led")
-    payload.should.have.key("version").which.should.equal(2)
-    payload.should.have.key("timestamp")
+    assert payload["state"] == json.loads(expected_state)
+    assert "led" in payload["metadata"]["reported"]
+    assert payload["version"] == 2
+    assert "timestamp" in payload
 
     res = client.get_thing_shadow(thingName=name)
     payload = json.loads(res["payload"].read())
     expected_state = b'{"desired": {"led": "on"}, "reported": {"led": "on"}}'
-    payload.should.have.key("state").which.should.equal(json.loads(expected_state))
-    payload.should.have.key("metadata").which.should.have.key(
-        "desired"
-    ).which.should.have.key("led")
-    payload.should.have.key("version").which.should.equal(2)
-    payload.should.have.key("timestamp")
+    assert payload["state"] == json.loads(expected_state)
+    assert "led" in payload["metadata"]["desired"]
+    assert payload["version"] == 2
+    assert "timestamp" in payload
 
     raw_payload = b'{"state": {"desired": {"led": "on"}}, "version": 1}'
     with pytest.raises(ClientError) as ex:
         client.update_thing_shadow(thingName=name, payload=raw_payload)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(409)
-    ex.value.response["Error"]["Message"].should.equal("Version conflict")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 409
+    assert ex.value.response["Error"]["Message"] == "Version conflict"
+
+
+@mock_iot
+@mock_iotdata
+def test_create_named_shadows():
+    iot_client = boto3.client("iot", region_name="ap-northeast-1")
+    client = boto3.client("iot-data", region_name="ap-northeast-1")
+    thing_name = "my-thing"
+    iot_client.create_thing(thingName=thing_name)
+
+    # default shadow
+    default_payload = json.dumps({"state": {"desired": {"name": "default"}}})
+    res = client.update_thing_shadow(thingName=thing_name, payload=default_payload)
+    payload = json.loads(res["payload"].read())
+    assert payload["state"] == {"desired": {"name": "default"}}
+
+    # Create named shadows
+    for name in ["shadow1", "shadow2"]:
+        named_payload = json.dumps({"state": {"reported": {"name": name}}}).encode(
+            "utf-8"
+        )
+        client.update_thing_shadow(
+            thingName=thing_name, payload=named_payload, shadowName=name
+        )
+
+        res = client.get_thing_shadow(thingName=thing_name, shadowName=name)
+        payload = json.loads(res["payload"].read())
+        assert payload["state"]["reported"] == {"name": name}
+
+    # List named shadows
+    shadows = client.list_named_shadows_for_thing(thingName=thing_name)["results"]
+    assert len(shadows) == 2
+
+    for shadow in shadows:
+        shadow.pop("metadata")
+        shadow.pop("timestamp")
+        shadow.pop("version")
+
+    # Verify both named shadows are present
+    for name in ["shadow1", "shadow2"]:
+        assert {
+            "state": {"reported": {"name": name}, "delta": {"name": name}}
+        } in shadows
+
+    # Verify we can delete a named shadow
+    client.delete_thing_shadow(thingName=thing_name, shadowName="shadow2")
+
+    with pytest.raises(ClientError):
+        client.get_thing_shadow(thingName="shadow1")
+
+    # The default and other named shadow are still there
+    assert "payload" in client.get_thing_shadow(thingName=thing_name)
+    assert "payload" in client.get_thing_shadow(
+        thingName=thing_name, shadowName="shadow1"
+    )
 
 
 @mock_iotdata
@@ -116,10 +159,10 @@ def test_publish():
 
     if not settings.TEST_SERVER_MODE:
         mock_backend = moto.iotdata.models.iotdata_backends[ACCOUNT_ID][region_name]
-        mock_backend.published_payloads.should.have.length_of(3)
-        mock_backend.published_payloads.should.contain(("test/topic1", b"pl1"))
-        mock_backend.published_payloads.should.contain(("test/topic2", b"pl2"))
-        mock_backend.published_payloads.should.contain(("test/topic3", b"\xbf"))
+        assert len(mock_backend.published_payloads) == 3
+        assert ("test/topic1", b"pl1") in mock_backend.published_payloads
+        assert ("test/topic2", b"pl2") in mock_backend.published_payloads
+        assert ("test/topic3", b"\xbf") in mock_backend.published_payloads
 
 
 @mock_iot
