@@ -1,7 +1,6 @@
 from urllib.parse import quote
 
 import pytest
-import sure  # noqa # pylint: disable=unused-import
 
 import moto.server as server
 from moto import mock_iotdata
@@ -18,8 +17,8 @@ def test_iotdata_list():
 
     # just making sure that server is up
     thing_name = "nothing"
-    res = test_client.get("/things/{}/shadow".format(thing_name))
-    res.status_code.should.equal(404)
+    res = test_client.get(f"/things/{thing_name}/shadow")
+    assert res.status_code == 404
 
 
 @pytest.mark.parametrize(
@@ -37,5 +36,5 @@ def test_publish(url_encode_topic):
     topic = "test/topic"
     topic_for_path = quote(topic, safe="") if url_encode_topic else topic
 
-    result = test_client.post("/topics/{}".format(topic_for_path))
-    result.status_code.should.equal(200)
+    result = test_client.post(f"/topics/{topic_for_path}")
+    assert result.status_code == 200
