@@ -1,16 +1,14 @@
 import datetime
 import time
-import pytest
 
 import boto3
+import pytest
 from botocore.exceptions import ClientError
-
 from dateutil.tz import tzlocal
 
 from moto import mock_kinesis
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-
-import sure  # noqa # pylint: disable=unused-import
+from moto.core.utils import utcnow
 
 
 @mock_kinesis
@@ -19,27 +17,30 @@ def test_stream_creation_on_demand():
     client.create_stream(
         StreamName="my_stream", StreamModeDetails={"StreamMode": "ON_DEMAND"}
     )
+    # At the same time, test whether we can pass the StreamARN instead of the name
+    stream_arn = get_stream_arn(client, "my_stream")
 
     # AWS starts with 4 shards by default
-    shard_list = client.list_shards(StreamName="my_stream")["Shards"]
-    shard_list.should.have.length_of(4)
+    shard_list = client.list_shards(StreamARN=stream_arn)["Shards"]
+    assert len(shard_list) == 4
 
     # Cannot update-shard-count when we're in on-demand mode
     with pytest.raises(ClientError) as exc:
         client.update_shard_count(
-            StreamName="my_stream", TargetShardCount=3, ScalingType="UNIFORM_SCALING"
+            StreamARN=stream_arn, TargetShardCount=3, ScalingType="UNIFORM_SCALING"
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ValidationException")
-    err["Message"].should.equal(
-        f"Request is invalid. Stream my_stream under account {ACCOUNT_ID} is in On-Demand mode."
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"]
+        == f"Request is invalid. Stream my_stream under account {ACCOUNT_ID} is in On-Demand mode."
     )
 
 
 @mock_kinesis
 def test_update_stream_mode():
     client = boto3.client("kinesis", region_name="eu-west-1")
-    resp = client.create_stream(
+    client.create_stream(
         StreamName="my_stream", StreamModeDetails={"StreamMode": "ON_DEMAND"}
     )
     arn = client.describe_stream(StreamName="my_stream")["StreamDescription"][
@@ -52,32 +53,34 @@ def test_update_stream_mode():
 
     resp = client.describe_stream_summary(StreamName="my_stream")
     stream = resp["StreamDescriptionSummary"]
-    stream.should.have.key("StreamModeDetails").equals({"StreamMode": "PROVISIONED"})
+    assert stream["StreamModeDetails"] == {"StreamMode": "PROVISIONED"}
 
 
 @mock_kinesis
-def test_describe_non_existent_stream_boto3():
+def test_describe_non_existent_stream():
     client = boto3.client("kinesis", region_name="us-west-2")
     with pytest.raises(ClientError) as exc:
         client.describe_stream_summary(StreamName="not-a-stream")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal(
-        "Stream not-a-stream under account 123456789012 not found."
-    )
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "Stream not-a-stream under account 123456789012 not found."
 
 
 @mock_kinesis
-def test_list_and_delete_stream_boto3():
+def test_list_and_delete_stream():
     client = boto3.client("kinesis", region_name="us-west-2")
-    client.list_streams()["StreamNames"].should.have.length_of(0)
+    assert len(client.list_streams()["StreamNames"]) == 0
 
     client.create_stream(StreamName="stream1", ShardCount=1)
     client.create_stream(StreamName="stream2", ShardCount=1)
-    client.list_streams()["StreamNames"].should.have.length_of(2)
+    assert len(client.list_streams()["StreamNames"]) == 2
 
     client.delete_stream(StreamName="stream1")
-    client.list_streams()["StreamNames"].should.have.length_of(1)
+    assert len(client.list_streams()["StreamNames"]) == 1
+
+    stream_arn = get_stream_arn(client, "stream2")
+    client.delete_stream(StreamARN=stream_arn)
+    assert len(client.list_streams()["StreamNames"]) == 0
 
 
 @mock_kinesis
@@ -86,10 +89,8 @@ def test_delete_unknown_stream():
     with pytest.raises(ClientError) as exc:
         client.delete_stream(StreamName="not-a-stream")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal(
-        "Stream not-a-stream under account 123456789012 not found."
-    )
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "Stream not-a-stream under account 123456789012 not found."
 
 
 @mock_kinesis
@@ -97,18 +98,18 @@ def test_list_many_streams():
     conn = boto3.client("kinesis", region_name="us-west-2")
 
     for i in range(11):
-        conn.create_stream(StreamName="stream%d" % i, ShardCount=1)
+        conn.create_stream(StreamName=f"stream{i}", ShardCount=1)
 
     resp = conn.list_streams()
     stream_names = resp["StreamNames"]
     has_more_streams = resp["HasMoreStreams"]
-    stream_names.should.have.length_of(10)
-    has_more_streams.should.be(True)
+    assert len(stream_names) == 10
+    assert has_more_streams is True
     resp2 = conn.list_streams(ExclusiveStartStreamName=stream_names[-1])
     stream_names = resp2["StreamNames"]
     has_more_streams = resp2["HasMoreStreams"]
-    stream_names.should.have.length_of(1)
-    has_more_streams.should.equal(False)
+    assert len(stream_names) == 1
+    assert has_more_streams is False
 
 
 @mock_kinesis
@@ -121,16 +122,23 @@ def test_describe_stream_summary():
     resp = conn.describe_stream_summary(StreamName=stream_name)
     stream = resp["StreamDescriptionSummary"]
 
-    stream["StreamName"].should.equal(stream_name)
-    stream["OpenShardCount"].should.equal(shard_count)
-    stream["StreamARN"].should.equal(
-        "arn:aws:kinesis:us-west-2:{}:stream/{}".format(ACCOUNT_ID, stream_name)
+    assert stream["StreamName"] == stream_name
+    assert stream["OpenShardCount"] == shard_count
+    assert (
+        stream["StreamARN"]
+        == f"arn:aws:kinesis:us-west-2:{ACCOUNT_ID}:stream/{stream_name}"
     )
-    stream["StreamStatus"].should.equal("ACTIVE")
+    assert stream["StreamStatus"] == "ACTIVE"
+
+    stream_arn = get_stream_arn(conn, stream_name)
+    resp = conn.describe_stream_summary(StreamARN=stream_arn)
+    stream = resp["StreamDescriptionSummary"]
+
+    assert stream["StreamName"] == stream_name
 
 
 @mock_kinesis
-def test_basic_shard_iterator_boto3():
+def test_basic_shard_iterator():
     client = boto3.client("kinesis", region_name="us-west-1")
 
     stream_name = "mystream"
@@ -144,12 +152,35 @@ def test_basic_shard_iterator_boto3():
     shard_iterator = resp["ShardIterator"]
 
     resp = client.get_records(ShardIterator=shard_iterator)
-    resp.should.have.key("Records").length_of(0)
-    resp.should.have.key("MillisBehindLatest").equal(0)
+    assert len(resp["Records"]) == 0
+    assert resp["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
-def test_get_invalid_shard_iterator_boto3():
+def test_basic_shard_iterator_by_stream_arn():
+    client = boto3.client("kinesis", region_name="us-west-1")
+
+    stream_name = "mystream"
+    client.create_stream(StreamName=stream_name, ShardCount=1)
+    stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
+    shard_id = stream["Shards"][0]["ShardId"]
+
+    resp = client.get_shard_iterator(
+        StreamARN=stream["StreamARN"],
+        ShardId=shard_id,
+        ShardIteratorType="TRIM_HORIZON",
+    )
+    shard_iterator = resp["ShardIterator"]
+
+    resp = client.get_records(
+        StreamARN=stream["StreamARN"], ShardIterator=shard_iterator
+    )
+    assert len(resp["Records"]) == 0
+    assert resp["MillisBehindLatest"] == 0
+
+
+@mock_kinesis
+def test_get_invalid_shard_iterator():
     client = boto3.client("kinesis", region_name="us-west-1")
 
     stream_name = "mystream"
@@ -160,30 +191,32 @@ def test_get_invalid_shard_iterator_boto3():
             StreamName=stream_name, ShardId="123", ShardIteratorType="TRIM_HORIZON"
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
+    assert err["Code"] == "ResourceNotFoundException"
     # There is some magic in AWS, that '123' is automatically converted into 'shardId-000000000123'
     # AWS itself returns this normalized ID in the error message, not the given id
-    err["Message"].should.equal(
-        f"Shard 123 in stream {stream_name} under account {ACCOUNT_ID} does not exist"
+    assert (
+        err["Message"]
+        == f"Shard 123 in stream {stream_name} under account {ACCOUNT_ID} does not exist"
     )
 
 
 @mock_kinesis
-def test_put_records_boto3():
+def test_put_records():
     client = boto3.client("kinesis", region_name="eu-west-2")
 
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=1)
     stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
+    stream_arn = stream["StreamARN"]
     shard_id = stream["Shards"][0]["ShardId"]
 
     data = b"hello world"
     partition_key = "1234"
 
-    response = client.put_record(
-        StreamName=stream_name, Data=data, PartitionKey=partition_key
+    client.put_records(
+        Records=[{"Data": data, "PartitionKey": partition_key}] * 5,
+        StreamARN=stream_arn,
     )
-    response["SequenceNumber"].should.equal("1")
 
     resp = client.get_shard_iterator(
         StreamName=stream_name, ShardId=shard_id, ShardIteratorType="TRIM_HORIZON"
@@ -191,27 +224,28 @@ def test_put_records_boto3():
     shard_iterator = resp["ShardIterator"]
 
     resp = client.get_records(ShardIterator=shard_iterator)
-    resp["Records"].should.have.length_of(1)
+    assert len(resp["Records"]) == 5
     record = resp["Records"][0]
 
-    record["Data"].should.equal(b"hello world")
-    record["PartitionKey"].should.equal("1234")
-    record["SequenceNumber"].should.equal("1")
+    assert record["Data"] == data
+    assert record["PartitionKey"] == partition_key
+    assert record["SequenceNumber"] == "1"
 
 
 @mock_kinesis
-def test_get_records_limit_boto3():
+def test_get_records_limit():
     client = boto3.client("kinesis", region_name="eu-west-2")
 
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=1)
     stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
+    stream_arn = stream["StreamARN"]
     shard_id = stream["Shards"][0]["ShardId"]
 
     data = b"hello world"
 
     for index in range(5):
-        client.put_record(StreamName=stream_name, Data=data, PartitionKey=str(index))
+        client.put_record(StreamARN=stream_arn, Data=data, PartitionKey=str(index))
 
     resp = client.get_shard_iterator(
         StreamName=stream_name, ShardId=shard_id, ShardIteratorType="TRIM_HORIZON"
@@ -220,16 +254,16 @@ def test_get_records_limit_boto3():
 
     # Retrieve only 3 records
     resp = client.get_records(ShardIterator=shard_iterator, Limit=3)
-    resp["Records"].should.have.length_of(3)
+    assert len(resp["Records"]) == 3
 
     # Then get the rest of the results
     next_shard_iterator = resp["NextShardIterator"]
     response = client.get_records(ShardIterator=next_shard_iterator)
-    response["Records"].should.have.length_of(2)
+    assert len(response["Records"]) == 2
 
 
 @mock_kinesis
-def test_get_records_at_sequence_number_boto3():
+def test_get_records_at_sequence_number():
     client = boto3.client("kinesis", region_name="eu-west-2")
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=1)
@@ -263,12 +297,12 @@ def test_get_records_at_sequence_number_boto3():
 
     resp = client.get_records(ShardIterator=shard_iterator)
     # And the first result returned should be the second item
-    resp["Records"][0]["SequenceNumber"].should.equal(sequence_nr)
-    resp["Records"][0]["Data"].should.equal(b"data_2")
+    assert resp["Records"][0]["SequenceNumber"] == sequence_nr
+    assert resp["Records"][0]["Data"] == b"data_2"
 
 
 @mock_kinesis
-def test_get_records_after_sequence_number_boto3():
+def test_get_records_after_sequence_number():
     client = boto3.client("kinesis", region_name="eu-west-2")
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=1)
@@ -302,13 +336,13 @@ def test_get_records_after_sequence_number_boto3():
 
     resp = client.get_records(ShardIterator=shard_iterator)
     # And the first result returned should be the second item
-    resp["Records"][0]["SequenceNumber"].should.equal("3")
-    resp["Records"][0]["Data"].should.equal(b"data_3")
-    resp["MillisBehindLatest"].should.equal(0)
+    assert resp["Records"][0]["SequenceNumber"] == "3"
+    assert resp["Records"][0]["Data"] == b"data_3"
+    assert resp["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
-def test_get_records_latest_boto3():
+def test_get_records_latest():
     client = boto3.client("kinesis", region_name="eu-west-2")
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=1)
@@ -346,11 +380,11 @@ def test_get_records_latest_boto3():
 
     resp = client.get_records(ShardIterator=shard_iterator)
     # And the first result returned should be the second item
-    resp["Records"].should.have.length_of(1)
-    resp["Records"][0]["SequenceNumber"].should.equal("5")
-    resp["Records"][0]["PartitionKey"].should.equal("last_record")
-    resp["Records"][0]["Data"].should.equal(b"last_record")
-    resp["MillisBehindLatest"].should.equal(0)
+    assert len(resp["Records"]) == 1
+    assert resp["Records"][0]["SequenceNumber"] == "5"
+    assert resp["Records"][0]["PartitionKey"] == "last_record"
+    assert resp["Records"][0]["Data"] == b"last_record"
+    assert resp["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
@@ -372,7 +406,7 @@ def test_get_records_at_timestamp():
     # To test around this limitation we wait until we well into the next second
     # before capturing the time and storing the records we expect to retrieve.
     time.sleep(1.0)
-    timestamp = datetime.datetime.utcnow()
+    timestamp = utcnow()
 
     keys = [str(i) for i in range(5, 10)]
     for k in keys:
@@ -391,10 +425,10 @@ def test_get_records_at_timestamp():
 
     response = conn.get_records(ShardIterator=shard_iterator)
 
-    response["Records"].should.have.length_of(len(keys))
+    assert len(response["Records"]) == len(keys)
     partition_keys = [r["PartitionKey"] for r in response["Records"]]
-    partition_keys.should.equal(keys)
-    response["MillisBehindLatest"].should.equal(0)
+    assert partition_keys == keys
+    assert response["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
@@ -420,10 +454,10 @@ def test_get_records_at_very_old_timestamp():
     shard_iterator = response["ShardIterator"]
 
     response = conn.get_records(ShardIterator=shard_iterator)
-    response["Records"].should.have.length_of(len(keys))
+    assert len(response["Records"]) == len(keys)
     partition_keys = [r["PartitionKey"] for r in response["Records"]]
-    partition_keys.should.equal(keys)
-    response["MillisBehindLatest"].should.equal(0)
+    assert partition_keys == keys
+    assert response["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
@@ -450,12 +484,10 @@ def test_get_records_timestamp_filtering():
     shard_iterator = response["ShardIterator"]
 
     response = conn.get_records(ShardIterator=shard_iterator)
-    response["Records"].should.have.length_of(1)
-    response["Records"][0]["PartitionKey"].should.equal("1")
-    response["Records"][0]["ApproximateArrivalTimestamp"].should.be.greater_than(
-        timestamp
-    )
-    response["MillisBehindLatest"].should.equal(0)
+    assert len(response["Records"]) == 1
+    assert response["Records"][0]["PartitionKey"] == "1"
+    assert response["Records"][0]["ApproximateArrivalTimestamp"] > timestamp
+    assert response["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
@@ -476,8 +508,8 @@ def test_get_records_millis_behind_latest():
     shard_iterator = response["ShardIterator"]
 
     response = conn.get_records(ShardIterator=shard_iterator, Limit=1)
-    response["Records"].should.have.length_of(1)
-    response["MillisBehindLatest"].should.be.greater_than(0)
+    assert len(response["Records"]) == 1
+    assert response["MillisBehindLatest"] > 0
 
 
 @mock_kinesis
@@ -491,7 +523,7 @@ def test_get_records_at_very_new_timestamp():
     for k in keys:
         conn.put_record(StreamName=stream_name, Data=k, PartitionKey=k)
 
-    timestamp = datetime.datetime.utcnow() + datetime.timedelta(seconds=1)
+    timestamp = utcnow() + datetime.timedelta(seconds=1)
 
     # Get a shard iterator
     response = conn.describe_stream(StreamName=stream_name)
@@ -506,8 +538,8 @@ def test_get_records_at_very_new_timestamp():
 
     response = conn.get_records(ShardIterator=shard_iterator)
 
-    response["Records"].should.have.length_of(0)
-    response["MillisBehindLatest"].should.equal(0)
+    assert len(response["Records"]) == 0
+    assert response["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
@@ -516,7 +548,7 @@ def test_get_records_from_empty_stream_at_timestamp():
     stream_name = "my_stream"
     conn.create_stream(StreamName=stream_name, ShardCount=1)
 
-    timestamp = datetime.datetime.utcnow()
+    timestamp = utcnow()
 
     # Get a shard iterator
     response = conn.describe_stream(StreamName=stream_name)
@@ -531,8 +563,8 @@ def test_get_records_from_empty_stream_at_timestamp():
 
     response = conn.get_records(ShardIterator=shard_iterator)
 
-    response["Records"].should.have.length_of(0)
-    response["MillisBehindLatest"].should.equal(0)
+    assert len(response["Records"]) == 0
+    assert response["MillisBehindLatest"] == 0
 
 
 @mock_kinesis
@@ -546,7 +578,7 @@ def test_valid_increase_stream_retention_period():
     )
 
     response = conn.describe_stream(StreamName=stream_name)
-    response["StreamDescription"]["RetentionPeriodHours"].should.equal(40)
+    assert response["StreamDescription"]["RetentionPeriodHours"] == 40
 
 
 @mock_kinesis
@@ -562,9 +594,10 @@ def test_invalid_increase_stream_retention_period():
         conn.increase_stream_retention_period(
             StreamName=stream_name, RetentionPeriodHours=25
         )
-    ex.value.response["Error"]["Code"].should.equal("InvalidArgumentException")
-    ex.value.response["Error"]["Message"].should.equal(
-        "Requested retention period (25 hours) for stream my_stream can not be shorter than existing retention period (30 hours). Use DecreaseRetentionPeriod API."
+    assert ex.value.response["Error"]["Code"] == "InvalidArgumentException"
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "Requested retention period (25 hours) for stream my_stream can not be shorter than existing retention period (30 hours). Use DecreaseRetentionPeriod API."
     )
 
 
@@ -579,9 +612,10 @@ def test_invalid_increase_stream_retention_too_low():
             StreamName=stream_name, RetentionPeriodHours=20
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidArgumentException")
-    err["Message"].should.equal(
-        "Minimum allowed retention period is 24 hours. Requested retention period (20 hours) is too short."
+    assert err["Code"] == "InvalidArgumentException"
+    assert (
+        err["Message"]
+        == "Minimum allowed retention period is 24 hours. Requested retention period (20 hours) is too short."
     )
 
 
@@ -596,9 +630,10 @@ def test_invalid_increase_stream_retention_too_high():
             StreamName=stream_name, RetentionPeriodHours=9999
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidArgumentException")
-    err["Message"].should.equal(
-        "Maximum allowed retention period is 8760 hours. Requested retention period (9999 hours) is too long."
+    assert err["Code"] == "InvalidArgumentException"
+    assert (
+        err["Message"]
+        == "Maximum allowed retention period is 8760 hours. Requested retention period (9999 hours) is too long."
     )
 
 
@@ -607,6 +642,7 @@ def test_valid_decrease_stream_retention_period():
     conn = boto3.client("kinesis", region_name="us-west-2")
     stream_name = "decrease_stream"
     conn.create_stream(StreamName=stream_name, ShardCount=1)
+    stream_arn = get_stream_arn(conn, stream_name)
 
     conn.increase_stream_retention_period(
         StreamName=stream_name, RetentionPeriodHours=30
@@ -616,7 +652,13 @@ def test_valid_decrease_stream_retention_period():
     )
 
     response = conn.describe_stream(StreamName=stream_name)
-    response["StreamDescription"]["RetentionPeriodHours"].should.equal(25)
+    assert response["StreamDescription"]["RetentionPeriodHours"] == 25
+
+    conn.increase_stream_retention_period(StreamARN=stream_arn, RetentionPeriodHours=29)
+    conn.decrease_stream_retention_period(StreamARN=stream_arn, RetentionPeriodHours=26)
+
+    response = conn.describe_stream(StreamARN=stream_arn)
+    assert response["StreamDescription"]["RetentionPeriodHours"] == 26
 
 
 @mock_kinesis
@@ -630,9 +672,10 @@ def test_decrease_stream_retention_period_upwards():
             StreamName=stream_name, RetentionPeriodHours=40
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidArgumentException")
-    err["Message"].should.equal(
-        "Requested retention period (40 hours) for stream decrease_stream can not be longer than existing retention period (24 hours). Use IncreaseRetentionPeriod API."
+    assert err["Code"] == "InvalidArgumentException"
+    assert (
+        err["Message"]
+        == "Requested retention period (40 hours) for stream decrease_stream can not be longer than existing retention period (24 hours). Use IncreaseRetentionPeriod API."
     )
 
 
@@ -647,9 +690,10 @@ def test_decrease_stream_retention_period_too_low():
             StreamName=stream_name, RetentionPeriodHours=4
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidArgumentException")
-    err["Message"].should.equal(
-        "Minimum allowed retention period is 24 hours. Requested retention period (4 hours) is too short."
+    assert err["Code"] == "InvalidArgumentException"
+    assert (
+        err["Message"]
+        == "Minimum allowed retention period is 24 hours. Requested retention period (4 hours) is too short."
     )
 
 
@@ -664,14 +708,15 @@ def test_decrease_stream_retention_period_too_high():
             StreamName=stream_name, RetentionPeriodHours=9999
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidArgumentException")
-    err["Message"].should.equal(
-        "Maximum allowed retention period is 8760 hours. Requested retention period (9999 hours) is too long."
+    assert err["Code"] == "InvalidArgumentException"
+    assert (
+        err["Message"]
+        == "Maximum allowed retention period is 8760 hours. Requested retention period (9999 hours) is too long."
     )
 
 
 @mock_kinesis
-def test_invalid_shard_iterator_type_boto3():
+def test_invalid_shard_iterator_type():
     client = boto3.client("kinesis", region_name="eu-west-2")
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=1)
@@ -683,58 +728,73 @@ def test_invalid_shard_iterator_type_boto3():
             StreamName=stream_name, ShardId=shard_id, ShardIteratorType="invalid-type"
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("InvalidArgumentException")
-    err["Message"].should.equal("Invalid ShardIteratorType: invalid-type")
+    assert err["Code"] == "InvalidArgumentException"
+    assert err["Message"] == "Invalid ShardIteratorType: invalid-type"
 
 
 @mock_kinesis
-def test_add_list_remove_tags_boto3():
+def test_add_list_remove_tags():
     client = boto3.client("kinesis", region_name="eu-west-2")
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=1)
+    stream_arn = get_stream_arn(client, stream_name)
     client.add_tags_to_stream(
         StreamName=stream_name,
         Tags={"tag1": "val1", "tag2": "val2", "tag3": "val3", "tag4": "val4"},
     )
 
     tags = client.list_tags_for_stream(StreamName=stream_name)["Tags"]
-    tags.should.have.length_of(4)
-    tags.should.contain({"Key": "tag1", "Value": "val1"})
-    tags.should.contain({"Key": "tag2", "Value": "val2"})
-    tags.should.contain({"Key": "tag3", "Value": "val3"})
-    tags.should.contain({"Key": "tag4", "Value": "val4"})
+    assert len(tags) == 4
+    assert {"Key": "tag1", "Value": "val1"} in tags
+    assert {"Key": "tag2", "Value": "val2"} in tags
+    assert {"Key": "tag3", "Value": "val3"} in tags
+    assert {"Key": "tag4", "Value": "val4"} in tags
 
-    client.add_tags_to_stream(StreamName=stream_name, Tags={"tag5": "val5"})
+    client.add_tags_to_stream(StreamARN=stream_arn, Tags={"tag5": "val5"})
 
-    tags = client.list_tags_for_stream(StreamName=stream_name)["Tags"]
-    tags.should.have.length_of(5)
-    tags.should.contain({"Key": "tag5", "Value": "val5"})
+    tags = client.list_tags_for_stream(StreamARN=stream_arn)["Tags"]
+    assert len(tags) == 5
+    assert {"Key": "tag5", "Value": "val5"} in tags
 
     client.remove_tags_from_stream(StreamName=stream_name, TagKeys=["tag2", "tag3"])
 
     tags = client.list_tags_for_stream(StreamName=stream_name)["Tags"]
-    tags.should.have.length_of(3)
-    tags.should.contain({"Key": "tag1", "Value": "val1"})
-    tags.should.contain({"Key": "tag4", "Value": "val4"})
-    tags.should.contain({"Key": "tag5", "Value": "val5"})
+    assert len(tags) == 3
+    assert {"Key": "tag1", "Value": "val1"} in tags
+    assert {"Key": "tag4", "Value": "val4"} in tags
+    assert {"Key": "tag5", "Value": "val5"} in tags
+
+    client.remove_tags_from_stream(StreamARN=stream_arn, TagKeys=["tag4"])
+
+    tags = client.list_tags_for_stream(StreamName=stream_name)["Tags"]
+    assert len(tags) == 2
+    assert {"Key": "tag1", "Value": "val1"} in tags
+    assert {"Key": "tag5", "Value": "val5"} in tags
 
 
 @mock_kinesis
-def test_merge_shards_boto3():
+def test_merge_shards():
     client = boto3.client("kinesis", region_name="eu-west-2")
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=4)
+    stream_arn = get_stream_arn(client, stream_name)
 
-    for index in range(1, 100):
+    for index in range(1, 50):
         client.put_record(
             StreamName=stream_name,
             Data=f"data_{index}".encode("utf-8"),
             PartitionKey=str(index),
         )
+    for index in range(51, 100):
+        client.put_record(
+            StreamARN=stream_arn,
+            Data=f"data_{index}".encode("utf-8"),
+            PartitionKey=str(index),
+        )
 
     stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
     shards = stream["Shards"]
-    shards.should.have.length_of(4)
+    assert len(shards) == 4
 
     client.merge_shards(
         StreamName=stream_name,
@@ -746,7 +806,7 @@ def test_merge_shards_boto3():
     shards = stream["Shards"]
 
     # Old shards still exist, but are closed. A new shard is created out of the old one
-    shards.should.have.length_of(5)
+    assert len(shards) == 5
 
     # Only three shards are active - the two merged shards are closed
     active_shards = [
@@ -754,10 +814,10 @@ def test_merge_shards_boto3():
         for shard in shards
         if "EndingSequenceNumber" not in shard["SequenceNumberRange"]
     ]
-    active_shards.should.have.length_of(3)
+    assert len(active_shards) == 3
 
     client.merge_shards(
-        StreamName=stream_name,
+        StreamARN=stream_arn,
         ShardToMerge="shardId-000000000004",
         AdjacentShardToMerge="shardId-000000000002",
     )
@@ -770,23 +830,21 @@ def test_merge_shards_boto3():
         for shard in shards
         if "EndingSequenceNumber" not in shard["SequenceNumberRange"]
     ]
-    active_shards.should.have.length_of(2)
+    assert len(active_shards) == 2
 
     for shard in active_shards:
         del shard["HashKeyRange"]
         del shard["SequenceNumberRange"]
 
     # Original shard #3 is still active (0,1,2 have been merged and closed
-    active_shards.should.contain({"ShardId": "shardId-000000000003"})
+    assert {"ShardId": "shardId-000000000003"} in active_shards
     # Shard #4 was the child of #0 and #1
     # Shard #5 is the child of #4 (parent) and #2 (adjacent-parent)
-    active_shards.should.contain(
-        {
-            "ShardId": "shardId-000000000005",
-            "ParentShardId": "shardId-000000000004",
-            "AdjacentParentShardId": "shardId-000000000002",
-        }
-    )
+    assert {
+        "ShardId": "shardId-000000000005",
+        "ParentShardId": "shardId-000000000004",
+        "AdjacentParentShardId": "shardId-000000000002",
+    } in active_shards
 
 
 @mock_kinesis
@@ -802,5 +860,11 @@ def test_merge_shards_invalid_arg():
             AdjacentShardToMerge="shardId-000000000002",
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("InvalidArgumentException")
-    err["Message"].should.equal("shardId-000000000002")
+    assert err["Code"] == "InvalidArgumentException"
+    assert err["Message"] == "shardId-000000000002"
+
+
+def get_stream_arn(client, stream_name):
+    return client.describe_stream(StreamName=stream_name)["StreamDescription"][
+        "StreamARN"
+    ]
