@@ -2,6 +2,8 @@ import boto3
 
 from moto import mock_kinesis
 
+from .test_kinesis import get_stream_arn
+
 
 @mock_kinesis
 def test_enable_encryption():
@@ -10,8 +12,8 @@ def test_enable_encryption():
 
     resp = client.describe_stream(StreamName="my-stream")
     desc = resp["StreamDescription"]
-    desc.should.have.key("EncryptionType").should.equal("NONE")
-    desc.shouldnt.have.key("KeyId")
+    assert desc["EncryptionType"] == "NONE"
+    assert "KeyId" not in desc
 
     client.start_stream_encryption(
         StreamName="my-stream", EncryptionType="KMS", KeyId="n/a"
@@ -19,8 +21,8 @@ def test_enable_encryption():
 
     resp = client.describe_stream(StreamName="my-stream")
     desc = resp["StreamDescription"]
-    desc.should.have.key("EncryptionType").should.equal("KMS")
-    desc.should.have.key("KeyId").equals("n/a")
+    assert desc["EncryptionType"] == "KMS"
+    assert desc["KeyId"] == "n/a"
 
 
 @mock_kinesis
@@ -30,7 +32,7 @@ def test_disable_encryption():
 
     resp = client.describe_stream(StreamName="my-stream")
     desc = resp["StreamDescription"]
-    desc.should.have.key("EncryptionType").should.equal("NONE")
+    assert desc["EncryptionType"] == "NONE"
 
     client.start_stream_encryption(
         StreamName="my-stream", EncryptionType="KMS", KeyId="n/a"
@@ -42,5 +44,29 @@ def test_disable_encryption():
 
     resp = client.describe_stream(StreamName="my-stream")
     desc = resp["StreamDescription"]
-    desc.should.have.key("EncryptionType").should.equal("NONE")
-    desc.shouldnt.have.key("KeyId")
+    assert desc["EncryptionType"] == "NONE"
+    assert "KeyId" not in desc
+
+
+@mock_kinesis
+def test_disable_encryption__using_arns():
+    client = boto3.client("kinesis", region_name="us-west-2")
+    client.create_stream(StreamName="my-stream", ShardCount=2)
+    stream_arn = get_stream_arn(client, "my-stream")
+
+    resp = client.describe_stream(StreamName="my-stream")
+    desc = resp["StreamDescription"]
+    assert desc["EncryptionType"] == "NONE"
+
+    client.start_stream_encryption(
+        StreamARN=stream_arn, EncryptionType="KMS", KeyId="n/a"
+    )
+
+    client.stop_stream_encryption(
+        StreamARN=stream_arn, EncryptionType="KMS", KeyId="n/a"
+    )
+
+    resp = client.describe_stream(StreamName="my-stream")
+    desc = resp["StreamDescription"]
+    assert desc["EncryptionType"] == "NONE"
+    assert "KeyId" not in desc
