@@ -1,6 +1,9 @@
 import boto3
 
 from moto import mock_kinesis
+from tests import DEFAULT_ACCOUNT_ID
+
+from .test_kinesis import get_stream_arn
 
 
 @mock_kinesis
@@ -13,9 +16,13 @@ def test_enable_enhanced_monitoring_all():
         StreamName=stream_name, ShardLevelMetrics=["ALL"]
     )
 
-    resp.should.have.key("StreamName").equals(stream_name)
-    resp.should.have.key("CurrentShardLevelMetrics").equals([])
-    resp.should.have.key("DesiredShardLevelMetrics").equals(["ALL"])
+    assert resp["StreamName"] == stream_name
+    assert resp["CurrentShardLevelMetrics"] == []
+    assert resp["DesiredShardLevelMetrics"] == ["ALL"]
+    assert (
+        resp["StreamARN"]
+        == f"arn:aws:kinesis:us-east-1:{DEFAULT_ACCOUNT_ID}:stream/{stream_name}"
+    )
 
 
 @mock_kinesis
@@ -30,7 +37,7 @@ def test_enable_enhanced_monitoring_is_persisted():
 
     stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
     metrics = stream["EnhancedMonitoring"][0]["ShardLevelMetrics"]
-    set(metrics).should.equal({"IncomingBytes", "OutgoingBytes"})
+    assert set(metrics) == {"IncomingBytes", "OutgoingBytes"}
 
 
 @mock_kinesis
@@ -47,22 +54,20 @@ def test_enable_enhanced_monitoring_in_steps():
         StreamName=stream_name, ShardLevelMetrics=["WriteProvisionedThroughputExceeded"]
     )
 
-    resp.should.have.key("CurrentShardLevelMetrics").should.have.length_of(2)
-    resp["CurrentShardLevelMetrics"].should.contain("IncomingBytes")
-    resp["CurrentShardLevelMetrics"].should.contain("OutgoingBytes")
-    resp.should.have.key("DesiredShardLevelMetrics").should.have.length_of(3)
-    resp["DesiredShardLevelMetrics"].should.contain("IncomingBytes")
-    resp["DesiredShardLevelMetrics"].should.contain("OutgoingBytes")
-    resp["DesiredShardLevelMetrics"].should.contain(
-        "WriteProvisionedThroughputExceeded"
-    )
+    assert len(resp["CurrentShardLevelMetrics"]) == 2
+    assert "IncomingBytes" in resp["CurrentShardLevelMetrics"]
+    assert "OutgoingBytes" in resp["CurrentShardLevelMetrics"]
+    assert len(resp["DesiredShardLevelMetrics"]) == 3
+    assert "IncomingBytes" in resp["DesiredShardLevelMetrics"]
+    assert "OutgoingBytes" in resp["DesiredShardLevelMetrics"]
+    assert "WriteProvisionedThroughputExceeded" in resp["DesiredShardLevelMetrics"]
 
     stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
     metrics = stream["EnhancedMonitoring"][0]["ShardLevelMetrics"]
-    metrics.should.have.length_of(3)
-    metrics.should.contain("IncomingBytes")
-    metrics.should.contain("OutgoingBytes")
-    metrics.should.contain("WriteProvisionedThroughputExceeded")
+    assert len(metrics) == 3
+    assert "IncomingBytes" in metrics
+    assert "OutgoingBytes" in metrics
+    assert "WriteProvisionedThroughputExceeded" in metrics
 
 
 @mock_kinesis
@@ -70,9 +75,10 @@ def test_disable_enhanced_monitoring():
     client = boto3.client("kinesis", region_name="us-east-1")
     stream_name = "my_stream_summary"
     client.create_stream(StreamName=stream_name, ShardCount=4)
+    stream_arn = get_stream_arn(client, stream_name)
 
     client.enable_enhanced_monitoring(
-        StreamName=stream_name,
+        StreamARN=stream_arn,
         ShardLevelMetrics=[
             "IncomingBytes",
             "OutgoingBytes",
@@ -84,23 +90,32 @@ def test_disable_enhanced_monitoring():
         StreamName=stream_name, ShardLevelMetrics=["OutgoingBytes"]
     )
 
-    resp.should.have.key("CurrentShardLevelMetrics").should.have.length_of(3)
-    resp["CurrentShardLevelMetrics"].should.contain("IncomingBytes")
-    resp["CurrentShardLevelMetrics"].should.contain("OutgoingBytes")
-    resp["CurrentShardLevelMetrics"].should.contain(
-        "WriteProvisionedThroughputExceeded"
-    )
-    resp.should.have.key("DesiredShardLevelMetrics").should.have.length_of(2)
-    resp["DesiredShardLevelMetrics"].should.contain("IncomingBytes")
-    resp["DesiredShardLevelMetrics"].should.contain(
-        "WriteProvisionedThroughputExceeded"
+    assert resp["StreamName"] == stream_name
+    assert (
+        resp["StreamARN"]
+        == f"arn:aws:kinesis:us-east-1:{DEFAULT_ACCOUNT_ID}:stream/{stream_name}"
     )
 
+    assert len(resp["CurrentShardLevelMetrics"]) == 3
+    assert "IncomingBytes" in resp["CurrentShardLevelMetrics"]
+    assert "OutgoingBytes" in resp["CurrentShardLevelMetrics"]
+    assert "WriteProvisionedThroughputExceeded" in resp["CurrentShardLevelMetrics"]
+    assert len(resp["DesiredShardLevelMetrics"]) == 2
+    assert "IncomingBytes" in resp["DesiredShardLevelMetrics"]
+    assert "WriteProvisionedThroughputExceeded" in resp["DesiredShardLevelMetrics"]
+
     stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
     metrics = stream["EnhancedMonitoring"][0]["ShardLevelMetrics"]
-    metrics.should.have.length_of(2)
-    metrics.should.contain("IncomingBytes")
-    metrics.should.contain("WriteProvisionedThroughputExceeded")
+    assert len(metrics) == 2
+    assert "IncomingBytes" in metrics
+    assert "WriteProvisionedThroughputExceeded" in metrics
+
+    resp = client.disable_enhanced_monitoring(
+        StreamARN=stream_arn, ShardLevelMetrics=["IncomingBytes"]
+    )
+
+    assert len(resp["CurrentShardLevelMetrics"]) == 2
+    assert len(resp["DesiredShardLevelMetrics"]) == 1
 
 
 @mock_kinesis
@@ -124,4 +139,4 @@ def test_disable_enhanced_monitoring_all():
 
     stream = client.describe_stream(StreamName=stream_name)["StreamDescription"]
     metrics = stream["EnhancedMonitoring"][0]["ShardLevelMetrics"]
-    metrics.should.equal([])
+    assert metrics == []
