@@ -1,9 +1,9 @@
 import boto3
-import sure  # noqa # pylint: disable=unused-import
 import pytest
-from moto import mock_kinesisvideo
 from botocore.exceptions import ClientError
 
+from moto import mock_kinesisvideo
+
 
 @mock_kinesisvideo
 def test_create_stream():
@@ -13,7 +13,7 @@ def test_create_stream():
 
     # stream can be created
     res = client.create_stream(StreamName=stream_name, DeviceName=device_name)
-    res.should.have.key("StreamARN").which.should.contain(stream_name)
+    assert stream_name in res["StreamARN"]
 
 
 @mock_kinesisvideo
@@ -36,7 +36,7 @@ def test_describe_stream():
     device_name = "random-device"
 
     res = client.create_stream(StreamName=stream_name, DeviceName=device_name)
-    res.should.have.key("StreamARN").which.should.contain(stream_name)
+    assert stream_name in res["StreamARN"]
     stream_arn = res["StreamARN"]
 
     # cannot create with existing stream name
@@ -45,19 +45,17 @@ def test_describe_stream():
 
     # stream can be described with name
     res = client.describe_stream(StreamName=stream_name)
-    res.should.have.key("StreamInfo")
     stream_info = res["StreamInfo"]
-    stream_info.should.have.key("StreamARN").which.should.contain(stream_name)
-    stream_info.should.have.key("StreamName").which.should.equal(stream_name)
-    stream_info.should.have.key("DeviceName").which.should.equal(device_name)
+    assert stream_name in stream_info["StreamARN"]
+    assert stream_info["StreamName"] == stream_name
+    assert stream_info["DeviceName"] == device_name
 
     # stream can be described with arn
     res = client.describe_stream(StreamARN=stream_arn)
-    res.should.have.key("StreamInfo")
     stream_info = res["StreamInfo"]
-    stream_info.should.have.key("StreamARN").which.should.contain(stream_name)
-    stream_info.should.have.key("StreamName").which.should.equal(stream_name)
-    stream_info.should.have.key("DeviceName").which.should.equal(device_name)
+    assert stream_name in stream_info["StreamARN"]
+    assert stream_info["StreamName"] == stream_name
+    assert stream_info["DeviceName"] == device_name
 
 
 @mock_kinesisvideo
@@ -82,9 +80,8 @@ def test_list_streams():
 
     # streams can be listed
     res = client.list_streams()
-    res.should.have.key("StreamInfoList")
     streams = res["StreamInfoList"]
-    streams.should.have.length_of(2)
+    assert len(streams) == 2
 
 
 @mock_kinesisvideo
@@ -102,7 +99,7 @@ def test_delete_stream():
     client.delete_stream(StreamARN=stream_2_arn)
     res = client.list_streams()
     streams = res["StreamInfoList"]
-    streams.should.have.length_of(1)
+    assert len(streams) == 1
 
 
 @mock_kinesisvideo
@@ -134,4 +131,4 @@ def test_data_endpoint():
     api_name = "GET_MEDIA"
     client.create_stream(StreamName=stream_name, DeviceName=device_name)
     res = client.get_data_endpoint(StreamName=stream_name, APIName=api_name)
-    res.should.have.key("DataEndpoint")
+    assert "DataEndpoint" in res
