@@ -1,8 +1,9 @@
+from datetime import timedelta
+
 import boto3
-import sure  # noqa # pylint: disable=unused-import
-from moto import mock_kinesisvideoarchivedmedia
-from moto import mock_kinesisvideo
-from datetime import datetime, timedelta
+
+from moto import mock_kinesisvideo, mock_kinesisvideoarchivedmedia
+from moto.core.utils import utcnow
 
 
 @mock_kinesisvideo
@@ -23,10 +24,9 @@ def test_get_hls_streaming_session_url():
         endpoint_url=data_endpoint,
     )
     res = client.get_hls_streaming_session_url(StreamName=stream_name)
-    reg_exp = r"^{}/hls/v1/getHLSMasterPlaylist.m3u8\?SessionToken\=.+$".format(
-        data_endpoint
+    assert res["HLSStreamingSessionURL"].startswith(
+        f"{data_endpoint}/hls/v1/getHLSMasterPlaylist.m3u8?SessionToken="
     )
-    res.should.have.key("HLSStreamingSessionURL").which.should.match(reg_exp)
 
 
 @mock_kinesisvideo
@@ -47,10 +47,9 @@ def test_get_dash_streaming_session_url():
         endpoint_url=data_endpoint,
     )
     res = client.get_dash_streaming_session_url(StreamName=stream_name)
-    reg_exp = r"^{}/dash/v1/getDASHManifest.mpd\?SessionToken\=.+$".format(
-        data_endpoint
+    assert res["DASHStreamingSessionURL"].startswith(
+        f"{data_endpoint}/dash/v1/getDASHManifest.mpd?SessionToken="
     )
-    res.should.have.key("DASHStreamingSessionURL").which.should.match(reg_exp)
 
 
 @mock_kinesisvideo
@@ -70,7 +69,7 @@ def test_get_clip():
         region_name=region_name,
         endpoint_url=data_endpoint,
     )
-    end_timestamp = datetime.utcnow() - timedelta(hours=1)
+    end_timestamp = utcnow() - timedelta(hours=1)
     start_timestamp = end_timestamp - timedelta(minutes=5)
     res = client.get_clip(
         StreamName=stream_name,
@@ -82,5 +81,5 @@ def test_get_clip():
             },
         },
     )
-    res.should.have.key("ContentType").which.should.match("video/mp4")
-    res.should.have.key("Payload")
+    assert res["ContentType"] == "video/mp4"
+    assert "Payload" in res
