@@ -1,5 +1,3 @@
-import sure  # noqa # pylint: disable=unused-import
-
 import moto.server as server
 from moto import mock_kinesisvideoarchivedmedia
 
@@ -14,4 +12,4 @@ def test_kinesisvideoarchivedmedia_server_is_up():
     test_client = backend.test_client()
     res = test_client.post("/getHLSStreamingSessionURL")
     # Just checking server is up
-    res.status_code.should.equal(404)
+    assert res.status_code == 404
