@@ -1,14 +1,15 @@
-import boto3
 import json
+from unittest import mock
+
+import boto3
 import pytest
 from botocore.exceptions import ClientError
-from unittest import mock
+from cryptography.hazmat.primitives.asymmetric import rsa
 
 from moto import mock_kms
 from moto.kms.exceptions import AccessDeniedException
 from moto.kms.models import Key
 from moto.kms.policy_validator import validate_policy
-from cryptography.hazmat.primitives.asymmetric import rsa
 
 
 @mock_kms
@@ -46,7 +47,7 @@ class TestKMSPolicyEnforcement:
         with pytest.raises(ClientError) as exc:
             self.client.describe_key(KeyId=self.key_id)
         err = exc.value.response["Error"]
-        err["Code"].should.equal("AccessDeniedException")
+        assert err["Code"] == "AccessDeniedException"
 
     @pytest.mark.parametrize("actions", [["kms:unknown"], ["kms:describestuff"]])
     def test_policy__allow_based_on_actions(self, actions):
@@ -67,7 +68,7 @@ class TestKMSPolicyEnforcement:
             Policy=json.dumps(policy), PolicyName="default", KeyId=self.key_id
         )
         key = self.client.describe_key(KeyId=self.key_id)["KeyMetadata"]
-        key["Description"].should.equal("t")
+        assert key["Description"] == "t"
 
 
 class TestKMSPolicyValidator:
