@@ -1,16 +1,13 @@
 import json
-import time
-import sure  # noqa # pylint: disable=unused-import
-from datetime import timedelta, datetime
-from uuid import UUID
+from datetime import timedelta
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 from freezegun import freeze_time
 
-from moto import mock_logs, mock_s3, settings
-from moto.core.utils import unix_time_millis
+from moto import mock_logs, settings
+from moto.core.utils import unix_time_millis, utcnow
 from moto.logs.models import MAX_RESOURCE_POLICIES_PER_REGION
 
 TEST_REGION = "us-east-1" if settings.TEST_SERVER_MODE else "us-west-2"
@@ -136,8 +133,8 @@ def test_put_metric_filters_validation():
         with pytest.raises(ClientError) as exc:
             conn.put_metric_filter(**test_case["input"])
         response = exc.value.response
-        response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-        response["Error"]["Code"].should.equal("InvalidParameterException")
+        assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
+        assert response["Error"]["Code"] == "InvalidParameterException"
 
 
 @mock_logs
@@ -164,8 +161,8 @@ def test_describe_metric_filters_validation():
         with pytest.raises(ClientError) as exc:
             conn.describe_metric_filters(**test_case["input"])
         response = exc.value.response
-        response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-        response["Error"]["Code"].should.equal("InvalidParameterException")
+        assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
+        assert response["Error"]["Code"] == "InvalidParameterException"
 
 
 @mock_logs
@@ -216,7 +213,7 @@ def test_delete_metric_filter():
     response = client.describe_metric_filters(
         filterNamePrefix="filter", logGroupName="logGroupName2"
     )
-    response.should.have.key("metricFilters").equals([])
+    assert response["metricFilters"] == []
 
 
 @mock_logs
@@ -235,12 +232,13 @@ def test_delete_metric_filter_invalid_filter_name(filter_name, failing_constrain
     with pytest.raises(ClientError) as exc:
         conn.delete_metric_filter(filterName=filter_name, logGroupName="valid")
     response = exc.value.response
-    response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    response["Error"]["Code"].should.equal("InvalidParameterException")
-    response["Error"]["Message"].should.contain(
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert response["Error"]["Code"] == "InvalidParameterException"
+    assert (
         f"Value '{filter_name}' at 'filterName' failed to satisfy constraint"
+        in response["Error"]["Message"]
     )
-    response["Error"]["Message"].should.contain(failing_constraint)
+    assert failing_constraint in response["Error"]["Message"]
 
 
 @mock_logs
@@ -261,12 +259,13 @@ def test_delete_metric_filter_invalid_log_group_name(
     with pytest.raises(ClientError) as exc:
         conn.delete_metric_filter(filterName="valid", logGroupName=log_group_name)
     response = exc.value.response
-    response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    response["Error"]["Code"].should.equal("InvalidParameterException")
-    response["Error"]["Message"].should.contain(
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert response["Error"]["Code"] == "InvalidParameterException"
+    assert (
         f"Value '{log_group_name}' at 'logGroupName' failed to satisfy constraint"
+        in response["Error"]["Message"]
     )
-    response["Error"]["Message"].should.contain(failing_constraint)
+    assert failing_constraint in response["Error"]["Message"]
 
 
 @mock_logs
@@ -440,18 +439,18 @@ def test_create_log_group(kms_key_id):
         create_logs_params["kmsKeyId"] = kms_key_id
 
     # When
-    response = conn.create_log_group(**create_logs_params)
+    conn.create_log_group(**create_logs_params)
     response = conn.describe_log_groups()
 
     # Then
-    response["logGroups"].should.have.length_of(1)
+    assert len(response["logGroups"]) == 1
 
     log_group = response["logGroups"][0]
-    log_group.should_not.have.key("retentionInDays")
+    assert "retentionInDays" not in log_group
 
     if kms_key_id:
-        log_group.should.have.key("kmsKeyId")
-        log_group["kmsKeyId"].should.equal(kms_key_id)
+        assert "kmsKeyId" in log_group
+        assert log_group["kmsKeyId"] == kms_key_id
 
 
 @mock_logs
@@ -482,8 +481,8 @@ def test_exceptions():
             logEvents=[{"timestamp": 0, "message": "line"}],
         )
     error = ex.value.response["Error"]
-    error["Code"].should.equal("ResourceNotFoundException")
-    error["Message"].should.equal("The specified log stream does not exist.")
+    assert error["Code"] == "ResourceNotFoundException"
+    assert error["Message"] == "The specified log stream does not exist."
 
 
 @mock_logs
@@ -507,7 +506,7 @@ def test_put_logs():
     next_sequence_token = put_results["nextSequenceToken"]
     assert isinstance(next_sequence_token, str)
     assert len(next_sequence_token) == 56
-    events.should.have.length_of(2)
+    assert len(events) == 2
 
 
 @mock_logs
@@ -518,8 +517,8 @@ def test_put_log_events_in_wrong_order():
     conn.create_log_group(logGroupName=log_group_name)
     conn.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
 
-    ts_1 = int(unix_time_millis(datetime.utcnow() - timedelta(days=2)))
-    ts_2 = int(unix_time_millis(datetime.utcnow() - timedelta(days=5)))
+    ts_1 = int(unix_time_millis(utcnow() - timedelta(days=2)))
+    ts_2 = int(unix_time_millis(utcnow() - timedelta(days=5)))
 
     messages = [
         {"message": f"Message {idx}", "timestamp": ts}
@@ -534,9 +533,10 @@ def test_put_log_events_in_wrong_order():
             sequenceToken="49599396607703531511419593985621160512859251095480828066",
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.equal(
-        "Log events in a single PutLogEvents request must be in chronological order."
+    assert err["Code"] == "InvalidParameterException"
+    assert (
+        err["Message"]
+        == "Log events in a single PutLogEvents request must be in chronological order."
     )
 
 
@@ -549,16 +549,14 @@ def test_put_log_events_in_the_past(days_ago):
     conn.create_log_group(logGroupName=log_group_name)
     conn.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
 
-    timestamp = int(unix_time_millis(datetime.utcnow() - timedelta(days=days_ago)))
+    timestamp = int(unix_time_millis(utcnow() - timedelta(days=days_ago)))
 
     messages = [{"message": "Message number {}", "timestamp": timestamp}]
 
     resp = conn.put_log_events(
         logGroupName=log_group_name, logStreamName=log_stream_name, logEvents=messages
     )
-    resp.should.have.key("rejectedLogEventsInfo").should.equal(
-        {"tooOldLogEventEndIndex": 0}
-    )
+    assert resp["rejectedLogEventsInfo"] == {"tooOldLogEventEndIndex": 0}
 
 
 @mock_logs
@@ -570,31 +568,29 @@ def test_put_log_events_in_the_future(minutes):
     conn.create_log_group(logGroupName=log_group_name)
     conn.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
 
-    timestamp = int(unix_time_millis(datetime.utcnow() + timedelta(minutes=minutes)))
+    timestamp = int(unix_time_millis(utcnow() + timedelta(minutes=minutes)))
 
     messages = [{"message": "Message number {}", "timestamp": timestamp}]
 
     resp = conn.put_log_events(
         logGroupName=log_group_name, logStreamName=log_stream_name, logEvents=messages
     )
-    resp.should.have.key("rejectedLogEventsInfo").should.equal(
-        {"tooNewLogEventStartIndex": 0}
-    )
+    assert resp["rejectedLogEventsInfo"] == {"tooNewLogEventStartIndex": 0}
 
 
 @mock_logs
 def test_put_retention_policy():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
-    response = conn.create_log_group(logGroupName=log_group_name)
+    conn.create_log_group(logGroupName=log_group_name)
 
-    response = conn.put_retention_policy(logGroupName=log_group_name, retentionInDays=7)
+    conn.put_retention_policy(logGroupName=log_group_name, retentionInDays=7)
 
     response = conn.describe_log_groups(logGroupNamePrefix=log_group_name)
     assert len(response["logGroups"]) == 1
     assert response["logGroups"][0].get("retentionInDays") == 7
 
-    response = conn.delete_log_group(logGroupName=log_group_name)
+    conn.delete_log_group(logGroupName=log_group_name)
 
 
 @mock_logs
@@ -693,10 +689,10 @@ def test_put_resource_policy_too_many():
             policyName="too_many", policyDocument=json.dumps(json_policy_doc)
         )
     exc_value = exc.value
-    exc_value.operation_name.should.equal("PutResourcePolicy")
-    exc_value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    exc_value.response["Error"]["Code"].should.equal("LimitExceededException")
-    exc_value.response["Error"]["Message"].should.contain("Resource limit exceeded.")
+    assert exc_value.operation_name == "PutResourcePolicy"
+    assert exc_value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert exc_value.response["Error"]["Code"] == "LimitExceededException"
+    assert "Resource limit exceeded." in exc_value.response["Error"]["Message"]
 
     # put_resource_policy on already created policy, shouldnt throw any error
     client.put_resource_policy(
@@ -728,11 +724,12 @@ def test_delete_resource_policy():
     with pytest.raises(ClientError) as exc:
         client.delete_resource_policy(policyName="non-existent")
     exc_value = exc.value
-    exc_value.operation_name.should.equal("DeleteResourcePolicy")
-    exc_value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    exc_value.response["Error"]["Code"].should.equal("ResourceNotFoundException")
-    exc_value.response["Error"]["Message"].should.contain(
+    assert exc_value.operation_name == "DeleteResourcePolicy"
+    assert exc_value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert exc_value.response["Error"]["Code"] == "ResourceNotFoundException"
+    assert (
         "Policy with name [non-existent] does not exist"
+        in exc_value.response["Error"]["Message"]
     )
 
 
@@ -771,7 +768,7 @@ def test_get_log_events():
     client.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
 
     data = [
-        (int(unix_time_millis(datetime.utcnow() + timedelta(milliseconds=x))), str(x))
+        (int(unix_time_millis(utcnow() + timedelta(milliseconds=x))), str(x))
         for x in range(20)
     ]
     events = [{"timestamp": x, "message": y} for x, y in data]
@@ -784,15 +781,17 @@ def test_get_log_events():
         logGroupName=log_group_name, logStreamName=log_stream_name, limit=10
     )
 
-    resp["events"].should.have.length_of(10)
+    assert len(resp["events"]) == 10
     for idx, (x, y) in enumerate(data[10:]):
-        resp["events"][idx]["timestamp"].should.equal(x)
-        resp["events"][idx]["message"].should.equal(y)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000019"
+        assert resp["events"][idx]["timestamp"] == x
+        assert resp["events"][idx]["message"] == y
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000019"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000010"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000010"
     )
 
     resp = client.get_log_events(
@@ -802,15 +801,17 @@ def test_get_log_events():
         limit=20,
     )
 
-    resp["events"].should.have.length_of(10)
+    assert len(resp["events"]) == 10
     for idx, (x, y) in enumerate(data[0:10]):
-        resp["events"][idx]["timestamp"].should.equal(x)
-        resp["events"][idx]["message"].should.equal(y)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000009"
+        assert resp["events"][idx]["timestamp"] == x
+        assert resp["events"][idx]["message"] == y
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000009"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000000"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000000"
     )
 
     resp = client.get_log_events(
@@ -820,12 +821,14 @@ def test_get_log_events():
         limit=10,
     )
 
-    resp["events"].should.have.length_of(0)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000000"
+    assert len(resp["events"]) == 0
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000000"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000000"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000000"
     )
 
     resp = client.get_log_events(
@@ -835,15 +838,17 @@ def test_get_log_events():
         limit=1,
     )
 
-    resp["events"].should.have.length_of(1)
+    assert len(resp["events"]) == 1
     x, y = data[1]
-    resp["events"][0]["timestamp"].should.equal(x)
-    resp["events"][0]["message"].should.equal(y)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000001"
+    assert resp["events"][0]["timestamp"] == x
+    assert resp["events"][0]["message"] == y
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000001"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000001"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000001"
     )
 
 
@@ -856,7 +861,7 @@ def test_get_log_events_with_start_from_head():
     client.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
 
     data = [
-        (int(unix_time_millis(datetime.utcnow() + timedelta(milliseconds=x))), str(x))
+        (int(unix_time_millis(utcnow() + timedelta(milliseconds=x))), str(x))
         for x in range(20)
     ]
     events = [{"timestamp": x, "message": y} for x, y in data]
@@ -872,15 +877,17 @@ def test_get_log_events_with_start_from_head():
         startFromHead=True,  # this parameter is only relevant without the usage of nextToken
     )
 
-    resp["events"].should.have.length_of(10)
+    assert len(resp["events"]) == 10
     for idx, (x, y) in enumerate(data[0:10]):
-        resp["events"][idx]["timestamp"].should.equal(x)
-        resp["events"][idx]["message"].should.equal(y)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000009"
+        assert resp["events"][idx]["timestamp"] == x
+        assert resp["events"][idx]["message"] == y
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000009"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000000"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000000"
     )
 
     resp = client.get_log_events(
@@ -890,15 +897,17 @@ def test_get_log_events_with_start_from_head():
         limit=20,
     )
 
-    resp["events"].should.have.length_of(10)
+    assert len(resp["events"]) == 10
     for idx, (x, y) in enumerate(data[10:]):
-        resp["events"][idx]["timestamp"].should.equal(x)
-        resp["events"][idx]["message"].should.equal(y)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000019"
+        assert resp["events"][idx]["timestamp"] == x
+        assert resp["events"][idx]["message"] == y
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000019"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000010"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000010"
     )
 
     resp = client.get_log_events(
@@ -908,12 +917,14 @@ def test_get_log_events_with_start_from_head():
         limit=10,
     )
 
-    resp["events"].should.have.length_of(0)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000019"
+    assert len(resp["events"]) == 0
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000019"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000019"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000019"
     )
 
     resp = client.get_log_events(
@@ -923,15 +934,17 @@ def test_get_log_events_with_start_from_head():
         limit=1,
     )
 
-    resp["events"].should.have.length_of(1)
+    assert len(resp["events"]) == 1
     x, y = data[18]
-    resp["events"][0]["timestamp"].should.equal(x)
-    resp["events"][0]["message"].should.equal(y)
-    resp["nextForwardToken"].should.equal(
-        "f/00000000000000000000000000000000000000000000000000000018"
+    assert resp["events"][0]["timestamp"] == x
+    assert resp["events"][0]["message"] == y
+    assert (
+        resp["nextForwardToken"]
+        == "f/00000000000000000000000000000000000000000000000000000018"
     )
-    resp["nextBackwardToken"].should.equal(
-        "b/00000000000000000000000000000000000000000000000000000018"
+    assert (
+        resp["nextBackwardToken"]
+        == "b/00000000000000000000000000000000000000000000000000000018"
     )
 
 
@@ -950,11 +963,11 @@ def test_get_log_events_errors():
             nextToken="n/00000000000000000000000000000000000000000000000000000000",
         )
     exc_value = exc.value
-    exc_value.operation_name.should.equal("GetLogEvents")
-    exc_value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    exc_value.response["Error"]["Code"].should.equal("InvalidParameterException")
-    exc_value.response["Error"]["Message"].should.contain(
-        "The specified nextToken is invalid."
+    assert exc_value.operation_name == "GetLogEvents"
+    assert exc_value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert exc_value.response["Error"]["Code"] == "InvalidParameterException"
+    assert (
+        "The specified nextToken is invalid." in exc_value.response["Error"]["Message"]
     )
 
     with pytest.raises(ClientError) as exc:
@@ -964,11 +977,11 @@ def test_get_log_events_errors():
             nextToken="not-existing-token",
         )
     exc_value = exc.value
-    exc_value.operation_name.should.equal("GetLogEvents")
-    exc_value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    exc_value.response["Error"]["Code"].should.equal("InvalidParameterException")
-    exc_value.response["Error"]["Message"].should.contain(
-        "The specified nextToken is invalid."
+    assert exc_value.operation_name == "GetLogEvents"
+    assert exc_value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert exc_value.response["Error"]["Code"] == "InvalidParameterException"
+    assert (
+        "The specified nextToken is invalid." in exc_value.response["Error"]["Message"]
     )
 
 
@@ -978,16 +991,16 @@ def test_list_tags_log_group():
     log_group_name = "dummy"
     tags = {"tag_key_1": "tag_value_1", "tag_key_2": "tag_value_2"}
 
-    response = conn.create_log_group(logGroupName=log_group_name)
+    conn.create_log_group(logGroupName=log_group_name)
     response = conn.list_tags_log_group(logGroupName=log_group_name)
     assert response["tags"] == {}
 
-    response = conn.delete_log_group(logGroupName=log_group_name)
-    response = conn.create_log_group(logGroupName=log_group_name, tags=tags)
+    conn.delete_log_group(logGroupName=log_group_name)
+    conn.create_log_group(logGroupName=log_group_name, tags=tags)
     response = conn.list_tags_log_group(logGroupName=log_group_name)
     assert response["tags"] == tags
 
-    response = conn.delete_log_group(logGroupName=log_group_name)
+    conn.delete_log_group(logGroupName=log_group_name)
 
 
 @mock_logs
@@ -995,47 +1008,43 @@ def test_tag_log_group():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
     tags = {"tag_key_1": "tag_value_1"}
-    response = conn.create_log_group(logGroupName=log_group_name)
+    conn.create_log_group(logGroupName=log_group_name)
 
-    response = conn.tag_log_group(logGroupName=log_group_name, tags=tags)
+    conn.tag_log_group(logGroupName=log_group_name, tags=tags)
     response = conn.list_tags_log_group(logGroupName=log_group_name)
     assert response["tags"] == tags
 
     tags_with_added_value = {"tag_key_1": "tag_value_1", "tag_key_2": "tag_value_2"}
-    response = conn.tag_log_group(
-        logGroupName=log_group_name, tags={"tag_key_2": "tag_value_2"}
-    )
+    conn.tag_log_group(logGroupName=log_group_name, tags={"tag_key_2": "tag_value_2"})
     response = conn.list_tags_log_group(logGroupName=log_group_name)
     assert response["tags"] == tags_with_added_value
 
     tags_with_updated_value = {"tag_key_1": "tag_value_XX", "tag_key_2": "tag_value_2"}
-    response = conn.tag_log_group(
-        logGroupName=log_group_name, tags={"tag_key_1": "tag_value_XX"}
-    )
+    conn.tag_log_group(logGroupName=log_group_name, tags={"tag_key_1": "tag_value_XX"})
     response = conn.list_tags_log_group(logGroupName=log_group_name)
     assert response["tags"] == tags_with_updated_value
 
-    response = conn.delete_log_group(logGroupName=log_group_name)
+    conn.delete_log_group(logGroupName=log_group_name)
 
 
 @mock_logs
 def test_untag_log_group():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
-    response = conn.create_log_group(logGroupName=log_group_name)
+    conn.create_log_group(logGroupName=log_group_name)
 
     tags = {"tag_key_1": "tag_value_1", "tag_key_2": "tag_value_2"}
-    response = conn.tag_log_group(logGroupName=log_group_name, tags=tags)
+    conn.tag_log_group(logGroupName=log_group_name, tags=tags)
     response = conn.list_tags_log_group(logGroupName=log_group_name)
     assert response["tags"] == tags
 
     tags_to_remove = ["tag_key_1"]
     remaining_tags = {"tag_key_2": "tag_value_2"}
-    response = conn.untag_log_group(logGroupName=log_group_name, tags=tags_to_remove)
+    conn.untag_log_group(logGroupName=log_group_name, tags=tags_to_remove)
     response = conn.list_tags_log_group(logGroupName=log_group_name)
     assert response["tags"] == remaining_tags
 
-    response = conn.delete_log_group(logGroupName=log_group_name)
+    conn.delete_log_group(logGroupName=log_group_name)
 
 
 @mock_logs
@@ -1049,7 +1058,7 @@ def test_describe_subscription_filters():
     response = client.describe_subscription_filters(logGroupName=log_group_name)
 
     # then
-    response["subscriptionFilters"].should.have.length_of(0)
+    assert len(response["subscriptionFilters"]) == 0
 
 
 @mock_logs
@@ -1063,11 +1072,12 @@ def test_describe_subscription_filters_errors():
 
     # then
     exc_value = exc.value
-    exc_value.operation_name.should.equal("DescribeSubscriptionFilters")
-    exc_value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    exc_value.response["Error"]["Code"].should.contain("ResourceNotFoundException")
-    exc_value.response["Error"]["Message"].should.equal(
-        "The specified log group does not exist"
+    assert exc_value.operation_name == "DescribeSubscriptionFilters"
+    assert exc_value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "ResourceNotFoundException" in exc_value.response["Error"]["Code"]
+    assert (
+        exc_value.response["Error"]["Message"]
+        == "The specified log group does not exist."
     )
 
 
@@ -1086,25 +1096,25 @@ def test_describe_log_groups_paging():
         client.create_log_group(logGroupName=name)
 
     resp = client.describe_log_groups()
-    resp["logGroups"].should.have.length_of(4)
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logGroups"]) == 4
+    assert "nextToken" not in resp
 
     resp = client.describe_log_groups(limit=2)
-    resp["logGroups"].should.have.length_of(2)
-    resp.should.have.key("nextToken")
+    assert len(resp["logGroups"]) == 2
+    assert "nextToken" in resp
 
     resp = client.describe_log_groups(nextToken=resp["nextToken"], limit=1)
-    resp["logGroups"].should.have.length_of(1)
-    resp.should.have.key("nextToken")
+    assert len(resp["logGroups"]) == 1
+    assert "nextToken" in resp
 
     resp = client.describe_log_groups(nextToken=resp["nextToken"])
-    resp["logGroups"].should.have.length_of(1)
-    resp["logGroups"][0]["logGroupName"].should.equal("/aws/lambda/lowercase-dev")
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logGroups"]) == 1
+    assert resp["logGroups"][0]["logGroupName"] == "/aws/lambda/lowercase-dev"
+    assert "nextToken" not in resp
 
     resp = client.describe_log_groups(nextToken="invalid-token")
-    resp["logGroups"].should.have.length_of(0)
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logGroups"]) == 0
+    assert "nextToken" not in resp
 
 
 @mock_logs
@@ -1120,36 +1130,43 @@ def test_describe_log_streams_simple_paging():
 
     # Get stream 1-10
     resp = client.describe_log_streams(logGroupName=group_name)
-    resp["logStreams"].should.have.length_of(10)
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logStreams"]) == 10
+    assert "nextToken" not in resp
 
     # Get stream 1-4
     resp = client.describe_log_streams(logGroupName=group_name, limit=4)
-    resp["logStreams"].should.have.length_of(4)
-    [stream["logStreamName"] for stream in resp["logStreams"]].should.equal(
-        ["stream0", "stream1", "stream2", "stream3"]
-    )
-    resp.should.have.key("nextToken")
+    assert len(resp["logStreams"]) == 4
+    assert [stream["logStreamName"] for stream in resp["logStreams"]] == [
+        "stream0",
+        "stream1",
+        "stream2",
+        "stream3",
+    ]
+    assert "nextToken" in resp
 
     # Get stream 4-8
     resp = client.describe_log_streams(
         logGroupName=group_name, limit=4, nextToken=str(resp["nextToken"])
     )
-    resp["logStreams"].should.have.length_of(4)
-    [stream["logStreamName"] for stream in resp["logStreams"]].should.equal(
-        ["stream4", "stream5", "stream6", "stream7"]
-    )
-    resp.should.have.key("nextToken")
+    assert len(resp["logStreams"]) == 4
+    assert [stream["logStreamName"] for stream in resp["logStreams"]] == [
+        "stream4",
+        "stream5",
+        "stream6",
+        "stream7",
+    ]
+    assert "nextToken" in resp
 
     # Get stream 8-10
     resp = client.describe_log_streams(
         logGroupName=group_name, limit=4, nextToken=str(resp["nextToken"])
     )
-    resp["logStreams"].should.have.length_of(2)
-    [stream["logStreamName"] for stream in resp["logStreams"]].should.equal(
-        ["stream8", "stream9"]
-    )
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logStreams"]) == 2
+    assert [stream["logStreamName"] for stream in resp["logStreams"]] == [
+        "stream8",
+        "stream9",
+    ]
+    assert "nextToken" not in resp
 
 
 @mock_logs
@@ -1169,76 +1186,46 @@ def test_describe_log_streams_paging():
         client.create_log_stream(logGroupName=log_group_name, logStreamName=name)
 
     resp = client.describe_log_streams(logGroupName=log_group_name)
-    resp["logStreams"].should.have.length_of(4)
-    resp["logStreams"][0]["arn"].should.contain(log_group_name)
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logStreams"]) == 4
+    assert log_group_name in resp["logStreams"][0]["arn"]
+    assert "nextToken" not in resp
 
     resp = client.describe_log_streams(logGroupName=log_group_name, limit=2)
-    resp["logStreams"].should.have.length_of(2)
-    resp["logStreams"][0]["arn"].should.contain(log_group_name)
-    resp["nextToken"].should.equal(
-        f"{log_group_name}@{resp['logStreams'][1]['logStreamName']}"
+    assert len(resp["logStreams"]) == 2
+    assert log_group_name in resp["logStreams"][0]["arn"]
+    assert (
+        resp["nextToken"]
+        == f"{log_group_name}@{resp['logStreams'][1]['logStreamName']}"
     )
 
     resp = client.describe_log_streams(
         logGroupName=log_group_name, nextToken=resp["nextToken"], limit=1
     )
-    resp["logStreams"].should.have.length_of(1)
-    resp["logStreams"][0]["arn"].should.contain(log_group_name)
-    resp["nextToken"].should.equal(
-        f"{log_group_name}@{resp['logStreams'][0]['logStreamName']}"
+    assert len(resp["logStreams"]) == 1
+    assert log_group_name in resp["logStreams"][0]["arn"]
+    assert (
+        resp["nextToken"]
+        == f"{log_group_name}@{resp['logStreams'][0]['logStreamName']}"
     )
 
     resp = client.describe_log_streams(
         logGroupName=log_group_name, nextToken=resp["nextToken"]
     )
-    resp["logStreams"].should.have.length_of(1)
-    resp["logStreams"][0]["arn"].should.contain(log_group_name)
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logStreams"]) == 1
+    assert log_group_name in resp["logStreams"][0]["arn"]
+    assert "nextToken" not in resp
 
     resp = client.describe_log_streams(
         logGroupName=log_group_name, nextToken="invalid-token"
     )
-    resp["logStreams"].should.have.length_of(0)
-    resp.should_not.have.key("nextToken")
+    assert len(resp["logStreams"]) == 0
+    assert "nextToken" not in resp
 
     resp = client.describe_log_streams(
         logGroupName=log_group_name, nextToken="invalid@token"
     )
-    resp["logStreams"].should.have.length_of(0)
-    resp.should_not.have.key("nextToken")
-
-
-@mock_logs
-def test_start_query():
-    client = boto3.client("logs", "us-east-1")
-
-    log_group_name = "/aws/codebuild/lowercase-dev"
-    client.create_log_group(logGroupName=log_group_name)
-
-    response = client.start_query(
-        logGroupName=log_group_name,
-        startTime=int(time.time()),
-        endTime=int(time.time()) + 300,
-        queryString="test",
-    )
-
-    assert "queryId" in response
-
-    with pytest.raises(ClientError) as exc:
-        client.start_query(
-            logGroupName="/aws/codebuild/lowercase-dev-invalid",
-            startTime=int(time.time()),
-            endTime=int(time.time()) + 300,
-            queryString="test",
-        )
-
-    # then
-    exc_value = exc.value
-    exc_value.response["Error"]["Code"].should.contain("ResourceNotFoundException")
-    exc_value.response["Error"]["Message"].should.equal(
-        "The specified log group does not exist"
-    )
+    assert len(resp["logStreams"]) == 0
+    assert "nextToken" not in resp
 
 
 @pytest.mark.parametrize("nr_of_events", [10001, 1000000])
@@ -1257,12 +1244,13 @@ def test_get_too_many_log_events(nr_of_events):
             limit=nr_of_events,
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.contain("1 validation error detected")
-    err["Message"].should.contain(
+    assert err["Code"] == "InvalidParameterException"
+    assert "1 validation error detected" in err["Message"]
+    assert (
         f"Value '{nr_of_events}' at 'limit' failed to satisfy constraint"
+        in err["Message"]
     )
-    err["Message"].should.contain("Member must have value less than or equal to 10000")
+    assert "Member must have value less than or equal to 10000" in err["Message"]
 
 
 @pytest.mark.parametrize("nr_of_events", [10001, 1000000])
@@ -1281,12 +1269,13 @@ def test_filter_too_many_log_events(nr_of_events):
             limit=nr_of_events,
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.contain("1 validation error detected")
-    err["Message"].should.contain(
+    assert err["Code"] == "InvalidParameterException"
+    assert "1 validation error detected" in err["Message"]
+    assert (
         f"Value '{nr_of_events}' at 'limit' failed to satisfy constraint"
+        in err["Message"]
     )
-    err["Message"].should.contain("Member must have value less than or equal to 10000")
+    assert "Member must have value less than or equal to 10000" in err["Message"]
 
 
 @pytest.mark.parametrize("nr_of_groups", [51, 100])
@@ -1296,12 +1285,13 @@ def test_describe_too_many_log_groups(nr_of_groups):
     with pytest.raises(ClientError) as ex:
         client.describe_log_groups(limit=nr_of_groups)
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.contain("1 validation error detected")
-    err["Message"].should.contain(
+    assert err["Code"] == "InvalidParameterException"
+    assert "1 validation error detected" in err["Message"]
+    assert (
         f"Value '{nr_of_groups}' at 'limit' failed to satisfy constraint"
+        in err["Message"]
     )
-    err["Message"].should.contain("Member must have value less than or equal to 50")
+    assert "Member must have value less than or equal to 50" in err["Message"]
 
 
 @pytest.mark.parametrize("nr_of_streams", [51, 100])
@@ -1313,12 +1303,13 @@ def test_describe_too_many_log_streams(nr_of_streams):
     with pytest.raises(ClientError) as ex:
         client.describe_log_streams(logGroupName=log_group_name, limit=nr_of_streams)
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.contain("1 validation error detected")
-    err["Message"].should.contain(
+    assert err["Code"] == "InvalidParameterException"
+    assert "1 validation error detected" in err["Message"]
+    assert (
         f"Value '{nr_of_streams}' at 'limit' failed to satisfy constraint"
+        in err["Message"]
     )
-    err["Message"].should.contain("Member must have value less than or equal to 50")
+    assert "Member must have value less than or equal to 50" in err["Message"]
 
 
 @pytest.mark.parametrize("length", [513, 1000])
@@ -1329,12 +1320,13 @@ def test_create_log_group_invalid_name_length(length):
     with pytest.raises(ClientError) as ex:
         client.create_log_group(logGroupName=log_group_name)
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.contain("1 validation error detected")
-    err["Message"].should.contain(
+    assert err["Code"] == "InvalidParameterException"
+    assert "1 validation error detected" in err["Message"]
+    assert (
         f"Value '{log_group_name}' at 'logGroupName' failed to satisfy constraint"
+        in err["Message"]
     )
-    err["Message"].should.contain("Member must have length less than or equal to 512")
+    assert "Member must have length less than or equal to 512" in err["Message"]
 
 
 @pytest.mark.parametrize("invalid_orderby", ["", "sth", "LogStreamname"])
@@ -1348,13 +1340,15 @@ def test_describe_log_streams_invalid_order_by(invalid_orderby):
             logGroupName=log_group_name, orderBy=invalid_orderby
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.contain("1 validation error detected")
-    err["Message"].should.contain(
+    assert err["Code"] == "InvalidParameterException"
+    assert "1 validation error detected" in err["Message"]
+    assert (
         f"Value '{invalid_orderby}' at 'orderBy' failed to satisfy constraint"
+        in err["Message"]
     )
-    err["Message"].should.contain(
+    assert (
         "Member must satisfy enum value set: [LogStreamName, LastEventTime]"
+        in err["Message"]
     )
 
 
@@ -1373,62 +1367,5 @@ def test_describe_log_streams_no_prefix():
             logStreamNamePrefix="sth",
         )
     err = ex.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterException")
-    err["Message"].should.equal(
-        "Cannot order by LastEventTime with a logStreamNamePrefix."
-    )
-
-
-@mock_s3
-@mock_logs
-def test_create_export_task_happy_path():
-    log_group_name = "/aws/codebuild/blah1"
-    destination = "mybucket"
-    fromTime = 1611316574
-    to = 1642852574
-    logs = boto3.client("logs", region_name="ap-southeast-1")
-    s3 = boto3.client("s3")
-    logs.create_log_group(logGroupName=log_group_name)
-    s3.create_bucket(Bucket=destination)
-    resp = logs.create_export_task(
-        logGroupName=log_group_name, fromTime=fromTime, to=to, destination=destination
-    )
-    # taskId resembles a valid UUID (i.e. a string of 32 hexadecimal digits)
-    assert UUID(resp["taskId"])
-    assert resp["ResponseMetadata"]["HTTPStatusCode"] == 200
-
-
-@mock_logs
-def test_create_export_task_raises_ClientError_when_bucket_not_found():
-    log_group_name = "/aws/codebuild/blah1"
-    destination = "368a7022dea3dd621"
-    fromTime = 1611316574
-    to = 1642852574
-    logs = boto3.client("logs", region_name="ap-southeast-1")
-    logs.create_log_group(logGroupName=log_group_name)
-    with pytest.raises(ClientError):
-        logs.create_export_task(
-            logGroupName=log_group_name,
-            fromTime=fromTime,
-            to=to,
-            destination=destination,
-        )
-
-
-@mock_s3
-@mock_logs
-def test_create_export_raises_ResourceNotFoundException_log_group_not_found():
-    log_group_name = "/aws/codebuild/blah1"
-    destination = "mybucket"
-    fromTime = 1611316574
-    to = 1642852574
-    s3 = boto3.client("s3")
-    s3.create_bucket(Bucket=destination)
-    logs = boto3.client("logs", region_name="ap-southeast-1")
-    with pytest.raises(logs.exceptions.ResourceNotFoundException):
-        logs.create_export_task(
-            logGroupName=log_group_name,
-            fromTime=fromTime,
-            to=to,
-            destination=destination,
-        )
+    assert err["Code"] == "InvalidParameterException"
+    assert err["Message"] == "Cannot order by LastEventTime with a logStreamNamePrefix."
