@@ -1,4 +1,4 @@
-import sure  # noqa # pylint: disable=unused-import
+import json
 
 import moto.server as server
 from moto import mock_mediastoredata
@@ -12,5 +12,5 @@ Test the different server responses
 def test_mediastore_lists_containers():
     backend = server.create_backend_app("mediastore-data")
     test_client = backend.test_client()
-    response = test_client.get("/").data
-    response.should.contain(b'"Items": []')
+    body = test_client.get("/").data.decode("utf-8")
+    assert json.loads(body) == {"Items": []}
