@@ -1,18 +1,18 @@
-from tests.test_batch import _get_clients, _setup
-from tests.test_batch.test_batch_jobs import prepare_job, _wait_for_job_status
-
-import sure  # noqa # pylint: disable=unused-import
-
-from moto import mock_batch, mock_iam, mock_ec2, mock_ecs, mock_logs, settings
-from moto.moto_api import state_manager
 from unittest import SkipTest
 
+from moto import mock_batch, mock_ec2, mock_ecs, mock_iam, mock_logs, settings
+from moto.moto_api import state_manager
+from tests.markers import requires_docker
+from tests.test_batch import _get_clients, _setup
+from tests.test_batch.test_batch_jobs import _wait_for_job_status, prepare_job
+
 
 @mock_logs
 @mock_ec2
 @mock_ecs
 @mock_iam
 @mock_batch
+@requires_docker
 def test_cancel_pending_job():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Can't use state_manager in ServerMode directly")
@@ -42,10 +42,10 @@ def test_cancel_pending_job():
     _wait_for_job_status(batch_client, job_id, "FAILED", seconds_to_wait=20)
 
     resp = batch_client.describe_jobs(jobs=[job_id])
-    resp["jobs"][0]["jobName"].should.equal("test_job_name")
-    resp["jobs"][0]["statusReason"].should.equal("test_cancel")
+    assert resp["jobs"][0]["jobName"] == "test_job_name"
+    assert resp["jobs"][0]["statusReason"] == "test_cancel"
 
 
 @mock_batch
 def test_state_manager_should_return_registered_model():
-    state_manager.get_registered_models().should.contain("batch::job")
+    assert "batch::job" in state_manager.get_registered_models()
