@@ -1,12 +1,12 @@
 import boto3
-import sure  # noqa # pylint: disable=unused-import
+
 from moto import mock_neptune
 
 
 @mock_neptune
 def test_describe():
     client = boto3.client("neptune", "us-east-2")
-    client.describe_global_clusters()["GlobalClusters"].should.equal([])
+    assert client.describe_global_clusters()["GlobalClusters"] == []
 
 
 @mock_neptune
@@ -15,19 +15,19 @@ def test_create_global_cluster():
     resp = client.create_global_cluster(
         GlobalClusterIdentifier="g-id", Engine="neptune"
     )["GlobalCluster"]
-    resp.should.have.key("GlobalClusterIdentifier").equals("g-id")
-    resp.should.have.key("GlobalClusterResourceId")
-    resp.should.have.key("GlobalClusterArn")
-    resp.should.have.key("Engine").equals("neptune")
-    resp.should.have.key("EngineVersion").equals("1.2.0.0")
-    resp.should.have.key("StorageEncrypted").equals(False)
-    resp.should.have.key("DeletionProtection").equals(False)
+    assert resp["GlobalClusterIdentifier"] == "g-id"
+    assert "GlobalClusterResourceId" in resp
+    assert "GlobalClusterArn" in resp
+    assert resp["Engine"] == "neptune"
+    assert resp["EngineVersion"] == "1.2.0.0"
+    assert resp["StorageEncrypted"] is False
+    assert resp["DeletionProtection"] is False
 
-    client.describe_global_clusters()["GlobalClusters"].should.have.length_of(1)
+    assert len(client.describe_global_clusters()["GlobalClusters"]) == 1
 
     # As a global cluster, verify it can be retrieved everywhere
     europe_client = boto3.client("neptune", "eu-north-1")
-    europe_client.describe_global_clusters()["GlobalClusters"].should.have.length_of(1)
+    assert len(europe_client.describe_global_clusters()["GlobalClusters"]) == 1
 
 
 @mock_neptune
@@ -40,10 +40,10 @@ def test_create_global_cluster_with_additional_params():
         DeletionProtection=True,
         StorageEncrypted=True,
     )["GlobalCluster"]
-    resp.should.have.key("Engine").equals("neptune")
-    resp.should.have.key("EngineVersion").equals("1.0")
-    resp.should.have.key("StorageEncrypted").equals(True)
-    resp.should.have.key("DeletionProtection").equals(True)
+    assert resp["Engine"] == "neptune"
+    assert resp["EngineVersion"] == "1.0"
+    assert resp["StorageEncrypted"] is True
+    assert resp["DeletionProtection"] is True
 
 
 @mock_neptune
@@ -53,4 +53,4 @@ def test_delete_global_cluster():
 
     client.delete_global_cluster(GlobalClusterIdentifier="g-id2")
 
-    client.describe_global_clusters()["GlobalClusters"].should.equal([])
+    assert client.describe_global_clusters()["GlobalClusters"] == []
