@@ -1,8 +1,8 @@
 import boto3
-import sure  # noqa # pylint: disable=unused-import
+import pytest
+from botocore.exceptions import ClientError
 
-from moto import mock_opsworks
-from moto import mock_ec2
+from moto import mock_ec2, mock_opsworks
 from tests import EXAMPLE_AMI_ID
 
 
@@ -41,22 +41,36 @@ def test_create_instance():
         StackId=stack_id, LayerIds=[layer_id], InstanceType="t2.micro"
     )
 
-    response.should.contain("InstanceId")
+    assert "InstanceId" in response
 
-    client.create_instance.when.called_with(
-        StackId="nothere", LayerIds=[layer_id], InstanceType="t2.micro"
-    ).should.throw(Exception, "Unable to find stack with ID nothere")
+    with pytest.raises(ClientError) as exc:
+        client.create_instance(
+            StackId="nothere", LayerIds=[layer_id], InstanceType="t2.micro"
+        )
+    assert exc.value.response["Error"]["Message"] == (
+        "Unable to find stack with ID nothere"
+    )
+
+    with pytest.raises(ClientError) as exc:
+        client.create_instance(
+            StackId=stack_id, LayerIds=["nothere"], InstanceType="t2.micro"
+        )
+    assert exc.value.response["Error"]["Message"] == "nothere"
 
-    client.create_instance.when.called_with(
-        StackId=stack_id, LayerIds=["nothere"], InstanceType="t2.micro"
-    ).should.throw(Exception, "nothere")
     # ClientError
-    client.create_instance.when.called_with(
-        StackId=stack_id, LayerIds=[second_layer_id], InstanceType="t2.micro"
-    ).should.throw(Exception, "Please only provide layer IDs from the same stack")
+    with pytest.raises(ClientError) as exc:
+        client.create_instance(
+            StackId=stack_id, LayerIds=[second_layer_id], InstanceType="t2.micro"
+        )
+    assert exc.value.response["Error"]["Message"] == (
+        "Please only provide layer IDs from the same stack"
+    )
+
     # ClientError
-    client.start_instance.when.called_with(InstanceId="nothere").should.throw(
-        Exception, "Unable to find instance with ID nothere"
+    with pytest.raises(ClientError) as exc:
+        client.start_instance(InstanceId="nothere")
+    assert exc.value.response["Error"]["Message"] == (
+        "Unable to find instance with ID nothere"
     )
 
 
@@ -111,65 +125,65 @@ def test_describe_instances():
 
     # instances in Stack 1
     response = client.describe_instances(StackId=S1)["Instances"]
-    response.should.have.length_of(2)
-    S1L1_i1.should.be.within([i["InstanceId"] for i in response])
-    S1L1_i2.should.be.within([i["InstanceId"] for i in response])
+    assert len(response) == 2
+    assert S1L1_i1 in [i["InstanceId"] for i in response]
+    assert S1L1_i2 in [i["InstanceId"] for i in response]
 
     response2 = client.describe_instances(InstanceIds=[S1L1_i1, S1L1_i2])["Instances"]
-    sorted(response2, key=lambda d: d["InstanceId"]).should.equal(
+    assert sorted(response2, key=lambda d: d["InstanceId"]) == (
         sorted(response, key=lambda d: d["InstanceId"])
     )
 
     response3 = client.describe_instances(LayerId=S1L1)["Instances"]
-    sorted(response3, key=lambda d: d["InstanceId"]).should.equal(
+    assert sorted(response3, key=lambda d: d["InstanceId"]) == (
         sorted(response, key=lambda d: d["InstanceId"])
     )
 
     response = client.describe_instances(StackId=S1)["Instances"]
-    response.should.have.length_of(2)
-    S1L1_i1.should.be.within([i["InstanceId"] for i in response])
-    S1L1_i2.should.be.within([i["InstanceId"] for i in response])
+    assert len(response) == 2
+    assert S1L1_i1 in [i["InstanceId"] for i in response]
+    assert S1L1_i2 in [i["InstanceId"] for i in response]
 
     # instances in Stack 2
     response = client.describe_instances(StackId=S2)["Instances"]
-    response.should.have.length_of(3)
-    S2L1_i1.should.be.within([i["InstanceId"] for i in response])
-    S2L2_i1.should.be.within([i["InstanceId"] for i in response])
-    S2L2_i2.should.be.within([i["InstanceId"] for i in response])
+    assert len(response) == 3
+    assert S2L1_i1 in [i["InstanceId"] for i in response]
+    assert S2L2_i1 in [i["InstanceId"] for i in response]
+    assert S2L2_i2 in [i["InstanceId"] for i in response]
 
     response = client.describe_instances(LayerId=S2L1)["Instances"]
-    response.should.have.length_of(1)
-    S2L1_i1.should.be.within([i["InstanceId"] for i in response])
+    assert len(response) == 1
+    assert S2L1_i1 in [i["InstanceId"] for i in response]
 
     response = client.describe_instances(LayerId=S2L2)["Instances"]
-    response.should.have.length_of(2)
-    S2L1_i1.should_not.be.within([i["InstanceId"] for i in response])
+    assert len(response) == 2
+    assert S2L1_i1 not in [i["InstanceId"] for i in response]
 
     # ClientError
-    client.describe_instances.when.called_with(StackId=S1, LayerId=S1L1).should.throw(
-        Exception, "Please provide either one or more"
-    )
+    with pytest.raises(ClientError) as exc:
+        client.describe_instances(StackId=S1, LayerId=S1L1)
+    assert "Please provide either one or more" in exc.value.response["Error"]["Message"]
+
     # ClientError
-    client.describe_instances.when.called_with(StackId="nothere").should.throw(
-        Exception, "nothere"
-    )
+    with pytest.raises(ClientError) as exc:
+        client.describe_instances(StackId="nothere")
+    assert "nothere" in exc.value.response["Error"]["Message"]
+
     # ClientError
-    client.describe_instances.when.called_with(LayerId="nothere").should.throw(
-        Exception, "nothere"
-    )
+    with pytest.raises(ClientError) as exc:
+        client.describe_instances(LayerId="nothere")
+    assert "nothere" in exc.value.response["Error"]["Message"]
+
     # ClientError
-    client.describe_instances.when.called_with(InstanceIds=["nothere"]).should.throw(
-        Exception, "nothere"
-    )
+    with pytest.raises(ClientError) as exc:
+        client.describe_instances(InstanceIds=["nothere"])
+    assert exc.value.response["Error"]["Message"] == "nothere"
 
 
 @mock_opsworks
 @mock_ec2
 def test_ec2_integration():
-    """
-    instances created via OpsWorks should be discoverable via ec2
-    """
-
+    """Verify instances created via OpsWorks are discoverable via ec2."""
     opsworks = boto3.client("opsworks", region_name="us-east-1")
     stack_id = opsworks.create_stack(
         Name="S1",
@@ -194,20 +208,20 @@ def test_ec2_integration():
 
     # Before starting the instance, it shouldn't be discoverable via ec2
     reservations = ec2.describe_instances()["Reservations"]
-    assert reservations.should.be.empty
+    assert not reservations
 
     # Before starting the instance, its status should be "stopped"
     opsworks_instance = opsworks.describe_instances(StackId=stack_id)["Instances"][0]
-    opsworks_instance["Status"].should.equal("stopped")
+    assert opsworks_instance["Status"] == "stopped"
 
     # After starting the instance, it should be discoverable via ec2
     opsworks.start_instance(InstanceId=instance_id)
     reservations = ec2.describe_instances()["Reservations"]
-    reservations[0]["Instances"].should.have.length_of(1)
+    assert len(reservations[0]["Instances"]) == 1
     instance = reservations[0]["Instances"][0]
     opsworks_instance = opsworks.describe_instances(StackId=stack_id)["Instances"][0]
 
-    instance["InstanceId"].should.equal(opsworks_instance["Ec2InstanceId"])
-    instance["PrivateIpAddress"].should.equal(opsworks_instance["PrivateIp"])
+    assert instance["InstanceId"] == opsworks_instance["Ec2InstanceId"]
+    assert instance["PrivateIpAddress"] == opsworks_instance["PrivateIp"]
     # After starting the instance, its status should be "online"
-    opsworks_instance["Status"].should.equal("online")
+    assert opsworks_instance["Status"] == "online"
