@@ -1,12 +1,7 @@
-import sure  # noqa # pylint: disable=unused-import
-
+"""Test the different server responses."""
 import moto.server as server
 from moto import mock_polly
 
-"""
-Test the different server responses
-"""
-
 
 @mock_polly
 def test_polly_list():
@@ -14,4 +9,4 @@ def test_polly_list():
     test_client = backend.test_client()
 
     res = test_client.get("/v1/lexicons")
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
