@@ -1,11 +1,6 @@
-import sure  # noqa # pylint: disable=unused-import
-
+"""Test the different server responses."""
 import moto.server as server
 
-"""
-Test the different server responses
-"""
-
 
 def test_resourcegroupstaggingapi_list():
     backend = server.create_backend_app("resourcegroupstaggingapi")
