@@ -1,12 +1,14 @@
-import boto3
 import json
-import sure  # noqa # pylint: disable=unused-import
-
 from copy import deepcopy
+
+import boto3
+
 from moto import mock_cloudformation, mock_ec2, mock_route53
-from tests.test_cloudformation.fixtures import route53_ec2_instance_with_public_ip
-from tests.test_cloudformation.fixtures import route53_health_check
-from tests.test_cloudformation.fixtures import route53_roundrobin
+from tests.test_cloudformation.fixtures import (
+    route53_ec2_instance_with_public_ip,
+    route53_health_check,
+    route53_roundrobin,
+)
 
 template_hosted_zone = {
     "AWSTemplateFormatVersion": "2010-09-09",
@@ -55,8 +57,8 @@ def test_create_stack_hosted_zone_by_id():
 
     # then a hosted zone should exist
     zone = conn.list_hosted_zones()["HostedZones"][0]
-    zone.should.have.key("Name").equal("foo.bar.baz")
-    zone.should.have.key("ResourceRecordSetCount").equal(1)
+    assert zone["Name"] == "foo.bar.baz"
+    assert zone["ResourceRecordSetCount"] == 2
 
     # when adding a record set to this zone
     cf_conn.create_stack(
@@ -67,9 +69,9 @@ def test_create_stack_hosted_zone_by_id():
 
     # then the hosted zone should have a record
     updated_zone = conn.list_hosted_zones()["HostedZones"][0]
-    updated_zone.should.have.key("Id").equal(zone["Id"])
-    updated_zone.should.have.key("Name").equal("foo.bar.baz")
-    updated_zone.should.have.key("ResourceRecordSetCount").equal(2)
+    assert updated_zone["Id"] == zone["Id"]
+    assert updated_zone["Name"] == "foo.bar.baz"
+    assert updated_zone["ResourceRecordSetCount"] == 3
 
 
 @mock_cloudformation
@@ -82,35 +84,33 @@ def test_route53_roundrobin():
     cf.create_stack(StackName="test_stack", TemplateBody=template_json)
 
     zones = route53.list_hosted_zones()["HostedZones"]
-    zones.should.have.length_of(1)
+    assert len(zones) == 1
     zone_id = zones[0]["Id"].split("/")[2]
 
     rrsets = route53.list_resource_record_sets(HostedZoneId=zone_id)[
         "ResourceRecordSets"
     ]
-    rrsets.should.have.length_of(3)
-    record_set1 = rrsets[1]
-    record_set1["Name"].should.equal("test_stack.us-west-1.my_zone.")
-    record_set1["SetIdentifier"].should.equal("test_stack AWS")
-    record_set1["Type"].should.equal("CNAME")
-    record_set1["TTL"].should.equal(900)
-    record_set1["Weight"].should.equal(3)
-    record_set1["ResourceRecords"][0]["Value"].should.equal("aws.amazon.com")
+    assert len(rrsets) == 4
+    record_set1 = rrsets[2]
+    assert record_set1["Name"] == "test_stack.us-west-1.my_zone."
+    assert record_set1["SetIdentifier"] == "test_stack AWS"
+    assert record_set1["Type"] == "CNAME"
+    assert record_set1["TTL"] == 900
+    assert record_set1["Weight"] == 3
+    assert record_set1["ResourceRecords"][0]["Value"] == "aws.amazon.com"
 
-    record_set2 = rrsets[2]
-    record_set2["Name"].should.equal("test_stack.us-west-1.my_zone.")
-    record_set2["SetIdentifier"].should.equal("test_stack Amazon")
-    record_set2["Type"].should.equal("CNAME")
-    record_set2["TTL"].should.equal(900)
-    record_set2["Weight"].should.equal(1)
-    record_set2["ResourceRecords"][0]["Value"].should.equal("www.amazon.com")
+    record_set2 = rrsets[3]
+    assert record_set2["Name"] == "test_stack.us-west-1.my_zone."
+    assert record_set2["SetIdentifier"] == "test_stack Amazon"
+    assert record_set2["Type"] == "CNAME"
+    assert record_set2["TTL"] == 900
+    assert record_set2["Weight"] == 1
+    assert record_set2["ResourceRecords"][0]["Value"] == "www.amazon.com"
 
     stack = cf.describe_stacks(StackName="test_stack")["Stacks"][0]
     output = stack["Outputs"][0]
-    output["OutputKey"].should.equal("DomainName")
-    output["OutputValue"].should.equal(
-        "arn:aws:route53:::hostedzone/{0}".format(zone_id)
-    )
+    assert output["OutputKey"] == "DomainName"
+    assert output["OutputValue"] == f"arn:aws:route53:::hostedzone/{zone_id}"
 
 
 @mock_cloudformation
@@ -129,21 +129,21 @@ def test_route53_ec2_instance_with_public_ip():
     ]
 
     zones = route53.list_hosted_zones()["HostedZones"]
-    zones.should.have.length_of(1)
+    assert len(zones) == 1
     zone_id = zones[0]["Id"].split("/")[2]
 
     rrsets = route53.list_resource_record_sets(HostedZoneId=zone_id)[
         "ResourceRecordSets"
     ]
-    rrsets.should.have.length_of(2)
+    assert len(rrsets) == 3
 
-    record_set = rrsets[1]
-    record_set["Name"].should.equal("{0}.us-west-1.my_zone.".format(instance_id))
-    record_set.shouldnt.have.key("SetIdentifier")
-    record_set["Type"].should.equal("A")
-    record_set["TTL"].should.equal(900)
-    record_set.shouldnt.have.key("Weight")
-    record_set["ResourceRecords"][0]["Value"].should.equal("10.0.0.25")
+    record_set = rrsets[2]
+    assert record_set["Name"] == f"{instance_id}.us-west-1.my_zone."
+    assert record_set["Type"] == "A"
+    assert record_set["TTL"] == 900
+    assert record_set["ResourceRecords"][0]["Value"] == "10.0.0.25"
+    assert "SetIdentifier" not in record_set
+    assert "Weight" not in record_set
 
 
 @mock_cloudformation
@@ -156,27 +156,27 @@ def test_route53_associate_health_check():
     cf.create_stack(StackName="test_stack", TemplateBody=template_json)
 
     checks = route53.list_health_checks()["HealthChecks"]
-    checks.should.have.length_of(1)
+    assert len(checks) == 1
     check = checks[0]
     health_check_id = check["Id"]
     config = check["HealthCheckConfig"]
-    config["FailureThreshold"].should.equal(3)
-    config["IPAddress"].should.equal("10.0.0.4")
-    config["Port"].should.equal(80)
-    config["RequestInterval"].should.equal(10)
-    config["ResourcePath"].should.equal("/")
-    config["Type"].should.equal("HTTP")
+    assert config["FailureThreshold"] == 3
+    assert config["IPAddress"] == "10.0.0.4"
+    assert config["Port"] == 80
+    assert config["RequestInterval"] == 10
+    assert config["ResourcePath"] == "/"
+    assert config["Type"] == "HTTP"
 
     zones = route53.list_hosted_zones()["HostedZones"]
-    zones.should.have.length_of(1)
+    assert len(zones) == 1
     zone_id = zones[0]["Id"].split("/")[2]
 
     rrsets = route53.list_resource_record_sets(HostedZoneId=zone_id)[
         "ResourceRecordSets"
     ]
-    rrsets.should.have.length_of(2)
+    assert len(rrsets) == 3
     record_set = rrsets[0]
-    record_set["HealthCheckId"].should.equal(health_check_id)
+    assert record_set["HealthCheckId"] == health_check_id
 
 
 @mock_cloudformation
@@ -189,7 +189,7 @@ def test_route53_with_update():
     cf.create_stack(StackName="test_stack", TemplateBody=template_json)
 
     zones = route53.list_hosted_zones()["HostedZones"]
-    zones.should.have.length_of(1)
+    assert len(zones) == 1
     zone_id = zones[0]["Id"]
     zone_id = zone_id.split("/")
     zone_id = zone_id[2]
@@ -197,10 +197,10 @@ def test_route53_with_update():
     rrsets = route53.list_resource_record_sets(HostedZoneId=zone_id)[
         "ResourceRecordSets"
     ]
-    rrsets.should.have.length_of(2)
+    assert len(rrsets) == 3
 
     record_set = rrsets[0]
-    record_set["ResourceRecords"][0]["Value"].should.equal("my.example.com")
+    assert record_set["ResourceRecords"][0]["Value"] == "my.example.com"
 
     # # given
     template = deepcopy(route53_health_check.template)
@@ -214,22 +214,21 @@ def test_route53_with_update():
 
     # # then
     zones = route53.list_hosted_zones()["HostedZones"]
-    zones.should.have.length_of(1)
+    assert len(zones) == 1
     zone_id = zones[0]["Id"].split("/")[2]
 
     rrsets = route53.list_resource_record_sets(HostedZoneId=zone_id)[
         "ResourceRecordSets"
     ]
-    rrsets.should.have.length_of(2)
+    assert len(rrsets) == 3
 
     record_set = rrsets[0]
-    record_set["ResourceRecords"][0]["Value"].should.equal("my_other.example.com")
+    assert record_set["ResourceRecords"][0]["Value"] == "my_other.example.com"
 
 
 @mock_cloudformation
 @mock_route53
 def test_delete_route53_recordset():
-
     cf = boto3.client("cloudformation", region_name="us-west-1")
 
     # given a stack with a record set
