@@ -1,7 +1,7 @@
 import boto3
 import pytest
-
 from botocore.exceptions import ClientError
+
 from moto import mock_route53
 
 
@@ -10,8 +10,8 @@ def test_list_reusable_delegation_set():
     client = boto3.client("route53", region_name="us-east-1")
     resp = client.list_reusable_delegation_sets()
 
-    resp.should.have.key("DelegationSets").equals([])
-    resp.should.have.key("IsTruncated").equals(False)
+    assert resp["DelegationSets"] == []
+    assert resp["IsTruncated"] is False
 
 
 @mock_route53
@@ -20,13 +20,11 @@ def test_create_reusable_delegation_set():
     resp = client.create_reusable_delegation_set(CallerReference="r3f3r3nc3")
 
     headers = resp["ResponseMetadata"]["HTTPHeaders"]
-    headers.should.have.key("location")
+    assert "location" in headers
 
-    resp.should.have.key("DelegationSet")
-
-    resp["DelegationSet"].should.have.key("Id")
-    resp["DelegationSet"].should.have.key("CallerReference").equals("r3f3r3nc3")
-    resp["DelegationSet"].should.have.key("NameServers").length_of(4)
+    assert "Id" in resp["DelegationSet"]
+    assert resp["DelegationSet"]["CallerReference"] == "r3f3r3nc3"
+    assert len(resp["DelegationSet"]["NameServers"]) == 4
 
 
 @mock_route53
@@ -42,7 +40,7 @@ def test_create_reusable_delegation_set_from_hosted_zone():
         CallerReference="r3f3r3nc3", HostedZoneId=hosted_zone_id
     )
 
-    set(resp["DelegationSet"]["NameServers"]).should.equal(hosted_zone_name_servers)
+    assert set(resp["DelegationSet"]["NameServers"]) == hosted_zone_name_servers
 
 
 @mock_route53
@@ -54,9 +52,7 @@ def test_create_reusable_delegation_set_from_hosted_zone_with_delegationsetid():
         DelegationSetId="customdelegationsetid",
     )
 
-    response.should.have.key("DelegationSet")
-    response["DelegationSet"].should.have.key("Id").equals("customdelegationsetid")
-    response["DelegationSet"].should.have.key("NameServers")
+    assert response["DelegationSet"]["Id"] == "customdelegationsetid"
 
     hosted_zone_id = response["HostedZone"]["Id"]
     hosted_zone_name_servers = set(response["DelegationSet"]["NameServers"])
@@ -65,8 +61,8 @@ def test_create_reusable_delegation_set_from_hosted_zone_with_delegationsetid():
         CallerReference="r3f3r3nc3", HostedZoneId=hosted_zone_id
     )
 
-    resp["DelegationSet"].should.have.key("Id").shouldnt.equal("customdelegationsetid")
-    set(resp["DelegationSet"]["NameServers"]).should.equal(hosted_zone_name_servers)
+    assert resp["DelegationSet"]["Id"] != "customdelegationsetid"
+    assert set(resp["DelegationSet"]["NameServers"]) == hosted_zone_name_servers
 
 
 @mock_route53
@@ -78,11 +74,11 @@ def test_get_reusable_delegation_set():
 
     resp = client.get_reusable_delegation_set(Id=ds_id)
 
-    resp.should.have.key("DelegationSet")
+    assert "DelegationSet" in resp
 
-    resp["DelegationSet"].should.have.key("Id").equals(ds_id)
-    resp["DelegationSet"].should.have.key("CallerReference").equals("r3f3r3nc3")
-    resp["DelegationSet"].should.have.key("NameServers").length_of(4)
+    assert resp["DelegationSet"]["Id"] == ds_id
+    assert resp["DelegationSet"]["CallerReference"] == "r3f3r3nc3"
+    assert len(resp["DelegationSet"]["NameServers"]) == 4
 
 
 @mock_route53
@@ -92,8 +88,8 @@ def test_get_reusable_delegation_set_unknown():
     with pytest.raises(ClientError) as exc:
         client.get_reusable_delegation_set(Id="unknown")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("NoSuchDelegationSet")
-    err["Message"].should.equal("unknown")
+    assert err["Code"] == "NoSuchDelegationSet"
+    assert err["Message"] == "unknown"
 
 
 @mock_route53
@@ -103,8 +99,8 @@ def test_list_reusable_delegation_sets():
     client.create_reusable_delegation_set(CallerReference="r3f3r3nc4")
 
     resp = client.list_reusable_delegation_sets()
-    resp.should.have.key("DelegationSets").length_of(2)
-    resp.should.have.key("IsTruncated").equals(False)
+    assert len(resp["DelegationSets"]) == 2
+    assert resp["IsTruncated"] is False
 
 
 @mock_route53
@@ -116,4 +112,4 @@ def test_delete_reusable_delegation_set():
 
     client.delete_reusable_delegation_set(Id=ds_id)
 
-    client.list_reusable_delegation_sets()["DelegationSets"].should.have.length_of(0)
+    assert len(client.list_reusable_delegation_sets()["DelegationSets"]) == 0
