@@ -1,13 +1,15 @@
-import boto3
 import os
+from uuid import uuid4
+
+import boto3
 import pytest
 import requests
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
 from botocore.handlers import disable_signing
-from moto import mock_s3
-from uuid import uuid4
+
+from moto import mock_s3, settings
+
+from .test_s3 import add_proxy_details
 
 DEFAULT_REGION_NAME = "us-east-1"
 
@@ -22,10 +24,10 @@ DEFAULT_REGION_NAME = "us-east-1"
 @pytest.mark.parametrize("readwrite", ["Read", "Write"])
 @mock_s3
 def test_put_object_acl_using_grant(readwrite, type_key, value, has_quotes):
-    s3 = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
+    s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     bucket_name = str(uuid4())
-    bucket = s3.Bucket(bucket_name)
+    bucket = s3_resource.Bucket(bucket_name)
     bucket.create()
     keyname = "test.txt"
 
@@ -40,16 +42,16 @@ def test_put_object_acl_using_grant(readwrite, type_key, value, has_quotes):
     client.put_object_acl(**args)
 
     grants = client.get_object_acl(Bucket=bucket_name, Key=keyname)["Grants"]
-    grants.should.have.length_of(1)
-    grants[0].should.have.key("Grantee").equal({"Type": _type, response_key: value})
-    grants[0].should.have.key("Permission").equal(readwrite.upper())
+    assert len(grants) == 1
+    assert grants[0]["Grantee"] == {"Type": _type, response_key: value}
+    assert grants[0]["Permission"] == readwrite.upper()
 
 
 @mock_s3
 def test_acl_switching_boto3():
-    s3 = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
+    s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket = s3.Bucket("foobar")
+    bucket = s3_resource.Bucket("foobar")
     bucket.create()
     keyname = "test.txt"
 
@@ -57,32 +59,30 @@ def test_acl_switching_boto3():
     client.put_object_acl(ACL="private", Bucket="foobar", Key=keyname)
 
     grants = client.get_object_acl(Bucket="foobar", Key=keyname)["Grants"]
-    grants.shouldnt.contain(
-        {
-            "Grantee": {
-                "Type": "Group",
-                "URI": "http://acs.amazonaws.com/groups/global/AllUsers",
-            },
-            "Permission": "READ",
-        }
-    )
+    assert {
+        "Grantee": {
+            "Type": "Group",
+            "URI": "http://acs.amazonaws.com/groups/global/AllUsers",
+        },
+        "Permission": "READ",
+    } not in grants
 
 
 @mock_s3
 def test_acl_switching_nonexistent_key():
-    s3 = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3.create_bucket(Bucket="mybucket")
+    s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    s3_client.create_bucket(Bucket="mybucket")
 
-    with pytest.raises(ClientError) as e:
-        s3.put_object_acl(Bucket="mybucket", Key="nonexistent", ACL="private")
+    with pytest.raises(ClientError) as exc:
+        s3_client.put_object_acl(Bucket="mybucket", Key="nonexistent", ACL="private")
 
-    e.value.response["Error"]["Code"].should.equal("NoSuchKey")
+    assert exc.value.response["Error"]["Code"] == "NoSuchKey"
 
 
 @mock_s3
 def test_s3_object_in_public_bucket():
-    s3 = boto3.resource("s3")
-    bucket = s3.Bucket("test-bucket")
+    s3_resource = boto3.resource("s3")
+    bucket = s3_resource.Bucket("test-bucket")
     bucket.create(
         ACL="public-read", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
     )
@@ -96,19 +96,19 @@ def test_s3_object_in_public_bucket():
         .get()["Body"]
         .read()
     )
-    contents.should.equal(b"ABCD")
+    assert contents == b"ABCD"
 
     bucket.put_object(ACL="private", Body=b"ABCD", Key="file.txt")
 
     with pytest.raises(ClientError) as exc:
         s3_anonymous.Object(key="file.txt", bucket_name="test-bucket").get()
-    exc.value.response["Error"]["Code"].should.equal("403")
+    assert exc.value.response["Error"]["Code"] == "403"
 
 
 @mock_s3
 def test_s3_object_in_public_bucket_using_multiple_presigned_urls():
-    s3 = boto3.resource("s3")
-    bucket = s3.Bucket("test-bucket")
+    s3_resource = boto3.resource("s3")
+    bucket = s3_resource.Bucket("test-bucket")
     bucket.create(
         ACL="public-read", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
     )
@@ -118,15 +118,18 @@ def test_s3_object_in_public_bucket_using_multiple_presigned_urls():
     presigned_url = boto3.client("s3").generate_presigned_url(
         "get_object", params, ExpiresIn=900
     )
+    kwargs = {}
+    if settings.test_proxy_mode():
+        add_proxy_details(kwargs)
     for i in range(1, 10):
-        response = requests.get(presigned_url)
+        response = requests.get(presigned_url, **kwargs)
         assert response.status_code == 200, f"Failed on req number {i}"
 
 
 @mock_s3
 def test_s3_object_in_private_bucket():
-    s3 = boto3.resource("s3")
-    bucket = s3.Bucket("test-bucket")
+    s3_resource = boto3.resource("s3")
+    bucket = s3_resource.Bucket("test-bucket")
     bucket.create(
         ACL="private", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
     )
@@ -137,7 +140,7 @@ def test_s3_object_in_private_bucket():
 
     with pytest.raises(ClientError) as exc:
         s3_anonymous.Object(key="file.txt", bucket_name="test-bucket").get()
-    exc.value.response["Error"]["Code"].should.equal("403")
+    assert exc.value.response["Error"]["Code"] == "403"
 
     bucket.put_object(ACL="public-read", Body=b"ABCD", Key="file.txt")
     contents = (
@@ -145,15 +148,15 @@ def test_s3_object_in_private_bucket():
         .get()["Body"]
         .read()
     )
-    contents.should.equal(b"ABCD")
+    assert contents == b"ABCD"
 
 
 @mock_s3
 def test_put_bucket_acl_body():
-    s3 = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3.create_bucket(Bucket="bucket")
-    bucket_owner = s3.get_bucket_acl(Bucket="bucket")["Owner"]
-    s3.put_bucket_acl(
+    s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    s3_client.create_bucket(Bucket="bucket")
+    bucket_owner = s3_client.get_bucket_acl(Bucket="bucket")["Owner"]
+    s3_client.put_bucket_acl(
         Bucket="bucket",
         AccessControlPolicy={
             "Grants": [
@@ -176,15 +179,17 @@ def test_put_bucket_acl_body():
         },
     )
 
-    result = s3.get_bucket_acl(Bucket="bucket")
+    result = s3_client.get_bucket_acl(Bucket="bucket")
     assert len(result["Grants"]) == 2
-    for g in result["Grants"]:
-        assert g["Grantee"]["URI"] == "http://acs.amazonaws.com/groups/s3/LogDelivery"
-        assert g["Grantee"]["Type"] == "Group"
-        assert g["Permission"] in ["WRITE", "READ_ACP"]
+    for grant in result["Grants"]:
+        assert (
+            grant["Grantee"]["URI"] == "http://acs.amazonaws.com/groups/s3/LogDelivery"
+        )
+        assert grant["Grantee"]["Type"] == "Group"
+        assert grant["Permission"] in ["WRITE", "READ_ACP"]
 
     # With one:
-    s3.put_bucket_acl(
+    s3_client.put_bucket_acl(
         Bucket="bucket",
         AccessControlPolicy={
             "Grants": [
@@ -199,12 +204,12 @@ def test_put_bucket_acl_body():
             "Owner": bucket_owner,
         },
     )
-    result = s3.get_bucket_acl(Bucket="bucket")
+    result = s3_client.get_bucket_acl(Bucket="bucket")
     assert len(result["Grants"]) == 1
 
     # With no owner:
     with pytest.raises(ClientError) as err:
-        s3.put_bucket_acl(
+        s3_client.put_bucket_acl(
             Bucket="bucket",
             AccessControlPolicy={
                 "Grants": [
@@ -222,7 +227,7 @@ def test_put_bucket_acl_body():
 
     # With incorrect permission:
     with pytest.raises(ClientError) as err:
-        s3.put_bucket_acl(
+        s3_client.put_bucket_acl(
             Bucket="bucket",
             AccessControlPolicy={
                 "Grants": [
@@ -240,7 +245,7 @@ def test_put_bucket_acl_body():
     assert err.value.response["Error"]["Code"] == "MalformedACLError"
 
     # Clear the ACLs:
-    result = s3.put_bucket_acl(
+    result = s3_client.put_bucket_acl(
         Bucket="bucket", AccessControlPolicy={"Grants": [], "Owner": bucket_owner}
     )
     assert not result.get("Grants")
@@ -248,31 +253,33 @@ def test_put_bucket_acl_body():
 
 @mock_s3
 def test_object_acl_with_presigned_post():
-    s3 = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
 
     bucket_name = "imageS3Bucket"
     object_name = "text.txt"
     fields = {"acl": "public-read"}
-    file = open("text.txt", "w")
+    file = open("text.txt", "w", encoding="utf-8")
     file.write("test")
     file.close()
 
-    s3.create_bucket(Bucket=bucket_name)
-    response = s3.generate_presigned_post(
+    s3_client.create_bucket(Bucket=bucket_name)
+    response = s3_client.generate_presigned_post(
         bucket_name, object_name, Fields=fields, ExpiresIn=60000
     )
 
-    with open(object_name, "rb") as f:
-        files = {"file": (object_name, f)}
-        requests.post(response["url"], data=response["fields"], files=files)
+    with open(object_name, "rb") as fhandle:
+        kwargs = {"files": {"file": (object_name, fhandle)}}
+        if settings.test_proxy_mode():
+            add_proxy_details(kwargs)
+        requests.post(response["url"], data=response["fields"], **kwargs)
 
-    response = s3.get_object_acl(Bucket=bucket_name, Key=object_name)
+    response = s3_client.get_object_acl(Bucket=bucket_name, Key=object_name)
 
     assert "Grants" in response
     assert len(response["Grants"]) == 2
     assert response["Grants"][1]["Permission"] == "READ"
 
-    response = s3.get_object(Bucket=bucket_name, Key=object_name)
+    response = s3_client.get_object(Bucket=bucket_name, Key=object_name)
 
     assert "ETag" in response
     assert "Body" in response
@@ -281,9 +288,9 @@ def test_object_acl_with_presigned_post():
 
 @mock_s3
 def test_acl_setting_boto3():
-    s3 = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
+    s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket = s3.Bucket("foobar")
+    bucket = s3_resource.Bucket("foobar")
     bucket.create()
 
     content = b"imafile"
@@ -293,22 +300,20 @@ def test_acl_setting_boto3():
     )
 
     grants = client.get_object_acl(Bucket="foobar", Key=keyname)["Grants"]
-    grants.should.contain(
-        {
-            "Grantee": {
-                "Type": "Group",
-                "URI": "http://acs.amazonaws.com/groups/global/AllUsers",
-            },
-            "Permission": "READ",
-        }
-    )
+    assert {
+        "Grantee": {
+            "Type": "Group",
+            "URI": "http://acs.amazonaws.com/groups/global/AllUsers",
+        },
+        "Permission": "READ",
+    } in grants
 
 
 @mock_s3
 def test_acl_setting_via_headers_boto3():
-    s3 = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
+    s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket = s3.Bucket("foobar")
+    bucket = s3_resource.Bucket("foobar")
     bucket.create()
 
     keyname = "test.txt"
@@ -317,28 +322,27 @@ def test_acl_setting_via_headers_boto3():
     client.put_object_acl(ACL="public-read", Bucket="foobar", Key=keyname)
 
     grants = client.get_object_acl(Bucket="foobar", Key=keyname)["Grants"]
-    grants.should.contain(
-        {
-            "Grantee": {
-                "Type": "Group",
-                "URI": "http://acs.amazonaws.com/groups/global/AllUsers",
-            },
-            "Permission": "READ",
-        }
-    )
+    assert {
+        "Grantee": {
+            "Type": "Group",
+            "URI": "http://acs.amazonaws.com/groups/global/AllUsers",
+        },
+        "Permission": "READ",
+    } in grants
 
 
 @mock_s3
 def test_raise_exception_for_grant_and_acl():
-    client = boto3.client("s3")
-    s3 = boto3.resource("s3")
+    client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     bucket_name = "bucketname"
     client.create_bucket(Bucket=bucket_name)
-    bucket = s3.Bucket(bucket_name)
+    bucket = s3_resource.Bucket(bucket_name)
     acl = client.get_bucket_acl(Bucket=bucket_name)
     acl_grantee_id = acl["Owner"]["ID"]
 
-    # This should raise an exception or provide some error message, but runs without exception instead.
+    # This should raise an exception or provide some error message,
+    # but runs without exception instead.
     with pytest.raises(ClientError) as exc:
         bucket.put_object(
             ACL="bucket-owner-full-control",
@@ -348,7 +352,7 @@ def test_raise_exception_for_grant_and_acl():
             GrantFullControl=f'id="{acl_grantee_id}"',
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("InvalidRequest")
-    err["Message"].should.equal(
-        "Specifying both Canned ACLs and Header Grants is not allowed"
+    assert err["Code"] == "InvalidRequest"
+    assert (
+        err["Message"] == "Specifying both Canned ACLs and Header Grants is not allowed"
     )
