@@ -1,6 +1,6 @@
 import json
+
 import pytest
-import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_s3
 from moto.core.exceptions import InvalidNextTokenException
@@ -23,9 +23,7 @@ def test_s3_public_access_block_to_config_dict():
     }
 
     # Add a public access block:
-    s3_config_query_backend.put_bucket_public_access_block(
-        "bucket1", public_access_block
-    )
+    s3_config_query_backend.put_public_access_block("bucket1", public_access_block)
 
     result = s3_config_query_backend.buckets[
         "bucket1"
@@ -53,30 +51,30 @@ def test_list_config_discovered_resources():
     ) == ([], None)
 
     # With 10 buckets in us-west-2:
-    for x in range(0, 10):
-        s3_config_query_backend.create_bucket(f"bucket{x}", "us-west-2")
+    for idx in range(0, 10):
+        s3_config_query_backend.create_bucket(f"bucket{idx}", "us-west-2")
 
     # With 2 buckets in eu-west-1:
-    for x in range(10, 12):
-        s3_config_query_backend.create_bucket(f"eu-bucket{x}", "eu-west-1")
+    for idx in range(10, 12):
+        s3_config_query_backend.create_bucket(f"eu-bucket{idx}", "eu-west-1")
 
     result, next_token = s3_config_query.list_config_service_resources(
         DEFAULT_ACCOUNT_ID, None, None, 100, None
     )
     assert not next_token
     assert len(result) == 12
-    for x in range(0, 10):
-        assert result[x] == {
+    for idx in range(0, 10):
+        assert result[idx] == {
             "type": "AWS::S3::Bucket",
-            "id": f"bucket{x}",
-            "name": f"bucket{x}",
+            "id": f"bucket{idx}",
+            "name": f"bucket{idx}",
             "region": "us-west-2",
         }
-    for x in range(10, 12):
-        assert result[x] == {
+    for idx in range(10, 12):
+        assert result[idx] == {
             "type": "AWS::S3::Bucket",
-            "id": f"eu-bucket{x}",
-            "name": f"eu-bucket{x}",
+            "id": f"eu-bucket{idx}",
+            "name": f"eu-bucket{idx}",
             "region": "eu-west-1",
         }
 
@@ -379,7 +377,7 @@ def test_s3_notification_config_dict():
 
 @mock_s3
 def test_s3_acl_to_config_dict():
-    from moto.s3.models import FakeAcl, FakeGrant, FakeGrantee, OWNER
+    from moto.s3.models import OWNER, FakeAcl, FakeGrant, FakeGrantee
 
     # With 1 bucket in us-west-2:
     s3_config_query_backend.create_bucket("logbucket", "us-west-2")
@@ -450,7 +448,7 @@ def test_s3_acl_to_config_dict():
 
 @mock_s3
 def test_s3_config_dict():
-    from moto.s3.models import FakeAcl, FakeGrant, FakeGrantee, OWNER
+    from moto.s3.models import OWNER, FakeAcl, FakeGrant, FakeGrantee
 
     # Without any buckets:
     assert not s3_config_query.get_config_resource(DEFAULT_ACCOUNT_ID, "some_bucket")
