@@ -1,27 +1,27 @@
 import boto3
+import pytest
 from botocore.client import ClientError
 
-import pytest
-import sure  # noqa # pylint: disable=unused-import
 from moto import mock_s3
+from moto.s3.responses import DEFAULT_REGION_NAME
 
 
 @mock_s3
 def test_create_bucket_with_ownership():
     bucket = "bucket-with-owner"
     ownership = "BucketOwnerPreferred"
-    client = boto3.client("s3")
+    client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     client.create_bucket(Bucket=bucket, ObjectOwnership=ownership)
 
     response = client.get_bucket_ownership_controls(Bucket=bucket)
-    response["OwnershipControls"]["Rules"][0]["ObjectOwnership"].should.equal(ownership)
+    assert response["OwnershipControls"]["Rules"][0]["ObjectOwnership"] == ownership
 
 
 @mock_s3
 def test_put_ownership_to_bucket():
     bucket = "bucket-updated-with-owner"
     ownership = "ObjectWriter"
-    client = boto3.client("s3")
+    client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     client.create_bucket(Bucket=bucket)
 
     client.put_bucket_ownership_controls(
@@ -29,14 +29,14 @@ def test_put_ownership_to_bucket():
     )
 
     response = client.get_bucket_ownership_controls(Bucket=bucket)
-    response["OwnershipControls"]["Rules"][0]["ObjectOwnership"].should.equal(ownership)
+    assert response["OwnershipControls"]["Rules"][0]["ObjectOwnership"] == ownership
 
 
 @mock_s3
 def test_delete_ownership_from_bucket():
     bucket = "bucket-with-owner-removed"
     ownership = "BucketOwnerEnforced"
-    client = boto3.client("s3")
+    client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     client.create_bucket(Bucket=bucket, ObjectOwnership=ownership)
 
     client.delete_bucket_ownership_controls(Bucket=bucket)
@@ -44,7 +44,7 @@ def test_delete_ownership_from_bucket():
     with pytest.raises(ClientError) as ex:
         client.get_bucket_ownership_controls(Bucket=bucket)
 
-    ex.value.response["Error"]["Code"].should.equal("OwnershipControlsNotFoundError")
-    ex.value.response["Error"]["Message"].should.equal(
+    assert ex.value.response["Error"]["Code"] == "OwnershipControlsNotFoundError"
+    assert ex.value.response["Error"]["Message"] == (
         "The bucket ownership controls were not found"
     )
