@@ -1,18 +1,18 @@
-import boto3
+import re
 
+import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
 from botocore.exceptions import ClientError
 
 from moto import mock_cloudformation, mock_sagemaker
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 from .cloudformation_test_configs import (
-    NotebookInstanceTestConfig,
-    NotebookInstanceLifecycleConfigTestConfig,
-    ModelTestConfig,
     EndpointConfigTestConfig,
     EndpointTestConfig,
+    ModelTestConfig,
+    NotebookInstanceLifecycleConfigTestConfig,
+    NotebookInstanceTestConfig,
 )
 
 
@@ -44,7 +44,7 @@ def test_sagemaker_cloudformation_create(test_config):
     # Utilize test configuration to set-up any mock SageMaker resources
     test_config.run_setup_procedure(sm)
 
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     cf.create_stack(
         StackName=stack_name,
         TemplateBody=test_config.get_cloudformation_template(include_outputs=False),
@@ -53,8 +53,8 @@ def test_sagemaker_cloudformation_create(test_config):
     provisioned_resource = cf.list_stack_resources(StackName=stack_name)[
         "StackResourceSummaries"
     ][0]
-    provisioned_resource["LogicalResourceId"].should.equal(test_config.resource_name)
-    len(provisioned_resource["PhysicalResourceId"]).should.be.greater_than(0)
+    assert provisioned_resource["LogicalResourceId"] == test_config.resource_name
+    assert len(provisioned_resource["PhysicalResourceId"]) > 0
 
 
 @mock_cloudformation
@@ -77,7 +77,7 @@ def test_sagemaker_cloudformation_get_attr(test_config):
     test_config.run_setup_procedure(sm)
 
     # Create stack and get description for output values
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     cf.create_stack(
         StackName=stack_name, TemplateBody=test_config.get_cloudformation_template()
     )
@@ -87,7 +87,7 @@ def test_sagemaker_cloudformation_get_attr(test_config):
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: outputs["Name"]}
     )
-    outputs["Arn"].should.equal(resource_description[test_config.arn_parameter])
+    assert outputs["Arn"] == resource_description[test_config.arn_parameter]
 
 
 @mock_cloudformation
@@ -113,7 +113,7 @@ def test_sagemaker_cloudformation_notebook_instance_delete(test_config, error_me
     test_config.run_setup_procedure(sm)
 
     # Create stack and verify existence
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     cf.create_stack(
         StackName=stack_name, TemplateBody=test_config.get_cloudformation_template()
     )
@@ -122,7 +122,7 @@ def test_sagemaker_cloudformation_notebook_instance_delete(test_config, error_me
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: outputs["Name"]}
     )
-    outputs["Arn"].should.equal(resource_description[test_config.arn_parameter])
+    assert outputs["Arn"] == resource_description[test_config.arn_parameter]
 
     # Delete the stack and verify resource has also been deleted
     cf.delete_stack(StackName=stack_name)
@@ -130,7 +130,7 @@ def test_sagemaker_cloudformation_notebook_instance_delete(test_config, error_me
         getattr(sm, test_config.describe_function_name)(
             **{test_config.name_parameter: outputs["Name"]}
         )
-    ce.value.response["Error"]["Message"].should.contain(error_message)
+    assert error_message in ce.value.response["Error"]["Message"]
 
 
 @mock_cloudformation
@@ -142,7 +142,7 @@ def test_sagemaker_cloudformation_notebook_instance_update():
     test_config = NotebookInstanceTestConfig()
 
     # Set up template for stack with two different instance types
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     initial_instance_type = "ml.c4.xlarge"
     updated_instance_type = "ml.c4.4xlarge"
     initial_template_json = test_config.get_cloudformation_template(
@@ -160,19 +160,19 @@ def test_sagemaker_cloudformation_notebook_instance_update():
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: initial_notebook_name}
     )
-    initial_instance_type.should.equal(resource_description["InstanceType"])
+    assert initial_instance_type == resource_description["InstanceType"]
 
     # Update stack and check attributes
     cf.update_stack(StackName=stack_name, TemplateBody=updated_template_json)
     outputs = _get_stack_outputs(cf, stack_name)
 
     updated_notebook_name = outputs["Name"]
-    updated_notebook_name.should.equal(initial_notebook_name)
+    assert updated_notebook_name == initial_notebook_name
 
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: updated_notebook_name}
     )
-    updated_instance_type.should.equal(resource_description["InstanceType"])
+    assert updated_instance_type == resource_description["InstanceType"]
 
 
 @mock_cloudformation
@@ -184,7 +184,7 @@ def test_sagemaker_cloudformation_notebook_instance_lifecycle_config_update():
     test_config = NotebookInstanceLifecycleConfigTestConfig()
 
     # Set up template for stack with two different OnCreate scripts
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     initial_on_create_script = "echo Hello World"
     updated_on_create_script = "echo Goodbye World"
     initial_template_json = test_config.get_cloudformation_template(
@@ -202,25 +202,21 @@ def test_sagemaker_cloudformation_notebook_instance_lifecycle_config_update():
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: initial_config_name}
     )
-    len(resource_description["OnCreate"]).should.equal(1)
-    initial_on_create_script.should.equal(
-        resource_description["OnCreate"][0]["Content"]
-    )
+    assert len(resource_description["OnCreate"]) == 1
+    assert initial_on_create_script == resource_description["OnCreate"][0]["Content"]
 
     # Update stack and check attributes
     cf.update_stack(StackName=stack_name, TemplateBody=updated_template_json)
     outputs = _get_stack_outputs(cf, stack_name)
 
     updated_config_name = outputs["Name"]
-    updated_config_name.should.equal(initial_config_name)
+    assert updated_config_name == initial_config_name
 
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: updated_config_name}
     )
-    len(resource_description["OnCreate"]).should.equal(1)
-    updated_on_create_script.should.equal(
-        resource_description["OnCreate"][0]["Content"]
-    )
+    assert len(resource_description["OnCreate"]) == 1
+    assert updated_on_create_script == resource_description["OnCreate"][0]["Content"]
 
 
 @mock_cloudformation
@@ -232,7 +228,7 @@ def test_sagemaker_cloudformation_model_update():
     test_config = ModelTestConfig()
 
     # Set up template for stack with two different image versions
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     image = "404615174143.dkr.ecr.us-east-2.amazonaws.com/kmeans:{}"
     initial_image_version = 1
     updated_image_version = 2
@@ -251,7 +247,7 @@ def test_sagemaker_cloudformation_model_update():
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: initial_model_name}
     )
-    resource_description["PrimaryContainer"]["Image"].should.equal(
+    assert resource_description["PrimaryContainer"]["Image"] == (
         image.format(initial_image_version)
     )
 
@@ -260,12 +256,12 @@ def test_sagemaker_cloudformation_model_update():
     outputs = _get_stack_outputs(cf, stack_name)
 
     updated_model_name = outputs["Name"]
-    updated_model_name.should_not.equal(initial_model_name)
+    assert updated_model_name != initial_model_name
 
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: updated_model_name}
     )
-    resource_description["PrimaryContainer"]["Image"].should.equal(
+    assert resource_description["PrimaryContainer"]["Image"] == (
         image.format(updated_image_version)
     )
 
@@ -282,7 +278,7 @@ def test_sagemaker_cloudformation_endpoint_config_update():
     test_config.run_setup_procedure(sm)
 
     # Set up template for stack with two different production variant counts
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     initial_num_production_variants = 1
     updated_num_production_variants = 2
     initial_template_json = test_config.get_cloudformation_template(
@@ -300,7 +296,7 @@ def test_sagemaker_cloudformation_endpoint_config_update():
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: initial_endpoint_config_name}
     )
-    len(resource_description["ProductionVariants"]).should.equal(
+    assert len(resource_description["ProductionVariants"]) == (
         initial_num_production_variants
     )
 
@@ -309,12 +305,12 @@ def test_sagemaker_cloudformation_endpoint_config_update():
     outputs = _get_stack_outputs(cf, stack_name)
 
     updated_endpoint_config_name = outputs["Name"]
-    updated_endpoint_config_name.should_not.equal(initial_endpoint_config_name)
+    assert updated_endpoint_config_name != initial_endpoint_config_name
 
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: updated_endpoint_config_name}
     )
-    len(resource_description["ProductionVariants"]).should.equal(
+    assert len(resource_description["ProductionVariants"]) == (
         updated_num_production_variants
     )
 
@@ -328,7 +324,7 @@ def test_sagemaker_cloudformation_endpoint_update():
     test_config = EndpointTestConfig()
 
     # Set up template for stack with two different endpoint config names
-    stack_name = "{}_stack".format(test_config.resource_name)
+    stack_name = f"{test_config.resource_name}_stack"
     initial_endpoint_config_name = test_config.resource_name
     updated_endpoint_config_name = "updated-endpoint-config-name"
     initial_template_json = test_config.get_cloudformation_template(
@@ -341,7 +337,7 @@ def test_sagemaker_cloudformation_endpoint_update():
     # Create SM resources and stack with initial template and check attributes
     sm.create_model(
         ModelName=initial_endpoint_config_name,
-        ExecutionRoleArn="arn:aws:iam::{}:role/FakeRole".format(ACCOUNT_ID),
+        ExecutionRoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/FakeRole",
         PrimaryContainer={
             "Image": "404615174143.dkr.ecr.us-east-2.amazonaws.com/linear-learner:1",
         },
@@ -365,14 +361,14 @@ def test_sagemaker_cloudformation_endpoint_update():
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: initial_endpoint_name}
     )
-    resource_description["EndpointConfigName"].should.match(
-        initial_endpoint_config_name
+    assert re.match(
+        initial_endpoint_config_name, resource_description["EndpointConfigName"]
     )
 
     # Create additional SM resources and update stack
     sm.create_model(
         ModelName=updated_endpoint_config_name,
-        ExecutionRoleArn="arn:aws:iam::{}:role/FakeRole".format(ACCOUNT_ID),
+        ExecutionRoleArn=f"arn:aws:iam::{ACCOUNT_ID}:role/FakeRole",
         PrimaryContainer={
             "Image": "404615174143.dkr.ecr.us-east-2.amazonaws.com/linear-learner:1",
         },
@@ -393,11 +389,11 @@ def test_sagemaker_cloudformation_endpoint_update():
     outputs = _get_stack_outputs(cf, stack_name)
 
     updated_endpoint_name = outputs["Name"]
-    updated_endpoint_name.should.equal(initial_endpoint_name)
+    assert updated_endpoint_name == initial_endpoint_name
 
     resource_description = getattr(sm, test_config.describe_function_name)(
         **{test_config.name_parameter: updated_endpoint_name}
     )
-    resource_description["EndpointConfigName"].should.match(
-        updated_endpoint_config_name
+    assert re.match(
+        updated_endpoint_config_name, resource_description["EndpointConfigName"]
     )
