@@ -1,10 +1,10 @@
+import re
+
 import boto3
-from botocore.exceptions import ClientError
 import pytest
+from botocore.exceptions import ClientError
+
 from moto import mock_sagemaker
-
-import sure  # noqa # pylint: disable=unused-import
-
 from moto.sagemaker.models import VpcConfig
 
 TEST_REGION_NAME = "us-east-1"
@@ -18,7 +18,7 @@ def fixture_sagemaker_client():
         yield boto3.client("sagemaker", region_name=TEST_REGION_NAME)
 
 
-class MySageMakerModel(object):
+class MySageMakerModel:
     def __init__(self, name=None, arn=None, container=None, vpc_config=None):
         self.name = name or TEST_MODEL_NAME
         self.arn = arn or TEST_ARN
@@ -41,13 +41,13 @@ def test_describe_model(sagemaker_client):
     test_model = MySageMakerModel()
     test_model.save(sagemaker_client)
     model = sagemaker_client.describe_model(ModelName=TEST_MODEL_NAME)
-    assert model.get("ModelName").should.equal(TEST_MODEL_NAME)
+    assert model.get("ModelName") == TEST_MODEL_NAME
 
 
 def test_describe_model_not_found(sagemaker_client):
     with pytest.raises(ClientError) as err:
         sagemaker_client.describe_model(ModelName="unknown")
-    assert err.value.response["Error"]["Message"].should.contain("Could not find model")
+    assert "Could not find model" in err.value.response["Error"]["Message"]
 
 
 def test_create_model(sagemaker_client):
@@ -57,8 +57,8 @@ def test_create_model(sagemaker_client):
         ExecutionRoleArn=TEST_ARN,
         VpcConfig=vpc_config.response_object,
     )
-    model["ModelArn"].should.match(
-        r"^arn:aws:sagemaker:.*:.*:model/{}$".format(TEST_MODEL_NAME)
+    assert re.match(
+        rf"^arn:aws:sagemaker:.*:.*:model/{TEST_MODEL_NAME}$", model["ModelArn"]
     )
 
 
@@ -66,25 +66,26 @@ def test_delete_model(sagemaker_client):
     test_model = MySageMakerModel()
     test_model.save(sagemaker_client)
 
-    assert len(sagemaker_client.list_models()["Models"]).should.equal(1)
+    assert len(sagemaker_client.list_models()["Models"]) == 1
     sagemaker_client.delete_model(ModelName=TEST_MODEL_NAME)
-    assert len(sagemaker_client.list_models()["Models"]).should.equal(0)
+    assert len(sagemaker_client.list_models()["Models"]) == 0
 
 
 def test_delete_model_not_found(sagemaker_client):
     with pytest.raises(ClientError) as err:
         sagemaker_client.delete_model(ModelName="blah")
-    assert err.value.response["Error"]["Code"].should.equal("404")
+    assert err.value.response["Error"]["Code"] == "404"
 
 
 def test_list_models(sagemaker_client):
     test_model = MySageMakerModel()
     test_model.save(sagemaker_client)
     models = sagemaker_client.list_models()
-    assert len(models["Models"]).should.equal(1)
-    assert models["Models"][0]["ModelName"].should.equal(TEST_MODEL_NAME)
-    assert models["Models"][0]["ModelArn"].should.match(
-        r"^arn:aws:sagemaker:.*:.*:model/{}$".format(TEST_MODEL_NAME)
+    assert len(models["Models"]) == 1
+    assert models["Models"][0]["ModelName"] == TEST_MODEL_NAME
+    assert re.match(
+        rf"^arn:aws:sagemaker:.*:.*:model/{TEST_MODEL_NAME}$",
+        models["Models"][0]["ModelArn"],
     )
 
 
@@ -99,12 +100,12 @@ def test_list_models_multiple(sagemaker_client):
     test_model_2 = MySageMakerModel(name=name_model_2, arn=arn_model_2)
     test_model_2.save(sagemaker_client)
     models = sagemaker_client.list_models()
-    assert len(models["Models"]).should.equal(2)
+    assert len(models["Models"]) == 2
 
 
 def test_list_models_none(sagemaker_client):
     models = sagemaker_client.list_models()
-    assert len(models["Models"]).should.equal(0)
+    assert len(models["Models"]) == 0
 
 
 def test_add_tags_to_model(sagemaker_client):
