@@ -1,17 +1,18 @@
-import boto3
-from botocore.exceptions import ClientError
 import datetime
-import sure  # noqa # pylint: disable=unused-import
+import re
+
+import boto3
 import pytest
+from botocore.exceptions import ClientError
 
 from moto import mock_sagemaker
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
-FAKE_ROLE_ARN = "arn:aws:iam::{}:role/FakeRole".format(ACCOUNT_ID)
+FAKE_ROLE_ARN = f"arn:aws:iam::{ACCOUNT_ID}:role/FakeRole"
 TEST_REGION_NAME = "us-east-1"
 
 
-class MyTrainingJobModel(object):
+class MyTrainingJobModel:
     def __init__(
         self,
         training_job_name,
@@ -48,7 +49,7 @@ class MyTrainingJobModel(object):
                 "DataSource": {
                     "S3DataSource": {
                         "S3DataType": "S3Prefix",
-                        "S3Uri": "s3://{}/{}/train/".format(self.bucket, self.prefix),
+                        "S3Uri": f"s3://{self.bucket}/{self.prefix}/train/",
                         "S3DataDistributionType": "ShardedByS3Key",
                     }
                 },
@@ -60,9 +61,7 @@ class MyTrainingJobModel(object):
                 "DataSource": {
                     "S3DataSource": {
                         "S3DataType": "S3Prefix",
-                        "S3Uri": "s3://{}/{}/validation/".format(
-                            self.bucket, self.prefix
-                        ),
+                        "S3Uri": f"s3://{self.bucket}/{self.prefix}/validation/",
                         "S3DataDistributionType": "FullyReplicated",
                     }
                 },
@@ -71,7 +70,7 @@ class MyTrainingJobModel(object):
             },
         ]
         self.output_data_config = output_data_config or {
-            "S3OutputPath": "s3://{}/{}/".format(self.bucket, self.prefix)
+            "S3OutputPath": f"s3://{self.bucket}/{self.prefix}/"
         }
         self.hyper_parameters = hyper_parameters or {
             "feature_dim": "30",
@@ -105,7 +104,7 @@ def test_create_training_job():
     sagemaker = boto3.client("sagemaker", region_name=TEST_REGION_NAME)
 
     training_job_name = "MyTrainingJob"
-    role_arn = "arn:aws:iam::{}:role/FakeRole".format(ACCOUNT_ID)
+    role_arn = f"arn:aws:iam::{ACCOUNT_ID}:role/FakeRole"
     container = "382416733822.dkr.ecr.us-east-1.amazonaws.com/linear-learner:1"
     bucket = "my-bucket"
     prefix = "sagemaker/DEMO-breast-cancer-prediction/"
@@ -124,7 +123,7 @@ def test_create_training_job():
             "DataSource": {
                 "S3DataSource": {
                     "S3DataType": "S3Prefix",
-                    "S3Uri": "s3://{}/{}/train/".format(bucket, prefix),
+                    "S3Uri": f"s3://{bucket}/{prefix}/train/",
                     "S3DataDistributionType": "ShardedByS3Key",
                 }
             },
@@ -136,7 +135,7 @@ def test_create_training_job():
             "DataSource": {
                 "S3DataSource": {
                     "S3DataType": "S3Prefix",
-                    "S3Uri": "s3://{}/{}/validation/".format(bucket, prefix),
+                    "S3Uri": f"s3://{bucket}/{prefix}/validation/",
                     "S3DataDistributionType": "FullyReplicated",
                 }
             },
@@ -144,7 +143,7 @@ def test_create_training_job():
             "RecordWrapperType": "None",
         },
     ]
-    output_data_config = {"S3OutputPath": "s3://{}/{}/".format(bucket, prefix)}
+    output_data_config = {"S3OutputPath": f"s3://{bucket}/{prefix}/"}
     hyper_parameters = {
         "feature_dim": "30",
         "mini_batch_size": "100",
@@ -169,14 +168,16 @@ def test_create_training_job():
         stopping_condition=stopping_condition,
     )
     resp = job.save()
-    resp["TrainingJobArn"].should.match(
-        r"^arn:aws:sagemaker:.*:.*:training-job/{}$".format(training_job_name)
+    assert re.match(
+        rf"^arn:aws:sagemaker:.*:.*:training-job/{training_job_name}$",
+        resp["TrainingJobArn"],
     )
 
     resp = sagemaker.describe_training_job(TrainingJobName=training_job_name)
-    resp["TrainingJobName"].should.equal(training_job_name)
-    resp["TrainingJobArn"].should.match(
-        r"^arn:aws:sagemaker:.*:.*:training-job/{}$".format(training_job_name)
+    assert resp["TrainingJobName"] == training_job_name
+    assert re.match(
+        rf"^arn:aws:sagemaker:.*:.*:training-job/{training_job_name}$",
+        resp["TrainingJobArn"],
     )
     assert resp["ModelArtifacts"]["S3ModelArtifacts"].startswith(
         output_data_config["S3OutputPath"]
@@ -216,8 +217,6 @@ def test_create_training_job():
     assert "Value" in resp["FinalMetricDataList"][0]
     assert "Timestamp" in resp["FinalMetricDataList"][0]
 
-    pass
-
 
 @mock_sagemaker
 def test_list_training_jobs():
@@ -227,13 +226,12 @@ def test_list_training_jobs():
     test_training_job = MyTrainingJobModel(training_job_name=name, role_arn=arn)
     test_training_job.save()
     training_jobs = client.list_training_jobs()
-    assert len(training_jobs["TrainingJobSummaries"]).should.equal(1)
-    assert training_jobs["TrainingJobSummaries"][0]["TrainingJobName"].should.equal(
-        name
-    )
+    assert len(training_jobs["TrainingJobSummaries"]) == 1
+    assert training_jobs["TrainingJobSummaries"][0]["TrainingJobName"] == name
 
-    assert training_jobs["TrainingJobSummaries"][0]["TrainingJobArn"].should.match(
-        r"^arn:aws:sagemaker:.*:.*:training-job/{}$".format(name)
+    assert re.match(
+        rf"^arn:aws:sagemaker:.*:.*:training-job/{name}$",
+        training_jobs["TrainingJobSummaries"][0]["TrainingJobArn"],
     )
     assert training_jobs.get("NextToken") is None
 
@@ -255,18 +253,18 @@ def test_list_training_jobs_multiple():
     )
     test_training_job_2.save()
     training_jobs_limit = client.list_training_jobs(MaxResults=1)
-    assert len(training_jobs_limit["TrainingJobSummaries"]).should.equal(1)
+    assert len(training_jobs_limit["TrainingJobSummaries"]) == 1
 
     training_jobs = client.list_training_jobs()
-    assert len(training_jobs["TrainingJobSummaries"]).should.equal(2)
-    assert training_jobs.get("NextToken").should.be.none
+    assert len(training_jobs["TrainingJobSummaries"]) == 2
+    assert training_jobs.get("NextToken") is None
 
 
 @mock_sagemaker
 def test_list_training_jobs_none():
     client = boto3.client("sagemaker", region_name="us-east-1")
     training_jobs = client.list_training_jobs()
-    assert len(training_jobs["TrainingJobSummaries"]).should.equal(0)
+    assert len(training_jobs["TrainingJobSummaries"]) == 0
 
 
 @mock_sagemaker
@@ -275,7 +273,12 @@ def test_list_training_jobs_should_validate_input():
     junk_status_equals = "blah"
     with pytest.raises(ClientError) as ex:
         client.list_training_jobs(StatusEquals=junk_status_equals)
-    expected_error = f"1 validation errors detected: Value '{junk_status_equals}' at 'statusEquals' failed to satisfy constraint: Member must satisfy enum value set: ['Completed', 'Stopped', 'InProgress', 'Stopping', 'Failed']"
+    expected_error = (
+        f"1 validation errors detected: Value '{junk_status_equals}' at "
+        "'statusEquals' failed to satisfy constraint: Member must satisfy "
+        "enum value set: ['Completed', 'Stopped', 'InProgress', 'Stopping', "
+        "'Failed']"
+    )
     assert ex.value.response["Error"]["Code"] == "ValidationException"
     assert ex.value.response["Error"]["Message"] == expected_error
 
@@ -293,110 +296,108 @@ def test_list_training_jobs_should_validate_input():
 def test_list_training_jobs_with_name_filters():
     client = boto3.client("sagemaker", region_name="us-east-1")
     for i in range(5):
-        name = "xgboost-{}".format(i)
-        arn = "arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{}".format(i)
+        name = f"xgboost-{i}"
+        arn = f"arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{i}"
         MyTrainingJobModel(training_job_name=name, role_arn=arn).save()
     for i in range(5):
-        name = "vgg-{}".format(i)
-        arn = "arn:aws:sagemaker:us-east-1:000000000000:x-x/barfoo-{}".format(i)
+        name = f"vgg-{i}"
+        arn = f"arn:aws:sagemaker:us-east-1:000000000000:x-x/barfoo-{i}"
         MyTrainingJobModel(training_job_name=name, role_arn=arn).save()
     xgboost_training_jobs = client.list_training_jobs(NameContains="xgboost")
-    assert len(xgboost_training_jobs["TrainingJobSummaries"]).should.equal(5)
+    assert len(xgboost_training_jobs["TrainingJobSummaries"]) == 5
 
     training_jobs_with_2 = client.list_training_jobs(NameContains="2")
-    assert len(training_jobs_with_2["TrainingJobSummaries"]).should.equal(2)
+    assert len(training_jobs_with_2["TrainingJobSummaries"]) == 2
 
 
 @mock_sagemaker
 def test_list_training_jobs_paginated():
     client = boto3.client("sagemaker", region_name="us-east-1")
     for i in range(5):
-        name = "xgboost-{}".format(i)
-        arn = "arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{}".format(i)
+        name = f"xgboost-{i}"
+        arn = f"arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{i}"
         MyTrainingJobModel(training_job_name=name, role_arn=arn).save()
     xgboost_training_job_1 = client.list_training_jobs(
         NameContains="xgboost", MaxResults=1
     )
-    assert len(xgboost_training_job_1["TrainingJobSummaries"]).should.equal(1)
-    assert xgboost_training_job_1["TrainingJobSummaries"][0][
-        "TrainingJobName"
-    ].should.equal("xgboost-0")
-    assert xgboost_training_job_1.get("NextToken").should_not.be.none
+    assert len(xgboost_training_job_1["TrainingJobSummaries"]) == 1
+    assert (
+        xgboost_training_job_1["TrainingJobSummaries"][0]["TrainingJobName"]
+        == "xgboost-0"
+    )
+    assert xgboost_training_job_1.get("NextToken") is not None
 
     xgboost_training_job_next = client.list_training_jobs(
         NameContains="xgboost",
         MaxResults=1,
         NextToken=xgboost_training_job_1.get("NextToken"),
     )
-    assert len(xgboost_training_job_next["TrainingJobSummaries"]).should.equal(1)
-    assert xgboost_training_job_next["TrainingJobSummaries"][0][
-        "TrainingJobName"
-    ].should.equal("xgboost-1")
-    assert xgboost_training_job_next.get("NextToken").should_not.be.none
+    assert len(xgboost_training_job_next["TrainingJobSummaries"]) == 1
+    assert (
+        xgboost_training_job_next["TrainingJobSummaries"][0]["TrainingJobName"]
+        == "xgboost-1"
+    )
+    assert xgboost_training_job_next.get("NextToken") is not None
 
 
 @mock_sagemaker
 def test_list_training_jobs_paginated_with_target_in_middle():
     client = boto3.client("sagemaker", region_name="us-east-1")
     for i in range(5):
-        name = "xgboost-{}".format(i)
-        arn = "arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{}".format(i)
+        name = f"xgboost-{i}"
+        arn = f"arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{i}"
         MyTrainingJobModel(training_job_name=name, role_arn=arn).save()
     for i in range(5):
-        name = "vgg-{}".format(i)
-        arn = "arn:aws:sagemaker:us-east-1:000000000000:x-x/barfoo-{}".format(i)
+        name = f"vgg-{i}"
+        arn = f"arn:aws:sagemaker:us-east-1:000000000000:x-x/barfoo-{i}"
         MyTrainingJobModel(training_job_name=name, role_arn=arn).save()
 
     vgg_training_job_1 = client.list_training_jobs(NameContains="vgg", MaxResults=1)
-    assert len(vgg_training_job_1["TrainingJobSummaries"]).should.equal(0)
-    assert vgg_training_job_1.get("NextToken").should_not.be.none
+    assert len(vgg_training_job_1["TrainingJobSummaries"]) == 0
+    assert vgg_training_job_1.get("NextToken") is not None
 
     vgg_training_job_6 = client.list_training_jobs(NameContains="vgg", MaxResults=6)
 
-    assert len(vgg_training_job_6["TrainingJobSummaries"]).should.equal(1)
-    assert vgg_training_job_6["TrainingJobSummaries"][0][
-        "TrainingJobName"
-    ].should.equal("vgg-0")
-    assert vgg_training_job_6.get("NextToken").should_not.be.none
+    assert len(vgg_training_job_6["TrainingJobSummaries"]) == 1
+    assert vgg_training_job_6["TrainingJobSummaries"][0]["TrainingJobName"] == "vgg-0"
+    assert vgg_training_job_6.get("NextToken") is not None
 
     vgg_training_job_10 = client.list_training_jobs(NameContains="vgg", MaxResults=10)
 
-    assert len(vgg_training_job_10["TrainingJobSummaries"]).should.equal(5)
-    assert vgg_training_job_10["TrainingJobSummaries"][-1][
-        "TrainingJobName"
-    ].should.equal("vgg-4")
-    assert vgg_training_job_10.get("NextToken").should.be.none
+    assert len(vgg_training_job_10["TrainingJobSummaries"]) == 5
+    assert vgg_training_job_10["TrainingJobSummaries"][-1]["TrainingJobName"] == "vgg-4"
+    assert vgg_training_job_10.get("NextToken") is None
 
 
 @mock_sagemaker
 def test_list_training_jobs_paginated_with_fragmented_targets():
     client = boto3.client("sagemaker", region_name="us-east-1")
     for i in range(5):
-        name = "xgboost-{}".format(i)
-        arn = "arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{}".format(i)
+        name = f"xgboost-{i}"
+        arn = f"arn:aws:sagemaker:us-east-1:000000000000:x-x/foobar-{i}"
         MyTrainingJobModel(training_job_name=name, role_arn=arn).save()
     for i in range(5):
-        name = "vgg-{}".format(i)
-        arn = "arn:aws:sagemaker:us-east-1:000000000000:x-x/barfoo-{}".format(i)
+        name = f"vgg-{i}"
+        arn = f"arn:aws:sagemaker:us-east-1:000000000000:x-x/barfoo-{i}"
         MyTrainingJobModel(training_job_name=name, role_arn=arn).save()
 
     training_jobs_with_2 = client.list_training_jobs(NameContains="2", MaxResults=8)
-    assert len(training_jobs_with_2["TrainingJobSummaries"]).should.equal(2)
-    assert training_jobs_with_2.get("NextToken").should_not.be.none
+    assert len(training_jobs_with_2["TrainingJobSummaries"]) == 2
+    assert training_jobs_with_2.get("NextToken") is not None
 
     training_jobs_with_2_next = client.list_training_jobs(
         NameContains="2", MaxResults=1, NextToken=training_jobs_with_2.get("NextToken")
     )
-    assert len(training_jobs_with_2_next["TrainingJobSummaries"]).should.equal(0)
-    assert training_jobs_with_2_next.get("NextToken").should_not.be.none
+    assert len(training_jobs_with_2_next["TrainingJobSummaries"]) == 0
+    assert training_jobs_with_2_next.get("NextToken") is not None
 
     training_jobs_with_2_next_next = client.list_training_jobs(
         NameContains="2",
         MaxResults=1,
         NextToken=training_jobs_with_2_next.get("NextToken"),
     )
-    assert len(training_jobs_with_2_next_next["TrainingJobSummaries"]).should.equal(0)
-    assert training_jobs_with_2_next_next.get("NextToken").should.be.none
+    assert len(training_jobs_with_2_next_next["TrainingJobSummaries"]) == 0
+    assert training_jobs_with_2_next_next.get("NextToken") is None
 
 
 @mock_sagemaker
@@ -449,7 +450,8 @@ def test_describe_unknown_training_job():
     with pytest.raises(ClientError) as exc:
         client.describe_training_job(TrainingJobName="unknown")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ValidationException")
-    err["Message"].should.equal(
-        f"Could not find training job 'arn:aws:sagemaker:us-east-1:{ACCOUNT_ID}:training-job/unknown'."
+    assert err["Code"] == "ValidationException"
+    assert err["Message"] == (
+        "Could not find training job 'arn:aws:sagemaker:us-east-1:"
+        f"{ACCOUNT_ID}:training-job/unknown'."
     )
