@@ -3,7 +3,7 @@ import uuid
 import boto3
 
 from moto import mock_sagemaker
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 TEST_REGION_NAME = "us-east-1"
 
