@@ -1,9 +1,10 @@
 """Unit tests for scheduler-supported APIs."""
+from datetime import datetime
+
 import boto3
 import pytest
-
 from botocore.client import ClientError
-from datetime import datetime
+
 from moto import mock_scheduler
 from moto.core import DEFAULT_ACCOUNT_ID
 
@@ -144,6 +145,26 @@ def test_update_schedule(extra_kwargs):
     assert schedule["CreationDate"] != schedule["LastModificationDate"]
 
 
+@mock_scheduler
+def test_create_duplicate_schedule():
+    client = boto3.client("scheduler", region_name="us-east-1")
+    params = {
+        "ScheduleExpression": "at(2022-12-12T00:00:00)",
+        "FlexibleTimeWindow": {
+            "MaximumWindowInMinutes": 4,
+            "Mode": "FLEXIBLE",
+        },
+        "Target": {"Arn": "arn1", "RoleArn": "arn2"},
+    }
+
+    client.create_schedule(Name="schedule1", **params)
+    with pytest.raises(ClientError) as exc:
+        client.create_schedule(Name="schedule1", **params)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ConflictException"
+    assert err["Message"] == "Schedule schedule1 already exists."
+
+
 @mock_scheduler
 def test_get_schedule_for_unknown_group():
     client = boto3.client("scheduler", region_name="eu-west-1")
@@ -154,6 +175,17 @@ def test_get_schedule_for_unknown_group():
     assert err["Code"] == "ResourceNotFoundException"
 
 
+@mock_scheduler
+def test_get_schedule_for_none_existing_schedule():
+    client = boto3.client("scheduler", region_name="eu-west-1")
+
+    with pytest.raises(ClientError) as exc:
+        client.get_schedule(Name="my-schedule")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "Schedule my-schedule does not exist."
+
+
 @mock_scheduler
 def test_list_schedules():
     client = boto3.client("scheduler", region_name="eu-west-1")
@@ -185,3 +217,14 @@ def test_list_schedules():
 
     schedules = client.list_schedules(State="ENABLED")["Schedules"]
     assert len(schedules) == 4
+
+
+@mock_scheduler
+def test_delete_schedule_for_none_existing_schedule():
+    client = boto3.client("scheduler", region_name="eu-west-1")
+
+    with pytest.raises(ClientError) as exc:
+        client.delete_schedule(Name="my-schedule")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "Schedule my-schedule does not exist."
