@@ -1,8 +1,7 @@
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_sdb
 
 
@@ -14,9 +13,9 @@ def test_create_domain_invalid(name):
     with pytest.raises(ClientError) as exc:
         sdb.create_domain(DomainName=name)
     err = exc.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterValue")
-    err["Message"].should.equal(f"Value ({name}) for parameter DomainName is invalid. ")
-    err.should.have.key("BoxUsage")
+    assert err["Code"] == "InvalidParameterValue"
+    assert err["Message"] == f"Value ({name}) for parameter DomainName is invalid. "
+    assert "BoxUsage" in err
 
 
 @mock_sdb
@@ -35,7 +34,7 @@ def test_create_domain_and_list():
     sdb.create_domain(DomainName="mydomain")
 
     all_domains = sdb.list_domains()["DomainNames"]
-    all_domains.should.equal(["mydomain"])
+    assert all_domains == ["mydomain"]
 
 
 @mock_sdb
@@ -45,7 +44,7 @@ def test_delete_domain():
     sdb.delete_domain(DomainName="mydomain")
 
     all_domains = sdb.list_domains()
-    all_domains.shouldnt.have.key("DomainNames")
+    assert "DomainNames" not in all_domains
 
 
 @mock_sdb
@@ -54,7 +53,7 @@ def test_delete_domain_unknown():
     sdb.delete_domain(DomainName="unknown")
 
     all_domains = sdb.list_domains()
-    all_domains.shouldnt.have.key("DomainNames")
+    assert "DomainNames" not in all_domains
 
 
 @mock_sdb
@@ -63,6 +62,6 @@ def test_delete_domain_invalid():
     with pytest.raises(ClientError) as exc:
         sdb.delete_domain(DomainName="a")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterValue")
-    err["Message"].should.equal("Value (a) for parameter DomainName is invalid. ")
-    err.should.have.key("BoxUsage")
+    assert err["Code"] == "InvalidParameterValue"
+    assert err["Message"] == "Value (a) for parameter DomainName is invalid. "
+    assert "BoxUsage" in err
