@@ -1,6 +1,4 @@
 """Test different server responses."""
-import sure  # noqa # pylint: disable=unused-import
-
 import moto.server as server
 from moto import mock_sdb
 
@@ -11,5 +9,5 @@ def test_sdb_list():
     test_client = backend.test_client()
 
     resp = test_client.post("/", data={"Action": "ListDomains"})
-    resp.status_code.should.equal(200)
-    str(resp.data).should.contain("ListDomainsResult")
+    assert resp.status_code == 200
+    assert "ListDomainsResult" in str(resp.data)
