@@ -1,21 +1,20 @@
 import os
+import re
+import string
+from datetime import datetime, timedelta, timezone
+from unittest import SkipTest
+from uuid import uuid4
 
 import boto3
-from dateutil.tz import tzlocal
-import re
-
-from moto import mock_secretsmanager, mock_lambda, settings
-from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-from botocore.exceptions import ClientError, ParamValidationError
-import string
-from freezegun import freeze_time
-from datetime import datetime, timedelta, timezone
-import sure  # noqa # pylint: disable=unused-import
-from uuid import uuid4
 import pytest
-from unittest import SkipTest
+from botocore.exceptions import ClientError, ParamValidationError
+from dateutil.tz import tzlocal
+from freezegun import freeze_time
 
-DEFAULT_SECRET_NAME = "test-secret"
+from moto import mock_lambda, mock_secretsmanager, settings
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+
+DEFAULT_SECRET_NAME = "test-secret7"
 
 
 @mock_secretsmanager
@@ -65,7 +64,9 @@ def test_get_secret_value_by_arn():
     secret_value = "test_get_secret_value_by_arn"
     result = conn.create_secret(Name=name, SecretString=secret_value)
     arn = result["ARN"]
-    arn.should.match(f"^arn:aws:secretsmanager:us-west-2:{ACCOUNT_ID}:secret:{name}")
+    assert re.match(
+        f"^arn:aws:secretsmanager:us-west-2:{ACCOUNT_ID}:secret:{name}", arn
+    )
 
     result = conn.get_secret_value(SecretId=arn)
     assert result["SecretString"] == secret_value
@@ -123,10 +124,10 @@ def test_get_secret_value_that_is_marked_deleted():
 def test_get_secret_that_has_no_value():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
 
-    conn.create_secret(Name="java-util-test-password")
+    conn.create_secret(Name="secret-no-value")
 
     with pytest.raises(ClientError) as cm:
-        conn.get_secret_value(SecretId="java-util-test-password")
+        conn.get_secret_value(SecretId="secret-no-value")
 
     assert (
         "Secrets Manager can't find the specified secret value for staging label: AWSCURRENT"
@@ -138,7 +139,7 @@ def test_get_secret_that_has_no_value():
 def test_get_secret_version_that_does_not_exist():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
 
-    result = conn.create_secret(Name="java-util-test-password")
+    result = conn.create_secret(Name="java-util-test-password", SecretString="v")
     secret_arn = result["ARN"]
     missing_version_id = "00000000-0000-0000-0000-000000000000"
 
@@ -146,8 +147,8 @@ def test_get_secret_version_that_does_not_exist():
         conn.get_secret_value(SecretId=secret_arn, VersionId=missing_version_id)
 
     assert (
-        "An error occurred (ResourceNotFoundException) when calling the GetSecretValue operation: Secrets "
-        "Manager can't find the specified secret value for VersionId: 00000000-0000-0000-0000-000000000000"
+        "Secrets Manager can't find the specified "
+        "secret value for VersionId: 00000000-0000-0000-0000-000000000000"
     ) == cm.value.response["Error"]["Message"]
 
 
@@ -249,6 +250,108 @@ def test_create_secret_with_tags_and_description():
     assert secret_details["Description"] == "desc"
 
 
+@mock_secretsmanager
+def test_create_secret_without_value():
+    conn = boto3.client("secretsmanager", region_name="us-east-2")
+    secret_name = f"secret-{str(uuid4())[0:6]}"
+
+    create = conn.create_secret(Name=secret_name)
+    assert set(create.keys()) == {"ARN", "Name", "ResponseMetadata"}
+
+    describe = conn.describe_secret(SecretId=secret_name)
+    assert set(describe.keys()) == {
+        "ARN",
+        "Name",
+        "LastChangedDate",
+        "CreatedDate",
+        "ResponseMetadata",
+    }
+
+    with pytest.raises(ClientError) as exc:
+        conn.get_secret_value(SecretId=secret_name)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+
+    updated = conn.update_secret(
+        SecretId=secret_name,
+        Description="new desc",
+    )
+    assert set(updated.keys()) == {"ARN", "Name", "ResponseMetadata"}
+
+    describe = conn.describe_secret(SecretId=secret_name)
+    assert set(describe.keys()) == {
+        "ARN",
+        "Name",
+        "Description",
+        "LastChangedDate",
+        "CreatedDate",
+        "ResponseMetadata",
+    }
+
+    deleted = conn.delete_secret(SecretId=secret_name)
+    assert set(deleted.keys()) == {"ARN", "Name", "DeletionDate", "ResponseMetadata"}
+
+
+@mock_secretsmanager
+def test_create_secret_that_has_no_value_and_then_update():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    conn.create_secret(Name="secret-no-value")
+
+    conn.update_secret(
+        SecretId="secret-no-value",
+        SecretString="barsecret",
+        Description="desc",
+    )
+
+    secret = conn.get_secret_value(SecretId="secret-no-value")
+    assert secret["SecretString"] == "barsecret"
+
+
+@mock_secretsmanager
+def test_update_secret_without_value():
+    conn = boto3.client("secretsmanager", region_name="us-east-2")
+    secret_name = f"secret-{str(uuid4())[0:6]}"
+
+    create = conn.create_secret(Name=secret_name, SecretString="foosecret")
+    assert set(create.keys()) == {"ARN", "Name", "VersionId", "ResponseMetadata"}
+    version_id = create["VersionId"]
+
+    describe1 = conn.describe_secret(SecretId=secret_name)
+    assert set(describe1.keys()) == {
+        "ARN",
+        "Name",
+        "LastChangedDate",
+        "VersionIdsToStages",
+        "CreatedDate",
+        "ResponseMetadata",
+    }
+
+    conn.get_secret_value(SecretId=secret_name)
+
+    updated = conn.update_secret(SecretId=secret_name, Description="desc")
+    assert set(updated.keys()) == {"ARN", "Name", "ResponseMetadata"}
+
+    describe2 = conn.describe_secret(SecretId=secret_name)
+    # AWS also includes 'LastAccessedDate'
+    assert set(describe2.keys()) == {
+        "ARN",
+        "Name",
+        "Description",
+        "LastChangedDate",
+        "VersionIdsToStages",
+        "CreatedDate",
+        "ResponseMetadata",
+    }
+    assert describe1["VersionIdsToStages"] == describe2["VersionIdsToStages"]
+
+    value = conn.get_secret_value(SecretId=secret_name)
+    assert value["SecretString"] == "foosecret"
+    assert value["VersionId"] == version_id
+
+    conn.delete_secret(SecretId=secret_name)
+
+
 @mock_secretsmanager
 def test_delete_secret():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -300,7 +403,7 @@ def test_delete_secret_force():
     assert result["Name"] == "test-secret"
 
     with pytest.raises(ClientError):
-        result = conn.get_secret_value(SecretId="test-secret")
+        conn.get_secret_value(SecretId="test-secret")
 
 
 @mock_secretsmanager
@@ -329,7 +432,7 @@ def test_delete_secret_force_with_arn():
     assert result["Name"] == "test-secret"
 
     with pytest.raises(ClientError):
-        result = conn.get_secret_value(SecretId="test-secret")
+        conn.get_secret_value(SecretId="test-secret")
 
 
 @mock_secretsmanager
@@ -559,9 +662,9 @@ def test_describe_secret_with_arn(name):
     secret_description = conn.describe_secret(SecretId=results["ARN"])
 
     assert secret_description  # Returned dict is not empty
-    secret_description["Name"].should.equal(name)
-    secret_description["ARN"].should.equal(results["ARN"])
-    conn.list_secrets()["SecretList"][0]["ARN"].should.equal(results["ARN"])
+    assert secret_description["Name"] == name
+    assert secret_description["ARN"] == results["ARN"]
+    assert conn.list_secrets()["SecretList"][0]["ARN"] == results["ARN"]
 
     # We can also supply a partial ARN
     partial_arn = f"arn:aws:secretsmanager:us-west-2:{ACCOUNT_ID}:secret:{name}"
@@ -581,8 +684,8 @@ def test_describe_secret_with_KmsKeyId():
 
     secret_description = conn.describe_secret(SecretId=results["ARN"])
 
-    secret_description["KmsKeyId"].should.equal("dummy_arn")
-    conn.list_secrets()["SecretList"][0]["KmsKeyId"].should.equal(
+    assert secret_description["KmsKeyId"] == "dummy_arn"
+    assert conn.list_secrets()["SecretList"][0]["KmsKeyId"] == (
         secret_description["KmsKeyId"]
     )
 
@@ -687,7 +790,7 @@ def test_cancel_rotate_secret():
     )
     func = lambda_conn.create_function(
         FunctionName="testFunction",
-        Runtime="python3.8",
+        Runtime="python3.11",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_rotation_zip_file()},
@@ -703,7 +806,7 @@ def test_cancel_rotate_secret():
     secrets_conn.rotate_secret(
         SecretId=DEFAULT_SECRET_NAME,
         RotationLambdaARN=func["FunctionArn"],
-        RotationRules=dict(AutomaticallyAfterDays=30),
+        RotationRules={"AutomaticallyAfterDays": 30},
     )
     secrets_conn.cancel_rotate_secret(SecretId=DEFAULT_SECRET_NAME)
     cancelled_rotation = secrets_conn.describe_secret(SecretId=DEFAULT_SECRET_NAME)
@@ -754,16 +857,17 @@ def test_rotate_secret():
 
 @mock_secretsmanager
 def test_rotate_secret_without_secretstring():
-    conn = boto3.client("secretsmanager", region_name="us-west-2")
+    # This test just verifies that Moto does not fail
+    conn = boto3.client("secretsmanager", region_name="us-east-2")
     conn.create_secret(Name=DEFAULT_SECRET_NAME, Description="foodescription")
 
+    # AWS will always require a Lambda ARN to do the actual rotating
     rotated_secret = conn.rotate_secret(SecretId=DEFAULT_SECRET_NAME)
-
-    assert rotated_secret
-    assert rotated_secret["ARN"] == rotated_secret["ARN"]
     assert rotated_secret["Name"] == DEFAULT_SECRET_NAME
-    assert rotated_secret["VersionId"] == rotated_secret["VersionId"]
 
+    # Without secret-value, and without actual rotating, we can't verify much
+    # Just that the secret exists/can be described
+    # We cannot verify any versions info (as that is not created without a secret-value)
     describe_secret = conn.describe_secret(SecretId=DEFAULT_SECRET_NAME)
     assert describe_secret["Description"] == "foodescription"
 
@@ -774,9 +878,7 @@ def test_rotate_secret_enable_rotation():
     conn.create_secret(Name=DEFAULT_SECRET_NAME, SecretString="foosecret")
 
     initial_description = conn.describe_secret(SecretId=DEFAULT_SECRET_NAME)
-    assert initial_description
-    assert initial_description["RotationEnabled"] is False
-    assert initial_description["RotationRules"]["AutomaticallyAfterDays"] == 0
+    assert "RotationEnabled" not in initial_description
 
     conn.rotate_secret(
         SecretId=DEFAULT_SECRET_NAME, RotationRules={"AutomaticallyAfterDays": 42}
@@ -831,7 +933,7 @@ def test_rotate_secret_client_request_token_too_long():
     conn.create_secret(Name=DEFAULT_SECRET_NAME, SecretString="foosecret")
 
     client_request_token = (
-        "ED9F8B6C-85B7-446A-B7E4-38F2A3BEB13C-" "ED9F8B6C-85B7-446A-B7E4-38F2A3BEB13C"
+        "ED9F8B6C-85B7-446A-B7E4-38F2A3BEB13C-ED9F8B6C-85B7-446A-B7E4-38F2A3BEB13C"
     )
     with pytest.raises(ClientError):
         conn.rotate_secret(
@@ -953,7 +1055,7 @@ if settings.TEST_SERVER_MODE:
         )
         func = lambda_conn.create_function(
             FunctionName="testFunction",
-            Runtime="python3.8",
+            Runtime="python3.11",
             Role=get_role_name(),
             Handler="lambda_function.lambda_handler",
             Code={"ZipFile": get_rotation_zip_file()},
@@ -976,7 +1078,7 @@ if settings.TEST_SERVER_MODE:
         rotated_secret = secrets_conn.rotate_secret(
             SecretId=DEFAULT_SECRET_NAME,
             RotationLambdaARN=func["FunctionArn"],
-            RotationRules=dict(AutomaticallyAfterDays=30),
+            RotationRules={"AutomaticallyAfterDays": 30},
         )
 
         # Ensure we received an updated VersionId from `rotate_secret`
@@ -1004,7 +1106,7 @@ def test_put_secret_value_on_non_existing_secret():
             VersionStages=["AWSCURRENT"],
         )
 
-    cm.value.response["Error"]["Message"].should.equal(
+    assert cm.value.response["Error"]["Message"] == (
         "Secrets Manager can't find the specified secret."
     )
 
@@ -1067,8 +1169,8 @@ def test_put_secret_binary_requires_either_string_or_binary():
     with pytest.raises(ClientError) as ire:
         conn.put_secret_value(SecretId=DEFAULT_SECRET_NAME)
 
-    ire.value.response["Error"]["Code"].should.equal("InvalidRequestException")
-    ire.value.response["Error"]["Message"].should.equal(
+    assert ire.value.response["Error"]["Code"] == "InvalidRequestException"
+    assert ire.value.response["Error"]["Message"] == (
         "You must provide either SecretString or SecretBinary."
     )
 
@@ -1449,7 +1551,7 @@ def test_update_secret_with_KmsKeyId():
     assert secret["SecretString"] == "foosecret"
 
     secret_details = conn.describe_secret(SecretId="test-secret")
-    secret_details["KmsKeyId"].should.equal("foo_arn")
+    assert secret_details["KmsKeyId"] == "foo_arn"
 
     updated_secret = conn.update_secret(
         SecretId="test-secret", SecretString="barsecret", KmsKeyId="bar_arn"
@@ -1464,7 +1566,7 @@ def test_update_secret_with_KmsKeyId():
     assert created_secret["VersionId"] != updated_secret["VersionId"]
 
     secret_details = conn.describe_secret(SecretId="test-secret")
-    secret_details["KmsKeyId"].should.equal("bar_arn")
+    assert secret_details["KmsKeyId"] == "bar_arn"
 
 
 @mock_secretsmanager
@@ -1628,7 +1730,7 @@ def test_update_secret_with_client_request_token():
             SecretString="fourth-secret",
             ClientRequestToken=invalid_request_token,
         )
-        pve.value.response["Error"]["Code"].should.equal("InvalidParameterException")
-        pve.value.response["Error"]["Message"].should.equal(
+        assert pve.value.response["Error"]["Code"] == "InvalidParameterException"
+        assert pve.value.response["Error"]["Message"] == (
             "ClientRequestToken must be 32-64 characters long."
         )
