@@ -1,9 +1,10 @@
 """Unit tests for servicediscovery-supported APIs."""
+import re
+
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_servicediscovery
 
 # See our Development Tips on writing tests for hints on how to write good tests:
@@ -15,7 +16,7 @@ def test_list_operations_initial():
     client = boto3.client("servicediscovery", region_name="eu-west-1")
     resp = client.list_operations()
 
-    resp.should.have.key("Operations").equals([])
+    assert resp["Operations"] == []
 
 
 @mock_servicediscovery
@@ -23,12 +24,12 @@ def test_list_operations():
     client = boto3.client("servicediscovery", region_name="eu-west-2")
 
     resp = client.create_http_namespace(Name="n/a")
-    resp.should.have.key("OperationId")
+    assert "OperationId" in resp
     op_id = resp["OperationId"]
 
     resp = client.list_operations()
-    resp.should.have.key("Operations").length_of(1)
-    resp["Operations"].should.equal([{"Id": op_id, "Status": "SUCCESS"}])
+    assert len(resp["Operations"]) == 1
+    assert resp["Operations"] == [{"Id": op_id, "Status": "SUCCESS"}]
 
 
 @mock_servicediscovery
@@ -36,26 +37,26 @@ def test_get_create_http_namespace_operation():
     client = boto3.client("servicediscovery", region_name="eu-west-1")
     resp = client.create_http_namespace(Name="mynamespace")
 
-    resp["OperationId"].should.match("[a-z0-9]{32}-[a-z0-9]{8}")
+    assert re.match("[a-z0-9]{32}-[a-z0-9]{8}", resp["OperationId"])
 
     operation_id = resp["OperationId"]
 
     resp = client.get_operation(OperationId=operation_id)
 
-    resp.should.have.key("Operation")
+    assert "Operation" in resp
     operation = resp["Operation"]
-    operation.should.have.key("Id").equals(operation_id)
-    operation.should.have.key("Type").equals("CREATE_NAMESPACE")
-    operation.should.have.key("Status").equals("SUCCESS")
-    operation.should.have.key("CreateDate")
-    operation.should.have.key("UpdateDate")
-    operation.should.have.key("Targets")
+    assert operation["Id"] == operation_id
+    assert operation["Type"] == "CREATE_NAMESPACE"
+    assert operation["Status"] == "SUCCESS"
+    assert "CreateDate" in operation
+    assert "UpdateDate" in operation
+    assert "Targets" in operation
 
     targets = operation["Targets"]
-    targets.should.have.key("NAMESPACE")
+    assert "NAMESPACE" in targets
 
     namespaces = client.list_namespaces()["Namespaces"]
-    [ns["Id"] for ns in namespaces].should.contain(targets["NAMESPACE"])
+    assert targets["NAMESPACE"] in [ns["Id"] for ns in namespaces]
 
 
 @mock_servicediscovery
@@ -63,20 +64,20 @@ def test_get_private_dns_namespace_operation():
     client = boto3.client("servicediscovery", region_name="eu-west-1")
     resp = client.create_private_dns_namespace(Name="dns_ns", Vpc="vpc_id")
 
-    resp["OperationId"].should.match("[a-z0-9]{32}-[a-z0-9]{8}")
+    assert re.match("[a-z0-9]{32}-[a-z0-9]{8}", resp["OperationId"])
 
     operation_id = resp["OperationId"]
 
     resp = client.get_operation(OperationId=operation_id)
 
-    resp.should.have.key("Operation")
+    assert "Operation" in resp
     operation = resp["Operation"]
-    operation.should.have.key("Id").equals(operation_id)
-    operation.should.have.key("Type").equals("CREATE_NAMESPACE")
-    operation.should.have.key("Status").equals("SUCCESS")
-    operation.should.have.key("CreateDate")
-    operation.should.have.key("UpdateDate")
-    operation.should.have.key("Targets")
+    assert operation["Id"] == operation_id
+    assert operation["Type"] == "CREATE_NAMESPACE"
+    assert operation["Status"] == "SUCCESS"
+    assert "CreateDate" in operation
+    assert "UpdateDate" in operation
+    assert "Targets" in operation
 
 
 @mock_servicediscovery
@@ -84,20 +85,20 @@ def test_get_public_dns_namespace_operation():
     client = boto3.client("servicediscovery", region_name="eu-west-1")
     resp = client.create_public_dns_namespace(Name="dns_ns")
 
-    resp["OperationId"].should.match("[a-z0-9]{32}-[a-z0-9]{8}")
+    assert re.match("[a-z0-9]{32}-[a-z0-9]{8}", resp["OperationId"])
 
     operation_id = resp["OperationId"]
 
     resp = client.get_operation(OperationId=operation_id)
 
-    resp.should.have.key("Operation")
+    assert "Operation" in resp
     operation = resp["Operation"]
-    operation.should.have.key("Id").equals(operation_id)
-    operation.should.have.key("Type").equals("CREATE_NAMESPACE")
-    operation.should.have.key("Status").equals("SUCCESS")
-    operation.should.have.key("CreateDate")
-    operation.should.have.key("UpdateDate")
-    operation.should.have.key("Targets")
+    assert operation["Id"] == operation_id
+    assert operation["Type"] == "CREATE_NAMESPACE"
+    assert operation["Status"] == "SUCCESS"
+    assert "CreateDate" in operation
+    assert "UpdateDate" in operation
+    assert "Targets" in operation
 
 
 @mock_servicediscovery
@@ -109,20 +110,20 @@ def test_get_update_service_operation():
 
     resp = client.update_service(Id=service_id, Service={"Description": "updated desc"})
 
-    resp["OperationId"].should.match("[a-z0-9]{32}-[a-z0-9]{8}")
+    assert re.match("[a-z0-9]{32}-[a-z0-9]{8}", resp["OperationId"])
 
     operation_id = resp["OperationId"]
 
     resp = client.get_operation(OperationId=operation_id)
 
-    resp.should.have.key("Operation")
+    assert "Operation" in resp
     operation = resp["Operation"]
-    operation.should.have.key("Id").equals(operation_id)
-    operation.should.have.key("Type").equals("UPDATE_SERVICE")
-    operation.should.have.key("Status").equals("SUCCESS")
-    operation.should.have.key("CreateDate")
-    operation.should.have.key("UpdateDate")
-    operation.should.have.key("Targets")
+    assert operation["Id"] == operation_id
+    assert operation["Type"] == "UPDATE_SERVICE"
+    assert operation["Status"] == "SUCCESS"
+    assert "CreateDate" in operation
+    assert "UpdateDate" in operation
+    assert "Targets" in operation
 
 
 @mock_servicediscovery
@@ -132,4 +133,4 @@ def test_get_unknown_operation():
     with pytest.raises(ClientError) as exc:
         client.get_operation(OperationId="unknown")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("OperationNotFound")
+    assert err["Code"] == "OperationNotFound"
