@@ -1,7 +1,6 @@
 """Unit tests for signer-supported APIs."""
 import boto3
 
-import sure  # noqa # pylint: disable=unused-import
 from moto import mock_signer
 
 # See our Development Tips on writing tests for hints on how to write good tests:
@@ -13,9 +12,8 @@ def test_list_signing_platforms():
     client = boto3.client("signer", region_name="us-east-2")
     resp = client.list_signing_platforms()
 
-    resp.should.have.key("platforms").should.have.length_of(4)
+    assert "platforms" in resp
+    assert len(resp["platforms"]) == 4
 
     partners = [x["partner"] for x in resp["platforms"]]
-    set(partners).should.equal(
-        {"AmazonFreeRTOS", "AWSLambda", "AWSIoTDeviceManagement"}
-    )
+    assert set(partners) == {"AmazonFreeRTOS", "AWSLambda", "AWSIoTDeviceManagement"}
