@@ -1,16 +1,14 @@
-import boto3
 import json
 
-import sure  # noqa # pylint: disable=unused-import
-
-from botocore.exceptions import ClientError
+import boto3
 import pytest
+from botocore.exceptions import ClientError
 
 from moto import mock_sns, mock_sqs
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.sns.models import (
-    DEFAULT_PAGE_SIZE,
     DEFAULT_EFFECTIVE_DELIVERY_POLICY,
+    DEFAULT_PAGE_SIZE,
 )
 
 
@@ -22,10 +20,10 @@ def test_subscribe_sms():
     arn = resp["TopicArn"]
 
     resp = client.subscribe(TopicArn=arn, Protocol="sms", Endpoint="+15551234567")
-    resp.should.have.key("SubscriptionArn")
+    assert "SubscriptionArn" in resp
 
     resp = client.subscribe(TopicArn=arn, Protocol="sms", Endpoint="+15/55-123.4567")
-    resp.should.have.key("SubscriptionArn")
+    assert "SubscriptionArn" in resp
 
 
 @mock_sns
@@ -42,7 +40,7 @@ def test_double_subscription():
         TopicArn=arn, Protocol="sqs", Endpoint="arn:aws:sqs:elasticmq:000000000000:foo"
     )
 
-    resp1["SubscriptionArn"].should.equal(resp2["SubscriptionArn"])
+    assert resp1["SubscriptionArn"] == resp2["SubscriptionArn"]
 
 
 @mock_sns
@@ -56,19 +54,29 @@ def test_subscribe_bad_sms():
         # Test invalid number
         client.subscribe(TopicArn=arn, Protocol="sms", Endpoint="NAA+15551234567")
     except ClientError as err:
-        err.response["Error"]["Code"].should.equal("InvalidParameter")
+        assert err.response["Error"]["Code"] == "InvalidParameter"
 
-    client.subscribe.when.called_with(
-        TopicArn=arn, Protocol="sms", Endpoint="+15--551234567"
-    ).should.throw(ClientError, "Invalid SMS endpoint: +15--551234567")
+    with pytest.raises(ClientError) as client_err:
+        client.subscribe(TopicArn=arn, Protocol="sms", Endpoint="+15--551234567")
+    assert (
+        client_err.value.response["Error"]["Message"]
+        == "Invalid SMS endpoint: +15--551234567"
+    )
 
-    client.subscribe.when.called_with(
-        TopicArn=arn, Protocol="sms", Endpoint="+15551234567."
-    ).should.throw(ClientError, "Invalid SMS endpoint: +15551234567.")
+    with pytest.raises(ClientError) as client_err:
+        client.subscribe(TopicArn=arn, Protocol="sms", Endpoint="+15551234567.")
+    assert (
+        client_err.value.response["Error"]["Message"]
+        == "Invalid SMS endpoint: +15551234567."
+    )
 
-    client.subscribe.when.called_with(
-        TopicArn=arn, Protocol="sms", Endpoint="/+15551234567"
-    ).should.throw(ClientError, "Invalid SMS endpoint: /+15551234567")
+    with pytest.raises(ClientError) as client_err:
+        assert client.subscribe(TopicArn=arn, Protocol="sms", Endpoint="/+15551234567")
+
+    assert (
+        client_err.value.response["Error"]["Message"]
+        == "Invalid SMS endpoint: /+15551234567"
+    )
 
 
 @mock_sns
@@ -81,19 +89,19 @@ def test_creating_subscription():
     conn.subscribe(TopicArn=topic_arn, Protocol="http", Endpoint="http://example.com/")
 
     subscriptions = conn.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(1)
+    assert len(subscriptions) == 1
     subscription = subscriptions[0]
-    subscription["TopicArn"].should.equal(topic_arn)
-    subscription["Protocol"].should.equal("http")
-    subscription["SubscriptionArn"].should.contain(topic_arn)
-    subscription["Endpoint"].should.equal("http://example.com/")
+    assert subscription["TopicArn"] == topic_arn
+    assert subscription["Protocol"] == "http"
+    assert topic_arn in subscription["SubscriptionArn"]
+    assert subscription["Endpoint"] == "http://example.com/"
 
     # Now unsubscribe the subscription
     conn.unsubscribe(SubscriptionArn=subscription["SubscriptionArn"])
 
     # And there should be zero subscriptions left
     subscriptions = conn.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(0)
+    assert len(subscriptions) == 0
 
 
 @mock_sns
@@ -108,13 +116,13 @@ def test_unsubscribe_from_deleted_topic():
     )
 
     subscriptions = client.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(1)
+    assert len(subscriptions) == 1
     subscription = subscriptions[0]
     subscription_arn = subscription["SubscriptionArn"]
-    subscription["TopicArn"].should.equal(topic_arn)
-    subscription["Protocol"].should.equal("http")
-    subscription_arn.should.contain(topic_arn)
-    subscription["Endpoint"].should.equal("http://example.com/")
+    assert subscription["TopicArn"] == topic_arn
+    assert subscription["Protocol"] == "http"
+    assert topic_arn in subscription_arn
+    assert subscription["Endpoint"] == "http://example.com/"
 
     # Now delete the topic
     client.delete_topic(TopicArn=topic_arn)
@@ -122,17 +130,17 @@ def test_unsubscribe_from_deleted_topic():
     # And there should now be 0 topics
     topics_json = client.list_topics()
     topics = topics_json["Topics"]
-    topics.should.have.length_of(0)
+    assert len(topics) == 0
 
     # as per the documentation deleting a topic deletes all the subscriptions
     subscriptions = client.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(0)
+    assert len(subscriptions) == 0
 
     # Now delete hanging subscription
     client.unsubscribe(SubscriptionArn=subscription_arn)
 
     subscriptions = client.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(0)
+    assert len(subscriptions) == 0
 
     # Deleting it again should not result in any error
     client.unsubscribe(SubscriptionArn=subscription_arn)
@@ -159,8 +167,8 @@ def test_getting_subscriptions_by_topic():
     topic1_subscriptions = conn.list_subscriptions_by_topic(TopicArn=topic1_arn)[
         "Subscriptions"
     ]
-    topic1_subscriptions.should.have.length_of(1)
-    topic1_subscriptions[0]["Endpoint"].should.equal("http://example1.com/")
+    assert len(topic1_subscriptions) == 1
+    assert topic1_subscriptions[0]["Endpoint"] == "http://example1.com/"
 
 
 @mock_sns
@@ -180,26 +188,24 @@ def test_subscription_paging():
         )
 
     all_subscriptions = conn.list_subscriptions()
-    all_subscriptions["Subscriptions"].should.have.length_of(DEFAULT_PAGE_SIZE)
+    assert len(all_subscriptions["Subscriptions"]) == DEFAULT_PAGE_SIZE
     next_token = all_subscriptions["NextToken"]
-    next_token.should.equal(str(DEFAULT_PAGE_SIZE))
+    assert next_token == str(DEFAULT_PAGE_SIZE)
 
     all_subscriptions = conn.list_subscriptions(NextToken=next_token)
-    all_subscriptions["Subscriptions"].should.have.length_of(int(DEFAULT_PAGE_SIZE / 3))
-    all_subscriptions.shouldnt.have("NextToken")
+    assert len(all_subscriptions["Subscriptions"]) == int(DEFAULT_PAGE_SIZE / 3)
+    assert "NextToken" not in all_subscriptions
 
     topic1_subscriptions = conn.list_subscriptions_by_topic(TopicArn=topic1_arn)
-    topic1_subscriptions["Subscriptions"].should.have.length_of(DEFAULT_PAGE_SIZE)
+    assert len(topic1_subscriptions["Subscriptions"]) == DEFAULT_PAGE_SIZE
     next_token = topic1_subscriptions["NextToken"]
-    next_token.should.equal(str(DEFAULT_PAGE_SIZE))
+    assert next_token == str(DEFAULT_PAGE_SIZE)
 
     topic1_subscriptions = conn.list_subscriptions_by_topic(
         TopicArn=topic1_arn, NextToken=next_token
     )
-    topic1_subscriptions["Subscriptions"].should.have.length_of(
-        int(DEFAULT_PAGE_SIZE / 3)
-    )
-    topic1_subscriptions.shouldnt.have("NextToken")
+    assert len(topic1_subscriptions["Subscriptions"]) == int(DEFAULT_PAGE_SIZE / 3)
+    assert "NextToken" not in topic1_subscriptions
 
 
 @mock_sns
@@ -215,17 +221,17 @@ def test_subscribe_attributes():
         SubscriptionArn=resp["SubscriptionArn"]
     )
 
-    response.should.contain("Attributes")
+    assert "Attributes" in response
     attributes = response["Attributes"]
-    attributes["PendingConfirmation"].should.equal("false")
-    attributes["ConfirmationWasAuthenticated"].should.equal("true")
-    attributes["Endpoint"].should.equal("http://test.com")
-    attributes["TopicArn"].should.equal(arn)
-    attributes["Protocol"].should.equal("http")
-    attributes["SubscriptionArn"].should.equal(resp["SubscriptionArn"])
-    attributes["Owner"].should.equal(str(ACCOUNT_ID))
-    attributes["RawMessageDelivery"].should.equal("false")
-    json.loads(attributes["EffectiveDeliveryPolicy"]).should.equal(
+    assert attributes["PendingConfirmation"] == "false"
+    assert attributes["ConfirmationWasAuthenticated"] == "true"
+    assert attributes["Endpoint"] == "http://test.com"
+    assert attributes["TopicArn"] == arn
+    assert attributes["Protocol"] == "http"
+    assert attributes["SubscriptionArn"] == resp["SubscriptionArn"]
+    assert attributes["Owner"] == str(ACCOUNT_ID)
+    assert attributes["RawMessageDelivery"] == "false"
+    assert json.loads(attributes["EffectiveDeliveryPolicy"]) == (
         DEFAULT_EFFECTIVE_DELIVERY_POLICY
     )
 
@@ -272,28 +278,28 @@ def test_creating_subscription_with_attributes():
     )
 
     subscriptions = conn.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(1)
+    assert len(subscriptions) == 1
     subscription = subscriptions[0]
-    subscription["TopicArn"].should.equal(topic_arn)
-    subscription["Protocol"].should.equal("http")
-    subscription["SubscriptionArn"].should.contain(topic_arn)
-    subscription["Endpoint"].should.equal("http://example.com/")
+    assert subscription["TopicArn"] == topic_arn
+    assert subscription["Protocol"] == "http"
+    assert topic_arn in subscription["SubscriptionArn"]
+    assert subscription["Endpoint"] == "http://example.com/"
 
     # Test the subscription attributes have been set
     subscription_arn = subscription["SubscriptionArn"]
     attrs = conn.get_subscription_attributes(SubscriptionArn=subscription_arn)
 
-    attrs["Attributes"]["RawMessageDelivery"].should.equal("true")
-    attrs["Attributes"]["DeliveryPolicy"].should.equal(delivery_policy)
-    attrs["Attributes"]["FilterPolicy"].should.equal(filter_policy)
-    attrs["Attributes"]["SubscriptionRoleArn"].should.equal(subscription_role_arn)
+    assert attrs["Attributes"]["RawMessageDelivery"] == "true"
+    assert attrs["Attributes"]["DeliveryPolicy"] == delivery_policy
+    assert attrs["Attributes"]["FilterPolicy"] == filter_policy
+    assert attrs["Attributes"]["SubscriptionRoleArn"] == subscription_role_arn
 
     # Now unsubscribe the subscription
     conn.unsubscribe(SubscriptionArn=subscription["SubscriptionArn"])
 
     # And there should be zero subscriptions left
     subscriptions = conn.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(0)
+    assert len(subscriptions) == 0
 
     # invalid attr name
     with pytest.raises(ClientError):
@@ -319,12 +325,12 @@ def test_delete_subscriptions_on_delete_topic():
     )
     subscriptions = conn.list_subscriptions()["Subscriptions"]
 
-    subscriptions.should.have.length_of(1)
+    assert len(subscriptions) == 1
 
     conn.delete_topic(TopicArn=topic.get("TopicArn"))
 
     subscriptions = conn.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(0)
+    assert len(subscriptions) == 0
 
 
 @mock_sns
@@ -337,16 +343,16 @@ def test_set_subscription_attributes():
     conn.subscribe(TopicArn=topic_arn, Protocol="http", Endpoint="http://example.com/")
 
     subscriptions = conn.list_subscriptions()["Subscriptions"]
-    subscriptions.should.have.length_of(1)
+    assert len(subscriptions) == 1
     subscription = subscriptions[0]
-    subscription["TopicArn"].should.equal(topic_arn)
-    subscription["Protocol"].should.equal("http")
-    subscription["SubscriptionArn"].should.contain(topic_arn)
-    subscription["Endpoint"].should.equal("http://example.com/")
+    assert subscription["TopicArn"] == topic_arn
+    assert subscription["Protocol"] == "http"
+    assert topic_arn in subscription["SubscriptionArn"]
+    assert subscription["Endpoint"] == "http://example.com/"
 
     subscription_arn = subscription["SubscriptionArn"]
     attrs = conn.get_subscription_attributes(SubscriptionArn=subscription_arn)
-    attrs.should.have.key("Attributes")
+    assert "Attributes" in attrs
     conn.set_subscription_attributes(
         SubscriptionArn=subscription_arn,
         AttributeName="RawMessageDelivery",
@@ -384,9 +390,10 @@ def test_set_subscription_attributes():
 
     attrs = conn.get_subscription_attributes(SubscriptionArn=subscription_arn)
 
-    attrs["Attributes"]["RawMessageDelivery"].should.equal("true")
-    attrs["Attributes"]["DeliveryPolicy"].should.equal(delivery_policy)
-    attrs["Attributes"]["FilterPolicy"].should.equal(filter_policy)
+    assert attrs["Attributes"]["RawMessageDelivery"] == "true"
+    assert attrs["Attributes"]["DeliveryPolicy"] == delivery_policy
+    assert attrs["Attributes"]["FilterPolicy"] == filter_policy
+    assert attrs["Attributes"]["FilterPolicyScope"] == "MessageAttributes"
 
     filter_policy_scope = "MessageBody"
     conn.set_subscription_attributes(
@@ -397,7 +404,18 @@ def test_set_subscription_attributes():
 
     attrs = conn.get_subscription_attributes(SubscriptionArn=subscription_arn)
 
-    attrs["Attributes"]["FilterPolicyScope"].should.equal(filter_policy_scope)
+    assert attrs["Attributes"]["FilterPolicyScope"] == filter_policy_scope
+
+    # test unsetting a filter policy
+    conn.set_subscription_attributes(
+        SubscriptionArn=subscription_arn,
+        AttributeName="FilterPolicy",
+        AttributeValue="",
+    )
+
+    attrs = conn.get_subscription_attributes(SubscriptionArn=subscription_arn)
+    assert "FilterPolicy" not in attrs["Attributes"]
+    assert "FilterPolicyScope" not in attrs["Attributes"]
 
     # not existing subscription
     with pytest.raises(ClientError):
@@ -407,7 +425,7 @@ def test_set_subscription_attributes():
             AttributeValue="true",
         )
     with pytest.raises(ClientError):
-        attrs = conn.get_subscription_attributes(SubscriptionArn="invalid")
+        conn.get_subscription_attributes(SubscriptionArn="invalid")
 
     # invalid attr name
     with pytest.raises(ClientError):
@@ -436,8 +454,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: FilterPolicy: Filter policy is too complex"
     )
 
@@ -450,8 +468,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: FilterPolicy: Match value must be String, number, true, false, or null"
     )
 
@@ -464,8 +482,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: FilterPolicy: exists match pattern must be either true or false."
     )
 
@@ -478,8 +496,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: FilterPolicy: Unrecognized match type error"
     )
 
@@ -492,7 +510,7 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InternalFailure")
+    assert err.response["Error"]["Code"] == "InternalFailure"
 
     with pytest.raises(ClientError) as err_info:
         conn.subscribe(
@@ -505,8 +523,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: Attributes Reason: FilterPolicy: Value of < must be numeric\n at ..."
     )
 
@@ -523,8 +541,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: Attributes Reason: FilterPolicy: Value of <= must be numeric\n at ..."
     )
 
@@ -537,9 +555,10 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
-        "Invalid parameter: Attributes Reason: FilterPolicy: Invalid member in numeric match: ]\n at ..."
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
+        "Invalid parameter: Attributes Reason: FilterPolicy: "
+        "Invalid member in numeric match: ]\n at ..."
     )
 
     with pytest.raises(ClientError) as err_info:
@@ -553,9 +572,10 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
-        "Invalid parameter: Attributes Reason: FilterPolicy: Invalid member in numeric match: 50\n at ..."
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
+        "Invalid parameter: Attributes Reason: FilterPolicy: Invalid "
+        "member in numeric match: 50\n at ..."
     )
 
     with pytest.raises(ClientError) as err_info:
@@ -567,8 +587,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: Attributes Reason: FilterPolicy: Value of < must be numeric\n at ..."
     )
 
@@ -581,9 +601,10 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
-        "Invalid parameter: Attributes Reason: FilterPolicy: Unrecognized numeric range operator: 0\n at ..."
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
+        "Invalid parameter: Attributes Reason: FilterPolicy: "
+        "Unrecognized numeric range operator: 0\n at ..."
     )
 
     with pytest.raises(ClientError) as err_info:
@@ -597,9 +618,10 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
-        "Invalid parameter: Attributes Reason: FilterPolicy: Too many elements in numeric expression\n at ..."
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
+        "Invalid parameter: Attributes Reason: FilterPolicy: Too many "
+        "elements in numeric expression\n at ..."
     )
 
     with pytest.raises(ClientError) as err_info:
@@ -613,8 +635,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: Attributes Reason: FilterPolicy: Bad numeric range operator: >\n at ..."
     )
 
@@ -629,8 +651,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: Attributes Reason: FilterPolicy: Bottom must be less than top\n at ..."
     )
 
@@ -645,8 +667,8 @@ def test_subscribe_invalid_filter_policy():
         )
 
     err = err_info.value
-    err.response["Error"]["Code"].should.equal("InvalidParameter")
-    err.response["Error"]["Message"].should.equal(
+    assert err.response["Error"]["Code"] == "InvalidParameter"
+    assert err.response["Error"]["Message"] == (
         "Invalid parameter: Attributes Reason: FilterPolicy: Value of < must be numeric\n at ..."
     )
 
@@ -660,9 +682,10 @@ def test_subscribe_invalid_filter_policy():
             },
         )
     except ClientError as err:
-        err.response["Error"]["Code"].should.equal("InvalidParameter")
-        err.response["Error"]["Message"].should.equal(
-            "Invalid parameter: Filter policy scope MessageAttributes does not support nested filter policy"
+        assert err.response["Error"]["Code"] == "InvalidParameter"
+        assert err.response["Error"]["Message"] == (
+            "Invalid parameter: Filter policy scope MessageAttributes does "
+            "not support nested filter policy"
         )
 
     try:
@@ -681,8 +704,8 @@ def test_subscribe_invalid_filter_policy():
             Attributes={"FilterPolicy": json.dumps(filter_policy)},
         )
     except ClientError as err:
-        err.response["Error"]["Code"].should.equal("InvalidParameter")
-        err.response["Error"]["Message"].should.equal(
+        assert err.response["Error"]["Code"] == "InvalidParameter"
+        assert err.response["Error"]["Message"] == (
             "Invalid parameter: FilterPolicy: Filter policy can not have more than 5 keys"
         )
 
@@ -696,8 +719,9 @@ def test_subscribe_invalid_filter_policy():
             "key_d": {"key_e": ["value_one", "value_two", "value_three"]},
             "key_f": ["value_one", "value_two", "value_three"],
         }
-        # The first array has four values in a three-level nested key, and the second has three values in a two-level
-        # nested key. The total combination is calculated as follows:
+        # The first array has four values in a three-level nested key,
+        # and the second has three values in a two-level nested key. The
+        # total combination is calculated as follows:
         # 3 x 4 x 2 x 3 x 1 x 3 = 216
         conn.subscribe(
             TopicArn=topic_arn,
@@ -709,8 +733,8 @@ def test_subscribe_invalid_filter_policy():
             },
         )
     except ClientError as err:
-        err.response["Error"]["Code"].should.equal("InvalidParameter")
-        err.response["Error"]["Message"].should.equal(
+        assert err.response["Error"]["Code"] == "InvalidParameter"
+        assert err.response["Error"]["Message"] == (
             "Invalid parameter: FilterPolicy: Filter policy is too complex"
         )
 
@@ -720,8 +744,8 @@ def test_check_not_opted_out():
     conn = boto3.client("sns", region_name="us-east-1")
     response = conn.check_if_phone_number_is_opted_out(phoneNumber="+447428545375")
 
-    response.should.contain("isOptedOut")
-    response["isOptedOut"].should.be(False)
+    assert "isOptedOut" in response
+    assert response["isOptedOut"] is False
 
 
 @mock_sns
@@ -731,8 +755,8 @@ def test_check_opted_out():
     conn = boto3.client("sns", region_name="us-east-1")
     response = conn.check_if_phone_number_is_opted_out(phoneNumber="+447428545399")
 
-    response.should.contain("isOptedOut")
-    response["isOptedOut"].should.be(True)
+    assert "isOptedOut" in response
+    assert response["isOptedOut"] is True
 
 
 @mock_sns
@@ -749,8 +773,8 @@ def test_list_opted_out():
     conn = boto3.client("sns", region_name="us-east-1")
     response = conn.list_phone_numbers_opted_out()
 
-    response.should.contain("phoneNumbers")
-    len(response["phoneNumbers"]).should.be.greater_than(0)
+    assert "phoneNumbers" in response
+    assert len(response["phoneNumbers"]) > 0
 
 
 @mock_sns
@@ -763,8 +787,8 @@ def test_opt_in():
     conn.opt_in_phone_number(phoneNumber=response["phoneNumbers"][0])
 
     response = conn.list_phone_numbers_opted_out()
-    len(response["phoneNumbers"]).should.be.greater_than(0)
-    len(response["phoneNumbers"]).should.be.lower_than(current_len)
+    assert len(response["phoneNumbers"]) > 0
+    assert len(response["phoneNumbers"]) < current_len
 
 
 @mock_sns
@@ -774,7 +798,12 @@ def test_confirm_subscription():
 
     conn.confirm_subscription(
         TopicArn=response["TopicArn"],
-        Token="2336412f37fb687f5d51e6e241d59b68c4e583a5cee0be6f95bbf97ab8d2441cf47b99e848408adaadf4c197e65f03473d53c4ba398f6abbf38ce2e8ebf7b4ceceb2cd817959bcde1357e58a2861b05288c535822eb88cac3db04f592285249971efc6484194fc4a4586147f16916692",
+        Token=(
+            "2336412f37fb687f5d51e6e241d59b68c4e583a5cee0be6f95bbf97ab8d"
+            "2441cf47b99e848408adaadf4c197e65f03473d53c4ba398f6abbf38ce2"
+            "e8ebf7b4ceceb2cd817959bcde1357e58a2861b05288c535822eb88cac3"
+            "db04f592285249971efc6484194fc4a4586147f16916692"
+        ),
         AuthenticateOnUnsubscribe="true",
     )
 
@@ -783,15 +812,18 @@ def test_confirm_subscription():
 def test_get_subscription_attributes_error_not_exists():
     # given
     client = boto3.client("sns", region_name="us-east-1")
-    sub_arn = f"arn:aws:sqs:us-east-1:{ACCOUNT_ID}:test-queue:66d97e76-31e5-444f-8fa7-b60b680d0d39"
+    sub_arn = (
+        f"arn:aws:sqs:us-east-1:{ACCOUNT_ID}:test-queue"
+        ":66d97e76-31e5-444f-8fa7-b60b680d0d39"
+    )
 
     # when
-    with pytest.raises(ClientError) as e:
+    with pytest.raises(ClientError) as exc:
         client.get_subscription_attributes(SubscriptionArn=sub_arn)
 
     # then
-    ex = e.value
-    ex.operation_name.should.equal("GetSubscriptionAttributes")
-    ex.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(404)
-    ex.response["Error"]["Code"].should.contain("NotFound")
-    ex.response["Error"]["Message"].should.equal("Subscription does not exist")
+    exc_value = exc.value
+    assert exc_value.operation_name == "GetSubscriptionAttributes"
+    assert exc_value.response["ResponseMetadata"]["HTTPStatusCode"] == 404
+    assert "NotFound" in exc_value.response["Error"]["Code"]
+    assert exc_value.response["Error"]["Message"] == "Subscription does not exist"
