@@ -1,13 +1,12 @@
-import boto3
 import json
+
+import boto3
 import pytest
-
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_sns
-from moto.sns.models import DEFAULT_EFFECTIVE_DELIVERY_POLICY, DEFAULT_PAGE_SIZE
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from moto.sns.models import DEFAULT_EFFECTIVE_DELIVERY_POLICY, DEFAULT_PAGE_SIZE
 
 
 @mock_sns
@@ -18,8 +17,8 @@ def test_create_and_delete_topic():
 
         topics_json = conn.list_topics()
         topics = topics_json["Topics"]
-        topics.should.have.length_of(1)
-        topics[0]["TopicArn"].should.equal(
+        assert len(topics) == 1
+        assert topics[0]["TopicArn"] == (
             f"arn:aws:sns:{conn._client_config.region_name}:{ACCOUNT_ID}:{topic_name}"
         )
 
@@ -32,7 +31,7 @@ def test_create_and_delete_topic():
         # And there should now be 0 topics
         topics_json = conn.list_topics()
         topics = topics_json["Topics"]
-        topics.should.have.length_of(0)
+        assert len(topics) == 0
 
 
 @mock_sns
@@ -55,7 +54,7 @@ def test_create_topic_with_attributes():
     topic_arn = topics_json["Topics"][0]["TopicArn"]
 
     attributes = conn.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
-    attributes["DisplayName"].should.equal("test-topic")
+    assert attributes["DisplayName"] == "test-topic"
 
 
 @mock_sns
@@ -70,7 +69,7 @@ def test_create_topic_with_tags():
     )
     topic_arn = response["TopicArn"]
 
-    conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"].should.equal(
+    assert conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"] == (
         [
             {"Key": "tag_key_1", "Value": "tag_value_1"},
             {"Key": "tag_key_2", "Value": "tag_value_2"},
@@ -88,22 +87,23 @@ def test_create_topic_should_be_indempodent():
     topic_display_name = conn.get_topic_attributes(TopicArn=topic_arn)["Attributes"][
         "DisplayName"
     ]
-    topic_display_name.should.be.equal("should_be_set")
+    assert topic_display_name == "should_be_set"
 
     # recreate topic to prove indempodentcy
     topic_arn = conn.create_topic(Name="some-topic")["TopicArn"]
     topic_display_name = conn.get_topic_attributes(TopicArn=topic_arn)["Attributes"][
         "DisplayName"
     ]
-    topic_display_name.should.be.equal("should_be_set")
+    assert topic_display_name == "should_be_set"
 
 
 @mock_sns
 def test_get_missing_topic():
     conn = boto3.client("sns", region_name="us-east-1")
-    conn.get_topic_attributes.when.called_with(
-        TopicArn="arn:aws:sns:us-east-1:424242424242:a-fake-arn"
-    ).should.throw(ClientError)
+    with pytest.raises(ClientError):
+        conn.get_topic_attributes(
+            TopicArn="arn:aws:sns:us-east-1:424242424242:a-fake-arn"
+        )
 
 
 @mock_sns
@@ -111,21 +111,21 @@ def test_create_topic_must_meet_constraints():
     conn = boto3.client("sns", region_name="us-east-1")
     common_random_chars = [":", ";", "!", "@", "|", "^", "%"]
     for char in common_random_chars:
-        conn.create_topic.when.called_with(Name=f"no{char}_invalidchar").should.throw(
-            ClientError
-        )
-    conn.create_topic.when.called_with(Name="no spaces allowed").should.throw(
-        ClientError
-    )
+        with pytest.raises(ClientError):
+            conn.create_topic(Name=f"no{char}_invalidchar")
+    with pytest.raises(ClientError):
+        conn.create_topic(Name="no spaces allowed")
 
 
 @mock_sns
 def test_create_topic_should_be_of_certain_length():
     conn = boto3.client("sns", region_name="us-east-1")
     too_short = ""
-    conn.create_topic.when.called_with(Name=too_short).should.throw(ClientError)
+    with pytest.raises(ClientError):
+        conn.create_topic(Name=too_short)
     too_long = "x" * 257
-    conn.create_topic.when.called_with(Name=too_long).should.throw(ClientError)
+    with pytest.raises(ClientError):
+        conn.create_topic(Name=too_long)
 
 
 @mock_sns
@@ -134,7 +134,7 @@ def test_create_topic_in_multiple_regions():
         conn = boto3.client("sns", region_name=region)
         topic_arn = conn.create_topic(Name="some-topic")["TopicArn"]
         # We can find the topic
-        list(conn.list_topics()["Topics"]).should.have.length_of(1)
+        assert len(list(conn.list_topics()["Topics"])) == 1
 
         # We can read the Topic details
         topic = boto3.resource("sns", region_name=region).Topic(topic_arn)
@@ -158,7 +158,7 @@ def test_topic_corresponds_to_region():
         conn.create_topic(Name="some-topic")
         topics_json = conn.list_topics()
         topic_arn = topics_json["Topics"][0]["TopicArn"]
-        topic_arn.should.equal(f"arn:aws:sns:{region}:{ACCOUNT_ID}:some-topic")
+        assert topic_arn == f"arn:aws:sns:{region}:{ACCOUNT_ID}:some-topic"
 
 
 @mock_sns
@@ -170,42 +170,40 @@ def test_topic_attributes():
     topic_arn = topics_json["Topics"][0]["TopicArn"]
 
     attributes = conn.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
-    attributes["TopicArn"].should.equal(
+    assert attributes["TopicArn"] == (
         f"arn:aws:sns:{conn._client_config.region_name}:{ACCOUNT_ID}:some-topic"
     )
-    attributes["Owner"].should.equal(ACCOUNT_ID)
-    json.loads(attributes["Policy"]).should.equal(
-        {
-            "Version": "2008-10-17",
-            "Id": "__default_policy_ID",
-            "Statement": [
-                {
-                    "Effect": "Allow",
-                    "Sid": "__default_statement_ID",
-                    "Principal": {"AWS": "*"},
-                    "Action": [
-                        "SNS:GetTopicAttributes",
-                        "SNS:SetTopicAttributes",
-                        "SNS:AddPermission",
-                        "SNS:RemovePermission",
-                        "SNS:DeleteTopic",
-                        "SNS:Subscribe",
-                        "SNS:ListSubscriptionsByTopic",
-                        "SNS:Publish",
-                        "SNS:Receive",
-                    ],
-                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:some-topic",
-                    "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
-                }
-            ],
-        }
-    )
-    attributes["DisplayName"].should.equal("")
-    attributes["SubscriptionsPending"].should.equal("0")
-    attributes["SubscriptionsConfirmed"].should.equal("0")
-    attributes["SubscriptionsDeleted"].should.equal("0")
-    attributes["DeliveryPolicy"].should.equal("")
-    json.loads(attributes["EffectiveDeliveryPolicy"]).should.equal(
+    assert attributes["Owner"] == ACCOUNT_ID
+    assert json.loads(attributes["Policy"]) == {
+        "Version": "2008-10-17",
+        "Id": "__default_policy_ID",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Sid": "__default_statement_ID",
+                "Principal": {"AWS": "*"},
+                "Action": [
+                    "SNS:GetTopicAttributes",
+                    "SNS:SetTopicAttributes",
+                    "SNS:AddPermission",
+                    "SNS:RemovePermission",
+                    "SNS:DeleteTopic",
+                    "SNS:Subscribe",
+                    "SNS:ListSubscriptionsByTopic",
+                    "SNS:Publish",
+                    "SNS:Receive",
+                ],
+                "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:some-topic",
+                "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
+            }
+        ],
+    }
+    assert attributes["DisplayName"] == ""
+    assert attributes["SubscriptionsPending"] == "0"
+    assert attributes["SubscriptionsConfirmed"] == "0"
+    assert attributes["SubscriptionsDeleted"] == "0"
+    assert attributes["DeliveryPolicy"] == ""
+    assert json.loads(attributes["EffectiveDeliveryPolicy"]) == (
         DEFAULT_EFFECTIVE_DELIVERY_POLICY
     )
 
@@ -226,9 +224,9 @@ def test_topic_attributes():
     )
 
     attributes = conn.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
-    attributes["Policy"].should.equal('{"foo":"bar"}')
-    attributes["DisplayName"].should.equal("My display name")
-    attributes["DeliveryPolicy"].should.equal(
+    assert attributes["Policy"] == '{"foo":"bar"}'
+    assert attributes["DisplayName"] == "My display name"
+    assert attributes["DeliveryPolicy"] == (
         '{"http": {"defaultHealthyRetryPolicy": {"numRetries": 5}}}'
     )
 
@@ -243,14 +241,14 @@ def test_topic_paging():
     topics_list = response["Topics"]
     next_token = response["NextToken"]
 
-    len(topics_list).should.equal(DEFAULT_PAGE_SIZE)
-    int(next_token).should.equal(DEFAULT_PAGE_SIZE)
+    assert len(topics_list) == DEFAULT_PAGE_SIZE
+    assert int(next_token) == DEFAULT_PAGE_SIZE
 
     response = conn.list_topics(NextToken=next_token)
     topics_list = response["Topics"]
-    response.shouldnt.have("NextToken")
+    assert "NextToken" not in response
 
-    topics_list.should.have.length_of(int(DEFAULT_PAGE_SIZE / 2))
+    assert len(topics_list) == int(DEFAULT_PAGE_SIZE / 2)
 
 
 @mock_sns
@@ -266,69 +264,65 @@ def test_add_remove_permissions():
     )
 
     response = client.get_topic_attributes(TopicArn=topic_arn)
-    json.loads(response["Attributes"]["Policy"]).should.equal(
-        {
-            "Version": "2008-10-17",
-            "Id": "__default_policy_ID",
-            "Statement": [
-                {
-                    "Effect": "Allow",
-                    "Sid": "__default_statement_ID",
-                    "Principal": {"AWS": "*"},
-                    "Action": [
-                        "SNS:GetTopicAttributes",
-                        "SNS:SetTopicAttributes",
-                        "SNS:AddPermission",
-                        "SNS:RemovePermission",
-                        "SNS:DeleteTopic",
-                        "SNS:Subscribe",
-                        "SNS:ListSubscriptionsByTopic",
-                        "SNS:Publish",
-                        "SNS:Receive",
-                    ],
-                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
-                    "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
-                },
-                {
-                    "Sid": "test",
-                    "Effect": "Allow",
-                    "Principal": {"AWS": "arn:aws:iam::999999999999:root"},
-                    "Action": "SNS:Publish",
-                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
-                },
-            ],
-        }
-    )
+    assert json.loads(response["Attributes"]["Policy"]) == {
+        "Version": "2008-10-17",
+        "Id": "__default_policy_ID",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Sid": "__default_statement_ID",
+                "Principal": {"AWS": "*"},
+                "Action": [
+                    "SNS:GetTopicAttributes",
+                    "SNS:SetTopicAttributes",
+                    "SNS:AddPermission",
+                    "SNS:RemovePermission",
+                    "SNS:DeleteTopic",
+                    "SNS:Subscribe",
+                    "SNS:ListSubscriptionsByTopic",
+                    "SNS:Publish",
+                    "SNS:Receive",
+                ],
+                "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
+                "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
+            },
+            {
+                "Sid": "test",
+                "Effect": "Allow",
+                "Principal": {"AWS": "arn:aws:iam::999999999999:root"},
+                "Action": "SNS:Publish",
+                "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
+            },
+        ],
+    }
 
     client.remove_permission(TopicArn=topic_arn, Label="test")
 
     response = client.get_topic_attributes(TopicArn=topic_arn)
-    json.loads(response["Attributes"]["Policy"]).should.equal(
-        {
-            "Version": "2008-10-17",
-            "Id": "__default_policy_ID",
-            "Statement": [
-                {
-                    "Effect": "Allow",
-                    "Sid": "__default_statement_ID",
-                    "Principal": {"AWS": "*"},
-                    "Action": [
-                        "SNS:GetTopicAttributes",
-                        "SNS:SetTopicAttributes",
-                        "SNS:AddPermission",
-                        "SNS:RemovePermission",
-                        "SNS:DeleteTopic",
-                        "SNS:Subscribe",
-                        "SNS:ListSubscriptionsByTopic",
-                        "SNS:Publish",
-                        "SNS:Receive",
-                    ],
-                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
-                    "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
-                }
-            ],
-        }
-    )
+    assert json.loads(response["Attributes"]["Policy"]) == {
+        "Version": "2008-10-17",
+        "Id": "__default_policy_ID",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Sid": "__default_statement_ID",
+                "Principal": {"AWS": "*"},
+                "Action": [
+                    "SNS:GetTopicAttributes",
+                    "SNS:SetTopicAttributes",
+                    "SNS:AddPermission",
+                    "SNS:RemovePermission",
+                    "SNS:DeleteTopic",
+                    "SNS:Subscribe",
+                    "SNS:ListSubscriptionsByTopic",
+                    "SNS:Publish",
+                    "SNS:Receive",
+                ],
+                "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
+                "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
+            }
+        ],
+    }
 
     client.add_permission(
         TopicArn=topic_arn,
@@ -338,20 +332,18 @@ def test_add_remove_permissions():
     )
 
     response = client.get_topic_attributes(TopicArn=topic_arn)
-    json.loads(response["Attributes"]["Policy"])["Statement"][1].should.equal(
-        {
-            "Sid": "test",
-            "Effect": "Allow",
-            "Principal": {
-                "AWS": [
-                    "arn:aws:iam::888888888888:root",
-                    "arn:aws:iam::999999999999:root",
-                ]
-            },
-            "Action": ["SNS:Publish", "SNS:Subscribe"],
-            "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
-        }
-    )
+    assert json.loads(response["Attributes"]["Policy"])["Statement"][1] == {
+        "Sid": "test",
+        "Effect": "Allow",
+        "Principal": {
+            "AWS": [
+                "arn:aws:iam::888888888888:root",
+                "arn:aws:iam::999999999999:root",
+            ]
+        },
+        "Action": ["SNS:Publish", "SNS:Subscribe"],
+        "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
+    }
 
     # deleting non existing permission should be successful
     client.remove_permission(TopicArn=topic_arn, Label="non-existing")
@@ -368,30 +360,36 @@ def test_add_permission_errors():
         ActionName=["Publish"],
     )
 
-    client.add_permission.when.called_with(
-        TopicArn=topic_arn,
-        Label="test",
-        AWSAccountId=["999999999999"],
-        ActionName=["AddPermission"],
-    ).should.throw(ClientError, "Statement already exists")
+    with pytest.raises(ClientError) as client_err:
+        client.add_permission(
+            TopicArn=topic_arn,
+            Label="test",
+            AWSAccountId=["999999999999"],
+            ActionName=["AddPermission"],
+        )
+    assert client_err.value.response["Error"]["Message"] == "Statement already exists"
 
-    client.add_permission.when.called_with(
-        TopicArn=topic_arn + "-not-existing",
-        Label="test-2",
-        AWSAccountId=["999999999999"],
-        ActionName=["AddPermission"],
-    ).should.throw(
-        ClientError,
-        "An error occurred (NotFound) when calling the AddPermission operation: Topic does not exist",
+    with pytest.raises(ClientError) as client_err:
+        client.add_permission(
+            TopicArn=topic_arn + "-not-existing",
+            Label="test-2",
+            AWSAccountId=["999999999999"],
+            ActionName=["AddPermission"],
+        )
+    assert client_err.value.response["Error"]["Code"] == "NotFound"
+    assert client_err.value.response["Error"]["Message"] == "Topic does not exist"
+
+    with pytest.raises(ClientError) as client_err:
+        client.add_permission(
+            TopicArn=topic_arn,
+            Label="test-2",
+            AWSAccountId=["999999999999"],
+            ActionName=["NotExistingAction"],
+        )
+    assert client_err.value.response["Error"]["Message"] == (
+        "Policy statement action out of service scope!"
     )
 
-    client.add_permission.when.called_with(
-        TopicArn=topic_arn,
-        Label="test-2",
-        AWSAccountId=["999999999999"],
-        ActionName=["NotExistingAction"],
-    ).should.throw(ClientError, "Policy statement action out of service scope!")
-
 
 @mock_sns
 def test_remove_permission_errors():
@@ -404,12 +402,11 @@ def test_remove_permission_errors():
         ActionName=["Publish"],
     )
 
-    client.remove_permission.when.called_with(
-        TopicArn=topic_arn + "-not-existing", Label="test"
-    ).should.throw(
-        ClientError,
-        "An error occurred (NotFound) when calling the RemovePermission operation: Topic does not exist",
-    )
+    with pytest.raises(ClientError) as client_err:
+        client.remove_permission(TopicArn=topic_arn + "-not-existing", Label="test")
+
+    assert client_err.value.response["Error"]["Code"] == "NotFound"
+    assert client_err.value.response["Error"]["Message"] == "Topic does not exist"
 
 
 @mock_sns
@@ -421,14 +418,14 @@ def test_tag_topic():
     conn.tag_resource(
         ResourceArn=topic_arn, Tags=[{"Key": "tag_key_1", "Value": "tag_value_1"}]
     )
-    conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"].should.equal(
+    assert conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"] == (
         [{"Key": "tag_key_1", "Value": "tag_value_1"}]
     )
 
     conn.tag_resource(
         ResourceArn=topic_arn, Tags=[{"Key": "tag_key_2", "Value": "tag_value_2"}]
     )
-    conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"].should.equal(
+    assert conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"] == (
         [
             {"Key": "tag_key_1", "Value": "tag_value_1"},
             {"Key": "tag_key_2", "Value": "tag_value_2"},
@@ -438,7 +435,7 @@ def test_tag_topic():
     conn.tag_resource(
         ResourceArn=topic_arn, Tags=[{"Key": "tag_key_1", "Value": "tag_value_X"}]
     )
-    conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"].should.equal(
+    assert conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"] == (
         [
             {"Key": "tag_key_1", "Value": "tag_value_X"},
             {"Key": "tag_key_2", "Value": "tag_value_2"},
@@ -459,13 +456,13 @@ def test_untag_topic():
     topic_arn = response["TopicArn"]
 
     conn.untag_resource(ResourceArn=topic_arn, TagKeys=["tag_key_1"])
-    conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"].should.equal(
+    assert conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"] == (
         [{"Key": "tag_key_2", "Value": "tag_value_2"}]
     )
 
     # removing a non existing tag should not raise any error
     conn.untag_resource(ResourceArn=topic_arn, TagKeys=["not-existing-tag"])
-    conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"].should.equal(
+    assert conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"] == (
         [{"Key": "tag_key_2", "Value": "tag_value_2"}]
     )
 
@@ -477,9 +474,9 @@ def test_list_tags_for_resource_error():
         Name="some-topic-with-tags", Tags=[{"Key": "tag_key_1", "Value": "tag_value_X"}]
     )
 
-    conn.list_tags_for_resource.when.called_with(
-        ResourceArn="not-existing-topic"
-    ).should.throw(ClientError, "Resource does not exist")
+    with pytest.raises(ClientError) as client_err:
+        conn.list_tags_for_resource(ResourceArn="not-existing-topic")
+    assert client_err.value.response["Error"]["Message"] == "Resource does not exist"
 
 
 @mock_sns
@@ -490,22 +487,24 @@ def test_tag_resource_errors():
     )
     topic_arn = response["TopicArn"]
 
-    conn.tag_resource.when.called_with(
-        ResourceArn="not-existing-topic",
-        Tags=[{"Key": "tag_key_1", "Value": "tag_value_1"}],
-    ).should.throw(ClientError, "Resource does not exist")
+    with pytest.raises(ClientError) as client_err:
+        conn.tag_resource(
+            ResourceArn="not-existing-topic",
+            Tags=[{"Key": "tag_key_1", "Value": "tag_value_1"}],
+        )
+    assert client_err.value.response["Error"]["Message"] == "Resource does not exist"
 
     too_many_tags = [
         {"Key": f"tag_key_{i}", "Value": f"tag_value_{i}"} for i in range(51)
     ]
-    conn.tag_resource.when.called_with(
-        ResourceArn=topic_arn, Tags=too_many_tags
-    ).should.throw(
-        ClientError, "Could not complete request: tag quota of per resource exceeded"
+    with pytest.raises(ClientError) as client_err:
+        conn.tag_resource(ResourceArn=topic_arn, Tags=too_many_tags)
+    assert client_err.value.response["Error"]["Message"] == (
+        "Could not complete request: tag quota of per resource exceeded"
     )
 
     # when the request fails, the tags should not be updated
-    conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"].should.equal(
+    assert conn.list_tags_for_resource(ResourceArn=topic_arn)["Tags"] == (
         [{"Key": "tag_key_1", "Value": "tag_value_X"}]
     )
 
@@ -517,9 +516,9 @@ def test_untag_resource_error():
         Name="some-topic-with-tags", Tags=[{"Key": "tag_key_1", "Value": "tag_value_X"}]
     )
 
-    conn.untag_resource.when.called_with(
-        ResourceArn="not-existing-topic", TagKeys=["tag_key_1"]
-    ).should.throw(ClientError, "Resource does not exist")
+    with pytest.raises(ClientError) as client_err:
+        conn.untag_resource(ResourceArn="not-existing-topic", TagKeys=["tag_key_1"])
+    assert client_err.value.response["Error"]["Message"] == "Resource does not exist"
 
 
 @mock_sns
@@ -534,29 +533,32 @@ def test_create_fifo_topic():
     try:
         conn.create_topic(Name="test_topic", Attributes={"FifoTopic": "true"})
     except ClientError as err:
-        err.response["Error"]["Code"].should.equal("InvalidParameterValue")
-        err.response["Error"]["Message"].should.equal(
-            "Fifo Topic names must end with .fifo and must be made up of only uppercase and lowercase ASCII letters, "
-            "numbers, underscores, and hyphens, and must be between 1 and 256 characters long."
+        assert err.response["Error"]["Code"] == "InvalidParameterValue"
+        assert err.response["Error"]["Message"] == (
+            "Fifo Topic names must end with .fifo and must be made up of only "
+            "uppercase and lowercase ASCII letters, numbers, underscores, "
+            "and hyphens, and must be between 1 and 256 characters long."
         )
-        err.response["Error"]["Type"].should.equal("Sender")
+        assert err.response["Error"]["Type"] == "Sender"
 
     try:
         conn.create_topic(Name="test_topic.fifo")
     except ClientError as err:
-        err.response["Error"]["Code"].should.equal("InvalidParameterValue")
-        err.response["Error"]["Message"].should.equal(
-            "Topic names must be made up of only uppercase and lowercase ASCII letters, numbers, underscores, "
+        assert err.response["Error"]["Code"] == "InvalidParameterValue"
+        assert err.response["Error"]["Message"] == (
+            "Topic names must be made up of only uppercase and lowercase "
+            "ASCII letters, numbers, underscores, "
             "and hyphens, and must be between 1 and 256 characters long."
         )
 
     try:
         conn.create_topic(Name="topic.name.fifo", Attributes={"FifoTopic": "true"})
     except ClientError as err:
-        err.response["Error"]["Code"].should.equal("InvalidParameterValue")
-        err.response["Error"]["Message"].should.equal(
-            "Fifo Topic names must end with .fifo and must be made up of only uppercase and lowercase ASCII letters, "
-            "numbers, underscores, and hyphens, and must be between 1 and 256 characters long."
+        assert err.response["Error"]["Code"] == "InvalidParameterValue"
+        assert err.response["Error"]["Message"] == (
+            "Fifo Topic names must end with .fifo and must be made up of only "
+            "uppercase and lowercase ASCII letters, numbers, underscores, "
+            "and hyphens, and must be between 1 and 256 characters long."
         )
 
 
@@ -566,22 +568,22 @@ def test_topic_kms_master_key_id_attribute():
     resp = client.create_topic(Name="test-sns-no-key-attr")
     topic_arn = resp["TopicArn"]
     resp = client.get_topic_attributes(TopicArn=topic_arn)
-    resp["Attributes"].should_not.have.key("KmsMasterKeyId")
+    assert "KmsMasterKeyId" not in resp["Attributes"]
 
     client.set_topic_attributes(
         TopicArn=topic_arn, AttributeName="KmsMasterKeyId", AttributeValue="test-key"
     )
     resp = client.get_topic_attributes(TopicArn=topic_arn)
-    resp["Attributes"].should.have.key("KmsMasterKeyId")
-    resp["Attributes"]["KmsMasterKeyId"].should.equal("test-key")
+    assert "KmsMasterKeyId" in resp["Attributes"]
+    assert resp["Attributes"]["KmsMasterKeyId"] == "test-key"
 
     resp = client.create_topic(
         Name="test-sns-with-key-attr", Attributes={"KmsMasterKeyId": "key-id"}
     )
     topic_arn = resp["TopicArn"]
     resp = client.get_topic_attributes(TopicArn=topic_arn)
-    resp["Attributes"].should.have.key("KmsMasterKeyId")
-    resp["Attributes"]["KmsMasterKeyId"].should.equal("key-id")
+    assert "KmsMasterKeyId" in resp["Attributes"]
+    assert resp["Attributes"]["KmsMasterKeyId"] == "key-id"
 
 
 @mock_sns
@@ -593,11 +595,11 @@ def test_topic_fifo_get_attributes():
     topic_arn = resp["TopicArn"]
     attributes = client.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
 
-    attributes.should.have.key("FifoTopic")
-    attributes.should.have.key("ContentBasedDeduplication")
+    assert "FifoTopic" in attributes
+    assert "ContentBasedDeduplication" in attributes
 
-    attributes["FifoTopic"].should.equal("true")
-    attributes["ContentBasedDeduplication"].should.equal("false")
+    assert attributes["FifoTopic"] == "true"
+    assert attributes["ContentBasedDeduplication"] == "false"
 
     client.set_topic_attributes(
         TopicArn=topic_arn,
@@ -605,7 +607,7 @@ def test_topic_fifo_get_attributes():
         AttributeValue="true",
     )
     attributes = client.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
-    attributes["ContentBasedDeduplication"].should.equal("true")
+    assert attributes["ContentBasedDeduplication"] == "true"
 
 
 @mock_sns
@@ -615,8 +617,8 @@ def test_topic_get_attributes():
     topic_arn = resp["TopicArn"]
     attributes = client.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
 
-    attributes.should_not.have.key("FifoTopic")
-    attributes.should_not.have.key("ContentBasedDeduplication")
+    assert "FifoTopic" not in attributes
+    assert "ContentBasedDeduplication" not in attributes
 
 
 @mock_sns
@@ -628,5 +630,5 @@ def test_topic_get_attributes_with_fifo_false():
     topic_arn = resp["TopicArn"]
     attributes = client.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
 
-    attributes.should_not.have.key("FifoTopic")
-    attributes.should_not.have.key("ContentBasedDeduplication")
+    assert "FifoTopic" not in attributes
+    assert "ContentBasedDeduplication" not in attributes
