@@ -1,13 +1,10 @@
+"""Test different server responses."""
 import re
-import sure  # noqa # pylint: disable=unused-import
 import threading
 import time
 
 import moto.server as server
-
-"""
-Test the different server responses
-"""
+from moto.core.utils import utcnow
 
 
 def test_sqs_list_identities():
@@ -15,30 +12,30 @@ def test_sqs_list_identities():
     test_client = backend.test_client()
 
     res = test_client.get("/?Action=ListQueues")
-    res.data.should.contain(b"ListQueuesResponse")
+    assert b"ListQueuesResponse" in res.data
 
     # Make sure that we can receive messages from queues whose name contains dots (".")
     # The AWS API mandates that the names of FIFO queues use the suffix ".fifo"
-    # See: https://github.com/spulec/moto/issues/866
+    # See: https://github.com/getmoto/moto/issues/866
 
     for queue_name in ("testqueue", "otherqueue.fifo"):
 
-        res = test_client.put("/?Action=CreateQueue&QueueName=%s" % queue_name)
+        res = test_client.put(f"/?Action=CreateQueue&QueueName={queue_name}")
 
         res = test_client.put(
-            "/123/%s?MessageBody=test-message&Action=SendMessage" % queue_name
+            f"/123/{queue_name}?MessageBody=test-message&Action=SendMessage"
         )
 
         res = test_client.get(
-            "/123/%s?Action=ReceiveMessage&MaxNumberOfMessages=1" % queue_name
+            f"/123/{queue_name}?Action=ReceiveMessage&MaxNumberOfMessages=1"
         )
 
         message = re.search("<Body>(.*?)</Body>", res.data.decode("utf-8")).groups()[0]
-        message.should.equal("test-message")
+        assert message == "test-message"
 
     res = test_client.get("/?Action=ListQueues&QueueNamePrefix=other")
-    res.data.should.contain(b"otherqueue.fifo")
-    res.data.should_not.contain(b"testqueue")
+    assert b"otherqueue.fifo" in res.data
+    assert b"testqueue" not in res.data
 
 
 def test_messages_polling():
@@ -80,3 +77,20 @@ def test_messages_polling():
     # got each message in a separate call to ReceiveMessage, despite the long
     # WaitTimeSeconds
     assert len(messages) == 5
+
+
+def test_no_messages_polling_timeout():
+    backend = server.create_backend_app("sqs")
+    queue_name = "test-queue"
+    test_client = backend.test_client()
+    test_client.put(f"/?Action=CreateQueue&QueueName={queue_name}")
+    wait_seconds = 5
+    start = utcnow()
+    test_client.get(
+        f"/123/{queue_name}?Action=ReceiveMessage&"
+        f"MaxNumberOfMessages=1&WaitTimeSeconds={wait_seconds}"
+    )
+    end = utcnow()
+    duration = end - start
+    assert duration.seconds >= wait_seconds
+    assert duration.seconds <= wait_seconds + (wait_seconds / 2)
