@@ -1,8 +1,8 @@
-import boto3
 import json
 
+import boto3
 
-from moto import mock_ssm, mock_cloudformation
+from moto import mock_cloudformation, mock_ssm
 from tests import EXAMPLE_AMI_ID
 
 
