@@ -1,5 +1,4 @@
 import boto3
-import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_ssm
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
@@ -12,15 +11,24 @@ def test_ssm_get_by_path():
     params = client.get_parameters_by_path(Path=path)["Parameters"]
 
     pacific = [p for p in params if p["Value"] == "af-south-1"][0]
-    pacific["Name"].should.equal(
-        "/aws/service/global-infrastructure/regions/af-south-1"
+    assert pacific["Name"] == "/aws/service/global-infrastructure/regions/af-south-1"
+    assert pacific["Type"] == "String"
+    assert pacific["Version"] == 1
+    assert pacific["ARN"] == (
+        f"arn:aws:ssm:us-west-1:{ACCOUNT_ID}:parameter/aws/service"
+        "/global-infrastructure/regions/af-south-1"
     )
-    pacific["Type"].should.equal("String")
-    pacific["Version"].should.equal(1)
-    pacific["ARN"].should.equal(
-        f"arn:aws:ssm:us-west-1:{ACCOUNT_ID}:parameter/aws/service/global-infrastructure/regions/af-south-1"
+    assert "LastModifiedDate" in pacific
+
+
+@mock_ssm
+def test_global_infrastructure_services():
+    client = boto3.client("ssm", region_name="us-west-1")
+    path = "/aws/service/global-infrastructure/services"
+    params = client.get_parameters_by_path(Path=path)["Parameters"]
+    assert params[0]["Name"] == (
+        "/aws/service/global-infrastructure/services/accessanalyzer"
     )
-    pacific.should.have.key("LastModifiedDate")
 
 
 @mock_ssm
@@ -31,5 +39,4 @@ def test_ssm_region_query():
     )
 
     value = param["Parameter"]["Value"]
-
-    value.should.equal("US West (N. California)")
+    assert value == "US West (N. California)"
