@@ -1,20 +1,18 @@
+import copy
+import datetime
+import hashlib
+import json
+import pkgutil
+from datetime import timezone
+
 import boto3
 import botocore.exceptions
-import sure  # noqa # pylint: disable=unused-import
-import datetime
-from datetime import timezone
-import json
-import yaml
-import hashlib
-import copy
-import pkgutil
 import pytest
-
+import yaml
 from botocore.exceptions import ClientError
 
-from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-
 from moto import mock_ssm
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
 def _get_yaml_template():
@@ -32,107 +30,99 @@ def _validate_document_description(
 ):
 
     if expected_format == "JSON":
-        doc_description["Hash"].should.equal(
+        assert doc_description["Hash"] == (
             hashlib.sha256(json.dumps(json_doc).encode("utf-8")).hexdigest()
         )
     else:
-        doc_description["Hash"].should.equal(
+        assert doc_description["Hash"] == (
             hashlib.sha256(yaml.dump(json_doc).encode("utf-8")).hexdigest()
         )
 
-    doc_description["HashType"].should.equal("Sha256")
-    doc_description["Name"].should.equal(doc_name)
-    doc_description["Owner"].should.equal(ACCOUNT_ID)
+    assert doc_description["HashType"] == "Sha256"
+    assert doc_description["Name"] == doc_name
+    assert doc_description["Owner"] == ACCOUNT_ID
 
     difference = datetime.datetime.now(tz=timezone.utc) - doc_description["CreatedDate"]
     if difference.min > datetime.timedelta(minutes=1):
         assert False
 
-    doc_description["Status"].should.equal("Active")
-    doc_description["DocumentVersion"].should.equal(expected_document_version)
-    doc_description["Description"].should.equal(json_doc["description"])
+    assert doc_description["Status"] == "Active"
+    assert doc_description["DocumentVersion"] == expected_document_version
+    assert doc_description["Description"] == json_doc["description"]
 
     doc_description["Parameters"] = sorted(
         doc_description["Parameters"], key=lambda doc: doc["Name"]
     )
 
-    doc_description["Parameters"][0]["Name"].should.equal("Parameter1")
-    doc_description["Parameters"][0]["Type"].should.equal("Integer")
-    doc_description["Parameters"][0]["Description"].should.equal("Command Duration.")
-    doc_description["Parameters"][0]["DefaultValue"].should.equal("3")
+    assert doc_description["Parameters"][0]["Name"] == "Parameter1"
+    assert doc_description["Parameters"][0]["Type"] == "Integer"
+    assert doc_description["Parameters"][0]["Description"] == "Command Duration."
+    assert doc_description["Parameters"][0]["DefaultValue"] == "3"
 
-    doc_description["Parameters"][1]["Name"].should.equal("Parameter2")
-    doc_description["Parameters"][1]["Type"].should.equal("String")
-    doc_description["Parameters"][1]["DefaultValue"].should.equal("def")
+    assert doc_description["Parameters"][1]["Name"] == "Parameter2"
+    assert doc_description["Parameters"][1]["Type"] == "String"
+    assert doc_description["Parameters"][1]["DefaultValue"] == "def"
 
-    doc_description["Parameters"][2]["Name"].should.equal("Parameter3")
-    doc_description["Parameters"][2]["Type"].should.equal("Boolean")
-    doc_description["Parameters"][2]["Description"].should.equal("A boolean")
-    doc_description["Parameters"][2]["DefaultValue"].should.equal("False")
+    assert doc_description["Parameters"][2]["Name"] == "Parameter3"
+    assert doc_description["Parameters"][2]["Type"] == "Boolean"
+    assert doc_description["Parameters"][2]["Description"] == "A boolean"
+    assert doc_description["Parameters"][2]["DefaultValue"] == "False"
 
-    doc_description["Parameters"][3]["Name"].should.equal("Parameter4")
-    doc_description["Parameters"][3]["Type"].should.equal("StringList")
-    doc_description["Parameters"][3]["Description"].should.equal("A string list")
-    doc_description["Parameters"][3]["DefaultValue"].should.equal('["abc", "def"]')
+    assert doc_description["Parameters"][3]["Name"] == "Parameter4"
+    assert doc_description["Parameters"][3]["Type"] == "StringList"
+    assert doc_description["Parameters"][3]["Description"] == "A string list"
+    assert doc_description["Parameters"][3]["DefaultValue"] == '["abc", "def"]'
 
-    doc_description["Parameters"][4]["Name"].should.equal("Parameter5")
-    doc_description["Parameters"][4]["Type"].should.equal("StringMap")
+    assert doc_description["Parameters"][4]["Name"] == "Parameter5"
+    assert doc_description["Parameters"][4]["Type"] == "StringMap"
 
-    doc_description["Parameters"][5]["Name"].should.equal("Parameter6")
-    doc_description["Parameters"][5]["Type"].should.equal("MapList")
+    assert doc_description["Parameters"][5]["Name"] == "Parameter6"
+    assert doc_description["Parameters"][5]["Type"] == "MapList"
 
     if expected_format == "JSON":
         # We have to replace single quotes from the response to package it back up
-        json.loads(doc_description["Parameters"][4]["DefaultValue"]).should.equal(
-            {
-                "NotificationArn": "$dependency.topicArn",
-                "NotificationEvents": ["Failed"],
-                "NotificationType": "Command",
-            }
-        )
+        assert json.loads(doc_description["Parameters"][4]["DefaultValue"]) == {
+            "NotificationArn": "$dependency.topicArn",
+            "NotificationEvents": ["Failed"],
+            "NotificationType": "Command",
+        }
 
-        json.loads(doc_description["Parameters"][5]["DefaultValue"]).should.equal(
-            [
-                {"DeviceName": "/dev/sda1", "Ebs": {"VolumeSize": "50"}},
-                {"DeviceName": "/dev/sdm", "Ebs": {"VolumeSize": "100"}},
-            ]
-        )
+        assert json.loads(doc_description["Parameters"][5]["DefaultValue"]) == [
+            {"DeviceName": "/dev/sda1", "Ebs": {"VolumeSize": "50"}},
+            {"DeviceName": "/dev/sdm", "Ebs": {"VolumeSize": "100"}},
+        ]
     else:
-        yaml.safe_load(doc_description["Parameters"][4]["DefaultValue"]).should.equal(
-            {
-                "NotificationArn": "$dependency.topicArn",
-                "NotificationEvents": ["Failed"],
-                "NotificationType": "Command",
-            }
-        )
-        yaml.safe_load(doc_description["Parameters"][5]["DefaultValue"]).should.equal(
-            [
-                {"DeviceName": "/dev/sda1", "Ebs": {"VolumeSize": "50"}},
-                {"DeviceName": "/dev/sdm", "Ebs": {"VolumeSize": "100"}},
-            ]
-        )
+        assert yaml.safe_load(doc_description["Parameters"][4]["DefaultValue"]) == {
+            "NotificationArn": "$dependency.topicArn",
+            "NotificationEvents": ["Failed"],
+            "NotificationType": "Command",
+        }
+        assert yaml.safe_load(doc_description["Parameters"][5]["DefaultValue"]) == [
+            {"DeviceName": "/dev/sda1", "Ebs": {"VolumeSize": "50"}},
+            {"DeviceName": "/dev/sdm", "Ebs": {"VolumeSize": "100"}},
+        ]
 
-    doc_description["DocumentType"].should.equal("Command")
-    doc_description["SchemaVersion"].should.equal("2.2")
-    doc_description["LatestVersion"].should.equal(expected_latest_version)
-    doc_description["DefaultVersion"].should.equal(expected_default_version)
-    doc_description["DocumentFormat"].should.equal(expected_format)
+    assert doc_description["DocumentType"] == "Command"
+    assert doc_description["SchemaVersion"] == "2.2"
+    assert doc_description["LatestVersion"] == expected_latest_version
+    assert doc_description["DefaultVersion"] == expected_default_version
+    assert doc_description["DocumentFormat"] == expected_format
 
 
 def _get_doc_validator(
     response, version_name, doc_version, json_doc_content, document_format
 ):
-    response["Name"].should.equal("TestDocument3")
+    assert response["Name"] == "TestDocument3"
     if version_name:
-        response["VersionName"].should.equal(version_name)
-    response["DocumentVersion"].should.equal(doc_version)
-    response["Status"].should.equal("Active")
+        assert response["VersionName"] == version_name
+    assert response["DocumentVersion"] == doc_version
+    assert response["Status"] == "Active"
     if document_format == "JSON":
-        json.loads(response["Content"]).should.equal(json_doc_content)
+        assert json.loads(response["Content"]) == json_doc_content
     else:
-        yaml.safe_load(response["Content"]).should.equal(json_doc_content)
-    response["DocumentType"].should.equal("Command")
-    response["DocumentFormat"].should.equal(document_format)
+        assert yaml.safe_load(response["Content"]) == json_doc_content
+    assert response["DocumentType"] == "Command"
+    assert response["DocumentFormat"] == document_format
 
 
 @mock_ssm
@@ -174,9 +164,9 @@ def test_create_document():
         Tags=[{"Key": "testing", "Value": "testingValue"}],
     )
     doc_description = response["DocumentDescription"]
-    doc_description["VersionName"].should.equal("Base")
-    doc_description["TargetType"].should.equal("/AWS::EC2::Instance")
-    doc_description["Tags"].should.equal([{"Key": "testing", "Value": "testingValue"}])
+    assert doc_description["VersionName"] == "Base"
+    assert doc_description["TargetType"] == "/AWS::EC2::Instance"
+    assert doc_description["Tags"] == [{"Key": "testing", "Value": "testingValue"}]
 
     _validate_document_description(
         "TestDocument3", doc_description, json_doc, "1", "1", "1", "JSON"
@@ -191,9 +181,9 @@ def test_create_document():
         )
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("CreateDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document already exists."
+        assert err.operation_name == "CreateDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document already exists."
         )
 
     try:
@@ -205,9 +195,10 @@ def test_create_document():
         )
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("CreateDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The content for the document is not valid."
+        assert err.operation_name == "CreateDocument"
+        assert (
+            err.response["Error"]["Message"]
+            == "The content for the document is not valid."
         )
 
     del json_doc["parameters"]
@@ -219,25 +210,25 @@ def test_create_document():
     )
     doc_description = response["DocumentDescription"]
 
-    doc_description["Hash"].should.equal(
+    assert doc_description["Hash"] == (
         hashlib.sha256(yaml.dump(json_doc).encode("utf-8")).hexdigest()
     )
-    doc_description["HashType"].should.equal("Sha256")
-    doc_description["Name"].should.equal("EmptyParamDoc")
-    doc_description["Owner"].should.equal(ACCOUNT_ID)
+    assert doc_description["HashType"] == "Sha256"
+    assert doc_description["Name"] == "EmptyParamDoc"
+    assert doc_description["Owner"] == ACCOUNT_ID
 
     difference = datetime.datetime.now(tz=timezone.utc) - doc_description["CreatedDate"]
     if difference.min > datetime.timedelta(minutes=1):
         assert False
 
-    doc_description["Status"].should.equal("Active")
-    doc_description["DocumentVersion"].should.equal("1")
-    doc_description["Description"].should.equal(json_doc["description"])
-    doc_description["DocumentType"].should.equal("Command")
-    doc_description["SchemaVersion"].should.equal("2.2")
-    doc_description["LatestVersion"].should.equal("1")
-    doc_description["DefaultVersion"].should.equal("1")
-    doc_description["DocumentFormat"].should.equal("YAML")
+    assert doc_description["Status"] == "Active"
+    assert doc_description["DocumentVersion"] == "1"
+    assert doc_description["Description"] == json_doc["description"]
+    assert doc_description["DocumentType"] == "Command"
+    assert doc_description["SchemaVersion"] == "2.2"
+    assert doc_description["LatestVersion"] == "1"
+    assert doc_description["DefaultVersion"] == "1"
+    assert doc_description["DocumentFormat"] == "YAML"
 
 
 @mock_ssm
@@ -251,9 +242,9 @@ def test_get_document():
         client.get_document(Name="DNE")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("GetDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "GetDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     client.create_document(
@@ -306,18 +297,18 @@ def test_get_document():
         )
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("GetDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "GetDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     try:
         response = client.get_document(Name="TestDocument3", DocumentVersion="3")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("GetDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "GetDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     # Updating default should update normal get
@@ -337,9 +328,9 @@ def test_delete_document():
         client.delete_document(Name="DNE")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("DeleteDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "DeleteDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     # Test simple
@@ -357,9 +348,9 @@ def test_delete_document():
         client.get_document(Name="TestDocument3")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("GetDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "GetDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     # Delete default version with other version is bad
@@ -407,8 +398,8 @@ def test_delete_document():
         client.delete_document(Name="TestDocument3", DocumentVersion="1")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("DeleteDocument")
-        err.response["Error"]["Message"].should.equal(
+        assert err.operation_name == "DeleteDocument"
+        assert err.response["Error"]["Message"] == (
             "Default version of the document can't be deleted."
         )
 
@@ -416,8 +407,8 @@ def test_delete_document():
         client.delete_document(Name="TestDocument3", VersionName="Base")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("DeleteDocument")
-        err.response["Error"]["Message"].should.equal(
+        assert err.operation_name == "DeleteDocument"
+        assert err.response["Error"]["Message"] == (
             "Default version of the document can't be deleted."
         )
 
@@ -429,7 +420,7 @@ def test_delete_document():
 
     # Check that latest version is changed
     response = client.describe_document(Name="TestDocument3")
-    response["Document"]["LatestVersion"].should.equal("4")
+    assert response["Document"]["LatestVersion"] == "4"
 
     client.delete_document(Name="TestDocument3", VersionName="NewBase")
 
@@ -444,31 +435,31 @@ def test_delete_document():
         client.get_document(Name="TestDocument3", DocumentVersion="1")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("GetDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "GetDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     try:
         client.get_document(Name="TestDocument3", DocumentVersion="3")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("GetDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "GetDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     try:
         client.get_document(Name="TestDocument3", DocumentVersion="4")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("GetDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "GetDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     response = client.list_documents()
-    len(response["DocumentIdentifiers"]).should.equal(0)
+    assert len(response["DocumentIdentifiers"]) == 0
 
 
 @mock_ssm
@@ -481,9 +472,9 @@ def test_update_document_default_version():
         client.update_document_default_version(Name="DNE", DocumentVersion="1")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("UpdateDocumentDefaultVersion")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "UpdateDocumentDefaultVersion"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     client.create_document(
@@ -511,8 +502,8 @@ def test_update_document_default_version():
     response = client.update_document_default_version(
         Name="TestDocument", DocumentVersion="2"
     )
-    response["Description"]["Name"].should.equal("TestDocument")
-    response["Description"]["DefaultVersion"].should.equal("2")
+    assert response["Description"]["Name"] == "TestDocument"
+    assert response["Description"]["DefaultVersion"] == "2"
 
     json_doc["description"] = "a new description3"
 
@@ -526,9 +517,9 @@ def test_update_document_default_version():
     response = client.update_document_default_version(
         Name="TestDocument", DocumentVersion="4"
     )
-    response["Description"]["Name"].should.equal("TestDocument")
-    response["Description"]["DefaultVersion"].should.equal("4")
-    response["Description"]["DefaultVersionName"].should.equal("NewBase")
+    assert response["Description"]["Name"] == "TestDocument"
+    assert response["Description"]["DefaultVersion"] == "4"
+    assert response["Description"]["DefaultVersionName"] == "NewBase"
 
 
 @mock_ssm
@@ -547,9 +538,9 @@ def test_update_document():
         )
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("UpdateDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "UpdateDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     client.create_document(
@@ -569,8 +560,8 @@ def test_update_document():
         )
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("UpdateDocument")
-        err.response["Error"]["Message"].should.equal(
+        assert err.operation_name == "UpdateDocument"
+        assert err.response["Error"]["Message"] == (
             "The document version is not valid or does not exist."
         )
 
@@ -584,8 +575,8 @@ def test_update_document():
         )
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("UpdateDocument")
-        err.response["Error"]["Message"].should.equal(
+        assert err.operation_name == "UpdateDocument"
+        assert err.response["Error"]["Message"] == (
             "The content of the association document matches another "
             "document. Change the content of the document and try again."
         )
@@ -602,8 +593,8 @@ def test_update_document():
         )
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("UpdateDocument")
-        err.response["Error"]["Message"].should.equal(
+        assert err.operation_name == "UpdateDocument"
+        assert err.response["Error"]["Message"] == (
             "The specified version name is a duplicate."
         )
 
@@ -614,10 +605,10 @@ def test_update_document():
         DocumentVersion="1",
         DocumentFormat="JSON",
     )
-    response["DocumentDescription"]["Description"].should.equal("a new description")
-    response["DocumentDescription"]["DocumentVersion"].should.equal("2")
-    response["DocumentDescription"]["LatestVersion"].should.equal("2")
-    response["DocumentDescription"]["DefaultVersion"].should.equal("1")
+    assert response["DocumentDescription"]["Description"] == "a new description"
+    assert response["DocumentDescription"]["DocumentVersion"] == "2"
+    assert response["DocumentDescription"]["LatestVersion"] == "2"
+    assert response["DocumentDescription"]["DefaultVersion"] == "1"
 
     json_doc["description"] = "a new description2"
 
@@ -628,11 +619,11 @@ def test_update_document():
         DocumentFormat="JSON",
         VersionName="NewBase",
     )
-    response["DocumentDescription"]["Description"].should.equal("a new description2")
-    response["DocumentDescription"]["DocumentVersion"].should.equal("3")
-    response["DocumentDescription"]["LatestVersion"].should.equal("3")
-    response["DocumentDescription"]["DefaultVersion"].should.equal("1")
-    response["DocumentDescription"]["VersionName"].should.equal("NewBase")
+    assert response["DocumentDescription"]["Description"] == "a new description2"
+    assert response["DocumentDescription"]["DocumentVersion"] == "3"
+    assert response["DocumentDescription"]["LatestVersion"] == "3"
+    assert response["DocumentDescription"]["DefaultVersion"] == "1"
+    assert response["DocumentDescription"]["VersionName"] == "NewBase"
 
 
 @mock_ssm
@@ -645,9 +636,9 @@ def test_describe_document():
         client.describe_document(Name="DNE")
         raise RuntimeError("Should fail")
     except botocore.exceptions.ClientError as err:
-        err.operation_name.should.equal("DescribeDocument")
-        err.response["Error"]["Message"].should.equal(
-            "The specified document does not exist."
+        assert err.operation_name == "DescribeDocument"
+        assert (
+            err.response["Error"]["Message"] == "The specified document does not exist."
         )
 
     client.create_document(
@@ -707,29 +698,29 @@ def test_list_documents():
     )
 
     response = client.list_documents()
-    len(response["DocumentIdentifiers"]).should.equal(3)
-    response["DocumentIdentifiers"][0]["Name"].should.equal("TestDocument")
-    response["DocumentIdentifiers"][1]["Name"].should.equal("TestDocument2")
-    response["DocumentIdentifiers"][2]["Name"].should.equal("TestDocument3")
-    response["NextToken"].should.equal("")
+    assert len(response["DocumentIdentifiers"]) == 3
+    assert response["DocumentIdentifiers"][0]["Name"] == "TestDocument"
+    assert response["DocumentIdentifiers"][1]["Name"] == "TestDocument2"
+    assert response["DocumentIdentifiers"][2]["Name"] == "TestDocument3"
+    assert response["NextToken"] == ""
 
     response = client.list_documents(MaxResults=1)
-    len(response["DocumentIdentifiers"]).should.equal(1)
-    response["DocumentIdentifiers"][0]["Name"].should.equal("TestDocument")
-    response["DocumentIdentifiers"][0]["DocumentVersion"].should.equal("1")
-    response["NextToken"].should.equal("1")
+    assert len(response["DocumentIdentifiers"]) == 1
+    assert response["DocumentIdentifiers"][0]["Name"] == "TestDocument"
+    assert response["DocumentIdentifiers"][0]["DocumentVersion"] == "1"
+    assert response["NextToken"] == "1"
 
     response = client.list_documents(MaxResults=1, NextToken=response["NextToken"])
-    len(response["DocumentIdentifiers"]).should.equal(1)
-    response["DocumentIdentifiers"][0]["Name"].should.equal("TestDocument2")
-    response["DocumentIdentifiers"][0]["DocumentVersion"].should.equal("1")
-    response["NextToken"].should.equal("2")
+    assert len(response["DocumentIdentifiers"]) == 1
+    assert response["DocumentIdentifiers"][0]["Name"] == "TestDocument2"
+    assert response["DocumentIdentifiers"][0]["DocumentVersion"] == "1"
+    assert response["NextToken"] == "2"
 
     response = client.list_documents(MaxResults=1, NextToken=response["NextToken"])
-    len(response["DocumentIdentifiers"]).should.equal(1)
-    response["DocumentIdentifiers"][0]["Name"].should.equal("TestDocument3")
-    response["DocumentIdentifiers"][0]["DocumentVersion"].should.equal("1")
-    response["NextToken"].should.equal("")
+    assert len(response["DocumentIdentifiers"]) == 1
+    assert response["DocumentIdentifiers"][0]["Name"] == "TestDocument3"
+    assert response["DocumentIdentifiers"][0]["DocumentVersion"] == "1"
+    assert response["NextToken"] == ""
 
     # making sure no bad interactions with update
     json_doc["description"] = "a new description"
@@ -750,24 +741,24 @@ def test_list_documents():
     client.update_document_default_version(Name="TestDocument", DocumentVersion="2")
 
     response = client.list_documents()
-    len(response["DocumentIdentifiers"]).should.equal(3)
-    response["DocumentIdentifiers"][0]["Name"].should.equal("TestDocument")
-    response["DocumentIdentifiers"][0]["DocumentVersion"].should.equal("2")
+    assert len(response["DocumentIdentifiers"]) == 3
+    assert response["DocumentIdentifiers"][0]["Name"] == "TestDocument"
+    assert response["DocumentIdentifiers"][0]["DocumentVersion"] == "2"
 
-    response["DocumentIdentifiers"][1]["Name"].should.equal("TestDocument2")
-    response["DocumentIdentifiers"][1]["DocumentVersion"].should.equal("1")
+    assert response["DocumentIdentifiers"][1]["Name"] == "TestDocument2"
+    assert response["DocumentIdentifiers"][1]["DocumentVersion"] == "1"
 
-    response["DocumentIdentifiers"][2]["Name"].should.equal("TestDocument3")
-    response["DocumentIdentifiers"][2]["DocumentVersion"].should.equal("1")
-    response["NextToken"].should.equal("")
+    assert response["DocumentIdentifiers"][2]["Name"] == "TestDocument3"
+    assert response["DocumentIdentifiers"][2]["DocumentVersion"] == "1"
+    assert response["NextToken"] == ""
 
     response = client.list_documents(Filters=[{"Key": "Owner", "Values": ["Self"]}])
-    len(response["DocumentIdentifiers"]).should.equal(3)
+    assert len(response["DocumentIdentifiers"]) == 3
 
     response = client.list_documents(
         Filters=[{"Key": "TargetType", "Values": ["/AWS::EC2::Instance"]}]
     )
-    len(response["DocumentIdentifiers"]).should.equal(1)
+    assert len(response["DocumentIdentifiers"]) == 1
 
 
 @mock_ssm
