@@ -1,14 +1,18 @@
-import boto3
 import datetime
-import pytest
-import sure  # noqa # pylint: disable=unused-import
-
-from botocore.exceptions import ClientError
-from moto import mock_ssoadmin
 from uuid import uuid4
 
+import boto3
+import pytest
+from botocore.exceptions import ClientError
+
+from moto import mock_ssoadmin
+
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
+DUMMY_PERMISSIONSET_ID = (
+    "arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo"
+)
+DUMMY_INSTANCE_ARN = "arn:aws:sso:::instance/ins-aaaabbbbccccdddd"
 
 
 @mock_ssoadmin
@@ -29,17 +33,17 @@ def test_create_account_assignment():
         PrincipalId=principal_id,
     )
 
-    resp.should.have.key("AccountAssignmentCreationStatus")
+    assert "AccountAssignmentCreationStatus" in resp
 
     status = resp["AccountAssignmentCreationStatus"]
-    status.should.have.key("Status").equals("SUCCEEDED")
-    status.should.have.key("RequestId")
-    status.shouldnt.have.key("FailureReason")
-    status.should.have.key("TargetId").equals(target_id)
-    status.should.have.key("TargetType").equals("AWS_ACCOUNT")
-    status.should.have.key("PermissionSetArn").equals(permission_set_arn)
-    status.should.have.key("PrincipalType").equals("USER")
-    status.should.have.key("PrincipalId").equals(principal_id)
+    assert status["Status"] == "SUCCEEDED"
+    assert "RequestId" in status
+    assert "FailureReason" not in status
+    assert status["TargetId"] == target_id
+    assert status["TargetType"] == "AWS_ACCOUNT"
+    assert status["PermissionSetArn"] == permission_set_arn
+    assert status["PrincipalType"] == "USER"
+    assert status["PrincipalId"] == principal_id
 
 
 @mock_ssoadmin
@@ -69,19 +73,19 @@ def test_delete_account_assignment():
         PrincipalType="USER",
         PrincipalId=principal_id,
     )
-    resp.should.have.key("AccountAssignmentDeletionStatus")
+    assert "AccountAssignmentDeletionStatus" in resp
 
     # Verify the correct response
     status = resp["AccountAssignmentDeletionStatus"]
-    status.should.have.key("Status").equals("SUCCEEDED")
-    status.should.have.key("RequestId")
-    status.shouldnt.have.key("FailureReason")
-    status.should.have.key("TargetId").equals(target_id)
-    status.should.have.key("TargetType").equals("AWS_ACCOUNT")
-    status.should.have.key("PermissionSetArn").equals(permission_set_arn)
-    status.should.have.key("PrincipalType").equals("USER")
-    status.should.have.key("PrincipalId").equals(principal_id)
-    status.should.have.key("CreatedDate").should.be.a(datetime.datetime)
+    assert status["Status"] == "SUCCEEDED"
+    assert "RequestId" in status
+    assert "FailureReason" not in status
+    assert status["TargetId"] == target_id
+    assert status["TargetType"] == "AWS_ACCOUNT"
+    assert status["PermissionSetArn"] == permission_set_arn
+    assert status["PrincipalType"] == "USER"
+    assert status["PrincipalId"] == principal_id
+    assert isinstance(status["CreatedDate"], datetime.datetime)
 
     # Verify this account assignment can no longer be found
     resp = client.list_account_assignments(
@@ -90,7 +94,7 @@ def test_delete_account_assignment():
         PermissionSetArn=permission_set_arn,
     )
 
-    resp.should.have.key("AccountAssignments").equals([])
+    assert resp["AccountAssignments"] == []
 
 
 @mock_ssoadmin
@@ -114,7 +118,7 @@ def test_delete_account_assignment_unknown():
             PrincipalId=principal_id,
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFound")
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_ssoadmin
@@ -135,7 +139,7 @@ def test_list_account_assignments():
         PermissionSetArn=permission_set_arn,
     )
 
-    resp.should.have.key("AccountAssignments").equals([])
+    assert resp["AccountAssignments"] == []
 
     client.create_account_assignment(
         InstanceArn=instance_arn,
@@ -152,16 +156,14 @@ def test_list_account_assignments():
         PermissionSetArn=permission_set_arn,
     )
 
-    resp.should.have.key("AccountAssignments").equals(
-        [
-            {
-                "AccountId": target_id1,
-                "PermissionSetArn": permission_set_arn,
-                "PrincipalType": "USER",
-                "PrincipalId": principal_id,
-            }
-        ]
-    )
+    assert resp["AccountAssignments"] == [
+        {
+            "AccountId": target_id1,
+            "PermissionSetArn": permission_set_arn,
+            "PrincipalType": "USER",
+            "PrincipalId": principal_id,
+        }
+    ]
 
     client.create_account_assignment(
         InstanceArn=instance_arn,
@@ -178,17 +180,209 @@ def test_list_account_assignments():
         PermissionSetArn=permission_set_arn,
     )
 
-    resp.should.have.key("AccountAssignments").equals(
-        [
+    assert resp["AccountAssignments"] == [
+        {
+            "AccountId": target_id2,
+            "PermissionSetArn": permission_set_arn,
+            "PrincipalType": "USER",
+            "PrincipalId": principal_id,
+        }
+    ]
+
+
+@mock_ssoadmin
+def test_list_account_assignments_pagination():
+    client = boto3.client("sso-admin", region_name="ap-southeast-1")
+    DUMMY_AWS_ACCOUNT_ID = "111111111111"
+
+    dummy_account_assignments = []
+    for _ in range(3):
+        dummy_account_assignments.append(
             {
-                "AccountId": target_id2,
-                "PermissionSetArn": permission_set_arn,
+                "InstanceArn": DUMMY_INSTANCE_ARN,
+                "TargetId": DUMMY_AWS_ACCOUNT_ID,
+                "TargetType": "AWS_ACCOUNT",
+                "PermissionSetArn": DUMMY_PERMISSIONSET_ID,
                 "PrincipalType": "USER",
-                "PrincipalId": principal_id,
-            }
-        ]
+                "PrincipalId": str(uuid4()),
+            },
+        )
+
+    for dummy_account_assignment in dummy_account_assignments:
+        client.create_account_assignment(**dummy_account_assignment)
+
+    account_assignments = []
+
+    response = client.list_account_assignments(
+        InstanceArn=DUMMY_INSTANCE_ARN,
+        AccountId=DUMMY_AWS_ACCOUNT_ID,
+        PermissionSetArn=DUMMY_PERMISSIONSET_ID,
+        MaxResults=2,
     )
 
+    assert len(response["AccountAssignments"]) == 2
+    account_assignments.extend(response["AccountAssignments"])
+
+    next_token = response["NextToken"]
+
+    response = client.list_account_assignments(
+        InstanceArn=DUMMY_INSTANCE_ARN,
+        AccountId=DUMMY_AWS_ACCOUNT_ID,
+        PermissionSetArn=DUMMY_PERMISSIONSET_ID,
+        MaxResults=2,
+        NextToken=next_token,
+    )
+
+    assert len(response["AccountAssignments"]) == 1
+    account_assignments.extend(response["AccountAssignments"])
+
+    # ensure 3 unique assignments returned
+    assert (
+        len(
+            set(
+                [
+                    account_assignment["PrincipalId"]
+                    for account_assignment in account_assignments
+                ]
+            )
+        )
+        == 3
+    )
+
+
+@mock_ssoadmin
+def test_list_account_assignments_for_principal():
+    client = boto3.client("sso-admin", region_name="us-west-2")
+
+    id_1 = str(uuid4())
+    id_2 = str(uuid4())
+
+    dummy_account_assignments = [
+        {
+            "InstanceArn": DUMMY_INSTANCE_ARN,
+            "TargetId": "111111111111",
+            "TargetType": "AWS_ACCOUNT",
+            "PermissionSetArn": DUMMY_PERMISSIONSET_ID,
+            "PrincipalType": "USER",
+            "PrincipalId": id_1,
+        },
+        {
+            "InstanceArn": DUMMY_INSTANCE_ARN,
+            "TargetId": "222222222222",
+            "TargetType": "AWS_ACCOUNT",
+            "PermissionSetArn": DUMMY_PERMISSIONSET_ID,
+            "PrincipalType": "USER",
+            "PrincipalId": id_2,
+        },
+        {
+            "InstanceArn": DUMMY_INSTANCE_ARN,
+            "TargetId": "333333333333",
+            "TargetType": "AWS_ACCOUNT",
+            "PermissionSetArn": DUMMY_PERMISSIONSET_ID,
+            "PrincipalType": "USER",
+            "PrincipalId": id_2,
+        },
+        {
+            "InstanceArn": DUMMY_INSTANCE_ARN,
+            "TargetId": "222222222222",
+            "TargetType": "AWS_ACCOUNT",
+            "PermissionSetArn": DUMMY_PERMISSIONSET_ID,
+            "PrincipalType": "GROUP",
+            "PrincipalId": id_2,
+        },
+    ]
+
+    # create the account assignments from above
+    for dummy_account_assignment in dummy_account_assignments:
+        client.create_account_assignment(**dummy_account_assignment)
+
+    # check user 1 assignments in all accounts
+    response = client.list_account_assignments_for_principal(
+        InstanceArn=DUMMY_INSTANCE_ARN, PrincipalId=id_1, PrincipalType="USER"
+    )
+    assert len(response["AccountAssignments"]) == 1
+    assert response["AccountAssignments"][0]["PrincipalId"] == id_1
+
+    # check user 2 in a single account
+    response = client.list_account_assignments_for_principal(
+        Filter={"AccountId": "222222222222"},
+        InstanceArn=DUMMY_INSTANCE_ARN,
+        PrincipalId=id_2,
+        PrincipalType="USER",
+    )
+    assert len(response["AccountAssignments"]) == 1
+    assert response["AccountAssignments"][0]["PrincipalId"] == id_2
+    assert response["AccountAssignments"][0]["AccountId"] == "222222222222"
+
+    # check group with id 2 is only returned
+    response = client.list_account_assignments_for_principal(
+        InstanceArn=DUMMY_INSTANCE_ARN,
+        PrincipalId=id_2,
+        PrincipalType="GROUP",
+    )
+    assert len(response["AccountAssignments"]) == 1
+    assert response["AccountAssignments"][0]["PrincipalId"] == id_2
+
+    # check empty response
+    response = client.list_account_assignments_for_principal(
+        InstanceArn=DUMMY_INSTANCE_ARN,
+        PrincipalId=str(uuid4()),
+        PrincipalType="USER",
+    )
+
+    assert len(response["AccountAssignments"]) == 0
+
+
+@mock_ssoadmin
+def test_list_account_assignments_for_principal_pagination():
+    client = boto3.client("sso-admin", region_name="us-east-2")
+
+    user_id = str(uuid4())
+
+    dummy_account_assignments = []
+    for x in range(3):
+        dummy_account_assignments.append(
+            {
+                "InstanceArn": DUMMY_INSTANCE_ARN,
+                "TargetId": str(x) * 12,
+                "TargetType": "AWS_ACCOUNT",
+                "PermissionSetArn": DUMMY_PERMISSIONSET_ID,
+                "PrincipalType": "USER",
+                "PrincipalId": user_id,
+            },
+        )
+
+    for dummy_account_assignment in dummy_account_assignments:
+        client.create_account_assignment(**dummy_account_assignment)
+
+    account_assignments = []
+
+    response = client.list_account_assignments_for_principal(
+        InstanceArn=DUMMY_INSTANCE_ARN,
+        PrincipalId=user_id,
+        PrincipalType="USER",
+        MaxResults=2,
+    )
+
+    assert len(response["AccountAssignments"]) == 2
+    account_assignments.extend(response["AccountAssignments"])
+    next_token = response["NextToken"]
+
+    response = client.list_account_assignments_for_principal(
+        InstanceArn=DUMMY_INSTANCE_ARN,
+        PrincipalId=user_id,
+        PrincipalType="USER",
+        MaxResults=2,
+        NextToken=next_token,
+    )
+
+    assert len(response["AccountAssignments"]) == 1
+    account_assignments.extend(response["AccountAssignments"])
+
+    assert set(
+        [account_assignment["AccountId"] for account_assignment in account_assignments]
+    ) == set(["000000000000", "111111111111", "222222222222"])
+
 
 @mock_ssoadmin
 def test_create_permission_set():
@@ -200,14 +394,14 @@ def test_create_permission_set():
         SessionDuration="PT1H",
         RelayState="https://console.aws.amazon.com/ec2",
     )
-    resp.should.have.key("PermissionSet")
-    permissionSet = resp["PermissionSet"]
-    permissionSet.should.have.key("Name").equals("test")
-    permissionSet.should.have.key("PermissionSetArn")
-    permissionSet.should.have.key("Description")
-    permissionSet.should.have.key("CreatedDate")
-    permissionSet.should.have.key("SessionDuration")
-    permissionSet.should.have.key("RelayState")
+    assert "PermissionSet" in resp
+    permission_set = resp["PermissionSet"]
+    assert permission_set["Name"] == "test"
+    assert "PermissionSetArn" in permission_set
+    assert "Description" in permission_set
+    assert "CreatedDate" in permission_set
+    assert "SessionDuration" in permission_set
+    assert "RelayState" in permission_set
 
 
 @mock_ssoadmin
@@ -219,28 +413,26 @@ def test_update_permission_set():
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
         SessionDuration="PT1H",
     )
-    permissionSet = resp["PermissionSet"]
+    permission_set = resp["PermissionSet"]
 
     resp = client.update_permission_set(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
-        PermissionSetArn=permissionSet["PermissionSetArn"],
+        PermissionSetArn=permission_set["PermissionSetArn"],
         Description="New description",
         SessionDuration="PT2H",
         RelayState="https://console.aws.amazon.com/s3",
     )
     resp = client.describe_permission_set(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
-        PermissionSetArn=permissionSet["PermissionSetArn"],
-    )
-    resp.should.have.key("PermissionSet")
-    permissionSet = resp["PermissionSet"]
-    permissionSet.should.have.key("Name").equals("test")
-    permissionSet.should.have.key("Description").equals("New description")
-    permissionSet.should.have.key("CreatedDate")
-    permissionSet.should.have.key("SessionDuration").equals("PT2H")
-    permissionSet.should.have.key("RelayState").equals(
-        "https://console.aws.amazon.com/s3"
+        PermissionSetArn=permission_set["PermissionSetArn"],
     )
+    assert "PermissionSet" in resp
+    permission_set = resp["PermissionSet"]
+    assert permission_set["Name"] == "test"
+    assert permission_set["Description"] == "New description"
+    assert "CreatedDate" in permission_set
+    assert permission_set["SessionDuration"] == "PT2H"
+    assert permission_set["RelayState"] == "https://console.aws.amazon.com/s3"
 
 
 @mock_ssoadmin
@@ -250,13 +442,16 @@ def test_update_permission_set_unknown():
     with pytest.raises(ClientError) as exc:
         client.update_permission_set(
             InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
-            PermissionSetArn="arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo",
+            PermissionSetArn=(
+                "arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/"
+                "ps-hhhhkkkkppppoooo"
+            ),
             Description="New description",
             SessionDuration="PT2H",
             RelayState="https://console.aws.amazon.com/s3",
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFound")
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_ssoadmin
@@ -268,19 +463,19 @@ def test_describe_permission_set():
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
         SessionDuration="PT1H",
     )
-    permissionSet = resp["PermissionSet"]
+    permission_set = resp["PermissionSet"]
 
     resp = client.describe_permission_set(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
-        PermissionSetArn=permissionSet["PermissionSetArn"],
+        PermissionSetArn=permission_set["PermissionSetArn"],
     )
-    resp.should.have.key("PermissionSet")
-    permissionSet = resp["PermissionSet"]
-    permissionSet.should.have.key("Name").equals("test")
-    permissionSet.should.have.key("PermissionSetArn")
-    permissionSet.should.have.key("Description")
-    permissionSet.should.have.key("CreatedDate")
-    permissionSet.should.have.key("SessionDuration")
+    assert "PermissionSet" in resp
+    permission_set = resp["PermissionSet"]
+    assert permission_set["Name"] == "test"
+    assert "PermissionSetArn" in permission_set
+    assert "Description" in permission_set
+    assert "CreatedDate" in permission_set
+    assert "SessionDuration" in permission_set
 
 
 @mock_ssoadmin
@@ -293,7 +488,7 @@ def test_describe_permission_set_unknown():
             PermissionSetArn="arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo",
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFound")
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_ssoadmin
@@ -305,18 +500,18 @@ def test_delete_permission_set():
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
         SessionDuration="PT1H",
     )
-    permissionSet = resp["PermissionSet"]
+    permission_set = resp["PermissionSet"]
     resp = client.delete_permission_set(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
-        PermissionSetArn=permissionSet["PermissionSetArn"],
+        PermissionSetArn=permission_set["PermissionSetArn"],
     )
     with pytest.raises(ClientError) as exc:
         client.describe_permission_set(
             InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
-            PermissionSetArn=permissionSet["PermissionSetArn"],
+            PermissionSetArn=permission_set["PermissionSetArn"],
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFound")
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_ssoadmin
@@ -329,7 +524,7 @@ def test_delete_permission_set_unknown():
             PermissionSetArn="arn:aws:sso:::permissionSet/ins-eeeeffffgggghhhh/ps-hhhhkkkkppppoooo",
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFound")
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_ssoadmin
@@ -339,9 +534,9 @@ def test_list_permission_sets():
     response = client.list_permission_sets(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
     )
-    response.should.have.key("PermissionSets")
-    permissionSets = response["PermissionSets"]
-    len(permissionSets).should.equal(0)
+    assert "PermissionSets" in response
+    permission_sets = response["PermissionSets"]
+    assert not permission_sets
 
     for i in range(5):
         client.create_permission_set(
@@ -353,9 +548,9 @@ def test_list_permission_sets():
     response = client.list_permission_sets(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
     )
-    response.should.have.key("PermissionSets")
-    permissionSets = response["PermissionSets"]
-    len(permissionSets).should.equal(5)
+    assert "PermissionSets" in response
+    permission_sets = response["PermissionSets"]
+    assert len(permission_sets) == 5
 
 
 @mock_ssoadmin
@@ -365,9 +560,9 @@ def test_list_permission_sets_pagination():
     response = client.list_permission_sets(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
     )
-    response.should.have.key("PermissionSets")
-    permissionSets = response["PermissionSets"]
-    len(permissionSets).should.equal(0)
+    assert "PermissionSets" in response
+    permission_sets = response["PermissionSets"]
+    assert not permission_sets
 
     for i in range(25):
         client.create_permission_set(
@@ -379,12 +574,12 @@ def test_list_permission_sets_pagination():
     response = client.list_permission_sets(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
     )
-    response.should.have.key("PermissionSets")
-    response.should_not.have.key("NextToken")
+    assert "PermissionSets" in response
+    assert "NextToken" not in response
 
     paginator = client.get_paginator("list_permission_sets")
     page_iterator = paginator.paginate(
         InstanceArn="arn:aws:sso:::instance/ins-aaaabbbbccccdddd", MaxResults=5
     )
     for page in page_iterator:
-        len(page["PermissionSets"]).should.be.lower_than_or_equal_to(5)
+        assert len(page["PermissionSets"]) <= 5
