@@ -1,8 +1,8 @@
-import boto3
 import json
-import sure  # noqa # pylint: disable=unused-import
-from botocore.exceptions import ClientError
+
+import boto3
 import pytest
+from botocore.exceptions import ClientError
 
 from moto import mock_cloudformation, mock_stepfunctions
 
@@ -12,7 +12,12 @@ from moto import mock_cloudformation, mock_stepfunctions
 def test_state_machine_cloudformation():
     sf = boto3.client("stepfunctions", region_name="us-east-1")
     cf = boto3.resource("cloudformation", region_name="us-east-1")
-    definition = '{"StartAt": "HelloWorld", "States": {"HelloWorld": {"Type": "Task", "Resource": "arn:aws:lambda:us-east-1:111122223333;:function:HelloFunction", "End": true}}}'
+    definition = (
+        '{"StartAt": "HelloWorld", '
+        '"States": {"HelloWorld": {"Type": "Task", '
+        '"Resource": "arn:aws:lambda:us-east-1:111122223333;:function:HelloFunction", '
+        '"End": true}}}'
+    )
     role_arn = (
         "arn:aws:iam::111122223333:role/service-role/StatesExecutionRole-us-east-1;"
     )
@@ -43,20 +48,20 @@ def test_state_machine_cloudformation():
     outputs_list = cf.Stack("test_stack").outputs
     output = {item["OutputKey"]: item["OutputValue"] for item in outputs_list}
     state_machine = sf.describe_state_machine(stateMachineArn=output["StateMachineArn"])
-    state_machine["stateMachineArn"].should.equal(output["StateMachineArn"])
-    state_machine["name"].should.equal(output["StateMachineName"])
-    state_machine["roleArn"].should.equal(role_arn)
-    state_machine["definition"].should.equal(definition)
+    assert state_machine["stateMachineArn"] == output["StateMachineArn"]
+    assert state_machine["name"] == output["StateMachineName"]
+    assert state_machine["roleArn"] == role_arn
+    assert state_machine["definition"] == definition
     tags = sf.list_tags_for_resource(resourceArn=output["StateMachineArn"]).get("tags")
     for i, tag in enumerate(tags, 1):
-        tag["key"].should.equal("key{}".format(i))
-        tag["value"].should.equal("value{}".format(i))
+        assert tag["key"] == f"key{i}"
+        assert tag["value"] == f"value{i}"
 
     cf.Stack("test_stack").delete()
     with pytest.raises(ClientError) as ex:
         sf.describe_state_machine(stateMachineArn=output["StateMachineArn"])
-    ex.value.response["Error"]["Code"].should.equal("StateMachineDoesNotExist")
-    ex.value.response["Error"]["Message"].should.contain("Does Not Exist")
+    assert ex.value.response["Error"]["Code"] == "StateMachineDoesNotExist"
+    assert "Does Not Exist" in ex.value.response["Error"]["Message"]
 
 
 @mock_stepfunctions
@@ -64,7 +69,12 @@ def test_state_machine_cloudformation():
 def test_state_machine_cloudformation_update_with_replacement():
     sf = boto3.client("stepfunctions", region_name="us-east-1")
     cf = boto3.resource("cloudformation", region_name="us-east-1")
-    definition = '{"StartAt": "HelloWorld", "States": {"HelloWorld": {"Type": "Task", "Resource": "arn:aws:lambda:us-east-1:111122223333;:function:HelloFunction", "End": true}}}'
+    definition = (
+        '{"StartAt": "HelloWorld", '
+        '"States": {"HelloWorld": {"Type": "Task", '
+        '"Resource": "arn:aws:lambda:us-east-1:111122223333;:function:HelloFunction", '
+        '"End": true}}}'
+    )
     role_arn = (
         "arn:aws:iam::111122223333:role/service-role/StatesExecutionRole-us-east-1"
     )
@@ -116,21 +126,21 @@ def test_state_machine_cloudformation_update_with_replacement():
     outputs_list = cf.Stack("test_stack").outputs
     output = {item["OutputKey"]: item["OutputValue"] for item in outputs_list}
     state_machine = sf.describe_state_machine(stateMachineArn=output["StateMachineArn"])
-    state_machine["stateMachineArn"].should_not.equal(original_machine_arn)
-    state_machine["name"].should.equal("New-StateMachine-Name")
-    state_machine["creationDate"].should.be.greater_than(original_creation_date)
-    state_machine["roleArn"].should.equal(updated_role)
-    state_machine["definition"].should.equal(updated_definition)
+    assert state_machine["stateMachineArn"] != original_machine_arn
+    assert state_machine["name"] == "New-StateMachine-Name"
+    assert state_machine["creationDate"] > original_creation_date
+    assert state_machine["roleArn"] == updated_role
+    assert state_machine["definition"] == updated_definition
     tags = sf.list_tags_for_resource(resourceArn=output["StateMachineArn"]).get("tags")
-    tags.should.have.length_of(3)
+    assert len(tags) == 3
     for tag in tags:
         if tag["key"] == "key1":
-            tag["value"].should.equal("updated_value")
+            assert tag["value"] == "updated_value"
 
     with pytest.raises(ClientError) as ex:
         sf.describe_state_machine(stateMachineArn=original_machine_arn)
-    ex.value.response["Error"]["Code"].should.equal("StateMachineDoesNotExist")
-    ex.value.response["Error"]["Message"].should.contain("State Machine Does Not Exist")
+    assert ex.value.response["Error"]["Code"] == "StateMachineDoesNotExist"
+    assert "State Machine Does Not Exist" in ex.value.response["Error"]["Message"]
 
 
 @mock_stepfunctions
@@ -138,7 +148,12 @@ def test_state_machine_cloudformation_update_with_replacement():
 def test_state_machine_cloudformation_update_with_no_interruption():
     sf = boto3.client("stepfunctions", region_name="us-east-1")
     cf = boto3.resource("cloudformation", region_name="us-east-1")
-    definition = '{"StartAt": "HelloWorld", "States": {"HelloWorld": {"Type": "Task", "Resource": "arn:aws:lambda:us-east-1:111122223333;:function:HelloFunction", "End": true}}}'
+    definition = (
+        '{"StartAt": "HelloWorld", '
+        '"States": {"HelloWorld": {"Type": '
+        '"Task", "Resource": "arn:aws:lambda:us-east-1:111122223333;:function:HelloFunction", '
+        '"End": true}}}'
+    )
     role_arn = (
         "arn:aws:iam::111122223333:role/service-role/StatesExecutionRole-us-east-1"
     )
@@ -188,12 +203,12 @@ def test_state_machine_cloudformation_update_with_no_interruption():
     cf.Stack("test_stack").update(TemplateBody=json.dumps(template))
 
     state_machine = sf.describe_state_machine(stateMachineArn=machine_arn)
-    state_machine["name"].should.equal("HelloWorld-StateMachine")
-    state_machine["creationDate"].should.equal(creation_date)
-    state_machine["roleArn"].should.equal(updated_role)
-    state_machine["definition"].should.equal(updated_definition)
+    assert state_machine["name"] == "HelloWorld-StateMachine"
+    assert state_machine["creationDate"] == creation_date
+    assert state_machine["roleArn"] == updated_role
+    assert state_machine["definition"] == updated_definition
     tags = sf.list_tags_for_resource(resourceArn=machine_arn).get("tags")
-    tags.should.have.length_of(3)
+    assert len(tags) == 3
     for tag in tags:
         if tag["key"] == "key1":
-            tag["value"].should.equal("updated_value")
+            assert tag["value"] == "updated_value"
