@@ -1,20 +1,15 @@
-import sure  # noqa # pylint: disable=unused-import
-
+"""Test the different server responses."""
 import moto.server as server
 
-"""
-Test the different server responses
-"""
-
 
 def test_sts_get_session_token():
     backend = server.create_backend_app("sts")
     test_client = backend.test_client()
 
     res = test_client.get("/?Action=GetSessionToken")
-    res.status_code.should.equal(200)
-    res.data.should.contain(b"SessionToken")
-    res.data.should.contain(b"AccessKeyId")
+    assert res.status_code == 200
+    assert b"SessionToken" in res.data
+    assert b"AccessKeyId" in res.data
 
 
 def test_sts_get_federation_token():
@@ -22,9 +17,9 @@ def test_sts_get_federation_token():
     test_client = backend.test_client()
 
     res = test_client.get("/?Action=GetFederationToken&Name=Bob")
-    res.status_code.should.equal(200)
-    res.data.should.contain(b"SessionToken")
-    res.data.should.contain(b"AccessKeyId")
+    assert res.status_code == 200
+    assert b"SessionToken" in res.data
+    assert b"AccessKeyId" in res.data
 
 
 def test_sts_get_caller_identity():
@@ -32,10 +27,10 @@ def test_sts_get_caller_identity():
     test_client = backend.test_client()
 
     res = test_client.get("/?Action=GetCallerIdentity")
-    res.status_code.should.equal(200)
-    res.data.should.contain(b"Arn")
-    res.data.should.contain(b"UserId")
-    res.data.should.contain(b"Account")
+    assert res.status_code == 200
+    assert b"Arn" in res.data
+    assert b"UserId" in res.data
+    assert b"Account" in res.data
 
 
 def test_sts_wellformed_xml():
@@ -43,8 +38,8 @@ def test_sts_wellformed_xml():
     test_client = backend.test_client()
 
     res = test_client.get("/?Action=GetFederationToken&Name=Bob")
-    res.data.should_not.contain(b"\n")
+    assert b"\n" not in res.data
     res = test_client.get("/?Action=GetSessionToken")
-    res.data.should_not.contain(b"\n")
+    assert b"\n" not in res.data
     res = test_client.get("/?Action=GetCallerIdentity")
-    res.data.should_not.contain(b"\n")
+    assert b"\n" not in res.data
