@@ -1,8 +1,9 @@
-import boto3
 import unittest
-
 from base64 import b64encode
-from moto import mock_dynamodb, mock_sts, mock_iam
+
+import boto3
+
+from moto import mock_dynamodb, mock_iam, mock_sts
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
@@ -32,7 +33,7 @@ class TestStsAssumeRole(unittest.TestCase):
             region_name="us-east-1",
         )
         assumed_arn = sts_account_b.get_caller_identity()["Arn"]
-        assumed_arn.should.equal(
+        assert assumed_arn == (
             f"arn:aws:sts::{self.account_b}:assumed-role/my-role/test-session-name"
         )
         iam_account_b = boto3.client(
@@ -45,7 +46,7 @@ class TestStsAssumeRole(unittest.TestCase):
 
         # Verify new users belong to the different account
         user = iam_account_b.create_user(UserName="user-in-new-account")["User"]
-        user["Arn"].should.equal(
+        assert user["Arn"] == (
             f"arn:aws:iam::{self.account_b}:user/user-in-new-account"
         )
 
@@ -135,7 +136,7 @@ class TestStsAssumeRole(unittest.TestCase):
 
         # Verify new users belong to the different account
         user = iam_account_b.create_user(UserName="user-in-new-account")["User"]
-        user["Arn"].should.equal(
+        assert user["Arn"] == (
             f"arn:aws:iam::{self.account_b}:user/user-in-new-account"
         )
 
@@ -174,11 +175,11 @@ class TestStsAssumeRole(unittest.TestCase):
         )
 
         table = ddb_client.describe_table(TableName="table-in-default-account")["Table"]
-        table["TableArn"].should.equal(
+        assert table["TableArn"] == (
             "arn:aws:dynamodb:us-east-1:123456789012:table/table-in-default-account"
         )
 
         table = ddb_account_b.describe_table(TableName="table-in-new-account")["Table"]
-        table["TableArn"].should.equal(
+        assert table["TableArn"] == (
             f"arn:aws:dynamodb:us-east-1:{self.account_b}:table/table-in-new-account"
         )
