@@ -1,7 +1,6 @@
 import boto3
-from botocore.exceptions import ClientError
-import sure  # noqa # pylint: disable=unused-import
 import pytest
+from botocore.exceptions import ClientError
 
 from moto import mock_swf
 
@@ -20,10 +19,10 @@ def test_register_activity_type_boto3():
     types = client.list_activity_types(
         domain="test-domain", registrationStatus="REGISTERED"
     )["typeInfos"]
-    types.should.have.length_of(1)
+    assert len(types) == 1
     actype = types[0]
-    actype["activityType"]["name"].should.equal("test-activity")
-    actype["activityType"]["version"].should.equal("v1.0")
+    assert actype["activityType"]["name"] == "test-activity"
+    assert actype["activityType"]["version"] == "v1.0"
 
 
 @mock_swf
@@ -40,11 +39,11 @@ def test_register_already_existing_activity_type_boto3():
         client.register_activity_type(
             domain="test-domain", name="test-activity", version="v1.0"
         )
-    ex.value.response["Error"]["Code"].should.equal("TypeAlreadyExistsFault")
-    ex.value.response["Error"]["Message"].should.equal(
+    assert ex.value.response["Error"]["Code"] == "TypeAlreadyExistsFault"
+    assert ex.value.response["Error"]["Message"] == (
         "ActivityType=[name=test-activity, version=v1.0]"
     )
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
 # ListActivityTypes endpoint
@@ -73,7 +72,7 @@ def test_list_activity_types_boto3():
     names = [
         activity_type["activityType"]["name"] for activity_type in types["typeInfos"]
     ]
-    names.should.equal(["a-test-activity", "b-test-activity", "c-test-activity"])
+    assert names == ["a-test-activity", "b-test-activity", "c-test-activity"]
 
 
 @mock_swf
@@ -99,7 +98,7 @@ def test_list_activity_types_reverse_order_boto3():
     names = [
         activity_type["activityType"]["name"] for activity_type in types["typeInfos"]
     ]
-    names.should.equal(["c-test-activity", "b-test-activity", "a-test-activity"])
+    assert names == ["c-test-activity", "b-test-activity", "a-test-activity"]
 
 
 # DeprecateActivityType endpoint
@@ -119,10 +118,10 @@ def test_deprecate_activity_type_boto3():
     types = client.list_activity_types(
         domain="test-domain", registrationStatus="DEPRECATED"
     )
-    types.should.have.key("typeInfos").being.length_of(1)
+    assert len(types["typeInfos"]) == 1
     actype = types["typeInfos"][0]
-    actype["activityType"]["name"].should.equal("test-activity")
-    actype["activityType"]["version"].should.equal("v1.0")
+    assert actype["activityType"]["name"] == "test-activity"
+    assert actype["activityType"]["version"] == "v1.0"
 
 
 @mock_swf
@@ -143,11 +142,11 @@ def test_deprecate_already_deprecated_activity_type_boto3():
             domain="test-domain",
             activityType={"name": "test-activity", "version": "v1.0"},
         )
-    ex.value.response["Error"]["Code"].should.equal("TypeDeprecatedFault")
-    ex.value.response["Error"]["Message"].should.equal(
+    assert ex.value.response["Error"]["Code"] == "TypeDeprecatedFault"
+    assert ex.value.response["Error"]["Message"] == (
         "ActivityType=[name=test-activity, version=v1.0]"
     )
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
 @mock_swf
@@ -162,11 +161,11 @@ def test_deprecate_non_existent_activity_type_boto3():
             domain="test-domain",
             activityType={"name": "test-activity", "version": "v1.0"},
         )
-    ex.value.response["Error"]["Code"].should.equal("UnknownResourceFault")
-    ex.value.response["Error"]["Message"].should.equal(
+    assert ex.value.response["Error"]["Code"] == "UnknownResourceFault"
+    assert ex.value.response["Error"]["Message"] == (
         "Unknown type: ActivityType=[name=test-activity, version=v1.0]"
     )
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
 # DeprecateActivityType endpoint
@@ -189,7 +188,7 @@ def test_undeprecate_activity_type():
     resp = client.describe_activity_type(
         domain="test-domain", activityType={"name": "test-activity", "version": "v1.0"}
     )
-    resp["typeInfo"]["status"].should.equal("REGISTERED")
+    assert resp["typeInfo"]["status"] == "REGISTERED"
 
 
 @mock_swf
@@ -208,9 +207,11 @@ def test_undeprecate_already_undeprecated_activity_type():
         domain="test-domain", activityType={"name": "test-activity", "version": "v1.0"}
     )
 
-    client.undeprecate_activity_type.when.called_with(
-        domain="test-domain", activityType={"name": "test-activity", "version": "v1.0"}
-    ).should.throw(ClientError)
+    with pytest.raises(ClientError):
+        client.undeprecate_activity_type(
+            domain="test-domain",
+            activityType={"name": "test-activity", "version": "v1.0"},
+        )
 
 
 @mock_swf
@@ -223,9 +224,11 @@ def test_undeprecate_never_deprecated_activity_type():
         domain="test-domain", name="test-activity", version="v1.0"
     )
 
-    client.undeprecate_activity_type.when.called_with(
-        domain="test-domain", activityType={"name": "test-activity", "version": "v1.0"}
-    ).should.throw(ClientError)
+    with pytest.raises(ClientError):
+        client.undeprecate_activity_type(
+            domain="test-domain",
+            activityType={"name": "test-activity", "version": "v1.0"},
+        )
 
 
 @mock_swf
@@ -235,9 +238,11 @@ def test_undeprecate_non_existent_activity_type():
         name="test-domain", workflowExecutionRetentionPeriodInDays="60"
     )
 
-    client.undeprecate_activity_type.when.called_with(
-        domain="test-domain", activityType={"name": "test-activity", "version": "v1.0"}
-    ).should.throw(ClientError)
+    with pytest.raises(ClientError):
+        client.undeprecate_activity_type(
+            domain="test-domain",
+            activityType={"name": "test-activity", "version": "v1.0"},
+        )
 
 
 # DescribeActivityType endpoint
@@ -258,11 +263,11 @@ def test_describe_activity_type_boto3():
     actype = client.describe_activity_type(
         domain="test-domain", activityType={"name": "test-activity", "version": "v1.0"}
     )
-    actype["configuration"]["defaultTaskList"]["name"].should.equal("foo")
+    assert actype["configuration"]["defaultTaskList"]["name"] == "foo"
     infos = actype["typeInfo"]
-    infos["activityType"]["name"].should.equal("test-activity")
-    infos["activityType"]["version"].should.equal("v1.0")
-    infos["status"].should.equal("REGISTERED")
+    assert infos["activityType"]["name"] == "test-activity"
+    assert infos["activityType"]["version"] == "v1.0"
+    assert infos["status"] == "REGISTERED"
 
 
 @mock_swf
@@ -277,8 +282,8 @@ def test_describe_non_existent_activity_type_boto3():
             domain="test-domain",
             activityType={"name": "test-activity", "version": "v1.0"},
         )
-    ex.value.response["Error"]["Code"].should.equal("UnknownResourceFault")
-    ex.value.response["Error"]["Message"].should.equal(
+    assert ex.value.response["Error"]["Code"] == "UnknownResourceFault"
+    assert ex.value.response["Error"]["Message"] == (
         "Unknown type: ActivityType=[name=test-activity, version=v1.0]"
     )
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
