@@ -1,12 +1,13 @@
 """Unit tests for textract-supported APIs."""
 from random import randint
-from botocore.exceptions import ClientError, ParamValidationError
-import pytest
-import boto3
-
 from unittest import SkipTest
+
+import boto3
+import pytest
+from botocore.exceptions import ClientError, ParamValidationError
+
+from moto import mock_textract, settings
 from moto.textract.models import TextractBackend
-from moto import settings, mock_textract
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
@@ -83,3 +84,18 @@ def test_get_document_text_detection_without_document_location():
         'Parameter validation failed:\nMissing required parameter in input: "DocumentLocation"'
         in e.value.args
     )
+
+
+@mock_textract
+def test_detect_document_text():
+    client = boto3.client("textract", region_name="us-east-1")
+    result = client.detect_document_text(
+        Document={
+            "S3Object": {
+                "Bucket": "bucket",
+                "Name": "name.jpg",
+            }
+        }
+    )
+    assert isinstance(result["Blocks"], list)
+    assert result["DetectDocumentTextModelVersion"] == "1.0"
