@@ -1,26 +1,40 @@
+from uuid import uuid4
+
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_timestreamwrite
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
+from . import timestreamwrite_aws_verified
 
-@mock_timestreamwrite
+
+@pytest.mark.aws_verified
+@timestreamwrite_aws_verified
 def test_create_database_simple():
     ts = boto3.client("timestream-write", region_name="us-east-1")
-    resp = ts.create_database(DatabaseName="mydatabase")
-    database = resp["Database"]
+    db_name = "db_" + str(uuid4())[0:6]
 
-    database.should.have.key("Arn").equals(
-        f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase"
-    )
-    database.should.have.key("DatabaseName").equals("mydatabase")
-    database.should.have.key("TableCount").equals(0)
-    database.should.have.key("KmsKeyId").equals(
-        f"arn:aws:kms:us-east-1:{ACCOUNT_ID}:key/default_key"
-    )
+    identity = boto3.client("sts", region_name="us-east-1").get_caller_identity()
+    account_id = identity["Account"]
+
+    try:
+        database = ts.create_database(DatabaseName=db_name)["Database"]
+
+        assert (
+            database["Arn"]
+            == f"arn:aws:timestream:us-east-1:{account_id}:database/{db_name}"
+        )
+        assert db_name == db_name
+        assert database["TableCount"] == 0
+        assert database["KmsKeyId"].startswith(
+            f"arn:aws:kms:us-east-1:{account_id}:key/"
+        )
+        assert "CreationTime" in database
+        assert "LastUpdatedTime" in database
+    finally:
+        ts.delete_database(DatabaseName=db_name)
 
 
 @mock_timestreamwrite
@@ -33,12 +47,12 @@ def test_create_database_advanced():
     )
     database = resp["Database"]
 
-    database.should.have.key("Arn").equals(
+    assert database["Arn"] == (
         f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase"
     )
-    database.should.have.key("DatabaseName").equals("mydatabase")
-    database.should.have.key("TableCount").equals(0)
-    database.should.have.key("KmsKeyId").equal("mykey")
+    assert database["DatabaseName"] == "mydatabase"
+    assert database["TableCount"] == 0
+    assert database["KmsKeyId"] == "mykey"
 
 
 @mock_timestreamwrite
@@ -48,22 +62,23 @@ def test_describe_database():
 
     database = ts.describe_database(DatabaseName="mydatabase")["Database"]
 
-    database.should.have.key("Arn").equals(
+    assert database["Arn"] == (
         f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase"
     )
-    database.should.have.key("DatabaseName").equals("mydatabase")
-    database.should.have.key("TableCount").equals(0)
-    database.should.have.key("KmsKeyId").equal("mykey")
+    assert database["DatabaseName"] == "mydatabase"
+    assert database["TableCount"] == 0
+    assert database["KmsKeyId"] == "mykey"
 
 
-@mock_timestreamwrite
+@pytest.mark.aws_verified
+@timestreamwrite_aws_verified
 def test_describe_unknown_database():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     with pytest.raises(ClientError) as exc:
         ts.describe_database(DatabaseName="unknown")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal("The database unknown does not exist.")
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "The database unknown does not exist."
 
 
 @mock_timestreamwrite
@@ -74,23 +89,24 @@ def test_list_databases():
 
     resp = ts.list_databases()
     databases = resp["Databases"]
-    databases.should.have.length_of(2)
-    databases.should.contain(
-        {
-            "Arn": f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/db_with",
-            "DatabaseName": "db_with",
-            "TableCount": 0,
-            "KmsKeyId": "mykey",
-        }
-    )
-    databases.should.contain(
-        {
-            "Arn": f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/db_without",
-            "DatabaseName": "db_without",
-            "TableCount": 0,
-            "KmsKeyId": f"arn:aws:kms:us-east-1:{ACCOUNT_ID}:key/default_key",
-        }
-    )
+    assert len(databases) == 2
+
+    for db in databases:
+        db.pop("CreationTime")
+        db.pop("LastUpdatedTime")
+
+    assert {
+        "Arn": f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/db_with",
+        "DatabaseName": "db_with",
+        "TableCount": 0,
+        "KmsKeyId": "mykey",
+    } in databases
+    assert {
+        "Arn": f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/db_without",
+        "DatabaseName": "db_without",
+        "TableCount": 0,
+        "KmsKeyId": f"arn:aws:kms:us-east-1:{ACCOUNT_ID}:key/default_key",
+    } in databases
 
 
 @mock_timestreamwrite
@@ -100,13 +116,13 @@ def test_delete_database():
     ts.create_database(DatabaseName="db_2")
     ts.create_database(DatabaseName="db_3", KmsKeyId="mysecondkey")
 
-    ts.list_databases()["Databases"].should.have.length_of(3)
+    assert len(ts.list_databases()["Databases"]) == 3
 
     ts.delete_database(DatabaseName="db_2")
 
     databases = ts.list_databases()["Databases"]
-    databases.should.have.length_of(2)
-    [db["DatabaseName"] for db in databases].should.equal(["db_1", "db_3"])
+    assert len(databases) == 2
+    assert [db["DatabaseName"] for db in databases] == ["db_1", "db_3"]
 
 
 @mock_timestreamwrite
@@ -114,10 +130,10 @@ def test_update_database():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     ts.create_database(DatabaseName="mydatabase", KmsKeyId="mykey")
     resp = ts.update_database(DatabaseName="mydatabase", KmsKeyId="updatedkey")
-    resp.should.have.key("Database")
+    assert "Database" in resp
     database = resp["Database"]
-    database.should.have.key("Arn")
-    database.should.have.key("KmsKeyId").equal("updatedkey")
+    assert "Arn" in database
+    assert database["KmsKeyId"] == "updatedkey"
 
     database = ts.describe_database(DatabaseName="mydatabase")["Database"]
-    database.should.have.key("KmsKeyId").equal("updatedkey")
+    assert database["KmsKeyId"] == "updatedkey"
