@@ -1,92 +1,125 @@
 import time
+from uuid import uuid4
+
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
-
 from botocore.exceptions import ClientError
+
 from moto import mock_timestreamwrite, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
+from . import timestreamwrite_aws_verified
 
-@mock_timestreamwrite
+
+@pytest.mark.aws_verified
+@timestreamwrite_aws_verified
 def test_create_table():
     ts = boto3.client("timestream-write", region_name="us-east-1")
-    ts.create_database(DatabaseName="mydatabase")
+    db_name = "db_" + str(uuid4())[0:6]
+    table_name = "t_" + str(uuid4())[0:6]
 
-    resp = ts.create_table(
-        DatabaseName="mydatabase",
-        TableName="mytable",
-        RetentionProperties={
-            "MemoryStoreRetentionPeriodInHours": 7,
-            "MagneticStoreRetentionPeriodInDays": 42,
-        },
-    )
-    table = resp["Table"]
-    table.should.have.key("Arn").equal(
-        f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase/table/mytable"
-    )
-    table.should.have.key("TableName").equal("mytable")
-    table.should.have.key("DatabaseName").equal("mydatabase")
-    table.should.have.key("TableStatus").equal("ACTIVE")
-    table.should.have.key("RetentionProperties").should.equal(
-        {
+    identity = boto3.client("sts", region_name="us-east-1").get_caller_identity()
+    account_id = identity["Account"]
+
+    try:
+        ts.create_database(DatabaseName=db_name)
+
+        resp = ts.create_table(
+            DatabaseName=db_name,
+            TableName=table_name,
+            RetentionProperties={
+                "MemoryStoreRetentionPeriodInHours": 7,
+                "MagneticStoreRetentionPeriodInDays": 42,
+            },
+        )
+        table = resp["Table"]
+        assert table["Arn"] == (
+            f"arn:aws:timestream:us-east-1:{account_id}:database/{db_name}/table/{table_name}"
+        )
+        assert table["TableName"] == table_name
+        assert table["DatabaseName"] == db_name
+        assert table["TableStatus"] == "ACTIVE"
+        assert table["RetentionProperties"] == {
             "MemoryStoreRetentionPeriodInHours": 7,
             "MagneticStoreRetentionPeriodInDays": 42,
         }
-    )
+    finally:
+        ts.delete_table(DatabaseName=db_name, TableName=table_name)
+        ts.delete_database(DatabaseName=db_name)
 
 
-@mock_timestreamwrite
+@pytest.mark.aws_verified
+@timestreamwrite_aws_verified
 def test_create_table__with_magnetic_store_write_properties():
     ts = boto3.client("timestream-write", region_name="us-east-1")
-    ts.create_database(DatabaseName="mydatabase")
+    db_name = "db_" + str(uuid4())[0:6]
+    table_name = "t_" + str(uuid4())[0:6]
 
-    resp = ts.create_table(
-        DatabaseName="mydatabase",
-        TableName="mytable",
-        MagneticStoreWriteProperties={
-            "EnableMagneticStoreWrites": True,
-            "MagneticStoreRejectedDataLocation": {
-                "S3Configuration": {"BucketName": "hithere"}
+    identity = boto3.client("sts", region_name="us-east-1").get_caller_identity()
+    account_id = identity["Account"]
+
+    bucket_name = f"b-{str(uuid4())[0:6]}"
+    s3 = boto3.client("s3", region_name="us-east-1")
+    s3.create_bucket(Bucket=bucket_name)
+
+    try:
+        ts.create_database(DatabaseName=db_name)
+
+        table = ts.create_table(
+            DatabaseName=db_name,
+            TableName=table_name,
+            MagneticStoreWriteProperties={
+                "EnableMagneticStoreWrites": True,
+                "MagneticStoreRejectedDataLocation": {
+                    "S3Configuration": {"BucketName": bucket_name}
+                },
             },
-        },
-    )
-    table = resp["Table"]
-    table.should.have.key("Arn").equal(
-        f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase/table/mytable"
-    )
-    table.should.have.key("TableName").equal("mytable")
-    table.should.have.key("DatabaseName").equal("mydatabase")
-    table.should.have.key("TableStatus").equal("ACTIVE")
-    table.should.have.key("MagneticStoreWriteProperties").should.equal(
-        {
+        )["Table"]
+        assert table["Arn"] == (
+            f"arn:aws:timestream:us-east-1:{account_id}:database/{db_name}/table/{table_name}"
+        )
+        assert table["TableName"] == table_name
+        assert table["DatabaseName"] == db_name
+        assert table["TableStatus"] == "ACTIVE"
+        assert table["MagneticStoreWriteProperties"] == {
             "EnableMagneticStoreWrites": True,
             "MagneticStoreRejectedDataLocation": {
-                "S3Configuration": {"BucketName": "hithere"}
+                "S3Configuration": {"BucketName": bucket_name}
             },
         }
-    )
+    finally:
+        ts.delete_table(DatabaseName=db_name, TableName=table_name)
+        ts.delete_database(DatabaseName=db_name)
+        s3.delete_bucket(Bucket=bucket_name)
 
 
-@mock_timestreamwrite
+@pytest.mark.aws_verified
+@timestreamwrite_aws_verified
 def test_create_table_without_retention_properties():
     ts = boto3.client("timestream-write", region_name="us-east-1")
-    ts.create_database(DatabaseName="mydatabase")
+    db_name = "db_" + str(uuid4())[0:6]
+    table_name = "t_" + str(uuid4())[0:6]
 
-    resp = ts.create_table(DatabaseName="mydatabase", TableName="mytable")
-    table = resp["Table"]
-    table.should.have.key("Arn").equal(
-        f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase/table/mytable"
-    )
-    table.should.have.key("TableName").equal("mytable")
-    table.should.have.key("DatabaseName").equal("mydatabase")
-    table.should.have.key("TableStatus").equal("ACTIVE")
-    table.should.have.key("RetentionProperties").equals(
-        {
-            "MemoryStoreRetentionPeriodInHours": 123,
-            "MagneticStoreRetentionPeriodInDays": 123,
+    identity = boto3.client("sts", region_name="us-east-1").get_caller_identity()
+    account_id = identity["Account"]
+
+    try:
+        ts.create_database(DatabaseName=db_name)
+
+        table = ts.create_table(DatabaseName=db_name, TableName=table_name)["Table"]
+        assert table["Arn"] == (
+            f"arn:aws:timestream:us-east-1:{account_id}:database/{db_name}/table/{table_name}"
+        )
+        assert table["TableName"] == table_name
+        assert table["DatabaseName"] == db_name
+        assert table["TableStatus"] == "ACTIVE"
+        assert table["RetentionProperties"] == {
+            "MemoryStoreRetentionPeriodInHours": 6,
+            "MagneticStoreRetentionPeriodInDays": 73000,
         }
-    )
+    finally:
+        ts.delete_table(DatabaseName=db_name, TableName=table_name)
+        ts.delete_database(DatabaseName=db_name)
 
 
 @mock_timestreamwrite
@@ -104,30 +137,34 @@ def test_describe_table():
     )
 
     table = ts.describe_table(DatabaseName="mydatabase", TableName="mytable")["Table"]
-    table.should.have.key("Arn").equal(
+    assert table["Arn"] == (
         f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase/table/mytable"
     )
-    table.should.have.key("TableName").equal("mytable")
-    table.should.have.key("DatabaseName").equal("mydatabase")
-    table.should.have.key("TableStatus").equal("ACTIVE")
-    table.should.have.key("RetentionProperties").should.equal(
-        {
-            "MemoryStoreRetentionPeriodInHours": 10,
-            "MagneticStoreRetentionPeriodInDays": 12,
-        }
-    )
+    assert table["TableName"] == "mytable"
+    assert table["DatabaseName"] == "mydatabase"
+    assert table["TableStatus"] == "ACTIVE"
+    assert table["RetentionProperties"] == {
+        "MemoryStoreRetentionPeriodInHours": 10,
+        "MagneticStoreRetentionPeriodInDays": 12,
+    }
 
 
-@mock_timestreamwrite
+@pytest.mark.aws_verified
+@timestreamwrite_aws_verified
 def test_describe_unknown_database():
     ts = boto3.client("timestream-write", region_name="us-east-1")
-    ts.create_database(DatabaseName="mydatabase")
+    db_name = "db_" + str(uuid4())[0:6]
 
-    with pytest.raises(ClientError) as exc:
-        ts.describe_table(DatabaseName="mydatabase", TableName="unknown")
-    err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal("The table unknown does not exist.")
+    try:
+        ts.create_database(DatabaseName=db_name)
+
+        with pytest.raises(ClientError) as exc:
+            ts.describe_table(DatabaseName=db_name, TableName="unknown")
+        err = exc.value.response["Error"]
+        assert err["Code"] == "ResourceNotFoundException"
+        assert err["Message"] == "The table unknown does not exist."
+    finally:
+        ts.delete_database(DatabaseName=db_name)
 
 
 @mock_timestreamwrite
@@ -147,15 +184,19 @@ def test_create_multiple_tables():
 
     database = ts.describe_database(DatabaseName="mydatabase")["Database"]
 
-    database.should.have.key("TableCount").equals(5)
+    assert database["TableCount"] == 5
 
     tables = ts.list_tables(DatabaseName="mydatabase")["Tables"]
-    tables.should.have.length_of(5)
-    set([t["DatabaseName"] for t in tables]).should.equal({"mydatabase"})
-    set([t["TableName"] for t in tables]).should.equal(
-        {"mytable_0", "mytable_1", "mytable_2", "mytable_3", "mytable_4"}
-    )
-    set([t["TableStatus"] for t in tables]).should.equal({"ACTIVE"})
+    assert len(tables) == 5
+    assert {t["DatabaseName"] for t in tables} == {"mydatabase"}
+    assert {t["TableName"] for t in tables} == {
+        "mytable_0",
+        "mytable_1",
+        "mytable_2",
+        "mytable_3",
+        "mytable_4",
+    }
+    assert {t["TableStatus"] for t in tables} == {"ACTIVE"}
 
 
 @mock_timestreamwrite
@@ -174,13 +215,13 @@ def test_delete_table():
         )
 
     tables = ts.list_tables(DatabaseName="mydatabase")["Tables"]
-    tables.should.have.length_of(3)
+    assert len(tables) == 3
 
     ts.delete_table(DatabaseName="mydatabase", TableName="mytable_1")
 
     tables = ts.list_tables(DatabaseName="mydatabase")["Tables"]
-    tables.should.have.length_of(2)
-    set([t["TableName"] for t in tables]).should.equal({"mytable_0", "mytable_2"})
+    assert len(tables) == 2
+    assert {t["TableName"] for t in tables} == {"mytable_0", "mytable_2"}
 
 
 @mock_timestreamwrite
@@ -198,26 +239,22 @@ def test_update_table():
         },
     )
     table = resp["Table"]
-    table.should.have.key("RetentionProperties").equals(
-        {
-            "MagneticStoreRetentionPeriodInDays": 2,
-            "MemoryStoreRetentionPeriodInHours": 1,
-        }
-    )
+    assert table["RetentionProperties"] == {
+        "MagneticStoreRetentionPeriodInDays": 2,
+        "MemoryStoreRetentionPeriodInHours": 1,
+    }
 
     table = ts.describe_table(DatabaseName="mydatabase", TableName="mytable")["Table"]
-    table.should.have.key("Arn").equal(
+    assert table["Arn"] == (
         f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase/table/mytable"
     )
-    table.should.have.key("TableName").equal("mytable")
-    table.should.have.key("DatabaseName").equal("mydatabase")
-    table.should.have.key("TableStatus").equal("ACTIVE")
-    table.should.have.key("RetentionProperties").equals(
-        {
-            "MagneticStoreRetentionPeriodInDays": 2,
-            "MemoryStoreRetentionPeriodInHours": 1,
-        }
-    )
+    assert table["TableName"] == "mytable"
+    assert table["DatabaseName"] == "mydatabase"
+    assert table["TableStatus"] == "ACTIVE"
+    assert table["RetentionProperties"] == {
+        "MagneticStoreRetentionPeriodInDays": 2,
+        "MemoryStoreRetentionPeriodInHours": 1,
+    }
 
 
 @mock_timestreamwrite
@@ -238,20 +275,18 @@ def test_update_table__with_magnetic_store_write_properties():
         },
     )
     table = resp["Table"]
-    table.should.have.key("Arn").equal(
+    assert table["Arn"] == (
         f"arn:aws:timestream:us-east-1:{ACCOUNT_ID}:database/mydatabase/table/mytable"
     )
-    table.should.have.key("TableName").equal("mytable")
-    table.should.have.key("DatabaseName").equal("mydatabase")
-    table.should.have.key("TableStatus").equal("ACTIVE")
-    table.should.have.key("MagneticStoreWriteProperties").should.equal(
-        {
-            "EnableMagneticStoreWrites": True,
-            "MagneticStoreRejectedDataLocation": {
-                "S3Configuration": {"BucketName": "hithere"}
-            },
-        }
-    )
+    assert table["TableName"] == "mytable"
+    assert table["DatabaseName"] == "mydatabase"
+    assert table["TableStatus"] == "ACTIVE"
+    assert table["MagneticStoreWriteProperties"] == {
+        "EnableMagneticStoreWrites": True,
+        "MagneticStoreRejectedDataLocation": {
+            "S3Configuration": {"BucketName": "hithere"}
+        },
+    }
 
 
 @mock_timestreamwrite
@@ -263,7 +298,8 @@ def test_write_records():
     ts.create_database(DatabaseName="mydatabase")
     ts.create_table(DatabaseName="mydatabase", TableName="mytable")
 
-    # Sample records from https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.write.html
+    # Sample records from:
+    # https://docs.aws.amazon.com/timestream/latest/developerguide/code-samples.write.html
     dimensions = [
         {"Name": "region", "Value": "us-east-1"},
         {"Name": "az", "Value": "az1"},
@@ -293,15 +329,15 @@ def test_write_records():
         TableName="mytable",
         Records=sample_records,
     ).get("RecordsIngested", {})
-    resp["Total"].should.equal(len(sample_records))
-    (resp["MemoryStore"] + resp["MagneticStore"]).should.equal(resp["Total"])
+    assert resp["Total"] == len(sample_records)
+    assert (resp["MemoryStore"] + resp["MagneticStore"]) == resp["Total"]
 
     if not settings.TEST_SERVER_MODE:
         from moto.timestreamwrite.models import timestreamwrite_backends
 
         backend = timestreamwrite_backends[ACCOUNT_ID]["us-east-1"]
         records = backend.databases["mydatabase"].tables["mytable"].records
-        records.should.equal(sample_records)
+        assert records == sample_records
 
         disk_utilization = {
             "Dimensions": dimensions,
@@ -317,4 +353,4 @@ def test_write_records():
             TableName="mytable",
             Records=[disk_utilization],
         )
-        records.should.equal(sample_records)
+        assert records == sample_records
