@@ -1,4 +1,5 @@
 import boto3
+
 from moto import mock_wafv2
 
 
@@ -6,4 +7,4 @@ from moto import mock_wafv2
 def test_list_rule_groups():
     client = boto3.client("wafv2", region_name="us-east-2")
     resp = client.list_rule_groups(Scope="CLOUDFRONT")
-    resp.should.have.key("RuleGroups").equals([])
+    assert resp["RuleGroups"] == []
